@@ -30,7 +30,6 @@
 #include "global.h"
 #include "conlin.h"
 
-extern AIDENTRY *us_aid;
 WINDOWPART *cli_curwindow;
 
 /* prototypes for local routines */
@@ -122,7 +121,7 @@ void cli_maketextfacet(NODEPROTO *np)
 		(void)askaid(us_aid, "edit-describe", (INTBIG)&name);
 		(void)initinfstr();
 		(void)addstringtoinfstr(name);
-		(void)addstringtoinfstr(" Editor equivalence for facet ");
+		(void)addstringtoinfstr(_(" Editor equivalence for facet "));
 		(void)addstringtoinfstr(np->cell->cellname);
 		(void)allocstring(&name, returninfstr(), el_tempcluster);
 		cli_curwindow = cli_makeeditorwindow(name, &chars, &lines);
@@ -346,7 +345,7 @@ void cli_eq_killnode(NODEINST *ni)
 		cli_deletecomponentdec(dec);
 		return;
 	}
-	ttyputmsg("Warning: cannot find node %s in text", compname);
+	ttyputmsg(_("Warning: cannot find node %s in text"), compname);
 }
 
 /* handle the change of node "ni" */
@@ -420,7 +419,7 @@ void cli_eq_modarc(ARCINST *ai)
 	cindex = cli_findtextconn(ai);
 	if (cindex == -1)
 	{
-		ttyputerr("Cannot find text equivalent for arc %s", describearcinst(ai));
+		ttyputerr(_("Cannot find text equivalent for arc %s"), describearcinst(ai));
 		return;
 	}
 
@@ -533,7 +532,7 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 		if (key == el_node_name)
 		{
 			/* construct the original name */
-			(void)sprintf(line, "NODE%ld", (INTBIG)ni);
+			(void)sprintf(line, _("NODE%ld"), (INTBIG)ni);
 
 			/* get the new node name */
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
@@ -581,7 +580,7 @@ void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 			if (var == NOVARIABLE) return;
 
 			/* construct the new node name */
-			(void)sprintf(line, "NODE%ld", (INTBIG)ni);
+			(void)sprintf(line, _("NODE%ld"), (INTBIG)ni);
 			cli_replacename((char *)var->addr, line);
 			return;
 		}
@@ -706,7 +705,7 @@ void cli_changeequivcomp(NODEINST *ni)
 		cli_deletecomponentdec(dec);
 		return;
 	}
-	ttyputmsg("Warning: cannot find node %s in text", compname);
+	ttyputmsg(_("Warning: cannot find node %s in text"), compname);
 }
 
 /*
@@ -785,33 +784,33 @@ void cli_replacename(char *oldname, char *newname)
 					switch (e->bits&STATEBITS)
 					{
 						case INPORT :
-							(void)addstringtoinfstr("input"); break;
+							(void)addstringtoinfstr(_("input")); break;
 						case OUTPORT:
-							(void)addstringtoinfstr("output"); break;
+							(void)addstringtoinfstr(_("output")); break;
 						case BIDIRPORT:
-							(void)addstringtoinfstr("bidirectional"); break;
+							(void)addstringtoinfstr(_("bidirectional")); break;
 						case PWRPORT:
-							(void)addstringtoinfstr("power"); break;
+							(void)addstringtoinfstr(_("power")); break;
 						case GNDPORT:
-							(void)addstringtoinfstr("ground"); break;
+							(void)addstringtoinfstr(_("ground")); break;
 						case CLKPORT:
-							(void)addstringtoinfstr("clock"); break;
+							(void)addstringtoinfstr(_("clock")); break;
 						case C1PORT:
-							(void)addstringtoinfstr("clock1"); break;
+							(void)addstringtoinfstr(_("clock1")); break;
 						case C2PORT:
-							(void)addstringtoinfstr("clock2"); break;
+							(void)addstringtoinfstr(_("clock2")); break;
 						case C3PORT:
-							(void)addstringtoinfstr("clock3"); break;
+							(void)addstringtoinfstr(_("clock3")); break;
 						case C4PORT:
-							(void)addstringtoinfstr("clock4"); break;
+							(void)addstringtoinfstr(_("clock4")); break;
 						case C5PORT:
-							(void)addstringtoinfstr("clock5"); break;
+							(void)addstringtoinfstr(_("clock5")); break;
 						case C6PORT:
-							(void)addstringtoinfstr("clock6"); break;
+							(void)addstringtoinfstr(_("clock6")); break;
 						case REFOUTPORT:
-							(void)addstringtoinfstr("refout"); break;
+							(void)addstringtoinfstr(_("refout")); break;
 						case REFINPORT:
-							(void)addstringtoinfstr("refin"); break;
+							(void)addstringtoinfstr(_("refin")); break;
 					}
 				}
 				if ((e->flag&EXPATTR) != 0)
@@ -997,7 +996,7 @@ char *cli_makearcline(ARCINST *ai)
 	char line[50];
 	REGISTER VARIABLE *var;
 	REGISTER INTSML i, len, doit, added;
-	REGISTER INTBIG conx, cony, xcons, ycons;
+	REGISTER INTBIG conx, cony, xcons, ycons, lambda;
 	REGISTER LINCON *conptr;
 
 	(void)initinfstr();
@@ -1041,6 +1040,7 @@ char *cli_makearcline(ARCINST *ai)
 	if (var != NOVARIABLE)
 	{
 		len = getlength(var) / LINCONSIZE;
+		lambda = lambdaofarc(ai);
 		for(i=0; i<len; i++)
 		{
 			conptr = &((LINCON *)var->addr)[i];
@@ -1049,22 +1049,22 @@ char *cli_makearcline(ARCINST *ai)
 			{
 				case CLLEFT:
 					xcons++;
-					conx = -conptr->value * ai->proto->tech->deflambda / WHOLE;
+					conx = -conptr->value * lambda / WHOLE;
 					(void)sprintf(line, " left %s", latoa(-conx));
 					break;
 				case CLRIGHT:
 					xcons++;
-					conx = conptr->value * ai->proto->tech->deflambda / WHOLE;
+					conx = conptr->value * lambda / WHOLE;
 					(void)sprintf(line, " right %s", latoa(conx));
 					break;
 				case CLDOWN:
 					ycons++;
-					cony = -conptr->value * ai->proto->tech->deflambda / WHOLE;
+					cony = -conptr->value * lambda / WHOLE;
 					(void)sprintf(line, " down %s", latoa(-cony));
 					break;
 				case CLUP:
 					ycons++;
-					cony = conptr->value * ai->proto->tech->deflambda / WHOLE;
+					cony = conptr->value * lambda / WHOLE;
 					(void)sprintf(line, " up %s", latoa(cony));
 					break;
 			}
@@ -1249,7 +1249,7 @@ INTSML cli_addcomponentinfo(NODEINST *ni)
 	if (ni->rotation != 0 || ni->transpose != 0)
 	{
 		if (added != 0) (void)addtoinfstr(','); else (void)addtoinfstr('[');
-		(void)sprintf(line, "rotation=%s", latoa(ni->rotation*el_curtech->deflambda/10));
+		(void)sprintf(line, "rotation=%s", frtoa(ni->rotation*WHOLE/10));
 		(void)addstringtoinfstr(line);
 		added += strlen(line) + 1;
 		if (ni->transpose != 0)
@@ -1310,7 +1310,7 @@ void cli_addcomponentdata(COMPONENT *compo)
 		if ((compo->flag&COMPROT) != 0)
 		{
 			if ((compo->flag&COMPSIZE) != 0) (void)addtoinfstr(',');
-			(void)sprintf(line, "rotation=%s", latoa(compo->rot*el_curtech->deflambda/10));
+			(void)sprintf(line, "rotation=%s", frtoa(compo->rot*WHOLE/10));
 			(void)addstringtoinfstr(line);
 			if (compo->trans != 0) (void)addtoinfstr('t');
 		}
