@@ -93,7 +93,7 @@ char *cli_parsebeginfacet(char *str, INTSML quiet)
 	if (st == NOSTRING) return(NOSTRING);
 	if (namesame(st, "beginfacet") != 0)
 	{
-		if (quiet == 0) ttyputerr("Missing 'beginfacet' keyword in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing 'beginfacet' keyword in '%s'"), str);
 		return(NOSTRING);
 	}
 
@@ -104,12 +104,12 @@ char *cli_parsebeginfacet(char *str, INTSML quiet)
 	/* make sure it ends with a ";" */
 	if (tonextchar(&pt) != ';')
 	{
-		if (quiet == 0) ttyputerr("Missing ';' in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing ';' in '%s'"), str);
 		return(NOSTRING);
 	}
 	if (tonextchar(&pt) != 0)
 	{
-		if (quiet == 0) ttyputerr("Unexpected text after ';' in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Unexpected text after ';' in '%s'"), str);
 		return(NOSTRING);
 	}
 	(void)allocstring(&pt, st, el_tempcluster);
@@ -129,7 +129,7 @@ EXPORT *cli_parseexport(char *str, INTSML quiet)
 	e = (EXPORT *)emalloc(sizeof (EXPORT), el_tempcluster);
 	if (e == 0)
 	{
-		if (quiet == 0) ttyputerr("No memory for parsing");
+		if (quiet == 0) ttyputnomemory();
 		return(NOEXPORT);
 	}
 	e->portname = e->component = e->subport = 0;
@@ -164,7 +164,7 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 	if (st == NOSTRING) return(1);
 	if (namesame(st, "export") != 0)
 	{
-		if (quiet == 0) ttyputerr("Missing 'export' keyword in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing 'export' keyword in '%s'"), str);
 		return(1);
 	}
 
@@ -179,12 +179,12 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 			if (opt == NOSTRING) return(1);
 			if (*opt == 0)
 			{
-				if (quiet == 0) ttyputerr("Missing option name in '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing option name in '%s'"), str);
 				return(1);
 			}
 			if (tonextchar(&pt) != '=')
 			{
-				if (quiet == 0) ttyputerr("Missing '=' after %s option", opt);
+				if (quiet == 0) ttyputerr(_("Missing '=' after %s option"), opt);
 				return(1);
 			}
 
@@ -194,7 +194,7 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 				if (st == NOSTRING) return(1);
 				if (*st == 0)
 				{
-					if (quiet == 0) ttyputerr("Missing type in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Missing type in '%s'"), str);
 					return(1);
 				}
 				if (namesame(st, "input")        == 0) e->bits |= INPORT; else
@@ -212,7 +212,7 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 				if (namesame(st, "refout")       == 0) e->bits |= REFOUTPORT; else
 				if (namesame(st, "refin")        == 0) e->bits |= REFINPORT; else
 				{
-					if (quiet == 0) ttyputerr("Invalid port type in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Invalid port type in '%s'"), str);
 					return(1);
 				}
 				e->flag |= EXPCHAR;
@@ -231,7 +231,7 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 			if (i == ']') break;
 			if (i != ',')
 			{
-				if (quiet == 0) ttyputerr("Missing ',' separating options in '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing ',' separating options in '%s'"), str);
 				return(1);
 			}
 		}
@@ -247,7 +247,7 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 	if (st == NOSTRING) return(1);
 	if (namesame(st, "is") != 0)
 	{
-		if (quiet == 0) ttyputerr("Missing 'is' keyword in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing 'is' keyword in '%s'"), str);
 		return(1);
 	}
 
@@ -269,12 +269,12 @@ INTSML cli_doparseexport(char *str, INTSML quiet, EXPORT *e)
 	/* make sure it ends with a ";" */
 	if (tonextchar(&pt) != ';')
 	{
-		if (quiet == 0) ttyputerr("Missing ';' in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing ';' in '%s'"), str);
 		return(1);
 	}
 	if (tonextchar(&pt) != 0)
 	{
-		if (quiet == 0) ttyputerr("Unexpected text after ';' in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Unexpected text after ';' in '%s'"), str);
 		return(1);
 	}
 	return(0);
@@ -293,7 +293,7 @@ CONNECTION *cli_parseconn(char *str, INTSML quiet)
 	dcl = (CONNECTION *)emalloc(sizeof (CONNECTION), el_tempcluster);
 	if (dcl == 0)
 	{
-		if (quiet == 0) ttyputerr("No memory for parsing");
+		if (quiet == 0) ttyputnomemory();
 		return(NOCONNECTION);
 	}
 	dcl->firstcons = NOCONS;
@@ -331,7 +331,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 	if (st == NOSTRING) return(1);
 	if (namesame(st, "connect") != 0)
 	{
-		if (quiet == 0) ttyputerr("Missing 'connect' keyword in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing 'connect' keyword in '%s'"), str);
 		return(1);
 	}
 
@@ -346,12 +346,12 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 			if (opt == NOSTRING) return(1);
 			if (*opt == 0)
 			{
-				if (quiet == 0) ttyputerr("Missing option name in '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing option name in '%s'"), str);
 				return(1);
 			}
 			if (tonextchar(&pt) != '=')
 			{
-				if (quiet == 0) ttyputerr("Missing '=' after %s option", opt);
+				if (quiet == 0) ttyputerr(_("Missing '=' after %s option"), opt);
 				return(1);
 			}
 
@@ -361,7 +361,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 				if (st == NOSTRING) return(1);
 				if (*st == 0)
 				{
-					if (quiet == 0) ttyputerr("Missing layer in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Missing layer in '%s'"), str);
 					return(1);
 				}
 				(void)allocstring(&dcl->layer, st, el_tempcluster);
@@ -372,7 +372,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 				if (st == NOSTRING) return(1);
 				if (*st == 0)
 				{
-					if (quiet == 0) ttyputerr("Missing width in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Missing width in '%s'"), str);
 					return(1);
 				}
 				dcl->width = atola(st);
@@ -392,7 +392,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 			if (i == ']') break;
 			if (i != ',')
 			{
-				if (quiet == 0) ttyputerr("Missing ',' separating options in '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing ',' separating options in '%s'"), str);
 				return(1);
 			}
 		}
@@ -403,7 +403,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 	if (st == NOSTRING) return(1);
 	if (*st == 0)
 	{
-		if (quiet == 0) ttyputerr("Incorrect prototype syntax in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Incorrect prototype syntax in '%s'"), str);
 		return(1);
 	}
 	(void)allocstring(&dcl->end1, st, el_tempcluster);
@@ -416,7 +416,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 		if (st == NOSTRING) return(1);
 		if (*st == 0)
 		{
-			if (quiet == 0) ttyputerr("Incorrect port syntax in '%s'", str);
+			if (quiet == 0) ttyputerr(_("Incorrect port syntax in '%s'"), str);
 			return(1);
 		}
 		(void)allocstring(&dcl->port1, st, el_tempcluster);
@@ -438,7 +438,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 		{
 			if (tonextchar(&pt) != '[')
 			{
-				if (quiet == 0) ttyputerr("Incorrect constraint syntax in '%s'", str);
+				if (quiet == 0) ttyputerr(_("Incorrect constraint syntax in '%s'"), str);
 				return(1);
 			}
 			st = getkeyword(&pt, " \t,");
@@ -447,14 +447,14 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 			dcl->flag |= OFFSETVALID;
 			if (tonextchar(&pt) != ',')
 			{
-				if (quiet == 0) ttyputerr("Missing comma in arc extent '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing comma in arc extent '%s'"), str);
 				return(1);
 			}
 			st = getkeyword(&pt, " \t]");
 			dcl->yoff = atola(st);
 			if (tonextchar(&pt) != ']')
 			{
-				if (quiet == 0) ttyputerr("Missing ']' in arc extent '%s'", str);
+				if (quiet == 0) ttyputerr(_("Missing ']' in arc extent '%s'"), str);
 				return(1);
 			}
 			continue;
@@ -464,7 +464,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 		if (namesame(st, "left") != 0 && namesame(st, "right") != 0 &&
 			namesame(st, "up") != 0 && namesame(st, "down") != 0)
 		{
-			if (quiet == 0) ttyputerr("Invalid relationship '%s' in '%s'", st, str);
+			if (quiet == 0) ttyputerr(_("Invalid relationship '%s' in '%s'"), st, str);
 			return(1);
 		}
 
@@ -472,7 +472,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 		cons = (CONS *)emalloc(sizeof (CONS), el_tempcluster);
 		if (cons == 0)
 		{
-			if (quiet == 0) ttyputerr("No memory for parsing");
+			if (quiet == 0) ttyputnomemory();
 			return(1);
 		}
 		cons->nextcons = NOCONS;
@@ -494,7 +494,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 			if (st == NOSTRING) return(1);
 			if (namesame(st, "or") != 0)
 			{
-				if (quiet == 0) ttyputerr("Unknown qualifier '%s' in '%s'", st, str);
+				if (quiet == 0) ttyputerr(_("Unknown qualifier '%s' in '%s'"), st, str);
 				return(1);
 			}
 			st = getkeyword(&pt, " \t;[");
@@ -504,7 +504,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 			if (namesame(st, "less") == 0) cons->flag = LEQ;
 			if (cons->flag == 999)
 			{
-				if (quiet == 0) ttyputerr("Unknown qualifier '%s' in '%s'", st, str);
+				if (quiet == 0) ttyputerr(_("Unknown qualifier '%s' in '%s'"), st, str);
 				return(1);
 			}
 		}
@@ -515,7 +515,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 	if (st == NOSTRING) return(1);
 	if (*st == 0)
 	{
-		if (quiet == 0) ttyputerr("Incorrect prototype syntax in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Incorrect prototype syntax in '%s'"), str);
 		return(1);
 	}
 	(void)allocstring(&dcl->end2, st, el_tempcluster);
@@ -528,7 +528,7 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 		if (st == NOSTRING) return(1);
 		if (*st == 0)
 		{
-			if (quiet == 0) ttyputerr("Incorrect port syntax in '%s'", str);
+			if (quiet == 0) ttyputerr(_("Incorrect port syntax in '%s'"), str);
 			return(1);
 		}
 		(void)allocstring(&dcl->port2, st, el_tempcluster);
@@ -536,12 +536,12 @@ INTSML cli_doparseconn(char *str, INTSML quiet, CONNECTION *dcl)
 	}
 	if (tonextchar(&pt) != ';')
 	{
-		if (quiet == 0) ttyputerr("Missing semicolon in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing semicolon in '%s'"), str);
 		return(1);
 	}
 	i = tonextchar(&pt);
 	if (i == 0) return(0);
-	if (quiet == 0) ttyputerr("Line '%s' should end with a semicolon", str);
+	if (quiet == 0) ttyputerr(_("Line '%s' should end with a semicolon"), str);
 	return(1);
 }
 
@@ -560,7 +560,7 @@ COMPONENTDEC *cli_parsecomp(char *str, INTSML quiet)
 	dcl = (COMPONENTDEC *)emalloc(sizeof (COMPONENTDEC), el_tempcluster);
 	if (dcl == 0)
 	{
-		if (quiet == 0) ttyputerr("No memory for parsing");
+		if (quiet == 0) ttyputnomemory();
 		return(NOCOMPONENTDEC);
 	}
 	dcl->firstcomponent = NOCOMPONENT;
@@ -573,7 +573,7 @@ COMPONENTDEC *cli_parsecomp(char *str, INTSML quiet)
 	st = getkeyword(&pt, " \t");
 	if (st == NOSTRING || namesame(st, "declare") != 0)
 	{
-		if (quiet == 0) ttyputerr("Missing 'declare' keyword in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing 'declare' keyword in '%s'"), str);
 		efree((char *)dcl);
 		return(NOCOMPONENTDEC);
 	}
@@ -612,7 +612,7 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 		if (st == NOSTRING) return(1);
 		if (*st == 0)
 		{
-			if (quiet == 0) ttyputerr("Missing component name in '%s'", str);
+			if (quiet == 0) ttyputerr(_("Missing component name in '%s'"), str);
 			return(1);
 		}
 
@@ -620,7 +620,7 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 		compo = (COMPONENT *)emalloc(sizeof (COMPONENT), el_tempcluster);
 		if (compo == 0)
 		{
-			if (quiet == 0) ttyputerr("No memory for parse strings");
+			if (quiet == 0) ttyputnomemory();
 			return(1);
 		}
 		compo->flag = 0;
@@ -647,12 +647,12 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 				if (opt == NOSTRING) return(1);
 				if (*opt == 0)
 				{
-					if (quiet == 0) ttyputerr("Missing option name in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Missing option name in '%s'"), str);
 					return(1);
 				}
 				if (tonextchar(pt) != '=')
 				{
-					if (quiet == 0) ttyputerr("Missing '=' after %s option", opt);
+					if (quiet == 0) ttyputerr(_("Missing '=' after %s option"), opt);
 					return(1);
 				}
 
@@ -690,7 +690,7 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 				if (i == ']') break;
 				if (i != ',')
 				{
-					if (quiet == 0) ttyputerr("Missing ',' separating options in '%s'", str);
+					if (quiet == 0) ttyputerr(_("Missing ',' separating options in '%s'"), str);
 					return(1);
 				}
 			}
@@ -706,7 +706,7 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 	if (st == NOSTRING) return(1);
 	if (*st == 0)
 	{
-		if (quiet == 0) ttyputerr("Missing prototype name at start of '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing prototype name at start of '%s'"), str);
 		return(1);
 	}
 	(void)allocstring(&dcl->protoname, st, el_tempcluster);
@@ -714,12 +714,12 @@ INTSML cli_doparsecomp(char **pt, char *str, INTSML quiet, COMPONENTDEC *dcl)
 	/* make sure line terminates properly */
 	if (tonextchar(pt) != ';')
 	{
-		if (quiet == 0) ttyputerr("Missing semicolon in '%s'", str);
+		if (quiet == 0) ttyputerr(_("Missing semicolon in '%s'"), str);
 		return(1);
 	}
 	i = tonextchar(pt);
 	if (i == 0) return(0);
-	if (quiet == 0) ttyputerr("Line '%s' should end with a semicolon", str);
+	if (quiet == 0) ttyputerr(_("Line '%s' should end with a semicolon"), str);
 	return(1);
 }
 
@@ -734,7 +734,7 @@ INTSML cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, INTSML qui
 
 	if (tonextchar(pt) != '(')
 	{
-		if (quiet == 0) ttyputerr("Missing '(' after %s option", name);
+		if (quiet == 0) ttyputerr(_("Missing '(' after %s option"), name);
 		return(1);
 	}
 	st = getkeyword(pt, " \t,)]");
@@ -742,7 +742,7 @@ INTSML cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, INTSML qui
 	*x = atola(st);
 	if (tonextchar(pt) != ',')
 	{
-		if (quiet == 0) ttyputerr("Missing ',' in %s option", name);
+		if (quiet == 0) ttyputerr(_("Missing ',' in %s option"), name);
 		return(1);
 	}
 	st = getkeyword(pt, " \t)]");
@@ -750,7 +750,7 @@ INTSML cli_parsetwovalue(INTBIG *x, INTBIG *y, char *name, char **pt, INTSML qui
 	*y = atola(st);
 	if (tonextchar(pt) != ')')
 	{
-		if (quiet == 0) ttyputerr("Missing ')' in size option");
+		if (quiet == 0) ttyputerr(_("Missing ')' in size option"));
 		return(1);
 	}
 	return(0);
@@ -789,7 +789,7 @@ ATTR *cli_getattr(char *opt, char **pt, char *str, INTSML quiet)
 		if (st == NOSTRING) return(NOATTR);
 		if (*st == 0)
 		{
-			if (quiet == 0) ttyputerr("Missing value in '%s'", str);
+			if (quiet == 0) ttyputerr(_("Missing value in '%s'"), str);
 			return(NOATTR);
 		}
 		if (isanumber(st) != 0)
@@ -866,7 +866,7 @@ ARCINST *cli_findarcname(char *line)
 		if (aend < 0 || bend < 0) continue;
 		if (aend == bend)
 		{
-			ttyputmsg("To and From found on end %d of arc %s", aend, describearcinst(ai));
+			ttyputmsg(_("To and From found on end %d of arc %s"), aend, describearcinst(ai));
 			continue;
 		}
 		if ((dcl->flag&PORT1VALID) != 0 &&
@@ -904,7 +904,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 	{
 		if (defai != NOARCINST) *nA = defai->end[0].nodeinst; else
 		{
-			ttyputerr("No end 0 specified");
+			ttyputerr(_("No end 0 specified"));
 			return(1);
 		}
 	} else
@@ -914,7 +914,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 		{
 			if (defnA == NONODEINST)
 			{
-				ttyputerr("Cannot find node %s", dcl->end1);
+				ttyputerr(_("Cannot find node %s"), dcl->end1);
 				return(1);
 			}
 			*nA = defnA;
@@ -926,7 +926,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 	{
 		if (defai != NOARCINST) *nB = defai->end[1].nodeinst; else
 		{
-			ttyputerr("No end 1 specified");
+			ttyputerr(_("No end 1 specified"));
 			return(1);
 		}
 	} else
@@ -936,7 +936,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 		{
 			if (defnB == NONODEINST)
 			{
-				ttyputerr("Cannot find node %s", dcl->end2);
+				ttyputerr(_("Cannot find node %s"), dcl->end2);
 				return(1);
 			}
 			*nB = defnB;
@@ -953,7 +953,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 		*pA = getportproto((*nA)->proto, dcl->port1);
 		if (*pA == NOPORTPROTO)
 		{
-			ttyputerr("Cannot find port %s", dcl->port1);
+			ttyputerr(_("Cannot find port %s"), dcl->port1);
 			return(1);
 		}
 	}
@@ -968,7 +968,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 		*pB = getportproto((*nB)->proto, dcl->port2);
 		if (*pB == NOPORTPROTO)
 		{
-			ttyputerr("Cannot find port %s", dcl->port2);
+			ttyputerr(_("Cannot find port %s"), dcl->port2);
 			return(1);
 		}
 	}
@@ -987,7 +987,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 			}
 			if ((*pA)->connects[i] == NOARCPROTO)
 			{
-				ttyputerr("Cannot find connecting layer");
+				ttyputerr(_("Cannot find connecting layer"));
 				return(1);
 			}
 			*ap = (*pA)->connects[i];
@@ -997,7 +997,7 @@ INTSML cli_pickwire(CONNECTION *dcl, NODEINST **nA, PORTPROTO **pA, NODEINST **n
 		*ap = getarcproto(dcl->layer);
 		if (*ap == NOARCPROTO)
 		{
-			ttyputerr("Cannot find connecting layer %s", dcl->layer);
+			ttyputerr(_("Cannot find connecting layer %s"), dcl->layer);
 			return(1);
 		}
 	}
