@@ -57,7 +57,7 @@ void db_nullconsetvariable(void);
 
 CONSTRAINT el_constraints[] =
 {
-	{"null", "Null constraints", NOCOMCOMP, NOCLUSTER, NOVARIABLE, 0,
+	{"null", N_("Null constraints"), NOCOMCOMP, NOCLUSTER, NOVARIABLE, 0,
 	db_nullconinit, db_nullconterm,						/* control */
 	db_nullconsetmode, db_nullconrequest,				/* action */
 	db_nullconsolve,									/* solution */
@@ -71,7 +71,7 @@ CONSTRAINT el_constraints[] =
 	db_nullconmodifyvariable, db_nullconinsertvariable,
 	db_nullcondeletevariable, db_nullconsetvariable},
 
-	{"layout", "Hierarchical layout constraints", &cla_layconp, NOCLUSTER,
+	{"layout", N_("Hierarchical layout constraints"), &cla_layconp, NOCLUSTER,
 		NOVARIABLE, 0,
 	cla_layconinit, cla_layconterm,						/* control */
 	cla_layconsetmode, cla_layconrequest,				/* action */
@@ -86,7 +86,7 @@ CONSTRAINT el_constraints[] =
 	cla_layconmodifyvariable, cla_layconinsertvariable,
 	cla_laycondeletevariable, cla_layconsetvariable},
 
-	{"linear", "Linear constraints", &cli_linconp, NOCLUSTER, NOVARIABLE, 0,
+	{"linear", N_("Linear constraints"), &cli_linconp, NOCLUSTER, NOVARIABLE, 0,
 	cli_linconinit, cli_linconterm,						/* control */
 	cli_linconsetmode, cli_linconrequest,				/* action */
 	cli_linconsolve,									/* solution */
