@@ -48,7 +48,7 @@
  *    INTBIG owid, INTBIG olen) {}
  * aa_modifyportproto(PORTPROTO *pp) {}
  * aa_modifynodeproto(NODEPROTO *np) {}
- * aa_modifydescript(VARIABLE *var, INTBIG old) {}
+ * aa_modifydescript(INTBIG addr, INTBIG type, VARIABLE *var, INTBIG old) {}
  * aa_newobject(INTBIG addr, INTBIG type) {}
  * aa_killobject(INTBIG addr, INTBIG type) {}
  * aa_newvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype) {}
@@ -350,9 +350,9 @@ AIDENTRY el_aids[] =
 	dr_modifynodeinst,     dr_modifyarcinst,     0,						/* modnode/modarc/modport */
 	0,                     0,											/* modnodeproto/moddescript */
 	dr_newobject,          dr_killobject,								/* newobject/killobject */
-	0,                     0,											/* newvariable/killvariable */
+	dr_newvariable,        0,											/* newvariable/killvariable */
 	0,                     0,                    0,						/* modvar/insvar/delvar */
-	0,                     dr_eraselibrary,      0,						/* readlib/eraselib/writelib */
+	dr_readlibrary,        dr_eraselibrary,      0,						/* readlib/eraselib/writelib */
 	NOVARIABLE,0},
 #endif
 
