@@ -40,7 +40,7 @@ CHANGEFACET *db_allocchangefacet(void);
 CHANGEBATCH *db_allocchangebatch(void);
 void db_freechangebatch(CHANGEBATCH*);
 void db_killbatch(CHANGEBATCH*);
-void db_namevariable(INTBIG, INTBIG);
+char *db_namevariable(INTBIG, INTBIG);
 CHANGEBATCH *db_preparenewbatch(void);
 void db_erasebatch(CHANGEBATCH*);
 void db_freechangefacet(CHANGEFACET*);
@@ -52,17 +52,17 @@ char *db_describechange(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG,
 /* Undo dialog */
 DIALOGITEM db_undodialogitems[] =
 {
- /*  1 */ {0, {468,608,492,680}, BUTTON, "OK"},
- /*  2 */ {0, {468,16,492,88}, BUTTON, "Undo"},
+ /*  1 */ {0, {468,608,492,680}, BUTTON, N_("OK")},
+ /*  2 */ {0, {468,16,492,88}, BUTTON, N_("Undo")},
  /*  3 */ {0, {32,8,455,690}, SCROLL, ""},
- /*  4 */ {0, {8,8,24,241}, MESSAGE, "These are the recent changes:"},
- /*  5 */ {0, {8,344,24,456}, CHECK, "Show details"},
- /*  6 */ {0, {468,108,492,180}, BUTTON, "Redo"}
+ /*  4 */ {0, {8,8,24,241}, MESSAGE, N_("These are the recent changes:")},
+ /*  5 */ {0, {8,344,24,456}, CHECK, N_("Show details")},
+ /*  6 */ {0, {468,108,492,180}, BUTTON, N_("Redo")}
 };
-DIALOG db_undodialog = {{50,75,555,774}, "Change History", 6, db_undodialogitems};
+DIALOG db_undodialog = {{50,75,555,774}, N_("Change History"), 0, 6, db_undodialogitems};
 
 INTBIG       db_batchtally;					/* number of batches in list */
-INTSML       db_maximumbatches;				/* limit of number of batches */
+INTBIG       db_maximumbatches;				/* limit of number of batches */
 INTSML       db_broadcasting = 0;			/* nonzero if broadcasting */
 INTBIG       db_batchnumber;				/* batch number counter */
 CHANGEBATCH *db_currentbatch;				/* current batch of changes */
@@ -118,7 +118,7 @@ void db_initializechanges(void)
 	/* initialize changes */
 	db_batchtally = 0;
 	db_batchnumber = 1;
-	db_maximumbatches = (INTSML)maxi(el_maxaid + el_maxaid/2 + 1, 20);
+	db_maximumbatches = maxi(el_maxaid + el_maxaid/2 + 1, 20);
 	db_currentbatch = db_headbatch = db_tailbatch = db_donebatch = NOCHANGEBATCH;
 }
 
@@ -138,16 +138,17 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	REGISTER CHANGE *c;
 	REGISTER LIBRARY *lib;
 	REGISTER VARIABLE *var;
-	static char *broadcasttype[] = {"nodeinstnew", "nodeinstkill", "nodeinstmod",
-		"arcinstnew", "arcinstkill", "arcinstmod", "portprotonew",
-		"portprotokill", "portprotomod", "nodeprotonew", "nodeprotokill",
-		"nodeprotomod", "objectstart", "objectend", "objectnew", "objectkill",
-		"variablenew", "variablekill", "variablemod", "variableinsert",
-		"variabledelete", "descriptmod"};
+	static char *broadcasttype[] = {N_("nodeinstnew"), N_("nodeinstkill"), N_("nodeinstmod"),
+		N_("arcinstnew"), N_("arcinstkill"), N_("arcinstmod"), N_("portprotonew"),
+		N_("portprotokill"), N_("portprotomod"), N_("nodeprotonew"), N_("nodeprotokill"),
+		N_("nodeprotomod"), N_("objectstart"), N_("objectend"), N_("objectnew"), N_("objectkill"),
+		N_("variablenew"), N_("variablekill"), N_("variablemod"), N_("variableinsert"),
+		N_("variabledelete"), N_("descriptmod")};
 
 	if (db_broadcasting != 0)
 	{
-		ttyputerr("Recieved this change during broadcast of type %s:", broadcasttype[db_broadcasting-1]);
+		ttyputerr(_("Recieved this change during broadcast of type %s:"),
+			_(broadcasttype[db_broadcasting-1]));
 		ttyputmsg("%s", db_describechange(change, obj, a1, a2, a3, a4, a5, a6));
 	}
 
@@ -241,7 +242,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 	c = db_allocchange();
 	if (c == NOCHANGE)
 	{
-		ttyputerr("No memory for changes");
+		ttyputnomemory();
 		return(NOCHANGE);
 	}
 
@@ -252,7 +253,7 @@ CHANGE *db_change(INTBIG obj, INTSML change, INTBIG a1, INTBIG a2, INTBIG a3, IN
 		db_currentbatch = db_preparenewbatch();
 		if (db_currentbatch == NOCHANGEBATCH)
 		{
-			ttyputerr("No memory for change batches");
+			ttyputnomemory();
 			return(NOCHANGE);
 		}
 		firstchange = 1;
@@ -630,12 +631,12 @@ void noredoallowed(void)
  * the list is returned.  If "newsize" is not positive, the size is not
  * changed, just returned.
  */
-INTSML historylistsize(INTSML newsize)
+INTBIG historylistsize(INTBIG newsize)
 {
 	REGISTER CHANGEBATCH *batch;
-	REGISTER INTSML oldsize;
+	REGISTER INTBIG oldsize;
 
-	if (newsize <= 0) return(db_maximumbatches);
+	if (newsize <= 0) return((INTSML)db_maximumbatches);
 
 	oldsize = db_maximumbatches;
 	db_maximumbatches = newsize;
@@ -1003,10 +1004,8 @@ INTSML db_reversechange(CHANGE *c)
 				var = getval(c->entryaddr, c->p1, c->p3 & (VTYPE|VISARRAY), attname);
 				if (var == NOVARIABLE)
 				{
-					(void)initinfstr();
-					db_namevariable(c->entryaddr, c->p1);
-					ttyputmsg("Warning: Could not find attribute %s on object %s", attname,
-						returninfstr());
+					ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
+						attname, db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
 				c->p3 = var->addr;
@@ -1027,10 +1026,8 @@ INTSML db_reversechange(CHANGE *c)
 			var = getvalkey(c->entryaddr, c->p1, c->p3&(VTYPE|VISARRAY), c->p2);
 			if (var == NOVARIABLE)
 			{
-				(void)initinfstr();
-				db_namevariable(c->entryaddr, c->p1);
-				ttyputmsg("Warning: Could not find attribute %s on object %s", makename(c->p2),
-					returninfstr());
+				ttyputmsg(_("Warning: Could not find attribute %s on object %s"),
+					makename(c->p2), db_namevariable(c->entryaddr, c->p1));
 				break;
 			}
 			c->p3 = var->addr;
@@ -1051,10 +1048,8 @@ INTSML db_reversechange(CHANGE *c)
 				var = setval(c->entryaddr, c->p1, attname, c->p3, c->p4);
 				if (var == NOVARIABLE)
 				{
-					(void)initinfstr();
-					db_namevariable(c->entryaddr, c->p1);
-					ttyputmsg("Warning: Could not set attribute %s on object %s", attname,
-						returninfstr());
+					ttyputmsg(_("Warning: Could not set attribute %s on object %s"),
+						attname, db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
 			} else
@@ -1062,10 +1057,8 @@ INTSML db_reversechange(CHANGE *c)
 				var = setvalkey(c->entryaddr, c->p1, c->p2, c->p3, c->p4);
 				if (var == NOVARIABLE)
 				{
-					(void)initinfstr();
-					db_namevariable(c->entryaddr, c->p1);
-					ttyputmsg("Warning: Could not set attribute %s on object %s", makename(c->p2),
-						returninfstr());
+					ttyputmsg(_("Warning: Could not set attribute %s on object %s"),
+						makename(c->p2), db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
 				var->textdescript = c->p5;
@@ -1083,10 +1076,8 @@ INTSML db_reversechange(CHANGE *c)
 				attname = changedvariablename(c->p1, c->p2, c->p4);
 				if (getind(c->entryaddr, c->p1, attname, c->p4, &oldval) != 0)
 				{
-					(void)initinfstr();
-					db_namevariable(c->entryaddr, c->p1);
-					ttyputmsg("Warning: Could not find index %ld of attribute %s on object %s",
-						c->p4, attname, returninfstr());
+					ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
+						c->p4, attname, db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
 				(void)setind(c->entryaddr, c->p1, attname, c->p4, c->p5);
@@ -1095,10 +1086,8 @@ INTSML db_reversechange(CHANGE *c)
 			{
 				if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval) != 0)
 				{
-					(void)initinfstr();
-					db_namevariable(c->entryaddr, c->p1);
-					ttyputmsg("Warning: Could not find index %ld of attribute %s on object %s",
-						c->p4, makename(c->p2), returninfstr());
+					ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
+						c->p4, makename(c->p2), db_namevariable(c->entryaddr, c->p1));
 					break;
 				}
 				(void)setindkey(c->entryaddr, c->p1, c->p2, c->p4, c->p5);
@@ -1110,10 +1099,8 @@ INTSML db_reversechange(CHANGE *c)
 			/* args: addr, type, key, vartype, aindex */
 			if (getindkey(c->entryaddr, c->p1, c->p2, c->p4, &oldval) != 0)
 			{
-				(void)initinfstr();
-				db_namevariable(c->entryaddr, c->p1);
-				ttyputmsg("Warning: Could not find index %ld of attribute %s on object %s",
-					c->p4, makename(c->p2), returninfstr());
+				ttyputmsg(_("Warning: Could not find index %ld of attribute %s on object %s"),
+					c->p4, makename(c->p2), db_namevariable(c->entryaddr, c->p1));
 				break;
 			}
 			nextvarchangequiet();
@@ -1226,16 +1213,11 @@ void showhistorylist(INTSML which)
 			if (batchreport->batchnumber > hibatch) hibatch = batchreport->batchnumber;
 			if (batchreport->batchnumber != which) continue;
 			(void)initinfstr();
-			(void)sprintf(line, "Batch %ld from %s aid", batchreport->batchnumber,
+			(void)formatinfstr(_("Batch %ld from %s aid"), batchreport->batchnumber,
 				batchreport->aid->aidname);
-			(void)addstringtoinfstr(line);
 			if (batchreport->activity != 0)
-			{
-				(void)addstringtoinfstr(", caused by '");
-				(void)addstringtoinfstr(batchreport->activity);
-				(void)addstringtoinfstr("'");
-			}
-			(void)addstringtoinfstr(" is:");
+				(void)formatinfstr(_(", caused by '%s'"), batchreport->activity);
+			(void)addstringtoinfstr(_(" is:"));
 			ttyputmsg("%s", returninfstr());
 
 			for(c = batchreport->changehead; c != NOCHANGE; c = c->nextchange)
@@ -1243,12 +1225,12 @@ void showhistorylist(INTSML which)
 					c->p3, c->p4, c->p5, c->p6));
 			return;
 		}
-		ttyputmsg("Batch %d is not in the list (range is %d to %d)", which, lobatch, hibatch);
+		ttyputmsg(_("Batch %d is not in the list (range is %d to %d)"), which, lobatch, hibatch);
 		return;
 	}
 
 	/* display the change batches */
-	ttyputmsg("%ld batches (limit is %d):", db_batchtally-1, db_maximumbatches);
+	ttyputmsg(_("%ld batches (limit is %ld):"), db_batchtally-1, db_maximumbatches);
 	for(batchreport = db_tailbatch; batchreport != NOCHANGEBATCH;
 		batchreport = batchreport->nextchangebatch)
 	{
@@ -1298,43 +1280,37 @@ void showhistorylist(INTSML which)
 		(void)sprintf(line, "%ld {", batchreport->batchnumber);
 		(void)addstringtoinfstr(line);
 		if (batchreport->activity != 0) (void)addstringtoinfstr(batchreport->activity);
-		(void)addstringtoinfstr("} affects");
+		(void)addstringtoinfstr(_("} affects"));
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %d node", node);
+			(void)sprintf(line, " %d %s", node, makeplural(_("node"), node));
 			(void)addstringtoinfstr(line);
-			if (node > 1) (void)addtoinfstr('s');
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %d arc", arcinst);
+			(void)sprintf(line, " %d %s", arcinst, makeplural(_("arc"), arcinst));
 			(void)addstringtoinfstr(line);
-			if (arcinst > 1) (void)addtoinfstr('s');
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %d port", portproto);
+			(void)sprintf(line, " %d %s", portproto, makeplural(_("port"), portproto));
 			(void)addstringtoinfstr(line);
-			if (portproto > 1) (void)addtoinfstr('s');
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %d facet", nproto);
+			(void)sprintf(line, " %d %s", nproto, makeplural(_("facet"), nproto));
 			(void)addstringtoinfstr(line);
-			if (nproto > 1) (void)addtoinfstr('s');
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %d object", object);
+			(void)sprintf(line, " %d %s", object, makeplural(_("object"), object));
 			(void)addstringtoinfstr(line);
-			if (object > 1) (void)addtoinfstr('s');
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %d variable", variable);
+			(void)sprintf(line, " %d %s", variable, makeplural(_("variable"), variable));
 			(void)addstringtoinfstr(line);
-			if (variable > 1) (void)addtoinfstr('s');
 		}
 		ttyputmsg("%s", returninfstr());
 	}
@@ -1349,237 +1325,148 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 	REGISTER NODEPROTO *np;
 	REGISTER VARIABLE *var;
 	VARIABLE myvar;
-	char line[50];
 
 	switch (changetype)
 	{
 		case NODEINSTNEW:
 			ni = (NODEINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Node '");
-			(void)addstringtoinfstr(describenodeinst(ni));
-			(void)addstringtoinfstr("' created in facet ");
-			(void)addstringtoinfstr(describenodeproto(ni->parent));
+			(void)formatinfstr(_(" Node '%s' created in facet %s"), describenodeinst(ni),
+				describenodeproto(ni->parent));
 			return(returninfstr());
 		case NODEINSTKILL:
 			ni = (NODEINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Node '");
-			(void)addstringtoinfstr(describenodeinst(ni));
-			(void)addstringtoinfstr("' killed in facet ");
-			(void)addstringtoinfstr(describenodeproto(ni->parent));
+			(void)formatinfstr(_(" Node '%s' killed in facet %s"), describenodeinst(ni),
+				describenodeproto(ni->parent));
 			return(returninfstr());
 		case NODEINSTMOD:
 			ni = (NODEINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Node '");
-			(void)addstringtoinfstr(describenodeinst(ni));
-			(void)addstringtoinfstr("' changed in facet ");
-			(void)addstringtoinfstr(describenodeproto(ni->parent));
-			(void)addstringtoinfstr(" [was ");
-			(void)addstringtoinfstr(latoa(p3-p1));
-			(void)addstringtoinfstr("x");
-			(void)addstringtoinfstr(latoa(p4-p2));
-			(void)addstringtoinfstr(", center (");
-			(void)addstringtoinfstr(latoa((p1+p3)/2));
-			(void)addstringtoinfstr(",");
-			(void)addstringtoinfstr(latoa((p2+p4)/2));
-			(void)addstringtoinfstr("), rotated ");
-			sprintf(line, "%ld", p5);
-			(void)addstringtoinfstr(line);
-			if (p6 != 0) (void)addstringtoinfstr(", transposed");
+			(void)formatinfstr(_(" Node '%s' changed in facet %s [was %sx%s, center (%s,%s), rotated %ld"),
+				describenodeinst(ni), describenodeproto(ni->parent), latoa(p3-p1), latoa(p4-p2),
+				latoa((p1+p3)/2), latoa((p2+p4)/2), p5);
+			if (p6 != 0) (void)addstringtoinfstr(_(", transposed"));
 			(void)addstringtoinfstr("]");
 			return(returninfstr());
 		case ARCINSTNEW:
 			ai = (ARCINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Arc '");
-			(void)addstringtoinfstr(describearcinst(ai));
-			(void)addstringtoinfstr("' created in facet ");
-			(void)addstringtoinfstr(describenodeproto(ai->parent));
+			(void)formatinfstr(_(" Arc '%s' created in facet %s"), describearcinst(ai),
+				describenodeproto(ai->parent));
 			return(returninfstr());
 		case ARCINSTKILL:
 			ai = (ARCINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Arc '");
-			(void)addstringtoinfstr(describearcinst(ai));
-			(void)addstringtoinfstr("' killed in facet ");
-			(void)addstringtoinfstr(describenodeproto(ai->parent));
+			(void)formatinfstr(_(" Arc '%s' killed in facet %s"), describearcinst(ai),
+				describenodeproto(ai->parent));
 			return(returninfstr());
 		case ARCINSTMOD:
 			ai = (ARCINST *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Arc '");
-			(void)addstringtoinfstr(describearcinst(ai));
-			(void)addstringtoinfstr("' modified in facet ");
-			(void)addstringtoinfstr(describenodeproto(ai->parent));
-			(void)addstringtoinfstr(" [was ");
-			(void)addstringtoinfstr(latoa(p5));
-			(void)addstringtoinfstr(" wide ");
-			(void)addstringtoinfstr(latoa(p6));
-			(void)addstringtoinfstr(" long from (");
-			(void)addstringtoinfstr(latoa(p1));
-			(void)addstringtoinfstr(",");
-			(void)addstringtoinfstr(latoa(p2));
-			(void)addstringtoinfstr(") to (");
-			(void)addstringtoinfstr(latoa(p3));
-			(void)addstringtoinfstr(",");
-			(void)addstringtoinfstr(latoa(p4));
-			(void)addstringtoinfstr(")]");
+			(void)formatinfstr(_(" Arc '%s' modified in facet %s [was %s wide %s long from (%s,%s) to (%s,%s)]"),
+				describearcinst(ai), describenodeproto(ai->parent), latoa(p5), latoa(p6), latoa(p1), latoa(p2),
+				latoa(p3), latoa(p4));
 			return(returninfstr());
 		case PORTPROTONEW:
 			pp = (PORTPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Port '");
-			(void)addstringtoinfstr(pp->protoname);
-			(void)addstringtoinfstr("' created in facet ");
-			(void)addstringtoinfstr(describenodeproto(pp->parent));
+			(void)formatinfstr(_(" Port '%s' created in facet %s"), pp->protoname,
+				describenodeproto(pp->parent));
 			return(returninfstr());
 		case PORTPROTOKILL:
 			pp = (PORTPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Port '");
-			(void)addstringtoinfstr(pp->protoname);
-			(void)addstringtoinfstr("' killed in facet ");
-			(void)addstringtoinfstr(describenodeproto(pp->parent));
+			(void)formatinfstr(_(" Port '%s' killed in facet %s"), pp->protoname,
+				describenodeproto(pp->parent));
 			return(returninfstr());
 		case PORTPROTOMOD:
 			pp = (PORTPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Port '");
-			(void)addstringtoinfstr(pp->protoname);
-			(void)addstringtoinfstr("' moved in facet ");
-			(void)addstringtoinfstr(describenodeproto(pp->parent));
-			(void)addstringtoinfstr(" [was on node ");
-			(void)addstringtoinfstr(describenodeinst((NODEINST *)p1));
-			(void)addstringtoinfstr(", subport ");
-			(void)addstringtoinfstr(((PORTPROTO *)p2)->protoname);
-			(void)addstringtoinfstr("]");
+			(void)formatinfstr(_(" Port '%s' moved in facet %s [was on node %s, subport %s]"),
+				pp->protoname, describenodeproto(pp->parent), describenodeinst((NODEINST *)p1),
+				((PORTPROTO *)p2)->protoname);
 			return(returninfstr());
 		case NODEPROTONEW:
 			np = (NODEPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Facet '");
-			(void)addstringtoinfstr(describenodeproto(np));
-			(void)addstringtoinfstr("' created");
+			(void)formatinfstr(_(" Facet '%s' created"), describenodeproto(np));
 			return(returninfstr());
 		case NODEPROTOKILL:
 			np = (NODEPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Facet '");
-			(void)addstringtoinfstr(describenodeproto(np));
-			(void)addstringtoinfstr("' killed");
+			(void)formatinfstr(_(" Facet %s' killed"), describenodeproto(np));
 			return(returninfstr());
 		case NODEPROTOMOD:
 			np = (NODEPROTO *)entryaddr;
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Facet '");
-			(void)addstringtoinfstr(describenodeproto(np));
-			(void)addstringtoinfstr("' modified [was from ");
-			(void)addstringtoinfstr(latoa(p1));
-			(void)addstringtoinfstr("<=X<=");
-			(void)addstringtoinfstr(latoa(p2));
-			(void)addstringtoinfstr(" ");
-			(void)addstringtoinfstr(latoa(p3));
-			(void)addstringtoinfstr("<=Y<=");
-			(void)addstringtoinfstr(latoa(p4));
-			(void)addstringtoinfstr("]");
+			(void)formatinfstr(_(" Facet '%s' modified [was from %s<=X<=%s %s<=Y<=%s]"),
+				describenodeproto(np), latoa(p1), latoa(p2), latoa(p3), latoa(p4));
 			return(returninfstr());
 		case OBJECTSTART:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Start change to object ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" Start change to object %s"), db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTEND:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" End change to object ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" End change to object %s"), db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTNEW:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Object ");
-			db_namevariable(entryaddr, p1);
-			(void)addstringtoinfstr(" created");
+			(void)formatinfstr(_(" Object %s created"), db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case OBJECTKILL:
 			/* args: addr, type */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Object ");
-			db_namevariable(entryaddr, p1);
-			(void)addstringtoinfstr(" deleted");
+			(void)formatinfstr(_(" Object %s deleted"), db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLENEW:
 			/* args: addr, type, key, newtype */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Variable '");
-			(void)addstringtoinfstr(changedvariablename(p1, p2,
-				p3));
-			(void)addstringtoinfstr("' created on ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" Variable '%s' created on %s"), changedvariablename(p1, p2, p3),
+				db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLEKILL:
 			/* args: addr, type, key, oldaddr, oldtype, olddescript */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Variable '");
-			(void)addstringtoinfstr(changedvariablename(p1, p2, p4));
-			(void)addstringtoinfstr("' killed on ");
-			db_namevariable(entryaddr, p1);
-			(void)addstringtoinfstr(" [was ");
 			myvar.key = p2;  myvar.type = p4;  myvar.addr = p3;
-			(void)addstringtoinfstr(describevariable(&myvar, -1, -1));
-			(void)addstringtoinfstr("]");
+			(void)formatinfstr(_(" Variable '%s' killed on %s [was %s]"), changedvariablename(p1, p2, p4),
+				db_namevariable(entryaddr, p1), describevariable(&myvar, -1, -1));
 			return(returninfstr());
 		case VARIABLEMOD:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Variable '");
-			(void)addstringtoinfstr(changedvariablename(p1, p2, p3));
-			(void)sprintf(line, "[%ld]", p4);
-			(void)addstringtoinfstr(line);
-			(void)addstringtoinfstr("' changed on ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" Variable '%s[%ld]' changed on %s"), changedvariablename(p1, p2, p3), p4,
+				db_namevariable(entryaddr, p1));
 			if ((p3&VCREF) == 0)
 			{
-				(void)addstringtoinfstr(" [was '");
 				myvar.key = p2;  myvar.type = p3 & ~VISARRAY;
 				myvar.addr = p5;
-				(void)addstringtoinfstr(describevariable(&myvar, -1, -1));
-				(void)addstringtoinfstr("']");
+				(void)formatinfstr(_(" [was '%s']"), describevariable(&myvar, -1, -1));
 			}
 			return(returninfstr());
 		case VARIABLEINS:
 			/* args: addr, type, key, vartype, aindex */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Variable '");
-			(void)addstringtoinfstr(changedvariablename(p1, p2, p3));
-			(void)sprintf(line, "[%ld]", p4);
-			(void)addstringtoinfstr(line);
-			(void)addstringtoinfstr("' inserted on ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" Variable '%s[%ld]' inserted on %s"), changedvariablename(p1, p2, p3), p4,
+				db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case VARIABLEDEL:
 			/* args: addr, type, key, vartype, aindex, oldvalue */
 			(void)initinfstr();
-			(void)addstringtoinfstr(" Variable '");
-			(void)addstringtoinfstr(changedvariablename(p1, p2, p3));
-			(void)sprintf(line, "[%ld]", p4);
-			(void)addstringtoinfstr(line);
-			(void)addstringtoinfstr("' deleted on ");
-			db_namevariable(entryaddr, p1);
+			(void)formatinfstr(_(" Variable '%s[%ld]' deleted on %s"), changedvariablename(p1, p2, p3), p4,
+				db_namevariable(entryaddr, p1));
 			return(returninfstr());
 		case DESCRIPTMOD:
 			var = (VARIABLE *)p2;
-			(void)initinfstr();
 			if (var != NOVARIABLE)
 			{
-				(void)addstringtoinfstr(" Text descriptor on variable ");
-				(void)addstringtoinfstr(makename(var->key));
-				(void)addstringtoinfstr(" changed [was ");
-				sprintf(line, "0%lo]", p3);
-				(void)addstringtoinfstr(line);
+				(void)initinfstr();
+				(void)formatinfstr(_(" Text descriptor on variable %s changed [was 0%lo]"),
+					makename(var->key), p3);
 				return(returninfstr());
 			}
 	}
@@ -1590,7 +1477,7 @@ char *db_describechange(INTSML changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
  * routine to name the variable at "addr" of type "type".  It is assumed
  * to be an object that can hold other variables
  */
-void db_namevariable(INTBIG addr, INTBIG type)
+char *db_namevariable(INTBIG addr, INTBIG type)
 {
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *np;
@@ -1610,144 +1497,106 @@ void db_namevariable(INTBIG addr, INTBIG type)
 	REGISTER WINDOWFRAME *wf;
 	REGISTER GRAPHICS *gra;
 	REGISTER CONSTRAINT *con;
-	char line[50];
+	REGISTER POLYGON *poly;
 
+	(void)initinfstr();
 	switch (type&VTYPE)
 	{
 		case VNODEINST:
 			ni = (NODEINST *)addr;
-			(void)addstringtoinfstr("NodeInstance(");
-			if (ni == NONODEINST) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(describenodeinst(ni));
+			(void)formatinfstr("NodeInstance(%s)", describenodeinst(ni));
 			break;
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
-			if (np->primindex == 0) (void)addstringtoinfstr("Facet("); else
-				(void)addstringtoinfstr("Primitive(");
-			if (np == NONODEPROTO) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(describenodeproto(np));
+			if (np->primindex == 0) (void)formatinfstr("Facet(%s)", describenodeproto(np)); else
+				(void)formatinfstr("Primitive(%s)", describenodeproto(np));
 			break;
 		case VPORTARCINST:
 			pi = (PORTARCINST *)addr;
-			(void)addstringtoinfstr("PortArcInstance(");
-			if (pi == NOPORTARCINST) (void)addstringtoinfstr("NULL"); else
-			{
-				(void)sprintf(line, "%ld", (INTBIG)pi);
-				(void)addstringtoinfstr(line);
-			}
+			if (pi == NOPORTARCINST) (void)addstringtoinfstr("PortArcInstance(NULL)"); else
+				(void)formatinfstr("PortArcInstance(%ld)", (INTBIG)pi);
 			break;
 		case VPORTEXPINST:
 			pe = (PORTEXPINST *)addr;
-			(void)addstringtoinfstr("PortExpInstance(");
-			if (pe == NOPORTEXPINST) (void)addstringtoinfstr("NULL"); else
-			{
-				(void)sprintf(line, "%ld", (INTBIG)pe);
-				(void)addstringtoinfstr(line);
-			}
+			if (pe == NOPORTEXPINST) (void)addstringtoinfstr("PortExpInstance(NULL)"); else
+				(void)formatinfstr("PortExpInstance(%ld)", (INTBIG)pe);
 			break;
 		case VPORTPROTO:
 			pp = (PORTPROTO *)addr;
-			(void)addstringtoinfstr("PortPrototype(");
-			if (pp == NOPORTPROTO) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(pp->protoname);
+			if (pp == NOPORTPROTO) (void)addstringtoinfstr("PortPrototype(NULL)"); else
+				(void)formatinfstr("PortPrototype(%s)", pp->protoname);
 			break;
 		case VARCINST:
 			ai = (ARCINST *)addr;
-			(void)addstringtoinfstr("ArcInstance(");
-			if (ai == NOARCINST) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(describearcinst(ai));
+			(void)formatinfstr("ArcInstance(%s)", describearcinst(ai));
 			break;
 		case VARCPROTO:
 			ap = (ARCPROTO *)addr;
-			(void)addstringtoinfstr("ArcPrototype(");
-			if (ap == NOARCPROTO) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(describearcproto(ap));
+			(void)formatinfstr("ArcPrototype(%s)", describearcproto(ap));
 			break;
 		case VGEOM:
 			geom = (GEOM *)addr;
-			(void)addstringtoinfstr("Geom(");
-			if (geom == NOGEOM) (void)addstringtoinfstr("NULL"); else
-			{
-				(void)sprintf(line, "%ld", (INTBIG)geom);
-				(void)addstringtoinfstr(line);
-			}
+			if (geom == NOGEOM) (void)addstringtoinfstr("Geom(NULL)"); else
+				(void)formatinfstr("Geom(%ld)", (INTBIG)geom);
 			break;
 		case VLIBRARY:
 			lib = (LIBRARY *)addr;
-			(void)addstringtoinfstr("Library(");
-			if (lib == NOLIBRARY) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(lib->libname);
+			if (lib == NOLIBRARY) (void)addstringtoinfstr("Library(NULL)"); else
+				(void)formatinfstr("Library(%s)", lib->libname);
 			break;
 		case VTECHNOLOGY:
 			tech = (TECHNOLOGY *)addr;
-			(void)addstringtoinfstr("Technology(");
-			if (tech == NOTECHNOLOGY) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(tech->techname);
+			if (tech == NOTECHNOLOGY) (void)addstringtoinfstr("Technology(NULL)"); else
+				(void)formatinfstr("Technology(%s)", tech->techname);
 			break;
 		case VAID:
 			aid = (AIDENTRY *)addr;
-			(void)addstringtoinfstr("Aid(");
-			if (aid == NOAID) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(aid->aidname);
+			if (aid == NOAID) (void)addstringtoinfstr("Aid(NULL)"); else
+				(void)formatinfstr("Aid(%s)", aid->aidname);
 			break;
 		case VRTNODE:
 			rtn = (RTNODE *)addr;
-			(void)addstringtoinfstr("Rtnode(");
-			if (rtn == NORTNODE) (void)addstringtoinfstr("NULL"); else
-			{
-				(void)sprintf(line, "%ld", (INTBIG)rtn);
-				(void)addstringtoinfstr(line);
-			}
+			if (rtn == NORTNODE) (void)addstringtoinfstr("Rtnode(NULL)"); else
+				(void)formatinfstr("Rtnode(%ld)", (INTBIG)rtn);
 			break;
 		case VCELL:
 			c = (CELL *)addr;
-			(void)addstringtoinfstr("Cell(");
-			if (c == NOCELL) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(c->cellname);
+			if (c == NOCELL) (void)addstringtoinfstr("Cell(NULL)"); else
+				(void)formatinfstr("Cell(%s)", c->cellname);
 			break;
 		case VVIEW:
 			v = (VIEW *)addr;
-			(void)addstringtoinfstr("View(");
-			if (v == NOVIEW) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(v->viewname);
+			if (v == NOVIEW) (void)addstringtoinfstr("View(NULL)"); else
+				(void)formatinfstr("View(%s)", v->viewname);
 			break;
 		case VWINDOWPART:
 			win = (WINDOWPART *)addr;
-			(void)addstringtoinfstr("WindowPart(");
-			(void)sprintf(line, "%ld", (INTBIG)win);
-			(void)addstringtoinfstr(line);
-			if (win != NOWINDOWPART)
-			{
-				(void)addstringtoinfstr(", ");
-				(void)addstringtoinfstr(win->location);
-			}
+			if (win != NOWINDOWPART) (void)formatinfstr("WindowPart(%s)", win->location); else
+				(void)formatinfstr("WindowPart(%ld)", (INTBIG)win);
 			break;
 		case VGRAPHICS:
 			gra = (GRAPHICS *)addr;
-			(void)addstringtoinfstr("Graphics(");
-			if (gra == NOGRAPHICS) (void)addstringtoinfstr("NULL"); else
-			{
-				(void)sprintf(line, "%ld", (INTBIG)gra);
-				(void)addstringtoinfstr(line);
-			}
+			if (gra == NOGRAPHICS) (void)addstringtoinfstr("Graphics(NULL)"); else
+				(void)formatinfstr("Graphics(%ld)", (INTBIG)gra);
 			break;
 		case VCONSTRAINT:
 			con = (CONSTRAINT *)addr;
-			(void)addstringtoinfstr("Constraint(");
-			if (con == NOCONSTRAINT) (void)addstringtoinfstr("NULL"); else
-				(void)addstringtoinfstr(con->conname);
+			if (con == NOCONSTRAINT) (void)addstringtoinfstr("Constraint(NULL)"); else
+				(void)formatinfstr("Constraint(%s)", con->conname);
 			break;
 		case VWINDOWFRAME:
 			wf = (WINDOWFRAME *)addr;
-			(void)addstringtoinfstr("WindowFrame(");
-			(void)sprintf(line, "%ld", (INTBIG)wf);
-			(void)addstringtoinfstr(line);
+			(void)formatinfstr("WindowFrame(%ld)", (INTBIG)wf);
+			break;
+		case VPOLYGON:
+			poly = (POLYGON *)addr;
+			(void)formatinfstr("Polygon(%ld)", (INTBIG)poly);
 			break;
 		default:
-			(void)addstringtoinfstr("UNKNOWN(?");
+			(void)addstringtoinfstr("UNKNOWN(?)");
 			break;
 	}
-	(void)addstringtoinfstr(")");
+	return(returninfstr());
 }
 
 /* routine to display the "undo" menu
@@ -1859,47 +1708,41 @@ void db_loadhistorylist(short details)
 		}
 
 		(void)initinfstr();
-		if (details != 0) (void)addstringtoinfstr("***** BATCH ");
+		if (details != 0) (void)addstringtoinfstr(_("***** BATCH "));
 		(void)sprintf(line, "%ld {", batch->batchnumber);
 		(void)addstringtoinfstr(line);
 		if (batch->activity != 0) (void)addstringtoinfstr(batch->activity);
-		(void)addstringtoinfstr("} affects");
+		(void)addstringtoinfstr(_("} affects"));
 
 		if (node != 0)
 		{
-			(void)sprintf(line, " %d node", node);
+			(void)sprintf(line, " %d %s", node, makeplural(_("node"), node));
 			(void)addstringtoinfstr(line);
-			if (node > 1) (void)addtoinfstr('s');
 		}
 		if (arcinst != 0)
 		{
-			(void)sprintf(line, " %d arc", arcinst);
+			(void)sprintf(line, " %d %s", arcinst, makeplural(_("arc"), arcinst));
 			(void)addstringtoinfstr(line);
-			if (arcinst > 1) (void)addtoinfstr('s');
 		}
 		if (portproto != 0)
 		{
-			(void)sprintf(line, " %d port", portproto);
+			(void)sprintf(line, " %d %s", portproto, makeplural(_("port"), portproto));
 			(void)addstringtoinfstr(line);
-			if (portproto > 1) (void)addtoinfstr('s');
 		}
 		if (nproto != 0)
 		{
-			(void)sprintf(line, " %d facet", nproto);
+			(void)sprintf(line, " %d %s", nproto, makeplural(_("facet"), nproto));
 			(void)addstringtoinfstr(line);
-			if (nproto > 1) (void)addtoinfstr('s');
 		}
 		if (object != 0)
 		{
-			(void)sprintf(line, " %d object", object);
+			(void)sprintf(line, " %d %s", object, makeplural(_("object"), object));
 			(void)addstringtoinfstr(line);
-			if (object > 1) (void)addtoinfstr('s');
 		}
 		if (variable != 0)
 		{
-			(void)sprintf(line, " %d variable", variable);
+			(void)sprintf(line, " %d %s", variable, makeplural(_("variable"), variable));
 			(void)addstringtoinfstr(line);
-			if (variable > 1) (void)addtoinfstr('s');
 		}
 		DiaStuffLine(3, returninfstr());
 		if (batch == db_donebatch) curline = lineno;
