@@ -33,7 +33,7 @@
 #include "tech.h"
 #include "edialogs.h"
 
-char *el_version = "6.01";		/* the current Electric version */
+char *el_version = "6.02";		/* the current Electric version */
 
 /* miscellaneous defaults */
 #define	DEFTECH     "nmos"        /* default technology */
@@ -42,6 +42,19 @@ char *el_version = "6.01";		/* the current Electric version */
 /* prototypes for local routines */
 void db_freeallmemory(void);
 
+#if 0		/* for testing "gettext" (the internationalization macro) */
+char *testgettext(char *text)
+{
+	char *foolbuf;
+
+	foolbuf = (char *)emalloc(strlen(text)+5, db_cluster);
+	strcpy(foolbuf, "{{");
+	strcat(foolbuf, text);
+	strcat(foolbuf, "}}");
+	return(foolbuf);
+}
+#endif
+
 /*
  * the primary initialization of Electric
  */
@@ -55,6 +68,12 @@ void osprimaryosinit(void)
 	char libname[10], libfile[10];
 	extern TECHNOLOGY el_technologylist[];
 
+#if 0	/* for internationalization */
+	setlocale(LC_ALL, "");
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+#endif
+  
 	/* initialize the memory allocation system */
 	db_initclusters();
 
@@ -95,7 +114,7 @@ void osprimaryosinit(void)
 		(void)addstringtoinfstr(tech->techname);
 		clus = alloccluster(returninfstr());
 		realtech = alloctechnology(clus);
-		if (realtech == NOTECHNOLOGY) error("No memory for technologies");
+		if (realtech == NOTECHNOLOGY) error(_("No memory for technologies"));
 
 		/* link it in */
 		if (lasttech == NOTECHNOLOGY) el_technologies = realtech; else
@@ -108,7 +127,7 @@ void osprimaryosinit(void)
 		realtech->deflambda = tech->deflambda;
 		realtech->parse = tech->parse;
 		realtech->cluster = clus;
-		(void)allocstring(&realtech->techdescript, tech->techdescript, clus);
+		(void)allocstring(&realtech->techdescript, _(tech->techdescript), clus);
 		realtech->layercount = tech->layercount;
 		realtech->layers = tech->layers;
 		realtech->arcprotocount = tech->arcprotocount;
@@ -151,10 +170,10 @@ void osprimaryosinit(void)
 		if (tech->init != 0)
 		{
 			if ((*tech->init)(tech, 0) != 0)
-				error("User pass 1 error initializing %s technology", tech->techname);
+				error(_("User pass 1 error initializing %s technology"), tech->techname);
 		}
 		if (tech_doinitprocess(tech) != 0)
-			error("Pass 1 error initializing %s technology", tech->techname);
+			error(_("Pass 1 error initializing %s technology"), tech->techname);
 	}
 
 	/* pass 1 initialization of the aids */
@@ -190,10 +209,10 @@ void ossecondaryinit(INTBIG argc, char *argv[])
 		if (tech->init != 0)
 		{
 			if ((*tech->init)(tech, 1) != 0)
-				error("User pass 2 error initializing %s technology", tech->techname);
+				error(_("User pass 2 error initializing %s technology"), tech->techname);
 		}
 		if (tech_doaddportsandvars(tech))
-			error("Pass 2 error initializing %s technology", tech->techname);
+			error(_("Pass 2 error initializing %s technology"), tech->techname);
 	}
 
 	/* pass 2 initialization of the aids */
@@ -205,7 +224,7 @@ void ossecondaryinit(INTBIG argc, char *argv[])
 		if (tech->init != 0)
 		{
 			if ((*tech->init)(tech, 2) != 0)
-				error("User pass 3 error initializing %s technology", tech->techname);
+				error(_("User pass 3 error initializing %s technology"), tech->techname);
 		}
 	}
 
@@ -400,19 +419,22 @@ void db_freeallmemory(void)
 	db_freemathmemory();
 	db_freemergememory();
 	db_freegeomemory();
+	initerrorlogging("");
 #  if LANGTCL
 	db_freetclmemory();
 #  endif
 #endif
 }
 
-INTSML stopping(char *who)
+INTSML stopping(INTBIG reason)
 {
+	extern char *db_stoppingreason[];
+
 	checkforinterrupt();
 	if (el_pleasestop != 1) return(el_pleasestop);
 	el_pleasestop = 0;
 	flushscreen();
-	ttyputmsg("%s stopped", who);
+	ttyputmsg(_("%s stopped"), db_stoppingreason[reason]);
 	el_pleasestop = 2;
 	return(el_pleasestop);
 }
