@@ -201,7 +201,7 @@ INTSML killnodeinst(NODEINST *ni)
 	if (ni->firstportarcinst != NOPORTARCINST)
 		return((INTSML)db_error(DBHASARCS|DBKILLNODEINST));
 
-	/* error if any ports exported */
+	/* error if any exports */
 	if (ni->firstportexpinst != NOPORTEXPINST)
 		return((INTSML)db_error(DBHASPORTS|DBKILLNODEINST));
 
@@ -496,7 +496,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDAC|DBNEWARCINST);
 		if (db_printerrors != 0)
-			ttyputmsg("Port %s of node %s in facet %s cannot connect to arc %s", pA->protoname,
+			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pA->protoname,
 				describenodeinst(nA), describenodeproto(parnt), describearcproto(typ));
 		return(NOARCINST);
 	}
@@ -506,7 +506,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDBC|DBNEWARCINST);
 		if (db_printerrors != 0)
-			ttyputmsg("Port %s of node %s in facet %s cannot connect to arc %s", pB->protoname,
+			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pB->protoname,
 				describenodeinst(nB), describenodeproto(parnt), describearcproto(typ));
 		return(NOARCINST);
 	}
@@ -518,7 +518,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDAP|DBNEWARCINST);
 		if (db_printerrors != 0)
-			ttyputmsg("Point (%s,%s) not inside port %s of node %s in facet %s", latoa(xA),
+			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xA),
 				latoa(yA), pA->protoname, describenodeinst(nA), describenodeproto(parnt));
 		return(NOARCINST);
 	}
@@ -527,7 +527,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDBP|DBNEWARCINST);
 		if (db_printerrors != 0)
-			ttyputmsg("Point (%s,%s) not inside port %s of node %s in facet %s", latoa(xB),
+			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xB),
 				latoa(yB), pB->protoname, describenodeinst(nB), describenodeproto(parnt));
 		return(NOARCINST);
 	}
@@ -792,9 +792,8 @@ INTSML modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG deltay
 		return((INTSML)db_error(DBBADNEWWID|DBMODIFYARCINST));
 	if (deltax1 != 0 || deltay1 != 0 || deltax2 != 0 || deltay2 != 0)
 	{
-		/* this error message could be more explanatory!!! */
 		if ((ai->userbits&(FIXED|CANTSLIDE)) != 0)
-			return((INTSML)db_error(DBNOTINPORT|DBMODIFYARCINST));
+			return((INTSML)db_error(DBNOSLIDING|DBMODIFYARCINST));
 
 		/* temporarily set the width and check for port validity */
 		ai->width += deltawid;
@@ -982,6 +981,7 @@ ARCINST *dummyarc(void)
 
 	arc.proto = el_technologies->firstarcproto;
 	arc.length = 0;
+	arc.parent = NONODEPROTO;
 	arc.width = 0;
 	arc.endshrink = 0;
 	arc.end[0].nodeinst = arc.end[1].nodeinst = dummynode();
@@ -1005,6 +1005,7 @@ PORTPROTO *allocportproto(CLUSTER *cluster)
 	if (pp == 0) return(NOPORTPROTO);
 	pp->userbits = pp->temp1 = pp->temp2 = 0;
 	pp->network = NONETWORK;
+	pp->connects = 0;
 	pp->numvar = 0;
 	pp->changeaddr = (char *)NOCHANGE;
 	pp->protoname = (char *)-1;
@@ -1198,7 +1199,7 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, char *name)
 	/* name must not have blank space in it */
 	for(ptr = name; *ptr != 0; ptr++) if (*ptr <= ' ' || *ptr >= 0177)
 	{
-		ttyputmsg("Port '%s' on primitive '%s' has bad name (spaces?)", name, np->primname);
+		ttyputmsg(_("Port '%s' on primitive '%s' has bad name (spaces?)"), name, np->primname);
 		return(NOPORTPROTO);
 	}
 
@@ -1230,8 +1231,8 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, char *name)
  * routine to delete portproto "pp" from nodeproto "np".  Returns 0 if
  * successful, nonzero if the portproto could not be deleted (does not
  * exist).  If the portproto has arcs connected to it in instances of the
- * facet, the arcs are deleted.  If the portproto is further exported from
- * instances of the facet, those ports are deleted (recursively).
+ * facet, the arcs are deleted.  If the portproto is an export of
+ * the facet, those exports are deleted (recursively).
  */
 INTSML killportproto(NODEPROTO *np, PORTPROTO *pp)
 {
@@ -1276,7 +1277,7 @@ void db_killportproto(PORTPROTO *pp)
 			}
 		}
 
-		/* see if this port is further exported */
+		/* see if this port is an export */
 		for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = nextpe)
 		{
 			nextpe = pe->nextportexpinst;
