@@ -129,7 +129,6 @@ ELKObject lsp_noundoallowed(void);
 ELKObject lsp_getview(ELKObject);
 ELKObject lsp_newview(ELKObject, ELKObject);
 ELKObject lsp_killview(ELKObject);
-ELKObject lsp_changelambda(ELKObject, ELKObject, ELKObject);
 ELKObject lsp_tellaid(long, ELKObject[]);
 ELKObject lsp_getarcproto(ELKObject);
 ELKObject lsp_getcell(ELKObject);
@@ -731,7 +730,8 @@ void lsp_getaddrandtype(ELKObject oaddr, INTBIG *addr, INTBIG *type)
 	if (otype == T_EWindow)      *type = VWINDOWPART; else
 	if (otype == T_EGraphics)    *type = VGRAPHICS; else
 	if (otype == T_EConstraint)  *type = VCONSTRAINT; else
-	if (otype == T_EWindowFrame) *type = VWINDOWFRAME; else return;
+	if (otype == T_EWindowFrame) *type = VWINDOWFRAME; else
+		return;
 	*addr = EELECTRIC(oaddr)->handle;
 }
 
@@ -898,7 +898,7 @@ ELKObject lsp_setval(ELKObject oaddr, ELKObject oname, ELKObject onaddr, ELKObje
 			}
 			if (i != 0 && ntype != lasttype)
 			{
-				ttyputerr("Inconsistent type in array");
+				ttyputerr(_("Inconsistent type in array"));
 				return(Null);
 			}
 			lasttype = ntype;
@@ -1253,7 +1253,7 @@ ELKObject lsp_replacenodeinst(ELKObject oni, ELKObject opr)
 	Ensure_Type(oni, T_ENodeInst);   ni = ENODEINST(oni)->handle;
 	Ensure_Type(opr, T_ENodeProto);  pr = ENODEPROTO(opr)->handle;
 
-	nni = replacenodeinst(ni, pr);
+	nni = replacenodeinst(ni, pr, 0);
 	if (nni == NONODEINST) return(Null);
 	return(Make_EElectric((INTBIG)nni, (INTSML)T_ENodeInst));
 }
@@ -1486,23 +1486,6 @@ ELKObject lsp_killview(ELKObject ov)
 
 /*************************** MISCELLANEOUS ROUTINES ***************************/
 
-ELKObject lsp_changelambda(ELKObject ooldl, ELKObject onewl, ELKObject otech)
-{
-	REGISTER TECHNOLOGY *tech;
-	INTBIG oldl, newl;
-
-	/* get inputs from LISP */
-	if (Nullp(otech)) tech = NOTECHNOLOGY; else
-	{
-		Ensure_Type(otech, T_ETechnology);   tech = ETECHNOLOGY(otech)->handle;
-	}
-	if (lsp_getnumericobject(ooldl, &oldl) != 0) return(Null);
-	if (lsp_getnumericobject(onewl, &newl) != 0) return(Null);
-
-	changelambda(oldl, newl, tech);
-	return(Null);
-}
-
 ELKObject lsp_tellaid(long argc, ELKObject argv[])
 {
 	REGISTER AIDENTRY *aid;
@@ -1726,7 +1709,6 @@ void init_lib_electric(void)
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_killview, "killview", 1, 1, EVAL);
 
 	/* define the miscellaneous predicates */
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_changelambda, "changelambda", 3, 3, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_tellaid, "tellaid", 1, MANY, VARARGS);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getarcproto, "getarcproto", 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getcell, "getcell", 1, 1, EVAL);
