@@ -32,10 +32,9 @@
 #include "database.h"
 
 /* prototypes for local routines */
-void db_scalefacet(NODEPROTO*, INTBIG, INTBIG);
+void db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*, INTBIG*);
 void db_validatearcinst(ARCINST*);
 void db_setarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
-INTBIG db_muldivq(INTBIG, INTBIG, INTBIG);
 INTBIG db_scaleunits(INTBIG *value, INTBIG num, INTBIG den);
 
 /****************************** LIBRARIES ******************************/
@@ -63,7 +62,15 @@ LIBRARY *alloclibrary(void)
 
 	lib->userbits = lib->temp1 = lib->temp2 = 0;
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-		lib->lambda[tech->techindex] = tech->deflambda;
+	{
+		if (el_curlib == NOLIBRARY)
+		{
+			lib->lambda[tech->techindex] = tech->deflambda;
+		} else
+		{
+			lib->lambda[tech->techindex] = el_curlib->lambda[tech->techindex];
+		}
+	}
 	lib->numvar = 0;
 	lib->libname = NOSTRING;
 	lib->libfile = NOSTRING;
@@ -111,7 +118,7 @@ LIBRARY *newlibrary(char *name, char *file)
 		if (nc != *ch) renamed++;
 		*ch = nc;
 	}
-	if (renamed != 0) ttyputerr("Warning: library renamed to '%s'", name);
+	if (renamed != 0) ttyputerr(_("Warning: library renamed to '%s'"), name);
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		if (namesame(name, lib->libname) == 0)
 			return((LIBRARY *)db_error(DBBADLIB|DBNEWLIBRARY));
@@ -176,7 +183,7 @@ void selectlibrary(LIBRARY *lib)
 	el_curlib = lib;
 
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-		db_scaletechnology(tech, el_curlib->lambda[tech->techindex], tech->deflambda);
+		changetechnologylambda(tech, el_curlib->lambda[tech->techindex]);
 }
 
 void killlibrary(LIBRARY *lib)
@@ -319,38 +326,44 @@ void eraselibrary(LIBRARY *lib)
 /****************************** LAMBDA ******************************/
 
 /*
- * routine to change value of lambda from "oldlam" to "lam" and adjust the
- * world to agree with the new value.
- * if tech!=NOTECHNOLOGY just make a change to technology "tech" (scale the
- *                       technology and update the library/technology value).
- * if tech==NOTECHNOLOGY adjust all technologies to match the current library
- *                       and scale all libraries to match the new lambda.
+ * routine to change value of lambda in "count" technologies.  The
+ * technologies are in "techarray" and the new lambda values for them
+ * are in "newlam".
+ * If "how" is 0, only change the technology (no libraries)
+ * If "how" is 1, change technology and library "whichlib"
+ * If "how" is 2, change technology and all libraries, specifically "whichlib"
  */
-void changelambda(INTBIG oldlam, INTBIG lam, TECHNOLOGY *tech)
+void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
+	LIBRARY *whichlib, INTBIG how)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG *oldlam, i;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *lib;
 
-	if (tech != NOTECHNOLOGY)
+	if (how == 0)
 	{
-		/* not scaling library: simply change this particular value */
-		db_scaletechnology(tech, lam, tech->deflambda);
-		el_curlib->lambda[tech->techindex] = lam;
+		/* special case when only changing technology values */
+		for(i=0; i<count; i++)
+			changetechnologylambda(techarray[i], newlam[i]);
 		return;
 	}
 
-	/* scale the technology values in the current library */
-	if (lam != oldlam)
-		for(i=0; i < el_maxtech; i++)
-			el_curlib->lambda[i] = muldiv(el_curlib->lambda[i], lam, oldlam);
+	oldlam = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
+	if (oldlam == 0) return;
+	for(i=0; i<count; i++)
+		oldlam[i] = whichlib->lambda[techarray[i]->techindex];
 
-	/* make all technologies agree with the current library */
-	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-		db_scaletechnology(tech, el_curlib->lambda[tech->techindex], tech->deflambda);
+	/* make the technology agree with the current library */
+	for(i=0; i<count; i++)
+		changetechnologylambda(techarray[i], newlam[i]);
 
-	/* no change to the library if lambda is the same */
-	if (lam == oldlam) return;
+	/* update lambda values in the libraries */
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+	{
+		if (how == 1 && whichlib != lib) continue;
+		for(i=0; i<count; i++)
+			lib->lambda[techarray[i]->techindex] = newlam[i];
+	}
 
 	/* mark all facets in the library for scaling */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -360,110 +373,148 @@ void changelambda(INTBIG oldlam, INTBIG lam, TECHNOLOGY *tech)
 	/* scale all the facets */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
+		if (how == 1 && whichlib != lib) continue;
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			db_scalefacet(np, lam, oldlam);
+			db_scalefacet(np, count, techarray, newlam, oldlam);
 		lib->userbits |= LIBCHANGEDMAJOR;
 	}
+	efree((char *)oldlam);
 }
 
 /*
- * routine to return the value of lambda to use for object "geom"
+ * routine to recursively scale the contents of facet "np" by "newlam/oldlam"
  */
-INTBIG figurelambda(GEOM *geom)
+void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray,
+	INTBIG *newlam, INTBIG *oldlam)
 {
+	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	REGISTER NODEINST *ni;
-
-	if (geom->entrytype == OBJARCINST)
-	{
-		ai = geom->entryaddr.ai;
-		return(ai->proto->tech->deflambda);
-	}
-	ni = geom->entryaddr.ni;
-	if (ni->proto->primindex != 0) return(ni->proto->tech->deflambda);
-	return(el_curtech->deflambda);
-}
-
-/*
- * routine to recursively scale the contents of facet "np" by "lam/oldlam"
- */
-void db_scalefacet(NODEPROTO *np, INTBIG lam, INTBIG oldlam)
-{
-	REGISTER NODEINST *ni;
+	REGISTER INTBIG i, *freq, bestfreq, besttechindex;
 
 	/* quit if the facet is already done */
 	if (np->temp1 != 0) return;
 
 	/* first look for sub-facets that are not yet scaled */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-		if (ni->proto->primindex == 0) db_scalefacet(ni->proto, lam, oldlam);
+		if (ni->proto->primindex == 0)
+			db_scalefacet(ni->proto, count, techarray, newlam, oldlam);
 
 	/* mark this facet "scaled" */
 	np->temp1++;
 
-	db_scaleonefacet(np, lam, oldlam);
-}
-
-/*
- * routine to scale facet "np" by the factor "num" / "denom"
- */
-void db_scaleonefacet(NODEPROTO *np, INTBIG num, INTBIG denom)
-{
-	REGISTER NODEINST *ni;
-	REGISTER ARCINST *ai;
-	REGISTER INTBIG sizex, sizey, dx, dy, len;
-	REGISTER INTSML i;
-	REGISTER VARIABLE *var;
-
+	/* see if there is anything from this technology in the facet */
+	freq = (INTBIG *)emalloc(count * SIZEOFINTBIG, el_tempcluster);
+	if (freq == 0) return;
+	for(i=0; i<count; i++) freq[i] = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		ni->lowx  = db_muldivq(ni->lowx,  num, denom);
-		ni->highx = db_muldivq(ni->highx, num, denom);
-		ni->lowy  = db_muldivq(ni->lowy,  num, denom);
-		ni->highy = db_muldivq(ni->highy, num, denom);
-		if (ni->proto->primindex == 0)
+		for(i=0; i<count; i++)
+		{
+			if (ni->proto->tech == techarray[i])
+			{
+				freq[i]++;
+				break;
+			}
+		}
+	}
+	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	{
+		for(i=0; i<count; i++)
+		{
+			if (ai->proto->tech == techarray[i])
+			{
+				freq[i]++;
+				break;
+			}
+		}
+	}
+
+	/* find the most prevalent technology in this facet */
+	bestfreq = -1;
+	for(i=0; i<count; i++)
+	{
+		if (freq[i] > bestfreq)
+		{
+			bestfreq = freq[i];
+			besttechindex = i;
+		}
+	}
+
+	/* if the technology is present, scale the entire facet */
+	if (bestfreq > 0)
+	{
+		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			db_scalenodeinst(ni, newlam[besttechindex], oldlam[besttechindex]);
+		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			db_scalearcinst(ai, newlam[besttechindex], oldlam[besttechindex]);
+		db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+	}
+	efree((char *)freq);
+}
+
+void db_scalenodeinst(NODEINST *ni, INTBIG newlam, INTBIG oldlam)
+{
+	REGISTER VARIABLE *var;
+	REGISTER INTBIG sizex, sizey, dx, dy, len, i, newlx, newhx, newly, newhy;
+
+	newlx = muldiv(ni->lowx,  newlam, oldlam);
+	newhx = muldiv(ni->highx, newlam, oldlam);
+	newly = muldiv(ni->lowy,  newlam, oldlam);
+	newhy = muldiv(ni->highy, newlam, oldlam);
+
+	if (ni->proto->primindex == 0)
+	{
+		sizex = ni->proto->highx - ni->proto->lowx;
+		sizey = ni->proto->highy - ni->proto->lowy;
+		dx = ni->highx - ni->lowx - sizex;
+		dy = ni->highy - ni->lowy - sizey;
+		ni->lowx = newlx;   ni->highx = newhx;
+		ni->lowy = newly;   ni->highy = newhy;
+		if (dx != 0 || dy != 0)
 		{
-			sizex = ni->proto->highx - ni->proto->lowx;
-			sizey = ni->proto->highy - ni->proto->lowy;
 			dx = ni->highx - ni->lowx - sizex;
 			dy = ni->highy - ni->lowy - sizey;
 			if (dx != 0 || dy != 0)
 			{
-				ttyputmsg("Facet %s, node %s size and position adjusted",
-					describenodeproto(np), describenodeinst(ni));
+				ttyputmsg(_("Facet %s, node %s size and position adjusted"),
+					describenodeproto(ni->parent), describenodeinst(ni));
 				ni->lowx += dx/2;   ni->highx = ni->lowx + sizex;
 				ni->lowy += dy/2;   ni->highy = ni->lowy + sizey;
 			}
-		} else
-		{
-			/* look for trace data on primitives */
-			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
-			if (var != NOVARIABLE)
-			{
-				len = getlength(var);
-				for(i=0; i<len; i++)
-					((INTBIG *)var->addr)[i] = db_muldivq(((INTBIG *)var->addr)[i], num, denom);
-			}
 		}
-		updategeom(ni->geom, np);
-	}
-	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	} else
 	{
-		ai->width = db_muldivq(ai->width, num, denom);
-		ai->end[0].xpos = db_muldivq(ai->end[0].xpos, num, denom);
-		ai->end[0].ypos = db_muldivq(ai->end[0].ypos, num, denom);
-		ai->end[1].xpos = db_muldivq(ai->end[1].xpos, num, denom);
-		ai->end[1].ypos = db_muldivq(ai->end[1].ypos, num, denom);
-		ai->length = computedistance(ai->end[0].xpos, ai->end[0].ypos,
-			ai->end[1].xpos, ai->end[1].ypos);
-		db_validatearcinst(ai);
-		updategeom(ai->geom, np);
-
-		/* look for curvature data on primitives */
-		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
-		if (var != NOVARIABLE) var->addr = db_muldivq(var->addr, num, denom);
+		/* look for trace data on primitives */
+		ni->lowx = newlx;   ni->highx = newhx;
+		ni->lowy = newly;   ni->highy = newhy;
+		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace);
+		if (var != NOVARIABLE)
+		{
+			len = getlength(var);
+			for(i=0; i<len; i++)
+				((INTBIG *)var->addr)[i] = muldiv(((INTBIG *)var->addr)[i], newlam, oldlam);
+		}
 	}
-	db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+	updategeom(ni->geom, ni->parent);
+}
+
+void db_scalearcinst(ARCINST *ai, INTBIG newlam, INTBIG oldlam)
+{
+	REGISTER VARIABLE *var;
+
+	ai->width = muldiv(ai->width, newlam, oldlam);
+	ai->end[0].xpos = muldiv(ai->end[0].xpos, newlam, oldlam);
+	ai->end[0].ypos = muldiv(ai->end[0].ypos, newlam, oldlam);
+	ai->end[1].xpos = muldiv(ai->end[1].xpos, newlam, oldlam);
+	ai->end[1].ypos = muldiv(ai->end[1].ypos, newlam, oldlam);
+	ai->length = computedistance(ai->end[0].xpos, ai->end[0].ypos,
+		ai->end[1].xpos, ai->end[1].ypos);
+	db_validatearcinst(ai);
+	updategeom(ai->geom, ai->parent);
+
+	/* look for curvature data on primitives */
+	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, el_arc_radius);
+	if (var != NOVARIABLE) var->addr = muldiv(var->addr, newlam, oldlam);
 }
 
 /*
@@ -520,7 +571,7 @@ void db_validatearcinst(ARCINST *ai)
 	getcenter(poly1, &tx, &ty);
 	ai->userbits &= ~FIXANG;
 	db_setarcinst(ai, fx, fy, tx, ty);
-	ttyputmsg("Facet %s, arc %s no longer fixed-angle",
+	ttyputmsg(_("Facet %s, arc %s no longer fixed-angle"),
 		describenodeproto(ai->parent), describearcinst(ai));
 }
 
@@ -537,21 +588,20 @@ void db_setarcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty)
 	updategeom(ai->geom, ai->parent);
 }
 
-/* routine to compute (a*b/c) rounded to the nearest quarter "b" */
-INTBIG db_muldivq(INTBIG a, INTBIG b, INTBIG c)
-{
-	REGISTER INTBIG j;
-
-	j = muldiv(a, b, c) * 4;
-	if (j < 0) j -= b/2; else j += b/2;
-	return((j / b) * b / 4);
-}
-
-void db_scaletechnology(TECHNOLOGY *tech, INTBIG newlambda, INTBIG oldlambda)
+/*
+ * Routine to change the value of lambda in technology "tech" to
+ * "newlambda".
+ */
+void changetechnologylambda(TECHNOLOGY *tech, INTBIG newlambda)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
 	REGISTER VARIABLE *var;
+	REGISTER INTBIG oldlambda;
+
+	oldlambda = tech->deflambda;
+	if (newlambda <= 0) newlambda = 1;
+	if (newlambda == oldlambda) return;
 
 	/* change the default width of the primitive arc prototypes */
 	for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
@@ -578,10 +628,7 @@ void db_scaletechnology(TECHNOLOGY *tech, INTBIG newlambda, INTBIG oldlambda)
 	}
 
 	/* finally, reset the default lambda value */
-	tech->deflambda = muldiv(tech->deflambda, newlambda, oldlambda);
-
-	/* prevent zero lambda values */
-	if (tech->deflambda <= 0) tech->deflambda = 1;
+	tech->deflambda = newlambda;
 }
 
 /*
@@ -589,7 +636,7 @@ void db_scaletechnology(TECHNOLOGY *tech, INTBIG newlambda, INTBIG oldlambda)
  * to "newunits".  If "whichlib" is NOLIBRARY, change the entire database (all
  * libraries and technologies).
  */
-void changeinternalunits(LIBRARY *whichlib, INTSML oldunits, INTSML newunits)
+void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 {
 	REGISTER INTBIG hardscaleerror, softscaleerror, len;
 	INTBIG num, den;
@@ -725,29 +772,29 @@ void changeinternalunits(LIBRARY *whichlib, INTSML oldunits, INTSML newunits)
 	/* report any failures */
 	if (hardscaleerror != 0 || softscaleerror != 0)
 	{
-		if (den > num) errortype = "roundoff"; else
-			errortype = "overflow";
-		if (hardscaleerror == 0) errorlocation = "display"; else
+		if (den > num) errortype = _("roundoff"); else
+			errortype = _("overflow");
+		if (hardscaleerror == 0) errorlocation = _("display"); else
 		{
-			if (whichlib == NOLIBRARY) errorlocation = "database"; else
-				errorlocation = "library";
+			if (whichlib == NOLIBRARY) errorlocation = _("database"); else
+				errorlocation = _("library");
 		}
-		ttyputerr("Change caused %s errors in %s", errortype, errorlocation);
+		ttyputerr(_("Change caused %s errors in %s"), errortype, errorlocation);
 		if (hardscaleerror != 0)
 		{
 			if (whichlib == NOLIBRARY)
 			{
-				ttyputmsg("Recommend check of database for validity and keep old library files");
+				ttyputmsg(_("Recommend check of database for validity and keep old library files"));
 				for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 					lib->userbits &= ~READFROMDISK;
 			} else
 			{
-				ttyputmsg("Recommend check of database for validity and keep old library file");
+				ttyputmsg(_("Recommend check of database for validity and keep old library file"));
 				whichlib->userbits &= ~READFROMDISK;
 			}
 		} else
 		{
-			ttyputmsg("Recommend redisplay");
+			ttyputmsg(_("Recommend redisplay"));
 		}
 	}
 }
