@@ -145,7 +145,7 @@ void db_initclusters(void)
 
 	/* create the database cluster by hand since it is the first */
 	db_cluster = (CLUSTER *)LOWLEVELALLOC(sizeof (CLUSTER));
-	if (db_cluster == 0) error("Memory system cannot initialize");
+	if (db_cluster == 0) error(_("Memory system cannot initialize"));
 	db_cluster->clustersize = 0;
 	db_cluster->flags = CLUSTERFILLING;
 	(void)strcpy(db_cluster->clustername, "DATABASE");
@@ -290,8 +290,8 @@ void freecluster(CLUSTER *clus)
 		/* really don't need this check any more!!! */
 		if (count > db_clustercount+10)
 		{
-			ttyputerr("WARNING: freecluster loop, memory arena questionable");
-			ttyputerr(" Recommended action: save and quit");
+			ttyputerr(_("Warning: freecluster loop, memory arena questionable"));
+			ttyputerr(_(" Recommended action: save and quit"));
 			return;
 		}
 		lastclus = thisclus;
@@ -329,7 +329,7 @@ INTBIG *emalloc(INTBIG amount, CLUSTER *cluster)
 
 	if (cluster == NOCLUSTER)
 	{
-		ttyputerr("Warning: allocated %ld bytes from null cluster!", amount);
+		ttyputerr(_("Warning: allocated %ld bytes from null cluster!"), amount);
 		return((INTBIG *)LOWLEVELALLOC(amount));
 	}
 
@@ -509,7 +509,7 @@ void efree(char *addr)
 	ptr = (INTBIG *)addr;
 	if ((ptr[-1]&FLAGBITS) != USED)
 	{
-		error("Warning: freed block not properly allocated");
+		error(_("Warning: freed block not properly allocated"));
 		return;
 	}
 
@@ -561,10 +561,10 @@ void db_checkmemoryblock(char *addr)
 	botptr = (INTBIG *)addr;
 	endptr = (INTBIG *)(*botptr++);
 	if (*botptr != 0xC0CEC0CE)
-		ttyputerr("Error: Memory bottom bound overwritten (allocated from %s, line %ld)",
+		ttyputerr(_("Error: Memory bottom bound overwritten (allocated from %s, line %ld)"),
 			&endptr[2], endptr[1]);
 	if (*endptr != 0xC0CEC0CE)
-		ttyputerr("Error: Memory top bound overwritten (allocated from %s, line %ld)",
+		ttyputerr(_("Error: Memory top bound overwritten (allocated from %s, line %ld)"),
 			&endptr[2], endptr[1]);
 }
 
@@ -597,7 +597,7 @@ void db_checkcluster(CLUSTER *clus)
 						db_memerrio = fopen(errorfile, "w");
 					}
 					if (errors == 0)
-						fprintf(db_memerrio, "***Errors from cluster %s:\n", clus->clustername);
+						fprintf(db_memerrio, _("***Errors from cluster %s:\n"), clus->clustername);
 					errors++;
 					modulename = (char *)&endptr[2];
 					line = endptr[1];
@@ -605,7 +605,7 @@ void db_checkcluster(CLUSTER *clus)
 					for(i=0; i<20; i++) if (dataptr[i] < ' ' || dataptr[i] >= 0177) dataarray[i] = ' '; else
 						dataarray[i] = dataptr[i];
 					dataarray[20] = 0;
-					fprintf(db_memerrio, "  Block allocated from %s, line %ld ('%s': 0%o 0%o 0%o 0%o)\n", modulename, line,
+					fprintf(db_memerrio, _("  Block allocated from %s, line %ld ('%s': 0%o 0%o 0%o 0%o)\n"), modulename, line,
 						dataarray, dataptr[0]&0xFF, dataptr[1]&0xFF, dataptr[2]&0xFF, dataptr[3]&0xFF);
 				}
 
@@ -639,7 +639,7 @@ char *db_getmorememory(CLUSTER *clus, INTBIG size, INTBIG insert)
 	addr = db_getpages(size);
 	if (addr == 0)
 	{
-		error("Attempt to extend %s cluster for a %ld byte block failed",
+		error(_("Attempt to extend %s cluster for a %ld byte block failed"),
 			clus->clustername, size);
 		return(0);
 	}
@@ -710,7 +710,7 @@ char *db_getpages(INTBIG size)
 		if (size >= old_size || old_size == 1)
 		{
 			if (old_size != 1)
-				ttyputerr("Not able to allocate %ld byte from memory", size * db_pagesize); else
+				ttyputerr(_("Not able to allocate %ld byte from memory"), size * db_pagesize); else
 					ttyputerr("SAVE QUICKLY THERE IS NO MORE MEMORY!!");
 			return(0);
 		} else amount = size / 2;
@@ -723,7 +723,7 @@ char *db_getpages(INTBIG size)
 
 		for(;;)
 		{
-			if (pass == 0) ttyputerr("!! Memory Low !! Save soon !!");
+			if (pass == 0) ttyputerr(_("!! Memory Low !! Save soon !!"));
 			pass++;
 			amount /= 2;
 			if (size > amount)
@@ -732,7 +732,7 @@ char *db_getpages(INTBIG size)
 				addr = valloc((unsigned) (amount * db_pagesize));
 				if (addr == 0)
 				{
-					ttyputerr("!! No memory left !!");
+					ttyputerr(_("!! No memory left !!"));
 					old_size = amount;
 					old_status = 0;
 					return(0);
@@ -742,7 +742,7 @@ char *db_getpages(INTBIG size)
 			addr = valloc((unsigned) (amount * db_pagesize));
 			if (addr == 0) continue; else
 			{
-				ttyputerr("!! Only %ld bytes of memory left !!", amount * db_pagesize);
+				ttyputerr(_("!! Only %ld bytes of memory left !!"), amount * db_pagesize);
 				break;
 			}
 		}
@@ -758,7 +758,7 @@ char *db_getpages(INTBIG size)
 			for(i=1; i<db_sparepagecount; i++)
 				if (db_sparepages[i].pagecount < smallest)
 					smallest = db_sparepages[newcount = i].pagecount;
-			ttyputmsg("No room for spare page memory, deleting %ld blocks", smallest);
+			ttyputmsg(_("No room for spare page memory, deleting %ld blocks"), smallest);
 		} else
 		{
 			/* take a new entry in the table */
@@ -788,12 +788,12 @@ void db_printclusterarena(char *which)
 		freesize = usedsize = blocksused = 0;
 		for(clus=db_firstcluster; clus!=NOCLUSTER; clus=clus->nextcluster)
 			db_printoneclusterarena(clus, 0, &freesize, &usedsize, &blocksused);
-		ttyputmsg("%4d blocks%8d used%8d free    TOTAL", blocksused, usedsize, freesize);
+		ttyputmsg(_("%4d blocks%8d used%8d free    TOTAL"), blocksused, usedsize, freesize);
 
 		/* print spare pages summary */
-		if (db_sparepagecount == 0) ttyputmsg("NO spare pages"); else
+		if (db_sparepagecount == 0) ttyputmsg(_("NO spare pages")); else
 			for(i=0; i<db_sparepagecount; i++)
-				ttyputmsg("%ld spare pages in location %ld", db_sparepages[i].pagecount, i);
+				ttyputmsg(_("%ld spare pages in location %ld"), db_sparepages[i].pagecount, i);
 	} else
 	{
 		for(clus=db_firstcluster; clus!=NOCLUSTER; clus=clus->nextcluster)
@@ -803,10 +803,10 @@ void db_printclusterarena(char *which)
 			db_printoneclusterarena(clus, 1, &freesize, &usedsize, &blocksused);
 			return;
 		}
-		ttyputmsg("No cluster called %s", which);
+		ttyputmsg(_("No cluster called %s"), which);
 	}
 #else
-		ttyputmsg("Cluster option is not in use");
+		ttyputmsg(_("Cluster option is not in use"));
 #endif
 }
 
@@ -955,7 +955,7 @@ char *valloc(INTBIG nbytes)
 	page = getpagesize();
 	ptr = LOWLEVELALLOC(nbytes + page - 1);
 	if (ptr == 0) return(0);
-	return (char *)(((INTBIG)ptr + page -1) & ~(page-1));
+	return(char *)(((INTBIG)ptr + page -1) & ~(page-1));
 #  endif
 }
 #endif	/* HAVE_VALLOC */
