@@ -38,7 +38,7 @@
 #include "efunction.h"
 #include <math.h>
 
-       INTSML      tech_realpolys;					/* polygon count without displayable variables */
+       INTBIG      tech_realpolys;					/* polygon count without displayable variables */
 
 /* cached variables */
 static INTBIG     *tech_node_widoff = 0;			/* cache for "nodesizeoffset" */
@@ -73,6 +73,9 @@ void tech_initlayername(void);
 void tech_initarcwidthoffset(void);
 INTBIG tech_getdrcmindistance(TECHNOLOGY*, INTSML, INTSML, INTSML);
 void tech_3ddefaultlayerheight(TECHNOLOGY *tech);
+void tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy,
+	INTBIG lambda);
+INTBIG tech_arcprotowidthoffset(ARCPROTO *ap, INTBIG lambda);
 
 /*
  * Routine to free all memory associated with this module.
@@ -564,77 +567,105 @@ void db_inittechcache(void)
 
 /*
  * routine to report the number of distinct graphical polygons used to compose
- * primitive nodeinst "ni".
+ * primitive nodeinst "ni".  If "reasonable" is nonzero, it is loaded with
+ * a smaller number of polygons (when multicut contacts grow too large, then
+ * a reasonable number of polygons is returned instead of the true number).
  */
-INTSML nodepolys(NODEINST *ni)
+INTBIG nodepolys(NODEINST *ni, INTBIG *reasonable)
 {
-	REGISTER INTSML pindex, count;
+	REGISTER INTBIG pindex, count, reasonablecount, cutcount, displayablepolys;
+	INTBIG fewer;
 	TECH_NODES *thistn;
 	REGISTER NODEPROTO *np;
 
 	np = ni->proto;
 	pindex = np->primindex;
-	if (pindex == 0) return(0);
+	if (pindex == 0)
+	{
+		if (reasonable != 0) *reasonable = 0;
+		return(0);
+	}
 
 	/* if the technology has its own routine, use it */
 	if (np->tech->nodepolys != 0)
-		return((*(np->tech->nodepolys))(ni));
+	{
+		count = (*(np->tech->nodepolys))(ni, reasonable);
+		return(count);
+	}
 
 	thistn = np->tech->nodeprotos[pindex-1];
-	count = thistn->layercount;
+	reasonablecount = count = thistn->layercount;
 	switch (thistn->special)
 	{
 		case MULTICUT:
-			count += tech_moscutcount(ni, thistn->f1, thistn->f2, thistn->f3, thistn->f4) - 1;
+			cutcount = tech_moscutcount(ni, thistn->f1, thistn->f2, thistn->f3, thistn->f4, &fewer);
+			count += cutcount - 1;
+			reasonablecount += fewer - 1;
 			break;
 		case SERPTRANS:
-			count = tech_inittrans(count, ni);
+			reasonablecount = count = tech_inittrans(count, ni);
 			break;
 	}
 
 	/* zero the count if this node is not to be displayed */
-	if ((ni->userbits&WIPED) != 0) count = 0; else
+	if ((ni->userbits&WIPED) != 0) reasonablecount = count = 0; else
 	{
 		/* zero the count if this node erases when connected to 1 or 2 arcs */
 		if ((np->userbits&WIPEON1OR2) != 0)
 		{
-			if (tech_pinusecount(ni, NOARCPROTO) != 0) count = 0;
+			if (tech_pinusecount(ni, NOARCPROTO) != 0) reasonablecount = count = 0;
 		}
 	}
 
 	/* add in displayable variables */
 	tech_realpolys = count;
-	count += tech_displayablenvars(ni);
+	displayablepolys = tech_displayablenvars(ni);
+	count += displayablepolys;
+	reasonablecount += displayablepolys;
+	if (reasonable != 0) *reasonable = reasonablecount;
 	return(count);
 }
 
 /*
  * routine to report the number of distinct electrical polygons used to
- * compose primitive nodeinst "ni".
+ * compose primitive nodeinst "ni".  If "reasonable" is nonzero, it is loaded with
+ * a smaller number of polygons (when multicut contacts grow too large, then
+ * a reasonable number of polygons is returned instead of the true number).
  */
-INTSML nodeEpolys(NODEINST *ni)
+INTBIG nodeEpolys(NODEINST *ni, INTBIG *reasonable)
 {
-	REGISTER INTSML pindex, count;
+	REGISTER INTBIG pindex, count, reasonablecount, cutcount;
+	INTBIG fewer;
 	REGISTER TECH_NODES *thistn;
 
 	pindex = ni->proto->primindex;
-	if (pindex == 0) return(0);
+	if (pindex == 0)
+	{
+		if (reasonable != 0) *reasonable = 0;
+		return(0);
+	}
 
 	/* if the technology has its own routine, use it */
 	if (ni->proto->tech->nodeEpolys != 0)
-		return((*(ni->proto->tech->nodeEpolys))(ni));
+	{
+		count = (*(ni->proto->tech->nodeEpolys))(ni, reasonable);
+		return(count);
+	}
 
 	thistn = ni->proto->tech->nodeprotos[pindex-1];
-	count = thistn->layercount;
+	reasonablecount = count = thistn->layercount;
 	switch (thistn->special)
 	{
 		case MULTICUT:
-			count += tech_moscutcount(ni, thistn->f1, thistn->f2, thistn->f3, thistn->f4) - 1;
+			cutcount = tech_moscutcount(ni, thistn->f1, thistn->f2, thistn->f3, thistn->f4, &fewer);
+			count += cutcount - 1;
+			reasonablecount += fewer - 1;
 			break;
 		case SERPTRANS:
-			count = tech_inittrans((INTSML)thistn->f1, ni);
+			reasonablecount = count = tech_inittrans(thistn->f1, ni);
 			break;
 	}
+	if (reasonable != 0) *reasonable = reasonablecount;
 	return(count);
 }
 
@@ -642,11 +673,11 @@ INTSML nodeEpolys(NODEINST *ni)
  * routine to report the shape of graphical polygon "box" of primitive
  * nodeinst "ni".  The polygon is returned in "poly".
  */
-void shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	TECH_POLYGON *lay;
 	REGISTER TECH_PORTS *p;
-	REGISTER INTSML pindex, count;
+	REGISTER INTBIG pindex, count;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG lambda;
 	REGISTER TECH_NODES *thistn;
@@ -671,7 +702,7 @@ void shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 	}
 
 	thistn = np->tech->nodeprotos[pindex-1];
-	lambda = np->tech->deflambda;
+	lambda = lambdaofnode(ni);
 	switch (thistn->special)
 	{
 		case SERPTRANS:
@@ -685,7 +716,7 @@ void shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			if (box >= count)
 			{
 				lay = &thistn->layerlist[count];
-				tech_moscutpoly(ni, (INTSML)(box-count), lay->points);
+				tech_moscutpoly(ni, box-count, lay->points);
 				tech_fillpoly(poly, lay, ni, lambda, FILLED);
 				break;
 			}
@@ -703,10 +734,10 @@ void shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
  * routine to report the shape of electrical polygon "box" of primitive
  * nodeinst "ni".  The polygon is returned in "poly".
  */
-void shapeEnodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	TECH_POLYGON *lay;
-	REGISTER INTSML pindex, count;
+	REGISTER INTBIG pindex, count;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG lambda;
 	REGISTER TECH_NODES *thistn;
@@ -724,7 +755,7 @@ void shapeEnodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 	}
 
 	thistn = np->tech->nodeprotos[pindex-1];
-	lambda = np->tech->deflambda;
+	lambda = lambdaofnode(ni);
 	switch (thistn->special)
 	{
 		case MOSTRANS:
@@ -741,7 +772,7 @@ void shapeEnodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			if (box >= count)
 			{
 				lay = &thistn->layerlist[count];
-				tech_moscutpoly(ni, (INTSML)(box-count), lay->points);
+				tech_moscutpoly(ni, box-count, lay->points);
 				tech_fillpoly(poly, lay, ni, lambda, FILLED);
 				break;
 			}
@@ -780,16 +811,26 @@ void nodesizeoffset(NODEINST *ni, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy
 	}
 
 	/* use value from prototype */
-	nodeprotosizeoffset(ni->proto, lx, ly, hx, hy);
+	tech_nodeprotosizeoffset(ni->proto, lx, ly, hx, hy, lambdaofnode(ni));
 }
 
 /*
- * routine to report the acutal size offsets of nodeinst "ni".
+ * routine to report the acutal size offsets of node prototype "np".
  * This is not always obvious since the extent of a nodeinst is not
  * necessarily its size.  This routine accesses the "node_width_offset"
  * variable on the technology objects.
  */
 void nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy)
+{
+	tech_nodeprotosizeoffset(np, lx, ly, hx, hy, el_curlib->lambda[np->tech->techindex]);
+}
+
+/*
+ * support routine for "nodesizeoffset" and "nodeprotosizeoffset" to report
+ * the acutal size offsets of a node prototype.
+ */
+void tech_nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTBIG *hy,
+	INTBIG lambda)
 {
 	REGISTER INTBIG *base, addr;
 
@@ -807,10 +848,10 @@ void nodeprotosizeoffset(NODEPROTO *np, INTBIG *lx, INTBIG *ly, INTBIG *hx, INTB
 	if (addr == 0) return;
 
 	base = &((INTBIG *)addr)[(np->primindex-1)*4];
-	*lx = *base++ * np->tech->deflambda/WHOLE;
-	*hx = *base++ * np->tech->deflambda/WHOLE;
-	*ly = *base++ * np->tech->deflambda/WHOLE;
-	*hy = *base * np->tech->deflambda/WHOLE;
+	*lx = *base++ * lambda/WHOLE;
+	*hx = *base++ * lambda/WHOLE;
+	*ly = *base++ * lambda/WHOLE;
+	*hy = *base * lambda/WHOLE;
 }
 
 /*
@@ -1046,73 +1087,72 @@ char *nodefunctionname(INTSML fun, NODEINST *ni)
 	/* these must match the "define"s in "efunction.h" */
 	static char *nodefunname[] =
 	{
-		"unknown",						/* NPUNKNOWN */
-		"pin",							/* NPPIN */
-		"contact",						/* NPCONTACT */
-		"pure-layer-node",				/* NPNODE */
-		"connection",					/* NPCONNECT */
-		"nMOS-transistor",				/* NPTRANMOS */
-		"DMOS-transistor",				/* NPTRADMOS */
-		"PMOS-transistor",				/* NPTRAPMOS */
-		"NPN-transistor",				/* NPTRANPN */
-		"PNP-transistor",				/* NPTRAPNP */
-		"n-type-JFET-transistor",		/* NPTRANJFET */
-		"p-type-JFET-transistor",		/* NPTRAPJFET */
-		"depletion-mesfet",				/* NPTRADMES */
-		"enhancement-mesfet",			/* NPTRAEMES */
-		"dual-emitter-transistor",		/* NPTRANE2L */
-		"prototype-defined-transistor",	/* NPTRANSREF */
-		"transistor",					/* NPTRANS */
-		"resistor",						/* NPRESIST */
-		"capacitor",					/* NPCAPAC */
-		"electrolytic-capacitor",		/* NPECAPAC */
-		"diode",						/* NPDIODE */
-		"zener-diode",					/* NPDIODEZ */
-		"inductor",						/* NPINDUCT */
-		"meter",						/* NPMETER */
-		"base",							/* NPBASE */
-		"emitter",						/* NPEMIT */
-		"collector",					/* NPCOLLECT */
-		"buffer",						/* NPBUFFER */
-		"AND-gate",						/* NPGATEAND */
-		"OR-gate",						/* NPGATEOR */
-		"XOR-gate",						/* NPGATEXOR */
-		"flip-flop",					/* NPFLIPFLOP */
-		"multiplexor",					/* NPMUX */
-		"power",						/* NPCONPOWER */
-		"ground",						/* NPCONGROUND */
-		"source",						/* NPSOURCE */
-		"voltage-source",				/* NPSOURCEV */
-		"current-source",				/* NPSOURCEC */
-		"current-meter",				/* NPSOURCECM */
-		"transient-analysis",			/* NPSOURCET */
-		"DC-analysis",					/* NPSOURCEDC */
-		"AC-analysis",					/* NPSOURCEAC */
-		"nodeset-source",				/* NPSOURCEN */
-		"extension-source",				/* NPSOURCEX */
-		"bulk-source",					/* NPSOURCEB */
-		"special-source",				/* NPSOURCES */
-		"substrate",					/* NPSUBSTRATE */
-		"well",							/* NPWELL */
-		"artwork",						/* NPART */
-		"array",						/* NPARRAY */
-		"align",						/* NPALIGN */
-		"ccvs",							/* NPCCVS */
-		"cccs",							/* NPCCCS */
-		"vcvs",							/* NPVCVS */
-		"vccs",							/* NPVCCS */
-		"transmission-line"				/* NPTLINE */
+		N_("unknown"),						/* NPUNKNOWN */
+		N_("pin"),							/* NPPIN */
+		N_("contact"),						/* NPCONTACT */
+		N_("pure-layer-node"),				/* NPNODE */
+		N_("connection"),					/* NPCONNECT */
+		N_("nMOS-transistor"),				/* NPTRANMOS */
+		N_("DMOS-transistor"),				/* NPTRADMOS */
+		N_("PMOS-transistor"),				/* NPTRAPMOS */
+		N_("NPN-transistor"),				/* NPTRANPN */
+		N_("PNP-transistor"),				/* NPTRAPNP */
+		N_("n-type-JFET-transistor"),		/* NPTRANJFET */
+		N_("p-type-JFET-transistor"),		/* NPTRAPJFET */
+		N_("depletion-mesfet"),				/* NPTRADMES */
+		N_("enhancement-mesfet"),			/* NPTRAEMES */
+		N_("dual-emitter-transistor"),		/* NPTRANE2L */
+		N_("prototype-defined-transistor"),	/* NPTRANSREF */
+		N_("transistor"),					/* NPTRANS */
+		N_("resistor"),						/* NPRESIST */
+		N_("capacitor"),					/* NPCAPAC */
+		N_("electrolytic-capacitor"),		/* NPECAPAC */
+		N_("diode"),						/* NPDIODE */
+		N_("zener-diode"),					/* NPDIODEZ */
+		N_("inductor"),						/* NPINDUCT */
+		N_("meter"),						/* NPMETER */
+		N_("base"),							/* NPBASE */
+		N_("emitter"),						/* NPEMIT */
+		N_("collector"),					/* NPCOLLECT */
+		N_("buffer"),						/* NPBUFFER */
+		N_("AND-gate"),						/* NPGATEAND */
+		N_("OR-gate"),						/* NPGATEOR */
+		N_("XOR-gate"),						/* NPGATEXOR */
+		N_("flip-flop"),					/* NPFLIPFLOP */
+		N_("multiplexor"),					/* NPMUX */
+		N_("power"),						/* NPCONPOWER */
+		N_("ground"),						/* NPCONGROUND */
+		N_("source"),						/* NPSOURCE */
+		N_("voltage-source"),				/* NPSOURCEV */
+		N_("current-source"),				/* NPSOURCEC */
+		N_("current-meter"),				/* NPSOURCECM */
+		N_("transient-analysis"),			/* NPSOURCET */
+		N_("DC-analysis"),					/* NPSOURCEDC */
+		N_("AC-analysis"),					/* NPSOURCEAC */
+		N_("nodeset-source"),				/* NPSOURCEN */
+		N_("extension-source"),				/* NPSOURCEX */
+		N_("bulk-source"),					/* NPSOURCEB */
+		N_("special-source"),				/* NPSOURCES */
+		N_("substrate"),					/* NPSUBSTRATE */
+		N_("well"),							/* NPWELL */
+		N_("artwork"),						/* NPART */
+		N_("array"),						/* NPARRAY */
+		N_("align"),						/* NPALIGN */
+		N_("ccvs"),							/* NPCCVS */
+		N_("cccs"),							/* NPCCCS */
+		N_("vcvs"),							/* NPVCVS */
+		N_("vccs"),							/* NPVCCS */
+		N_("transmission-line")				/* NPTLINE */
 	};
 
 	if (fun == NPTRANSREF && ni != NONODEINST)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("Transistor-");
-		(void)addstringtoinfstr(ni->proto->primname);
+		(void)formatinfstr(_("Transistor-%s"), ni->proto->primname);
 		return(returninfstr());
 	}
 	if (fun < 0 || fun > NPTLINE) return("");
-	return(nodefunname[fun]);
+	return(_(nodefunname[fun]));
 }
 
 /*
@@ -1180,7 +1220,7 @@ void transistorsize(NODEINST *ni, INTBIG *length, INTBIG *width)
 				}
 
 				var = getvalkey((INTBIG)ni, VNODEINST, VFRACT, el_transistor_width);
-				if (var != NOVARIABLE) *length = var->addr * ni->proto->tech->deflambda/WHOLE; else
+				if (var != NOVARIABLE) *length = var->addr * lambdaofnode(ni)/WHOLE; else
 				{
 					nodesizeoffset(ni, &lx, &ly, &hx, &hy);
 					*length = ni->proto->highy-hy - (ni->proto->lowy+ly);
@@ -1229,7 +1269,7 @@ void transistorports(NODEINST *ni, PORTPROTO **gateleft, PORTPROTO **gateright,
 	if (*activetop == NOPORTPROTO) return;
 	*gateright = (*activetop)->nextportproto;
 	if ((*gateright)->nextportproto == NOPORTPROTO || nodefunction(ni, &dummy) == NPTRANPN ||
-		nodefunction(ni, &dummy) == NPTRAPNP )
+		nodefunction(ni, &dummy) == NPTRAPNP)
 	{
 		*activebottom = *gateright;
 		*gateright = NOPORTPROTO;
@@ -1345,8 +1385,7 @@ NODEPROTO *getpurelayernode(TECHNOLOGY *tech, INTBIG layer, INTBIG function)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *ni;
-	REGISTER INTSML i;
-	REGISTER INTBIG fun;
+	REGISTER INTBIG i, fun;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
@@ -1359,7 +1398,7 @@ NODEPROTO *getpurelayernode(TECHNOLOGY *tech, INTBIG layer, INTBIG function)
 	{
 		if (((np->userbits&NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
 		ni->proto = np;
-		i = nodepolys(ni);
+		i = nodepolys(ni, 0);
 		if (i != 1) continue;
 		shapenodepoly(ni, 0, poly);
 		if (layer >= 0)
@@ -1512,9 +1551,9 @@ INTSML portisground(PORTPROTO *pp)
  * routine to report the number of distinct polygons used to compose
  * primitive arcinst "ai".
  */
-INTSML arcpolys(ARCINST *ai)
+INTBIG arcpolys(ARCINST *ai)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER TECHNOLOGY *tech;
 
 	/* if the technology has its own routine, use it */
@@ -1541,7 +1580,7 @@ INTSML arcpolys(ARCINST *ai)
  * routine to describe polygon number "box" of arcinst "ai".  The description
  * is placed in the polygon "poly".
  */
-void shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
 	REGISTER INTSML pindex;
 	REGISTER ARCPROTO *ap;
@@ -1569,7 +1608,7 @@ void shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	if (box >= tech->arcprotos[pindex]->laycount) tech_makearrow(ai, poly); else
 	{
 		thista = &tech->arcprotos[pindex]->list[box];
-		makearcpoly(ai->length, ai->width-thista->off*tech->deflambda/WHOLE, ai, poly,
+		makearcpoly(ai->length, ai->width-thista->off*lambdaofarc(ai)/WHOLE, ai, poly,
 			thista->style);
 		poly->layer = thista->lay;
 		poly->desc = tech->layers[poly->layer];
@@ -1704,7 +1743,7 @@ INTBIG arcwidthoffset(ARCINST *ai)
 	if (ap->tech->nodesizeoffset != 0)
 		return((*(ap->tech->arcwidthoffset))(ai));
 
-	return(arcprotowidthoffset(ap));
+	return(tech_arcprotowidthoffset(ap, lambdaofarc(ai)));
 }
 
 /*
@@ -1713,6 +1752,15 @@ INTBIG arcwidthoffset(ARCINST *ai)
  * variable on the technology objects.
  */
 INTBIG arcprotowidthoffset(ARCPROTO *ap)
+{
+	return(tech_arcprotowidthoffset(ap, el_curlib->lambda[ap->tech->techindex]));
+}
+
+/*
+ * support routine for "arcwidthoffset()" and "arcprotowidthoffset()" to return the offset
+ * between the nominal width of arcproto "ap" and the actual width.
+ */
+INTBIG tech_arcprotowidthoffset(ARCPROTO *ap, INTBIG lambda)
 {
 	REGISTER INTBIG addr;
 
@@ -1725,7 +1773,7 @@ INTBIG arcprotowidthoffset(ARCPROTO *ap)
 
 	addr = tech_arc_widoff[ap->tech->techindex];
 	if (addr == 0) return(0);
-	return(((INTBIG *)addr)[ap->arcindex]*ap->tech->deflambda/WHOLE);
+	return(((INTBIG *)addr)[ap->arcindex]*lambda/WHOLE);
 }
 
 /*
@@ -1735,30 +1783,30 @@ char *arcfunctionname(INTSML fun)
 {
 	static char *arcfunname[] =
 	{
-		"unknown",				/* APUNKNOWN */
-		"metal-1",				/* APMETAL1 */
-		"metal-2",				/* APMETAL2 */
-		"metal-3",				/* APMETAL3 */
-		"metal-4",				/* APMETAL4 */
-		"metal-5",				/* APMETAL5 */
-		"metal-6",				/* APMETAL6 */
-		"metal-7",				/* APMETAL7 */
-		"metal-8",				/* APMETAL8 */
-		"polysilicon-1",		/* APPOLY1 */
-		"polysilicon-2",		/* APPOLY2 */
-		"polysilicon-3",		/* APPOLY3 */
-		"diffusion",			/* APDIFF */
-		"p-diffusion",			/* APDIFFP */
-		"n-diffusion",			/* APDIFFN */
-		"substrate-diffusion",	/* APDIFFS */
-		"well-diffusion",		/* APDIFFW */
-		"bus",					/* APBUS */
-		"unrouted",				/* APUNROUTED */
-		"nonelectrical"			/* APNONELEC */
+		N_("unknown"),				/* APUNKNOWN */
+		N_("metal-1"),				/* APMETAL1 */
+		N_("metal-2"),				/* APMETAL2 */
+		N_("metal-3"),				/* APMETAL3 */
+		N_("metal-4"),				/* APMETAL4 */
+		N_("metal-5"),				/* APMETAL5 */
+		N_("metal-6"),				/* APMETAL6 */
+		N_("metal-7"),				/* APMETAL7 */
+		N_("metal-8"),				/* APMETAL8 */
+		N_("polysilicon-1"),		/* APPOLY1 */
+		N_("polysilicon-2"),		/* APPOLY2 */
+		N_("polysilicon-3"),		/* APPOLY3 */
+		N_("diffusion"),			/* APDIFF */
+		N_("p-diffusion"),			/* APDIFFP */
+		N_("n-diffusion"),			/* APDIFFN */
+		N_("substrate-diffusion"),	/* APDIFFS */
+		N_("well-diffusion"),		/* APDIFFW */
+		N_("bus"),					/* APBUS */
+		N_("unrouted"),				/* APUNROUTED */
+		N_("nonelectrical")			/* APNONELEC */
 	};
 
 	if (fun < 0 || fun > APNONELEC) return("");
-	return(arcfunname[fun]);
+	return(_(arcfunname[fun]));
 }
 
 /******************** LAYER DESCRIPTION ********************/
@@ -2002,11 +2050,12 @@ INTBIG tech_getdrcmindistance(TECHNOLOGY *tech, INTSML layer1, INTSML layer2,
 }
 
 /*
- * routine to tell the maximum distance around layer "layer" that needs
- * to be looked at for design-rule checking.  This routine accesses the
+ * routine to tell the maximum distance around layer "layer" in
+ * technology "tech" that needs to be looked at for design-rule
+ * checking (using library "lib").  This routine accesses the
  * database variable "DRC_max_distances" in the technologies.
  */
-INTBIG maxdrcsurround(TECHNOLOGY *tech, INTSML layer)
+INTBIG maxdrcsurround(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer)
 {
 	REGISTER INTBIG i, addr;
 
@@ -2023,17 +2072,18 @@ INTBIG maxdrcsurround(TECHNOLOGY *tech, INTSML layer)
 	if (addr == 0) return(XX);
 	i = ((INTBIG *)addr)[layer];
 	if (i < 0) return(XX);
-	i = i*tech->deflambda/WHOLE;
+	i = i*lib->lambda[tech->techindex]/WHOLE;
 	return(i);
 }
 
 /*
  * routine to tell the minimum distance between two layers "layer1" and
- * "layer2".  If "connected" is zero, the two layers are not connected,
- * if it is nonzero, they are connected electrically.
+ * "layer2" in technology "tech".  If "connected" is zero, the two layers
+ * are not connected, if it is nonzero, they are connected electrically.
+ * The layers reside in library "lib".
  * A negative return means that the two layers can overlap.
  */
-INTBIG drcmindistance(TECHNOLOGY *tech, INTSML layer1, INTSML layer2, INTSML connected)
+INTBIG drcmindistance(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer1, INTSML layer2, INTSML connected)
 {
 	REGISTER INTBIG i;
 
@@ -2041,14 +2091,15 @@ INTBIG drcmindistance(TECHNOLOGY *tech, INTSML layer1, INTSML layer2, INTSML con
 	i = tech_getdrcmindistance(tech, layer1, layer2, connected);
 
 	/* scale result for current lambda value */
-	if (i > 0) i = i * tech->deflambda / WHOLE;
+	if (i > 0) i = i * lib->lambda[tech->techindex] / WHOLE;
 	return(i);
 }
 
 /*
- * routine to return the minimum width of layer "layer" in technology "tech".
+ * routine to return the minimum width of layer "layer" in technology "tech", given
+ * that it appears in library "lib".
  */
-INTBIG drcminwidth(TECHNOLOGY *tech, INTSML layer)
+INTBIG drcminwidth(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer)
 {
 	REGISTER INTBIG addr;
 
@@ -2061,7 +2112,7 @@ INTBIG drcminwidth(TECHNOLOGY *tech, INTSML layer)
 
 	addr = tech_drcminwidth[tech->techindex];
 	if (addr == 0) return(XX);
-	return(((INTBIG *)addr)[layer]*tech->deflambda/WHOLE);
+	return(((INTBIG *)addr)[layer]*lib->lambda[tech->techindex]/WHOLE);
 }
 
 /******************** MATHEMATICS ********************/
