@@ -31,6 +31,7 @@
 #include "global.h"
 #include "database.h"
 #include "egraphics.h"
+#include "edialogs.h"
 #include "usr.h"
 #include <time.h>
 #ifdef TM_IN_SYS_TIME
@@ -65,25 +66,40 @@ INTSML db_descapoutputsize[2] = {0, 0};
 
 /* working memory for "makeplural()" */
 static INTBIG db_pluralbufsize = 0;
-static char *db_pluralbuffer;
+static char  *db_pluralbuffer;
+
+/* working memory for types of files */
+typedef struct
+{
+	char  *extension;
+	char  *winfilter;
+	INTBIG mactype;
+	INTBIG binary;
+	char  *shortname;
+	char  *longname;
+} FILETYPES;
+
+static INTBIG     db_filetypecount = 0;
+static FILETYPES *db_filetypeinfo;
 
 /* the infinite string package */
-#define	INFSTRCOUNT     5	/* number of infinite strings */
-#define	INFSTRDEFAULT 200	/* default infinite string length */
+#define	INFSTRCOUNT     8			/* number of infinite strings */
+#define	INFSTRDEFAULT 200			/* default infinite string length */
 #define	NOINFSTR ((INFSTR *)-1)
 typedef struct
 {
-	char *infstr;		/* the string address */
-	INTBIG infstrlength;		/* the length of the string */
-	INTBIG infstrptr;		/* the location of the string end */
+	char  *infstr;					/* the string address */
+	INTBIG infstrlength;			/* the length of the string */
+	INTBIG infstrptr;				/* the location of the string end */
+	INTBIG infstrinuse;				/* nonzero if in use */
 } INFSTR;
 
-INFSTR db_infstrstack[INFSTRCOUNT];	/* a stack of infinite strings */
-INFSTR *db_curinf = NOINFSTR;	/* the current infinite string */
-INTBIG db_infstrstackbase;	/* base position of the stack in the list */
-INTBIG db_infstrstackpos;	/* position within the stack */
-INTBIG db_infstrdeepeststack;	/* deepest amount of stacking */
-INTSML db_firstinf = 0;		/* initialization flag */
+INFSTR  db_infstrings[INFSTRCOUNT];	/* a stack of infinite strings */
+INFSTR *db_infstrstackptr[INFSTRCOUNT];/* a stack of infinite strings */
+INFSTR *db_curinf = NOINFSTR;		/* the current infinite string */
+INTBIG  db_infstrpointer;			/* base position of the stack in the list */
+INTBIG  db_infstrstackpos;			/* position within the stack */
+INTSML  db_firstinf = 0;			/* initialization flag */
 
 /* prototypes for local routines */
 INTSML db_beginsearch(char**);
@@ -104,7 +120,7 @@ void db_freetextmemory(void)
 	if (db_keywordbufferlength != 0) efree(db_keywordbuffer);
 	if (db_tryfilenamelen != 0) efree(db_tryfilename);
 	for(i=0; i<INFSTRCOUNT; i++)
-		efree((char *)db_infstrstack[i].infstr);
+		efree((char *)db_infstrings[i].infstr);
 
 	for(i=0; i<2; i++)
 		if (db_descnpoutputsize[i] != 0) efree(db_descnpoutput[i]);
@@ -114,6 +130,16 @@ void db_freetextmemory(void)
 		if (db_descaioutputsize[i] != 0) efree(db_descaioutput[i]);
 	for(i=0; i<2; i++)
 		if (db_descapoutputsize[i] != 0) efree(db_descapoutput[i]);
+
+	/* free file type memory */
+	for(i=0; i<db_filetypecount; i++)
+	{
+		efree((char *)db_filetypeinfo[i].extension);
+		efree((char *)db_filetypeinfo[i].winfilter);
+		efree((char *)db_filetypeinfo[i].shortname);
+		efree((char *)db_filetypeinfo[i].longname);
+	}
+	if (db_filetypecount > 0) efree((char *)db_filetypeinfo);
 }
 
 /************************* STRING PARSING *************************/
@@ -126,8 +152,8 @@ void db_freetextmemory(void)
  */
 INTBIG atola(char *pp)
 {
-	REGISTER INTBIG hipart, lonum, loden, retval;
-	REGISTER INTSML neg, units;
+	REGISTER INTBIG hipart, lonum, loden, retval, units;
+	REGISTER INTSML neg;
 	REGISTER char *ptr;
 	double scale;
 
@@ -155,8 +181,8 @@ INTBIG atola(char *pp)
 	if (ptr[0] == 'm' && ptr[1] == 'u') units = (units & ~DISPLAYUNITS) | DISPUNITMMIC;
 
 	/* convert to database units */
-	scale = db_getcurrentscale((INTSML)(el_units&INTERNALUNITS), units);
-	retval = rounddouble( ((double)hipart) * scale + ((double)lonum)*scale / ((double)loden) );
+	scale = db_getcurrentscale(el_units&INTERNALUNITS, units);
+	retval = rounddouble(((double)hipart) * scale + ((double)lonum)*scale / ((double)loden));
 	return(retval*neg);
 }
 
@@ -339,7 +365,7 @@ NODEPROTO *getnodeproto(char *initline)
  * routine to find cell "cellname".  Returns NOCELL if it cannot be found
  */
 static COMCOMP db_cellp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
-	NOBACKUP, 0, " \t", "cell", 0};
+	NOBACKUP, 0, " \t", M_("cell"), 0};
 CELL *getcell(char *cellname)
 {
 	REGISTER INTSML i, j;
@@ -357,7 +383,7 @@ CELL *getcell(char *cellname)
  * be found
  */
 static COMCOMP db_technologyp = {NOKEYWORD, topoftechs, nexttechs, NOPARAMS,
-	NOBACKUP, 0, " \t", "technology", 0};
+	NOBACKUP, 0, " \t", M_("technology"), 0};
 TECHNOLOGY *gettechnology(char *techname)
 {
 	REGISTER INTSML i;
@@ -374,7 +400,7 @@ TECHNOLOGY *gettechnology(char *techname)
  * routine to find view "viewname".  Returns NOVIEW if it cannot be found
  */
 static COMCOMP db_viewp = {NOKEYWORD, topofviews, nextviews, NOPARAMS,
-	NOBACKUP, 0, " \t", "view", 0};
+	NOBACKUP, 0, " \t", M_("view"), 0};
 VIEW *getview(char *viewname)
 {
 	REGISTER INTSML i, j;
@@ -575,7 +601,7 @@ INTSML parse(char *keyword, COMCOMP *list, INTSML noise)
 	/* if nothing found, give an error */
 	if (i == 0)
 	{
-		if (noise != 0) ttyputerr("Unknown command: %s", keyword);
+		if (noise != 0) ttyputerr(_("Unknown command: %s"), keyword);
 		return(-1);
 	}
 
@@ -594,7 +620,7 @@ INTSML parse(char *keyword, COMCOMP *list, INTSML noise)
 			(void)addtoinfstr(' ');
 			(void)addstringtoinfstr(pp);
 		}
-		ttyputerr("%s ambiguous:%s", keyword, returninfstr());
+		ttyputerr(_("%s ambiguous:%s"), keyword, returninfstr());
 	}
 	return(-1);
 }
@@ -1050,6 +1076,7 @@ char *describenodeproto(NODEPROTO *np)
 	} else
 	{
 		/* compute size of buffer */
+		if (np->cell->cellname == 0) return("***BOGUS***");
 		len = strlen(np->cell->cellname) + 1;
 		if (np->cell->lib != el_curlib) len += strlen(np->cell->lib->libname) + 1;
 		if (np->newestversion != np)
@@ -1136,7 +1163,7 @@ char *geomname(GEOM *geom)
 	if (geom == NOGEOM) return("***NOGEOM***");
 	if (geom->entrytype == OBJNODEINST) return(describenodeinst(geom->entryaddr.ni));
 	if (geom->entrytype == OBJARCINST) return(describearcinst(geom->entryaddr.ai));
-	return("dummy");
+	return(_("dummy"));
 }
 
 /*
@@ -1145,11 +1172,16 @@ char *geomname(GEOM *geom)
 char *describenetwork(NETWORK *net)
 {
 	REGISTER char *pt;
+	static char gennetname[50];
 	REGISTER INTSML i;
 
 	if (net == NONETWORK) return("***NONETWORK***");
 
-	if (net->namecount == 0) return("");
+	if (net->namecount == 0)
+	{
+		sprintf(gennetname, _("UNNAMED%ld"), (INTBIG)net);
+		return(gennetname);
+	}
 	if (net->namecount == 1) return(net->netname);
 
 	(void)initinfstr();
@@ -1179,7 +1211,7 @@ char *latoa(INTBIG i)
 	if (latoaswitch >= OUTBUFS) latoaswitch = 0;
 
 	/* determine scaling */
-	scale = db_getcurrentscale((INTSML)(el_units&INTERNALUNITS), (INTSML)(el_units&DISPLAYUNITS));
+	scale = db_getcurrentscale(el_units&INTERNALUNITS, el_units&DISPLAYUNITS);
 	number = ((double)i) / scale;
 	(void)sprintf(cur, "%g", number);
 
@@ -1236,32 +1268,6 @@ char *frtoa(INTBIG i)
 	return(start);
 }
 
-/*
- * routine to convert "word" to its plural form, depending on the value
- * of "amount" (if "amount" is zero or multiple, pluralize the word).
- */
-char *makeplural(char *word, INTBIG amount)
-{
-	INTBIG needed, len;
-
-	if (amount == 1) return(word);
-	len = strlen(word);
-	if (len == 0) return(word);
-	needed = len + 2;
-	if (needed > db_pluralbufsize)
-	{
-		if (db_pluralbufsize > 0) efree(db_pluralbuffer);
-		db_pluralbufsize = 0;
-		db_pluralbuffer = (char *)emalloc(needed, db_cluster);
-		if (db_pluralbuffer == 0) return(word);
-		db_pluralbufsize = needed;
-	}
-	strcpy(db_pluralbuffer, word);
-	if (isupper(word[len-1])) strcat(db_pluralbuffer, "S"); else
-		strcat(db_pluralbuffer, "s");
-	return(db_pluralbuffer);
-}
-
 /*
  * routine to determine whether or not the string in "pp" is a number.
  * Returns nonzero if it is.
@@ -1313,7 +1319,8 @@ INTSML isanumber(char *pp)
 INTSML truefontsize(INTSML font, WINDOWPART *w, TECHNOLOGY *tech)
 {
 	REGISTER INTSML inifont, minf, maxf;
-	REGISTER INTBIG pixper10lam;
+	REGISTER INTBIG pixper10lam, lambda;
+	REGISTER LIBRARY *lib;
 
 	/* absolute fonts need no adjustment */
 	if ((font >= TXT4P && font <= TXT20P) || font >= TXTEDITOR) return(font);
@@ -1322,14 +1329,17 @@ INTSML truefontsize(INTSML font, WINDOWPART *w, TECHNOLOGY *tech)
 	switch (font)
 	{
 		case TXTSMALL:  inifont = TXT10P;  minf = TXT4P;  maxf = TXT16P;  break;
-		default:        ttyputmsg("Warning: font size is %d", font);
+		default:        ttyputmsg(_("Warning: font size is %d"), font);
 		case TXTMEDIUM: inifont = TXT14P;  minf = TXT6P;  maxf = TXT18P;  break;
 		case TXTLARGE:  inifont = TXT16P;  minf = TXT8P;  maxf = TXT20P;  break;
 	}
 	if (w == NOWINDOWPART) return(inifont);
 
 	/* determine scale of this window */
-	pixper10lam = applyxscale(w, tech->deflambda*10);
+	if (w->curnodeproto == NONODEPROTO) lib = el_curlib; else
+		lib = w->curnodeproto->cell->lib;
+	lambda = lib->lambda[tech->techindex];
+	pixper10lam = applyxscale(w, lambda*10);
 
 	/* shrink down as window gets tight */
 	if (pixper10lam < IDEALPIXPER10LAM)
@@ -1526,7 +1536,8 @@ INTBIG defaulttextdescript(GEOM *geom)
  */
 char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 {
-	REGISTER INTSML err, i, len;
+	REGISTER INTSML err;
+	REGISTER INTBIG i, len;
 
 	if (var == NOVARIABLE)
 	{
@@ -1565,7 +1576,7 @@ char *describevariable(VARIABLE *var, INTSML aindex, INTSML purpose)
 		if ((var->type&VISARRAY) != 0)
 		{
 			/* compute the array length */
-			len = (INTSML)getlength(var);
+			len = getlength(var);
 
 			/* if asking for a single entry, get it */
 			if (aindex >= 0)
@@ -1687,6 +1698,7 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 	REGISTER VARIABLE *var;
 	REGISTER CONSTRAINT *con;
 	REGISTER WINDOWFRAME *wf;
+	REGISTER POLYGON *poly;
 
 	switch (type&VTYPE)
 	{
@@ -1728,8 +1740,8 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 			return(addstringtoinfstr(line));
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
-			if (purpose <= 0) return(addstringtoinfstr(describenodeproto(np))); else
-				return(db_addstring(describenodeproto(np)));
+			if (purpose <= 0) return(addstringtoinfstr(describenodeproto(np)));
+			return(db_addstring(describenodeproto(np)));
 		case VPORTARCINST:
 			pi = (PORTARCINST *)addr;
 			if (pi == NOPORTARCINST) return(addstringtoinfstr("***NOPORTARCINST***"));
@@ -1743,8 +1755,8 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 		case VPORTPROTO:
 			pp = (PORTPROTO *)addr;
 			if (pp == NOPORTPROTO) return(addstringtoinfstr("***NOPORTPROTO***"));
-			if (purpose <= 0) return(addstringtoinfstr(pp->protoname)); else
-				return(db_addstring(pp->protoname));
+			if (purpose <= 0) return(addstringtoinfstr(pp->protoname));
+			return(db_addstring(pp->protoname));
 		case VARCINST:
 			ai = (ARCINST *)addr;
 			if (ai == NOARCINST) return(addstringtoinfstr("***NOARCINST***"));
@@ -1752,8 +1764,8 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 			return(addstringtoinfstr(line));
 		case VARCPROTO:
 			ap = (ARCPROTO *)addr;
-			if (purpose <= 0) return(addstringtoinfstr(describearcproto(ap))); else
-				return(db_addstring(describearcproto(ap)));
+			if (purpose <= 0) return(addstringtoinfstr(describearcproto(ap)));
+			return(db_addstring(describearcproto(ap)));
 		case VGEOM:
 			geom = (GEOM *)addr;
 			if (geom == NOGEOM) return(addstringtoinfstr("***NOGEOM***"));
@@ -1762,18 +1774,18 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 		case VLIBRARY:
 			lib = (LIBRARY *)addr;
 			if (lib == NOLIBRARY) return(addstringtoinfstr("***NOLIBRARY***"));
-			if (purpose <= 0) return(addstringtoinfstr(lib->libname)); else
-				return(db_addstring(lib->libname));
+			if (purpose <= 0) return(addstringtoinfstr(lib->libname));
+			return(db_addstring(lib->libname));
 		case VTECHNOLOGY:
 			tech = (TECHNOLOGY *)addr;
 			if (tech == NOTECHNOLOGY) return(addstringtoinfstr("***NOTECHNOLOGY***"));
-			if (purpose <= 0) return(addstringtoinfstr(tech->techname)); else
-				return(db_addstring(tech->techname));
+			if (purpose <= 0) return(addstringtoinfstr(tech->techname));
+			return(db_addstring(tech->techname));
 		case VAID:
 			aid = (AIDENTRY *)addr;
 			if (aid == NOAID) return(addstringtoinfstr("***NOAID***"));
-			if (purpose <= 0) return(addstringtoinfstr(aid->aidname)); else
-				return(db_addstring(aid->aidname));
+			if (purpose <= 0) return(addstringtoinfstr(aid->aidname));
+			return(db_addstring(aid->aidname));
 		case VRTNODE:
 			rtn = (RTNODE *)addr;
 			if (rtn == NORTNODE) return(addstringtoinfstr("***NORTNODE***"));
@@ -1784,28 +1796,23 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 		case VNETWORK:
 			net = (NETWORK *)addr;
 			if (net == NONETWORK) return(addstringtoinfstr("***NONETWORK***"));
-			if (net->namecount != 0)
-			{
-				if (purpose <= 0) return(addstringtoinfstr(describenetwork(net))); else
-					return(db_addstring(describenetwork(net)));
-			}
-			(void)sprintf(line, "network%ld", (INTBIG)net);
-			return(addstringtoinfstr(line));
+			if (purpose <= 0) return(addstringtoinfstr(describenetwork(net)));
+			return(db_addstring(describenetwork(net)));
 		case VCELL:
 			cell = (CELL *)addr;
 			if (cell == NOCELL) return(addstringtoinfstr("***NOCELL***"));
-			if (purpose <= 0) return(addstringtoinfstr(cell->cellname)); else
-				return(db_addstring(cell->cellname));
+			if (purpose <= 0) return(addstringtoinfstr(cell->cellname));
+			return(db_addstring(cell->cellname));
 		case VVIEW:
 			view = (VIEW *)addr;
 			if (view == NOVIEW) return(addstringtoinfstr("***NOVIEW***"));
-			if (purpose <= 0) return(addstringtoinfstr(view->viewname)); else
-				return(db_addstring(view->viewname));
+			if (purpose <= 0) return(addstringtoinfstr(view->viewname));
+			return(db_addstring(view->viewname));
 		case VWINDOWPART:
 			win = (WINDOWPART *)addr;
 			if (win == NOWINDOWPART) return(addstringtoinfstr("***NOWINDOWPART***"));
-			if (purpose <= 0) return(addstringtoinfstr(win->location)); else
-				return(db_addstring(win->location));
+			if (purpose <= 0) return(addstringtoinfstr(win->location));
+			return(db_addstring(win->location));
 		case VGRAPHICS:
 			gra = (GRAPHICS *)addr;
 			if (gra == NOGRAPHICS) return(addstringtoinfstr("***NOGRAPHICS***"));
@@ -1817,8 +1824,8 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 		case VCONSTRAINT:
 			con = (CONSTRAINT *)addr;
 			if (con == NOCONSTRAINT) return(addstringtoinfstr("***NOCONSTRAINT***"));
-			if (purpose <= 0) return(addstringtoinfstr(con->conname)); else
-				return(db_addstring(con->conname));
+			if (purpose <= 0) return(addstringtoinfstr(con->conname));
+			return(db_addstring(con->conname));
 		case VGENERAL:
 			(void)sprintf(line, "***%ld-LONG-GENERAL-ARRAY***", ((type&VLENGTH)>>VLENGTHSH) / 2);
 			return(addstringtoinfstr(line));
@@ -1827,6 +1834,11 @@ INTSML db_makestringvar(INTBIG type, INTBIG addr, INTSML purpose)
 			if (wf == NOWINDOWFRAME) return(addstringtoinfstr("***NOWINDOWFRAME***"));
 			(void)sprintf(line, "wf%ld", (INTBIG)wf);
 			return(addstringtoinfstr(line));
+		case VPOLYGON:
+			poly = (POLYGON *)addr;
+			if (poly == NOPOLYGON) return(addstringtoinfstr("***NOPOLYGON***"));
+			(void)sprintf(line, "poly%ld", (INTBIG)poly);
+			return(addstringtoinfstr(line));
 	}
 	return(0);
 }
@@ -1881,16 +1893,277 @@ char *makeabbrev(char *pt, INTSML upper)
 /*
  * routine to report the name of the internal unit in "units".
  */
-char *unitsname(INTSML units)
+char *unitsname(INTBIG units)
 {
 	switch (units & INTERNALUNITS)
 	{
-		case INTUNITHMMIC:   return("half-millimicron");
-		case INTUNITHDMIC:   return("half-decimicron");
+		case INTUNITHMMIC:   return(_("half-millimicron"));
+		case INTUNITHDMIC:   return(_("half-decimicron"));
 	}
 	return("?");
 }
 
+/************************* INTERNATIONALIZATION *************************/
+
+#ifdef MACOS
+	extern DIALOG gra_fontdialog;
+#endif
+#ifdef WIN32
+	extern DIALOG db_severeerrordialog, gra_sesplaydialog;
+#endif
+#ifdef ONUNIX
+	extern DIALOG db_severeerrordialog, gra_sesplaydialog, gra_xfontdialog,
+		gra_fileindialog, gra_fileoutdialog;
+#endif
+#if DRCAID
+	extern DIALOG dr_optionsdialog, dr_hierdialog, dr_errdialog;
+#endif
+#if COMAID
+	extern DIALOG com_optionsdialog;
+#endif
+#if COMPENAID
+	extern DIALOG compen_factorsdialog;
+#endif
+#if ERCAID
+	extern DIALOG erc_optionsdialog;
+#endif
+#if LOGEFFAID
+	extern DIALOG le_leoptionsdialog, le_capacitancedialog, le_logeffortdialog;
+#endif
+#if PROJECTAID
+	extern DIALOG proj_usersdialog, proj_passworddialog, proj_listdialog,
+		proj_commentsdialog, proj_oldversdialog;
+#endif
+#if ROUTAID
+	extern DIALOG ro_optionsdialog;
+#endif
+#if SCAID
+	extern DIALOG sc_optionsdialog;
+#endif
+#if SIMAID
+	extern DIALOG sim_optionsdialog, sim_alsclockdialog, sim_spiceoptdialog,
+		sim_verilogoptdialog, sim_fasthenrydialog, sim_fasthenryarcdialog;
+#endif
+#if VHDLAID
+	extern DIALOG vhdl_optionsdialog;
+#endif
+	extern DIALOG db_undodialog,
+#if IOCIF
+	io_cifoptionsdialog,
+#endif
+#if IODEF
+	io_defoptionsdialog,
+#endif
+#if IODXF
+	io_dxfoptionsdialog,
+#endif
+#if IOEDIF
+	io_edifoptionsdialog,
+#endif
+#if IOGDS
+	io_gdsoptionsdialog,
+#endif
+#if IOSKILL
+	io_skilloptionsdialog,
+#endif
+	net_optionsdialog, io_techadjlamdialog, io_liboptdialog,
+	us_movetodialog, us_eprogressdialog, us_progressdialog, us_3ddepthdialog,
+	us_aboutgnudialog, us_alignmentdialog, us_defarcdialog, us_arcsizedialog,
+	us_arraydialog, us_artworkdialog, us_patterndialog, us_attrdialog,
+	us_changedialog, us_noyesdialog, us_yesnodialog, us_noyesalwaysdialog,
+	us_okmessagedialog, us_colormixdialog, us_menuposdialog, us_createtodialog,
+	us_copyfacetdialog, us_editfacetdialog, us_newfacetdialog, us_facetlistdialog,
+	us_facetdialog, us_drawingoptdialog, us_multigetinfodialog, us_shownodedialog,
+	us_showarcdialog, us_showtextdialog, us_portinfodialog, us_griddialog,
+	us_helpdialog, us_iconoptdialog, us_highlightlayerdialog, us_librarypathdialog,
+	us_chglibrarydialog, us_annringdialog, us_spelldialog, us_defnodedialog,
+	us_resistancedialog, us_capacitancedialog, us_inductancedialog, us_vccsdialog,
+	us_areadialog, us_widlendialog, us_gaindialog, us_sourcedialog,
+	us_nodesizedialog, us_optionsavingdialog, us_outlinedialog, us_portdialog,
+	us_portdisplaydialog, us_printingoptdialog, us_quickkeydialog, us_quitdialog,
+	us_rendialog, us_seloptdialog, us_selnamedialog, us_spreaddialog,
+	us_tecedlibtotechdialog, us_dependentlibdialog, us_techvarsdialog,
+	us_techselectdialog, us_techsetdialog, us_deftextdialog, us_unitsdialog,
+	us_variabledialog, us_newviewdialog, us_visiblelaydialog, us_windowviewdialog,
+	us_listdialog, us_ttyinputdialog, us_ttyfulldialog, us_purelayerdialog;
+
+
+DIALOG *db_alldialogs[] =
+{
+#ifdef MACOS
+	&gra_fontdialog,
+#endif
+#ifdef WIN32
+	&db_severeerrordialog, &gra_sesplaydialog,
+#endif
+#ifdef ONUNIX
+	&db_severeerrordialog, &gra_sesplaydialog, &gra_xfontdialog, &gra_fileindialog, &gra_fileoutdialog,
+#endif
+#if DRCAID
+	&dr_optionsdialog, &dr_hierdialog, &dr_errdialog,
+#endif
+#if COMAID
+	&com_optionsdialog,
+#endif
+#if COMPENAID
+	&compen_factorsdialog,
+#endif
+#if ERCAID
+	&erc_optionsdialog,
+#endif
+#if LOGEFFAID
+	&le_leoptionsdialog, &le_capacitancedialog, &le_logeffortdialog,
+#endif
+#if PROJECTAID
+	&proj_usersdialog, &proj_passworddialog, &proj_listdialog, &proj_commentsdialog, &proj_oldversdialog,
+#endif
+#if ROUTAID
+	&ro_optionsdialog,
+#endif
+#if SCAID
+	&sc_optionsdialog,
+#endif
+#if SIMAID
+	&sim_optionsdialog, &sim_alsclockdialog, &sim_spiceoptdialog, &sim_verilogoptdialog,
+	&sim_fasthenrydialog, &sim_fasthenryarcdialog,
+#endif
+#if VHDLAID
+	&vhdl_optionsdialog,
+#endif
+	&db_undodialog,
+#if IOCIF
+	&io_cifoptionsdialog,
+#endif
+#if IODEF
+	&io_defoptionsdialog,
+#endif
+#if IODXF
+	&io_dxfoptionsdialog,
+#endif
+#if IOEDIF
+	&io_edifoptionsdialog,
+#endif
+#if IOGDS
+	&io_gdsoptionsdialog,
+#endif
+#if IOSKILL
+	&io_skilloptionsdialog,
+#endif
+	&net_optionsdialog, &io_techadjlamdialog, &io_liboptdialog, &us_purelayerdialog,
+	&us_movetodialog, &us_eprogressdialog, &us_progressdialog, &us_3ddepthdialog, &us_aboutgnudialog,
+	&us_alignmentdialog, &us_defarcdialog, &us_arcsizedialog, &us_arraydialog, &us_artworkdialog,
+	&us_patterndialog, &us_attrdialog, &us_changedialog, &us_noyesdialog, &us_yesnodialog, &us_noyesalwaysdialog,
+	&us_okmessagedialog, &us_colormixdialog, &us_menuposdialog, &us_createtodialog, &us_copyfacetdialog,
+	&us_editfacetdialog, &us_newfacetdialog, &us_facetlistdialog, &us_facetdialog, &us_drawingoptdialog,
+	&us_multigetinfodialog, &us_shownodedialog, &us_showarcdialog, &us_showtextdialog, &us_portinfodialog,
+	&us_griddialog, &us_helpdialog, &us_iconoptdialog, &us_highlightlayerdialog, &us_librarypathdialog,
+	&us_chglibrarydialog, &us_annringdialog, &us_spelldialog, &us_defnodedialog, &us_resistancedialog,
+	&us_capacitancedialog, &us_inductancedialog, &us_vccsdialog, &us_areadialog, &us_widlendialog,
+	&us_gaindialog, &us_sourcedialog, &us_nodesizedialog, &us_optionsavingdialog, &us_outlinedialog,
+	&us_portdialog, &us_portdisplaydialog, &us_printingoptdialog, &us_quickkeydialog, &us_quitdialog,
+	&us_rendialog, &us_seloptdialog, &us_selnamedialog, &us_spreaddialog, &us_tecedlibtotechdialog,
+	&us_dependentlibdialog, &us_techvarsdialog, &us_techselectdialog, &us_techsetdialog, &us_deftextdialog,
+	&us_unitsdialog, &us_variabledialog, &us_newviewdialog, &us_visiblelaydialog, &us_windowviewdialog,
+	&us_listdialog, &us_ttyinputdialog, &us_ttyfulldialog,
+0};
+
+char *db_stoppingreason[] =
+{
+	N_("Contour gather"),		/* STOPREASONCONTOUR */
+	N_("DRC"),					/* STOPREASONDRC */
+	N_("Playback"),				/* STOPREASONPLAYBACK */
+	N_("Binary"),				/* STOPREASONBINARY */
+	N_("CIF"),					/* STOPREASONCIF */
+	N_("DXF"),					/* STOPREASONDXF */
+	N_("EDIF"),					/* STOPREASONEDIF */
+	N_("VHDL"),					/* STOPREASONVHDL */
+	N_("Compaction"),			/* STOPREASONCOMPACT */
+	N_("ERC"),					/* STOPREASONERC */
+	N_("Check-in"),				/* STOPREASONCHECKIN */
+	N_("Lock wait"),			/* STOPREASONLOCK */
+	N_("Network comparison"),	/* STOPREASONNCC */
+	N_("Port exploration"),		/* STOPREASONPORT */
+	N_("Routing"),				/* STOPREASONROUTING */
+	N_("Silicon compiler"),		/* STOPREASONSILCOMP */
+	N_("Display"),				/* STOPREASONDISPLAY */
+	N_("Simulation"),			/* STOPREASONSIMULATE */
+	N_("Deck generation"),		/* STOPREASONDECK */
+	N_("SPICE"),				/* STOPREASONSPICE */
+	N_("Check"),				/* STOPREASONCHECK */
+	N_("Array"),				/* STOPREASONARRAY */
+	N_("Iteration"),			/* STOPREASONITERATE */
+	N_("Replace"),				/* STOPREASONREPLACE */
+	N_("Spread"),				/* STOPREASONSPREAD */
+	N_("Execution"),			/* STOPREASONEXECUTE */
+	N_("Command file"),			/* STOPREASONCOMFILE */
+	N_("Selection"),			/* STOPREASONSELECT */
+	N_("Tracking"),				/* STOPREASONTRACK */
+	0
+};
+
+void db_inittranslation(void)
+{
+	REGISTER INTBIG i, j;
+	DIALOG *dia;
+	DIALOGITEM *item;
+
+	/* pretranslate the reasons for stopping */
+	for(i=0; db_stoppingreason[i] != 0; i++)
+		db_stoppingreason[i] = _(db_stoppingreason[i]);
+
+	/* pretranslate all strings in dialogs */
+	for(i=0; db_alldialogs[i] != 0; i++)
+	{
+		dia = db_alldialogs[i];
+		if (dia->translated != 0)
+			error("Dialog translated twice");
+		dia->translated = 1;
+		if (dia->movable != 0) dia->movable = _(dia->movable);
+		for(j=0; j<dia->items; j++)
+		{
+			item = &dia->list[j];
+			switch (item->type&ITEMTYPE)
+			{
+				case BUTTON:
+				case DEFBUTTON:
+				case CHECK:
+				case RADIO:
+				case MESSAGE:
+				case EDITTEXT:
+					if (*item->msg != 0)
+						item->msg = _(item->msg);
+					break;
+			}
+		}
+	}
+}
+
+/*
+ * routine to convert "word" to its plural form, depending on the value
+ * of "amount" (if "amount" is zero or multiple, pluralize the word).
+ */
+char *makeplural(char *word, INTBIG amount)
+{
+	INTBIG needed, len;
+
+	if (amount == 1) return(word);
+	len = strlen(word);
+	if (len == 0) return(word);
+	needed = len + 2;
+	if (needed > db_pluralbufsize)
+	{
+		if (db_pluralbufsize > 0) efree(db_pluralbuffer);
+		db_pluralbufsize = 0;
+		db_pluralbuffer = (char *)emalloc(needed, db_cluster);
+		if (db_pluralbuffer == 0) return(word);
+		db_pluralbufsize = needed;
+	}
+	strcpy(db_pluralbuffer, word);
+	if (isupper(word[len-1])) strcat(db_pluralbuffer, "S"); else
+		strcat(db_pluralbuffer, "s");
+	return(db_pluralbuffer);
+}
+
 /************************* STRING MANIPULATION *************************/
 
 /*
@@ -2029,7 +2302,7 @@ char *getkeyword(char **ptin, char *brk)
 		db_keywordbuffer = (char *)emalloc(pt2-pt+1, el_tempcluster);
 		if (db_keywordbuffer == 0)
 		{
-			ttyputerr("No memory for parse string");
+			ttyputnomemory();
 			return(NOSTRING);
 		}
 		db_keywordbufferlength = pt2-pt+1;
@@ -2095,24 +2368,35 @@ INTSML initinfstr(void)
 	{
 		for(i=0; i<INFSTRCOUNT; i++)
 		{
-			db_infstrstack[i].infstr = (char *)emalloc((INFSTRDEFAULT+1), db_cluster);
-			if (db_infstrstack[i].infstr == 0)
+			db_infstrings[i].infstr = (char *)emalloc((INFSTRDEFAULT+1), db_cluster);
+			if (db_infstrings[i].infstr == 0)
 				return((INTSML)db_error(DBNOMEM|DBINITINFSTR));
-			db_infstrstack[i].infstrlength = INFSTRDEFAULT;
+			db_infstrings[i].infstrlength = INFSTRDEFAULT;
+			db_infstrings[i].infstrinuse = 0;
 		}
 		db_firstinf = 1;
-		db_infstrstackpos = 0;
-		db_infstrstackbase = 0;
-		db_infstrdeepeststack = 0;
+		db_infstrstackpos = -1;
+		db_infstrpointer = 0;
 	}
 
-	/* grab a new infinite string and initialize it */
+	/* save any current infinite string on the stack */
 	if (db_infstrstackpos >= INFSTRCOUNT)
 		return((INTSML)db_error(DBRECURSIVE|DBINITINFSTR));
-	db_curinf = &db_infstrstack[(db_infstrstackbase+db_infstrstackpos) % INFSTRCOUNT];
-	if (db_infstrstackpos > db_infstrdeepeststack) db_infstrdeepeststack = db_infstrstackpos;
+	if (db_infstrstackpos >= 0)
+		db_infstrstackptr[db_infstrstackpos] = db_curinf;
 	db_infstrstackpos++;
+
+	/* grab a new infinite string and initialize it */
+	for(i=0; i<INFSTRCOUNT; i++)
+	{
+		db_curinf = &db_infstrings[db_infstrpointer % INFSTRCOUNT];
+		db_infstrpointer++;
+		if (db_curinf->infstrinuse == 0) break;
+	}
+	if (i >= INFSTRCOUNT)
+		return((INTSML)db_error(DBRECURSIVE|DBINITINFSTR));
 	db_curinf->infstrptr = 0;
+	db_curinf->infstrinuse = 1;
 	db_curinf->infstr[db_curinf->infstrptr] = 0;
 	return(0);
 }
@@ -2167,6 +2451,17 @@ INTSML addstringtoinfstr(char *pp)
 	return(0);
 }
 
+INTSML formatinfstr(char *msg, ...)
+{
+	va_list ap;
+	char line[8192];
+
+	var_start(ap, msg);
+	(void)vsprintf(line, msg, ap);
+	va_end(ap);
+	return(addstringtoinfstr(line));
+}
+
 char *returninfstr(void)
 {
 	REGISTER char *retval;
@@ -2176,15 +2471,15 @@ char *returninfstr(void)
 		(void)db_error(DBBADOBJECT|DBRETURNINFSTR);
 		return("");
 	}
+
+	/* get the inifinite string */
 	retval = db_curinf->infstr;
+	db_curinf->infstrinuse = 0;
+
+	/* if stacked, unstack */
 	db_infstrstackpos--;
-	if (db_infstrstackpos == 0)
-	{
-		db_infstrstackbase = db_infstrstackbase + 1 + db_infstrdeepeststack;
-		db_infstrdeepeststack = 0;
-		db_curinf = NOINFSTR;
-	} else
-		db_curinf = &db_infstrstack[(db_infstrstackbase+db_infstrstackpos-1) % INFSTRCOUNT];
+	if (db_infstrstackpos >= 0)
+		db_curinf = db_infstrstackptr[db_infstrstackpos];
 	return(retval);
 }
 
@@ -2325,7 +2620,7 @@ char *timetostring(UINTBIG curtime)
 }
 
 /*
- * Routine to parse the time in "curtime" and convert it to the year (since 1900),
+ * Routine to parse the time in "curtime" and convert it to the year,
  * month (0 = January), and day of month.
  */
 void parsetime(UINTBIG curtime, INTSML *year, INTSML *month, INTSML *mday,
@@ -2337,98 +2632,101 @@ void parsetime(UINTBIG curtime, INTSML *year, INTSML *month, INTSML *mday,
 	tm = localtime((time_t *)&curtime);
 	*month = tm->tm_mon;
 	*mday = tm->tm_mday;
-	*year = tm->tm_year;
+	*year = tm->tm_year + 1900;
 	*hour = tm->tm_hour;
 	*minute = tm->tm_min;
 	*second = tm->tm_sec;
 }
 
+INTBIG parsemonth(char *monthname)
+{
+	REGISTER INTBIG mon;
+	static char *name[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
+		"Aug", "Sep", "Oct", "Nov", "Dec"};
+
+	for (mon=0; mon<12; mon++)
+		if (namesame(name[mon], monthname) == 0) break;
+	if (mon < 12) return(mon+1);
+	return(0);
+}
+
 /******************** SUBROUTINES FOR FILE I/O ****************/
 
-struct
+INTBIG setupfiletype(char *extension, char *winfilter, INTBIG mactype, INTBIG binary,
+	char *shortname, char *longname)
 {
-	char *extension;
-	char *filter;
-	char *shortname;
-	char *longname;
-} db_filetypeinfo[] =
-{
-	{"tab",  "*.tab",		"actel",     "QuickPartTable"},		/* FILETYPEACTELTAB */
-	{"arr",  "*.arr",		"arrfile",   "Array"},				/* FILETYPEARRAY */
-	{"elib", "*.elib",      "blib",      "Binary library"},		/* FILETYPEBLIB */
-	{"",     "*.*",			"cadrc",     "Startup"},			/* FILETYPECADRC */
-	{"cif",  "*.cif",		"cif",       "CIF"},				/* FILETYPECIF */
-	{"map",  "*.map",		"color",     "Color map"},			/* FILETYPECOLORMAP */
-	{"def",  "*.def",		"def",       "DEF"},				/* FILETYPEDEF */
-	{"rul",  "*.map",		"drac",      "Dracula"},			/* FILETYPEDRAC */
-	{"dxf",  "*.dxf",		"dxf",       "AutoCAD DXF"},		/* FILETYPEDXF */
-	{"txt",  "*.txt",		"eagle",     "Eagle netlist"},		/* FILETYPEEAGLE */
-	{"edif", "*.edif;*.ed?","edif",      "EDIF"},				/* FILETYPEEDIF */
-	{"sim",  "*.sim",		"esim",      "ESIM netlist"},		/* FILETYPEESIM */
-	{"inp",  "*.inp",		"fasthenry", "FastHenry netlist"},	/* FILETYPEFASTHENRY */
-	{"fpga", "*.fpga",		"fpga",      "FPGA Architecture"},	/* FILETYPEFPGA */
-	{"gds",  "*.gds",		"gds",       "GDS II"},				/* FILETYPEGDS */
-	{"help", "*.help",		"help",      "Help"},				/* FILETYPEHELP */
-	{"hpgl", "*.hpgl",		"hpgl",      "HPGL"},				/* FILETYPEHPGL */
-	{"tr0",  "*.tr0",		"hspiceout", "HSPICE output"},		/* FILETYPEHSPICEOUT */
-	{"l",    "*.l",			"l",         "L"},					/* FILETYPEL */
-	{"lef",  "*.lef",		"lef",       "LEF"},				/* FILETYPELEF */
-	{"log",  "*.log",		"log",       "Log"},				/* FILETYPELOG */
-	{"mac",  "*.mac",		"macro",     "Macro package"},		/* FILETYPEMACRO */
-	{"ntk",  "*.ntk",		"mossim",    "MOSSIM netlist"},		/* FILETYPEMOSSIM */
-	{"net",  "*.net",		"netlisp",   "NetLisp netlist"},	/* FILETYPENETLISP */
-	{"news", "*.news",		"news",      "News"},				/* FILETYPENEWS */
-	{"asc",  "*.asc",		"pad",       "PADS netlist"},		/* FILETYPEPADS */
-	{"pal",  "*.pal",		"pal",       "Abel PAL"},			/* FILETYPEPAL */
-	{"",     "*.*",			"platab",    "PLA table"},			/* FILETYPEPLATAB */
-	{"",     "*.*",			"proj",      "Project"},			/* FILETYPEPROJ */
-	{"",     "*.*",			"projusers", "Project Users"},		/* FILETYPEPROJUSERS */
-	{"ps",   "*.ps;*.eps",	"ps",        "PostScript"},			/* FILETYPEPS */
-	{"net",  "*.net",		"als",       "ALS netlist"},		/* FILETYPEALS */
-	{"vec",  "*.vec",		"alsvec",    "ALS vector"},			/* FILETYPEALSVEC */
-	{"sci",  "*.sci",		"quisc",     "QUISC netlist"},		/* FILETYPEQUISC */
-	{"sim",  "*.sim",		"rsim",      "RSIM netlist"},		/* FILETYPERSIM */
-	{"",     "*.*",			"sctab",     "QUISC table"},		/* FILETYPESCTAB */
-	{"",     "*.*",			"scsim",     "QUISC simulation"},	/* FILETYPESCSIM */
-	{"sdf",  "*.sdf",		"sdf",       "SDF"},				/* FILETYPESDF */
-	{"sil",  "*.sil",		"silos",     "SILOS netlist"},		/* FILETYPESILOS */
-	{"il",   "*.il",		"skill",     "SKILL commands"},		/* FILETYPESKILL */
-	{"spi",  "*.spi;*.spo",	"spice",     "SPICE netlist"},		/* FILETYPESPICE */
-	{"spo",  "*.spo",		"spiceout",  "SPICE output"},		/* FILETYPESPICEOUT */
-	{"sue",  "*.sue",		"sue",       "SUE"},				/* FILETYPESUE */
-	{"tdl",  "*.tdl",		"tegas",     "TEGAS netlist"},		/* FILETYPETEGAS */
-	{"",     "*.*",			"tegastab",  "TEGAS table"},		/* FILETYPETEGASTAB */
-	{"",     "*.*",			"text",      "Text"},				/* FILETYPETEXT */
-	{"txt",  "*.txt",		"tlib",      "Text library"},		/* FILETYPETLIB */
-	{"v",    "*.v;*.ver",	"verilog",   "Verilog"},			/* FILETYPEVERILOG */
-	{"vhdl", "*.vhdl;*.vhd","vhdl",      "VHDL"},				/* FILETYPEVHDL */
-	{0, 0, 0}
-};
+	FILETYPES *newlist;
+	INTBIG oldcount, i;
+
+	oldcount = db_filetypecount;
+	db_filetypecount++;
+	newlist = (FILETYPES *)emalloc(db_filetypecount * (sizeof (FILETYPES)), db_cluster);
+	for(i=0; i<oldcount; i++)
+	{
+		newlist[i].extension = db_filetypeinfo[i].extension;
+		newlist[i].winfilter = db_filetypeinfo[i].winfilter;
+		newlist[i].mactype   = db_filetypeinfo[i].mactype;
+		newlist[i].binary    = db_filetypeinfo[i].binary;
+		newlist[i].shortname = db_filetypeinfo[i].shortname;
+		newlist[i].longname  = db_filetypeinfo[i].longname;
+	}
+	if (oldcount > 0) efree((char *)db_filetypeinfo);
+	db_filetypeinfo = newlist;
+	(void)allocstring(&db_filetypeinfo[oldcount].extension, extension, db_cluster);
+	(void)allocstring(&db_filetypeinfo[oldcount].winfilter, winfilter, db_cluster);
+	db_filetypeinfo[oldcount].mactype = mactype;
+	db_filetypeinfo[oldcount].binary = binary;
+	(void)allocstring(&db_filetypeinfo[oldcount].shortname, shortname, db_cluster);
+	(void)allocstring(&db_filetypeinfo[oldcount].longname, longname, db_cluster);
+	return(oldcount);
+}
 
 /*
  * Routine to return the extension, short name, and long name of file type "filetype".
  */
-void describefiletype(INTSML filetype, char **extension, char **filter, char **shortname, char **longname)
+void describefiletype(INTBIG filetype, char **extension, char **winfilter, INTBIG *mactype,
+	INTBIG *binary, char **shortname, char **longname)
 {
-	*extension = db_filetypeinfo[((FILETYPE & filetype) - 1)].extension;
-	*filter    = db_filetypeinfo[((FILETYPE & filetype) - 1)].filter;
-	*shortname = db_filetypeinfo[((FILETYPE & filetype) - 1)].shortname;
-	*longname = db_filetypeinfo[((FILETYPE & filetype) - 1)].longname;
+	REGISTER INTBIG index;
+
+	index = filetype & FILETYPE;
+	*extension = db_filetypeinfo[index].extension;
+	*winfilter = db_filetypeinfo[index].winfilter;
+	*mactype   = db_filetypeinfo[index].mactype;
+	*binary    = db_filetypeinfo[index].binary;
+	*shortname = db_filetypeinfo[index].shortname;
+	*longname  = db_filetypeinfo[index].longname;
 }
 
 /*
  * Routine to return the filetype associated with short name "shortname".
  * Returns zero on error.
  */
-INTSML getfiletype(char *shortname)
+INTBIG getfiletype(char *shortname)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	for(i=0; db_filetypeinfo[i].extension != 0; i++)
-		if (namesame(shortname, db_filetypeinfo[i].shortname) == 0) return(i+1);
+		if (namesame(shortname, db_filetypeinfo[i].shortname) == 0) return(i);
 	return(0);
 }
 
+/*
+ * routine to find the actual file name in a path/file specification.  The
+ * input path name is in "file" and a pointer to the file name is returned.
+ * Note that this routine handles the directory separating characters for
+ * all operating systems ('\' on Windows, '/' on UNIX, and ':' on Macintosh)
+ * because the strings may be from other systems.
+ */
+char *skippath(char *file)
+{
+	REGISTER char *pt;
+
+	pt = &file[strlen(file)-1];
+	while (pt != file && pt[-1] != '\\' && pt[-1] != '/' && pt[-1] != ':') pt--;
+	return(pt);
+}
+
 /*
  * routine to return the size of file whose stream is "f"
  */
@@ -2449,21 +2747,21 @@ INTBIG filesize(FILE *f)
  * The stream is returned (NULL if it can't be found), and the true name of the file (with
  * extensions and proper directory) is returned in "truename".
  */
-FILE *xopen(char *file, INTSML filetype, char *otherdir, char **truename)
+FILE *xopen(char *file, INTBIG filetype, char *otherdir, char **truename)
 {
 	REGISTER FILE *f;
 	REGISTER char *pp;
-	char rarg[3], *extension, *filter, *shortname, *longname;
+	INTBIG mactype, binary;
+	char rarg[3], *extension, *winfilter, *shortname, *longname;
+
+	/* determine extension to use */
+	describefiletype(filetype&FILETYPE, &extension, &winfilter, &mactype, &binary, &shortname, &longname);
 
 	/* determine argument to "fopen" */
 	if ((filetype&FILETYPEWRITE) != 0) strcpy(rarg, "w"); else
 		if ((filetype&FILETYPEAPPEND) != 0) strcpy(rarg, "a"); else
 			strcpy(rarg, "r");
-	if ((filetype&FILETYPE) == FILETYPELOG || (filetype&FILETYPE) == FILETYPEBLIB ||
-		(filetype&FILETYPE) == FILETYPEGDS) strcat(rarg, "b");
-
-	/* determine extension to use */
-	describefiletype((INTSML)(filetype&FILETYPE), &extension, &filter, &shortname, &longname);
+	if (binary != 0) strcat(rarg, "b");
 
 	/* remove "~" from the file name */
 	pp = truepath(file);
@@ -2543,17 +2841,21 @@ FILE *db_tryfile(char *pp, char *rarg, char *extension, char *otherdir, char **t
  * to differentiate errors in file creation from user aborts, the "truename" is set to zero
  * if the user aborts the command.
  */
-FILE *xcreate(char *name, INTSML filetype, char *prompt, char **truename)
+FILE *xcreate(char *name, INTBIG filetype, char *prompt, char **truename)
 {
 	REGISTER FILE *f;
 	REGISTER char *pt, *next;
-	char warg[3];
+	char warg[3], *extension, *winfilter, *shortname, *longname;
 	static char truenamelocal[256];
+	INTBIG mactype, binary;
+
+	/* determine extension to use */
+	describefiletype(filetype&FILETYPE, &extension, &winfilter, &mactype, &binary, &shortname, &longname);
 
 	pt = truepath(name);
 	if (prompt != 0 && (us_aid->aidstate&USEDIALOGS) != 0)
 	{
-		next = (char *)fileselect(prompt, (INTSML)(filetype | FILETYPEWRITE), pt);
+		next = (char *)fileselect(prompt, filetype | FILETYPEWRITE, pt);
 		if (next == 0 || *next == 0)
 		{
 			if (truename != 0) *truename = 0;
@@ -2570,27 +2872,19 @@ FILE *xcreate(char *name, INTSML filetype, char *prompt, char **truename)
 
 	/* determine argument to "fopen" */
 	strcpy(warg, "w");
-	if ((filetype&FILETYPE) == FILETYPELOG || (filetype&FILETYPE) == FILETYPEBLIB ||
-		(filetype&FILETYPE) == FILETYPEGDS) strcat(warg, "b");
+	if (binary != 0) strcat(warg, "b");
 	f = fopen(pt, warg);
 #ifdef	MACOS
 	if (f != NULL)
 	{
 		void mac_settypecreator(char*, INTBIG, INTBIG);
-		switch (filetype)
+
+		if (mactype == 'TEXT')
 		{
-			case FILETYPEBLIB:
-				mac_settypecreator(pt, 'Elec', 'Elec');
-				break;
-			case FILETYPEGDS:
-				mac_settypecreator(pt, '\?\?\?\?', '\?\?\?\?');
-				break;
-			case FILETYPELOG:
-				mac_settypecreator(pt, 'LOG ', 'Elec');
-				break;
-			default:
-				mac_settypecreator(pt, 'TEXT', 'ttxt');
-				break;
+			mac_settypecreator(pt, 'TEXT', 'ttxt');
+		} else
+		{
+			mac_settypecreator(pt, mactype, 'Elec');
 		}
 	}
 #endif
