@@ -44,10 +44,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 #if LANGTCL
-  extern "C"
-  {
 # include "dblang.h"
-  };
   INTBIG gra_initializetcl(void);
 #endif
 
@@ -109,7 +106,7 @@ BOOL CElectricApp::InitInstance()
 	// Change the registry key under which our settings are stored.
 	// You should modify this string to be something appropriate
 	// such as the name of your company or organization.
-	SetRegistryKey(_T("Electric-Editor-Incorporated"));
+	SetRegistryKey(_T("Static-Free-Software"));
 
 	LoadStdProfileSettings();  // Load standard INI file options (including MRU)
 
@@ -129,6 +126,10 @@ BOOL CElectricApp::InitInstance()
 		return FALSE;
 	m_pMainWnd = pMainFrame;
 
+//	m_pMainWnd->SetWindowText("Son of Electric");
+//	CMainFrame *wnd = (CMainFrame *)AfxGetMainWnd();
+//	wnd->SetWindowText("Daughter of Electric");
+
 	// Enable drag/drop open
 	m_pMainWnd->DragAcceptFiles();
 
@@ -160,7 +161,7 @@ BOOL CElectricApp::InitInstance()
 #if LANGTCL
 	/* initialize TCL here */
 	if (gra_initializetcl() == TCL_ERROR)
-		error("TCL initialization failed: %s\n", tcl_interp->result);
+		error(_("TCL initialization failed: %s\n"), tcl_interp->result);
 #endif
 
 	/* secondary initialization of Electric */
