@@ -96,11 +96,7 @@ void CElectricMsgView::OnChange()
 
 void CElectricMsgView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 {
-	UINT rChar;
-
-	if (nChar == 033) rChar = 04; else
-		rChar = nChar;
-	gra_keyaction(rChar, 0, 1);
+	gra_keyaction(nChar, 0, 1);
 }
 
 void CElectricMsgView::OnActivateView(BOOL bActivate, CView* pActivateView, CView* pDeactiveView)
