@@ -93,7 +93,8 @@
 #  define DIRSEP           '/'						/* directory separator */
 #  define NONFILECH        '?'						/* character that cannot be in file name */
 #  define CADRCFILENAME    ".cadrc"					/* CAD startup file */
-#  define LIBDIR           "lib/"					/* location of library files */
+#  define LIBDIR           "/usr/local/lib/electric/"		/* location of library files */
+#  define DOCDIR           "/usr/share/doc/electric/html/"	/* location of HTML files */
 #  define ESIMLOC          "/usr/local/bin/esim"
 #  define RSIMLOC          "/usr/local/bin/rsim"
 #  define PRESIMLOC        "/usr/local/bin/presim"
@@ -121,11 +122,16 @@
 #define SIMAID             1
 #define VHDLAID            1
 
+/* special features of tools */
+#define ROUTAIDSUN         FORCESUNTOOLS
+#define LOGEFFAIDSUN       FORCESUNTOOLS
+
 /* The I/O modules (Binary, Text, and printer formats are always enabled) */
 #define IOCIF              1
 #define IODEF              1
 #define IODXF              1
 #define IOEAGLE            1
+#define IOECAD             1
 #define IOEDIF             1
 #define IOGDS              1
 #define IOL                1
