@@ -34,8 +34,9 @@ extern "C"
 #endif
 
 /* the meaning of "DRC_options" */
-#define DRCHIERDIALOG   1				/* set to force hierarchical DRC to use dialog */
-#define DRCFIRSTERROR   2				/* set to stop after first error in a facet */
+#define DRCHIERDIALOG    1				/* set to force hierarchical DRC to use dialog */
+#define DRCFIRSTERROR    2				/* set to stop after first error in a facet */
+#define DRCREASONABLE    4				/* set to only examine "reasonable" number of polygons per node */
 
 extern AIDENTRY *dr_aid;				/* the DRC aid object */
 extern INTBIG    dr_ignore_listkey;		/* key for aid:drc.DRC_ignore_list */
@@ -62,14 +63,10 @@ INTSML   dr_flatunignore(char*);
 NETWORK *dr_network(NODEINST*, PORTPROTO*);
 INTBIG   drcb_check(NODEPROTO*);
 INTSML   drcb_debug(void);
-char    *drcb_next_error(INTSML highlight, GEOM **geom1, GEOM **geom2);
-char    *drcb_prev_error(void);
-char    *drcb_curr_error(INTSML highlight, GEOM **geom1, GEOM **geom2);
 void     drcb_reset_dates(void);
 INTSML   drcb_initincrementalcheck(NODEPROTO *facet);
 INTSML   drcb_checkincremental(GEOM *geom, INTSML partial);
 void     drcb_term(void);
-INTBIG   drcb_errorcount(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
