@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /******************************* GRAPHICS ********************************/
 
 /* bit map colors (in GRAPHICS->bits) */
@@ -159,3 +164,7 @@ extern INTSML el_colcursor;		/* color to use for cursor */
 #define	TXTEDITOR    16			/* fixed-width text for text editing     */
 #define	TXTMENU      17			/* text for menu selection               */
 #define TXTSTATUS    18			/* text for X status window              */
+
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+}
+#endif
