@@ -87,16 +87,25 @@ extern "C"
 {
 #endif
 
+/* for internationalization */
+#define _(String) (String)
+#define N_(String) (String)
+#define M_(String) (String)
+#define textdomain(Domain)
+#define bindtextdomain(Package, Directory)
+
 /*************************** VARIABLES ****************************/
 
 #define	NOVARIABLE  ((VARIABLE *)-1)
 
 /*
  * when adding objects to this list, also update:
- *   "dbchange.c:db_namevariable"
+ *   "dbchange.c:db_namevariable()"
+ *   "dblang*"
  *   "dbvars.c"
- *   "dbtext.c:db_makestringvar"
- *   "usrcom.c:us_nextvars"
+ *   "dbtext.c:db_makestringvar()"
+ *   "usrcom.c:us_nextvars()"
+ *   "usrstatus.c:us_vartypename[]"
  */
 /* the meaning of VARIABLE->type */
 #define	VUNKNOWN                   0		/* undefined variable */
@@ -128,6 +137,7 @@ extern "C"
 #define	VCONSTRAINT              032		/* constraint solver */
 #define	VGENERAL                 033		/* general address/type pairs (used only in fixed-length arrays) */
 #define	VWINDOWFRAME             034		/* window frame pointer */
+#define	VPOLYGON                 035		/* polygon pointer */
 #define	VTYPE                    037		/* all above type fields */
 #define	VCODE1                   040		/* variable is interpreted code (with VCODE2) */
 #define	VDISPLAY                0100		/* display variable (uses textdescript field) */
@@ -305,8 +315,11 @@ typedef struct Iaidentry
 	INTSML    numvar;						/* number of variables in list */
 } AIDENTRY;
 
-extern AIDENTRY el_aids[];					/* defined in "aidtable.c" */
-extern INTSML   el_maxaid;					/* current number of aids */
+extern AIDENTRY  el_aids[];					/* defined in "aidtable.c" */
+extern INTSML    el_maxaid;					/* current number of aids */
+extern AIDENTRY *us_aid;					/* the User aid object */
+extern AIDENTRY *io_aid;					/* the I/O aid object */
+extern AIDENTRY *net_aid;					/* the Network aid object */
 
 /* the meaning of AIDENTRY->aidstate */
 #define	AIDON                     01		/* set if aid is on */
@@ -802,6 +815,10 @@ typedef struct Ipolygon
 	INTSML              layer;				/* layer number of this polygon */
 	PORTPROTO          *portproto;			/* port prototype associated with this polygon */
 	struct Ipolygon    *nextpolygon;		/* for linking them into a list */
+
+	/* variables */
+	VARIABLE *firstvar;						/* first variable in list */
+	INTSML    numvar;						/* number of variables in list */
 } POLYGON;
 
 /******************** EDITOR MODULES ********************/
@@ -1158,18 +1175,18 @@ typedef struct Itechnology
 	void              (*paramnode)(NODEINST*);						/* top-down parameterize */
 
 	/* node description */
-	INTSML            (*nodepolys)(NODEINST*);						/* returns total real polygons in node */
-	INTSML            (*nodeEpolys)(NODEINST*);						/* returns total electrical polys in node */
-	void              (*shapenodepoly)(NODEINST*, INTSML, POLYGON*);	/* returns real polygon shape in node */
-	void              (*shapeEnodepoly)(NODEINST*, INTSML, POLYGON*);	/* returns electrical polygon shape in node */
+	INTBIG            (*nodepolys)(NODEINST*, INTBIG*);				/* returns total real polygons in node */
+	INTBIG            (*nodeEpolys)(NODEINST*, INTBIG*);			/* returns total electrical polys in node */
+	void              (*shapenodepoly)(NODEINST*, INTBIG, POLYGON*);	/* returns real polygon shape in node */
+	void              (*shapeEnodepoly)(NODEINST*, INTBIG, POLYGON*);	/* returns electrical polygon shape in node */
 	void              (*nodesizeoffset)(NODEINST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);	/* returns offset to true size */
 
 	/* node port description */
 	void              (*shapeportpoly)(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);/* returns port shape on a node */
 
 	/* arc description */
-	INTSML            (*arcpolys)(ARCINST*);						/* returns total polygons in arc */
-	void              (*shapearcpoly)(ARCINST*, INTSML, POLYGON*);	/* returns polygon shape in arc */
+	INTBIG            (*arcpolys)(ARCINST*);						/* returns total polygons in arc */
+	void              (*shapearcpoly)(ARCINST*, INTBIG, POLYGON*);	/* returns polygon shape in arc */
 	INTBIG            (*arcwidthoffset)(ARCINST*);					/* returns offset to true width */
 
 	struct Itechnology *nexttechnology;		/* next in linked list */
@@ -1244,61 +1261,53 @@ extern CONSTRAINT  el_constraints[];		/* list of constraint solvers */
 #define INTUNITHDMIC             020		/* half-decimicron units */
 
 /*
- * the file types for "xopen" and "xcreate"
- * (update table "dbtext.c:db_filetypeinfo[]" when changing this)
+ * reasons for aborting (the argument to "stopping()")
+ * (update table "dbtext.c:db_stoppingreason[]" when changing this)
  */
-#define FILETYPE                 077		/* type of file */
-#define FILETYPEACTELTAB          01		/* Actel tables */
-#define FILETYPEARRAY             02		/* Array */
-#define FILETYPEBLIB              03		/* Binary library */
-#define FILETYPECADRC             04		/* "cadrc" startup */
-#define FILETYPECIF               05		/* CIF */
-#define FILETYPECOLORMAP          06		/* Color map */
-#define FILETYPEDEF               07		/* DEF */
-#define FILETYPEDRAC             010		/* Dracula */
-#define FILETYPEDXF              011		/* DXF */
-#define FILETYPEEAGLE            012		/* EAGLE netlist */
-#define FILETYPEEDIF             013		/* EDIF */
-#define FILETYPEESIM             014		/* ESIM netlist */
-#define FILETYPEFASTHENRY        015		/* FastHenry netlist */
-#define FILETYPEFPGA             016		/* FPGA architecture */
-#define FILETYPEGDS              017		/* GDS */
-#define FILETYPEHELP             020		/* Help */
-#define FILETYPEHPGL             021		/* HPGL */
-#define FILETYPEHSPICEOUT        022		/* HSPICE output */
-#define FILETYPEL                023		/* L */
-#define FILETYPELEF              024		/* LEF */
-#define FILETYPELOG              025		/* Log */
-#define FILETYPEMACRO            026		/* Macro */
-#define FILETYPEMOSSIM           027		/* MOSSIM netlist */
-#define FILETYPENETLISP          030		/* Netlisp netlist */
-#define FILETYPENEWS             031		/* News */
-#define FILETYPEPADS             032		/* PADS netlist */
-#define FILETYPEPAL              033		/* PAL netlist */
-#define FILETYPEPLATAB           034		/* PLA table */
-#define FILETYPEPROJ             035		/* Project */
-#define FILETYPEPROJUSERS        036		/* Project users */
-#define FILETYPEPS               037		/* PostScript */
-#define FILETYPEALS              040		/* ALS netlist */
-#define FILETYPEALSVEC           041		/* ALS vectors */
-#define FILETYPEQUISC            042		/* QUISC netlist */
-#define FILETYPERSIM             043		/* RSIM netlist */
-#define FILETYPESCTAB            044		/* Silicon compiler table */
-#define FILETYPESCSIM            045		/* Silicon compiler simulation */
-#define FILETYPESDF              046		/* SDF */
-#define FILETYPESILOS            047		/* Silos netlist */
-#define FILETYPESKILL            050		/* SKILL commands */
-#define FILETYPESPICE            051		/* SPICE input */
-#define FILETYPESPICEOUT         052		/* SPICE output */
-#define FILETYPESUE              053		/* SUE */
-#define FILETYPETEGAS            054		/* Tegas netlist */
-#define FILETYPETEGASTAB         055		/* Tegas table */
-#define FILETYPETEXT             056		/* Plain text */
-#define FILETYPETLIB             057		/* Text library */
-#define FILETYPEVERILOG          060		/* Verilog */
-#define FILETYPEVHDL             061		/* VHDL */
-#define FILETYPEWRITE           0100		/* bit set to write file (instead of read) */
-#define FILETYPEAPPEND          0200		/* bit set to append to file (instead of read) */
+#define STOPREASONCONTOUR   0		/* "Contour gather" */
+#define STOPREASONDRC       1		/* "DRC" */
+#define STOPREASONPLAYBACK  2		/* "Playback" */
+#define STOPREASONBINARY    3		/* "Binary" */
+#define STOPREASONCIF       4		/* "CIF" */
+#define STOPREASONDXF       5		/* "DXF" */
+#define STOPREASONEDIF      6		/* "EDIF" */
+#define STOPREASONVHDL      7		/* "VHDL" */
+#define STOPREASONCOMPACT   8		/* "Compaction" */
+#define STOPREASONERC       9		/* "ERC" */
+#define STOPREASONCHECKIN  10		/* "Check-in" */
+#define STOPREASONLOCK     11		/* "Lock wait" */
+#define STOPREASONNCC      12		/* "Network comparison" */
+#define STOPREASONPORT     13		/* "Port exploration" */
+#define STOPREASONROUTING  14		/* "Routing" */
+#define STOPREASONSILCOMP  15		/* "Silicon compiler" */
+#define STOPREASONDISPLAY  16		/* "Display" */
+#define STOPREASONSIMULATE 17		/* "Simulation" */
+#define STOPREASONDECK     18		/* "Deck generation" */
+#define STOPREASONSPICE    19		/* "SPICE" */
+#define STOPREASONCHECK    20		/* "Check" */
+#define STOPREASONARRAY    21		/* "Array" */
+#define STOPREASONITERATE  22		/* "Iteration" */
+#define STOPREASONREPLACE  23		/* "Replace" */
+#define STOPREASONSPREAD   24		/* "Spread" */
+#define STOPREASONEXECUTE  25		/* "Execution" */
+#define STOPREASONCOMFILE  26		/* "Command file" */
+#define STOPREASONSELECT   27		/* "Selection" */
+#define STOPREASONTRACK    28		/* "Tracking" */
+
+/* a macro for converting Macintosh file types into integers */
+#ifdef MACOS
+#  define MACFSTAG(x) x
+#else
+#  define MACFSTAG(x) 0
+#endif
+
+/*
+ * the "filetype" parameter in "multifileselectin", "describefiletype",
+ * "setupfiletype", "getfiletype", "xopen", "xcreate"
+ */
+#define FILETYPE               01777		/* type of file */
+#define FILETYPEWRITE          02000		/* bit set to write file (instead of read) */
+#define FILETYPEAPPEND         04000		/* bit set to append to file (instead of read) */
 
 /* the "purpose" parameter (cursor shape) for "trackcursor()" */
 #define	TRACKNORMAL                0		/* standard cursor */
@@ -1309,9 +1318,10 @@ extern CONSTRAINT  el_constraints[];		/* list of constraint solvers */
 
 extern XARRAY el_matid;						/* identity matrix */
 extern INTSML el_pleasestop;				/* nonzero if abort is requested */
-extern INTSML el_units;						/* display and internal units */
+extern INTBIG el_units;						/* display and internal units */
 extern char  *el_libdir;					/* pointer to library directory */
 extern char  *el_version;					/* current version string */
+extern INTBIG el_filetypetext;				/* plain text disk file descriptor */
 
 /*************************** DECLARATIONS ****************************/
 
@@ -1322,11 +1332,11 @@ INTSML       killnodeinst(NODEINST *node);
 void         defaultnodesize(NODEPROTO *np, INTBIG *xs, INTBIG *ys);
 void         modifynodeinst(NODEINST *node, INTBIG Dlx, INTBIG Dly, INTBIG Dhx,
 				INTBIG Dhy, INTSML Drotation, INTSML Dtransposition);
-NODEINST    *replacenodeinst(NODEINST *oldnode, NODEPROTO *newproto);
-INTSML       nodepolys(NODEINST *node);
-void         shapenodepoly(NODEINST *node, INTSML box, POLYGON *poly);
-INTSML       nodeEpolys(NODEINST *node);
-void         shapeEnodepoly(NODEINST *node, INTSML box, POLYGON *poly);
+NODEINST    *replacenodeinst(NODEINST *oldnode, NODEPROTO *newproto, INTSML ignoreportnames);
+INTBIG       nodepolys(NODEINST *node, INTBIG *reasonable);
+void         shapenodepoly(NODEINST *node, INTBIG box, POLYGON *poly);
+INTBIG       nodeEpolys(NODEINST *node, INTBIG *reasonable);
+void         shapeEnodepoly(NODEINST *node, INTBIG box, POLYGON *poly);
 void         nodesizeoffset(NODEINST *node, INTBIG *lowx, INTBIG *lowy, INTBIG *highx, INTBIG *highy);
 void         nodeprotosizeoffset(NODEPROTO *np, INTBIG *lowx, INTBIG *lowy, INTBIG *highx, INTBIG *highy);
 INTSML       nodefunction(NODEINST *node, char **extra);
@@ -1339,6 +1349,7 @@ void         getarcendpoints(NODEINST *ni, double startoffset, double endangle,
 				INTBIG *tx, INTBIG *ty);
 void         transistorports(NODEINST *node, PORTPROTO **gateleft, PORTPROTO **gateright,
 				PORTPROTO **activetop, PORTPROTO **activebottom);
+INTBIG       lambdaofnode(NODEINST *ni);
 VARIABLE    *gettrace(NODEINST *node);
 void         nodearea(NODEINST *node, PORTPROTO *port, INTBIG *lowx, INTBIG *highx, INTBIG *lowy,
 				INTBIG *highy);
@@ -1359,8 +1370,8 @@ ARCINST     *aconnect(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, PORTPRO
 				ARCPROTO *arc, INTBIG x, INTBIG y, ARCINST **arc2, ARCINST **arc3, INTSML ang,
 				INTSML nozigzag);
 ARCINST     *replacearcinst(ARCINST *oldarc, ARCPROTO *newproto);
-INTSML       arcpolys(ARCINST *arc);
-void         shapearcpoly(ARCINST *arc, INTSML box, POLYGON *poly);
+INTBIG       arcpolys(ARCINST *arc);
+void         shapearcpoly(ARCINST *arc, INTBIG box, POLYGON *poly);
 char        *arcfunctionname(INTSML function);
 char        *describearcinst(ARCINST *arc);
 char        *describearcproto(ARCPROTO *arcproto);
@@ -1372,6 +1383,7 @@ void         makearcpoly(INTBIG length, INTBIG width, ARCINST *arc, POLYGON *pol
 INTSML       curvedarcoutline(ARCINST *arc, POLYGON *poly, INTSML style, INTBIG width);
 INTBIG       setshrinkvalue(ARCINST *arc, INTSML extend);
 void         determineangle(ARCINST *arc);
+INTBIG       lambdaofarc(ARCINST *ai);
 INTSML       arcconnects(INTSML ang, INTBIG lx1, INTBIG hx1, INTBIG ly1, INTBIG hy1, INTBIG lx2, INTBIG hx2,
 				INTBIG ly2, INTBIG hy2, INTBIG *x1, INTBIG *y1, INTBIG *x2, INTBIG *y2);
 ARCINST     *dummyarc(void);
@@ -1394,6 +1406,7 @@ void         downhierarchy(NODEINST *ni);
 void         uphierarchy(void);
 void         gettraversalpath(NODEINST ***nilist, INTSML *depth);
 NODEPROTO   *getcurfacet(void);
+INTBIG       lambdaoffacet(NODEPROTO *np);
 NODEINST    *descentparent(NODEPROTO *np);
 
 /* port routines */
@@ -1418,8 +1431,7 @@ VIEW        *getview(char *specification);
 NODEPROTO   *contentsview(NODEPROTO *facet);
 NODEPROTO   *iconview(NODEPROTO *facet);
 NODEPROTO   *layoutview(NODEPROTO *facet);
-NODEPROTO   *vhdlview(NODEPROTO *facet);
-NODEPROTO   *verilogview(NODEPROTO *facet);
+NODEPROTO   *anyview(NODEPROTO *np, VIEW *v);
 
 /* window routines */
 WINDOWPART  *newwindowpart(char *location, WINDOWPART *protowindow);
@@ -1476,7 +1488,7 @@ INTSML       undoabatch(AIDENTRY **aid);
 INTSML       redoabatch(AIDENTRY **aid);
 void         noundoallowed(void);
 void         noredoallowed(void);
-INTSML       historylistsize(INTSML newsize);
+INTBIG       historylistsize(INTBIG newsize);
 void         setactivity(char *message);
 void         showhistorylist(INTSML batch);
 char        *changedvariablename(INTBIG type, INTBIG key, INTBIG subtype);
@@ -1489,9 +1501,9 @@ INTSML       layerismetal(INTBIG fun);
 INTSML       layerispoly(INTBIG fun);
 INTSML       layeriscontact(INTBIG fun);
 INTBIG       layerfunctionheight(INTBIG layerfunct);
-INTBIG       maxdrcsurround(TECHNOLOGY *tech, INTSML layer);
-INTBIG       drcmindistance(TECHNOLOGY *tech, INTSML layer1, INTSML layer2, INTSML connected);
-INTBIG       drcminwidth(TECHNOLOGY *tech, INTSML layer);
+INTBIG       maxdrcsurround(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer);
+INTBIG       drcmindistance(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer1, INTSML layer2, INTSML connected);
+INTBIG       drcminwidth(TECHNOLOGY *tech, LIBRARY *lib, INTSML layer);
 INTSML       getecolor(char *colorname);
 INTSML       ecolorname(INTSML color, char **colorname, char **colorsymbol);
 INTSML       get3dfactors(TECHNOLOGY *tech, INTBIG layer, INTBIG *height, INTBIG *thickness);
@@ -1556,9 +1568,9 @@ INTBIG       rounddouble(double v);
 INTBIG       castint(float f);
 float        castfloat(INTBIG i);
 INTBIG       intsqrt(INTBIG v);
-INTBIG       scalefromdispunit(float value, INTSML dispunit);
-float        scaletodispunit(INTBIG value, INTSML dispunit);
-float        scaletodispunitsq(INTBIG value, INTSML dispunit);
+INTBIG       scalefromdispunit(float value, INTBIG dispunit);
+float        scaletodispunit(INTBIG value, INTBIG dispunit);
+float        scaletodispunitsq(INTBIG value, INTBIG dispunit);
 INTBIG       computedistance(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
 INTSML       figureangle(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
 INTSML       intersect(INTBIG x1, INTBIG y1, INTBIG angle1, INTBIG x2, INTBIG y2, INTBIG angle2,
@@ -1660,6 +1672,7 @@ INTSML       parse(char *keyword, COMCOMP *list, INTSML noise);
 INTSML       initinfstr(void);
 INTSML       addtoinfstr(char c);
 INTSML       addstringtoinfstr(char *str);
+INTSML       formatinfstr(char *msg, ...);
 char        *returninfstr(void);
 void        *newstringarray(CLUSTER *cluster);
 void         killstringarray(void *sa);
@@ -1671,7 +1684,7 @@ char        *getkeyword(char **ptin, char *brk);
 char         tonextchar(char **ptin);
 char         seenextchar(char **ptin);
 INTBIG       defaulttextdescript(GEOM *geom);
-char        *unitsname(INTSML units);
+char        *unitsname(INTBIG units);
 void         myencrypt(char *text, char *key);
 
 /* language interface routines */
@@ -1680,6 +1693,21 @@ INTSML       languageconverse(INTBIG language);
 INTSML       doquerry(char *code, INTBIG language, INTBIG type, INTBIG *retval);
 INTSML       loadcode(char *program, INTBIG language);
 
+/* error reporting routines */
+void         initerrorlogging(char *system);
+void        *logerror(char *message, NODEPROTO *facet, INTBIG sortkey);
+INTSML       addgeomtoerror(void *errorlist, GEOM *geom, INTSML showit);
+INTSML       addfacettoerror(void *errorlist, NODEPROTO *facet);
+INTSML       addlinetoerror(void *errorlist, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2);
+INTSML       addpolytoerror(void *errorlist, POLYGON *poly);
+INTSML       addpointtoerror(void *errorlist, INTBIG x, INTBIG y);
+void         termerrorlogging(void);
+void         sorterrors(void);
+INTBIG       numerrors(void);
+char        *reportnexterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
+char        *reportpreverror(void);
+char        *reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
+
 /* memory allocation routines */
 #ifdef DEBUGMEMORY
   INTBIG   *_emalloc(INTBIG size, CLUSTER *cluster, char*, INTBIG);
@@ -1727,6 +1755,10 @@ void         ttynewcommand(void);
 void         ttyputerr(char *format, ...);
 void         ttyputmsg(char *format, ...);
 void         ttyputverbose(char *format, ...);
+void         ttyputinstruction(char *keystroke, INTBIG length, char *meaning);
+void         ttyputusage(char *usage);
+void         ttyputbadusage(char *command);
+void         ttyputnomemory(void);
 void         error(char *format, ...);
 INTSML       ttyquiet(INTSML flag);
 void         ttybeep(void);
@@ -1765,6 +1797,7 @@ UINTBIG      getcurrenttime(void);
 char        *timetostring(UINTBIG time);
 void         parsetime(UINTBIG time, INTSML *year, INTSML *month, INTSML *mday,
 				INTSML *hour, INTSML *minute, INTSML *second);
+INTBIG       parsemonth(char *monthname);
 
 /* disk file routines */
 char        *truepath(char *path);
@@ -1772,8 +1805,8 @@ char        *skippath(char *file);
 void         emaketemp(char *file);
 INTBIG       erename(char *file, char *newfile);
 INTBIG       eunlink(char *file);
-char        *fileselect(char*, INTSML, char*);
-char        *multifileselectin(char *msg, INTSML filetype);
+char        *fileselect(char*, INTBIG, char*);
+char        *multifileselectin(char *msg, INTBIG filetype);
 INTSML       fileexistence(char *file);
 char        *currentdirectory(void);
 char        *hashomedir(void);
@@ -1783,12 +1816,14 @@ INTSML       lockfile(char *file);
 void         unlockfile(char *file);
 UINTBIG      filedate(char *file);
 INTBIG       filesize(FILE *stream);
-void         describefiletype(INTSML filetype, char **extension, char **filter,
-				char **shortname, char **longname);
 INTSML       browsefile(char *filename);
-INTSML       getfiletype(char *shortname);
-FILE        *xopen(char *file, INTSML filetype, char *otherdir, char **truename);
-FILE        *xcreate(char *name, INTSML filetype, char *prompt, char **truename);
+void         describefiletype(INTBIG filetype, char **extension, char **winfilter,
+				INTBIG *mactype, INTBIG *binary, char **shortname, char **longname);
+INTBIG       setupfiletype(char *extension, char *winfilter, INTBIG mactype, INTBIG binary,
+				char *shortname, char *longname);
+INTBIG       getfiletype(char *shortname);
+FILE        *xopen(char *file, INTBIG filetype, char *otherdir, char **truename);
+FILE        *xcreate(char *name, INTBIG filetype, char *prompt, char **truename);
 FILE        *xappend(char *file);
 void         xclose(FILE *stream);
 void         xflushbuf(FILE *stream);
@@ -1815,19 +1850,23 @@ void         channelrestore(int channel, INTBIG saved);
 void         setinteractivemode(int channel);
 
 /* miscellaneous routines */
-void         changelambda(INTBIG oldlam, INTBIG lam, TECHNOLOGY *tech);
+void         changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
+				LIBRARY *whichlib, INTBIG how);
+void         changetechnologylambda(TECHNOLOGY *tech, INTBIG newlambda);
 INTBIG       figurelambda(GEOM *geom);
-void         changeinternalunits(LIBRARY *whichlib, INTSML oldunits, INTSML newunits);
+void         changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits);
 NETWORK     *getnetwork(char *specification, NODEPROTO *facet);
 NETWORK     *getnetonport(NODEINST *node, PORTPROTO *port);
 char        *describenetwork(NETWORK *net);
 void         bringdown(void);
-INTSML       stopping(char *cause);
+INTSML       stopping(INTBIG reason);
 char        *egetenv(char *name);
 INTBIG       efork(void);
+INTBIG       esystem(char *command);
 void         eexec(char *program, char *args[]);
 INTBIG       ekill(INTBIG process);
 void         ewait(INTBIG process);
+char       **eprinterlist(void);
 void         flushscreen(void);
 void         exitprogram(void);
 
@@ -1846,6 +1885,7 @@ void         getpaletteparameters(INTSML *wid, INTSML *hei, INTSML *palettewidth
 void         sizewindowframe(WINDOWFRAME *frame, INTSML wid, INTSML hei);
 void         movewindowframe(WINDOWFRAME *frame, INTSML left, INTSML top);
 void         bringwindowtofront(WINDOWFRAME *frame);
+void         adjustwindowframe(INTSML how);
 WINDOWFRAME *getwindowframe(INTSML canfloat);
 void         getwindowframesize(WINDOWFRAME *frame, INTSML *wid, INTSML *hei);
 INTSML       graphicshas(INTSML want);
