@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /********************* for all simulators *********************/
 
 #define	ESIM       0					/* ESIM from MIT (SIM format) */
@@ -58,6 +63,22 @@ extern NODEPROTO *sim_simnt;			/* facet being simulated */
 extern int        sim_tosim[2];			/* pipe to the simulator process */
 extern int        sim_fromsim[2];		/* pipe from the simulator process */
 extern INTBIG     sim_process;			/* process number of simulator */
+extern INTBIG     sim_filetypeesim;		/* ESIM netlist disk file descriptor */
+extern INTBIG     sim_filetypefasthenry;/* FastHenry netlist disk file descriptor */
+extern INTBIG     sim_filetypehspiceout;/* HSPICE output disk file descriptor */
+extern INTBIG     sim_filetypemossim;	/* MOSSIM netlist disk file descriptor */
+extern INTBIG     sim_filetypepal;		/* PAL netlist disk file descriptor */
+extern INTBIG     sim_filetypeals;		/* ALS netlist disk file descriptor */
+extern INTBIG     sim_filetypealsvec;	/* ALS vectors disk file descriptor */
+extern INTBIG     sim_filetypenetlisp;	/* Netlisp netlist disk file descriptor */
+extern INTBIG     sim_filetypequisc;	/* QUISC netlist disk file descriptor */
+extern INTBIG     sim_filetypersim;		/* RSIM netlist disk file descriptor */
+extern INTBIG     sim_filetypesilos;	/* Silos netlist disk file descriptor */
+extern INTBIG     sim_filetypespice;	/* SPICE input disk file descriptor */
+extern INTBIG     sim_filetypespiceout;	/* SPICE output disk file descriptor */
+extern INTBIG     sim_filetypetegas;	/* Tegas netlist disk file descriptor */
+extern INTBIG     sim_filetypetegastab;	/* Tegas table disk file descriptor */
+extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
 
 /********************* for Simulation Window *********************/
 
@@ -202,11 +223,6 @@ extern INTBIG sim_fasthenryzheadkey;		/* cached key for "SIM_fasthenry_z_head" *
 extern INTBIG sim_fasthenryztailkey;		/* cached key for "SIM_fasthenry_z_tail" */
 extern INTBIG sim_fasthenrygroupnamekey;	/* cached key for "SIM_fasthenry_group_name" */
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for tool interface */
 void   sim_init(INTBIG*, char*[], AIDENTRY*);
 void   sim_done(void);
