@@ -228,7 +228,7 @@ INTSML    simals_alloc_ptr_buffer(INTBIG**, INTBIG*, INTBIG);
 void      simals_annotate_command(INTSML, char*[]);
 INTBIG    simals_atoi(char*);
 void      simals_build_actel_command(INTSML, char*[]);
-void      simals_clearallvectors(void);
+void      simals_clearallvectors(INTSML);
 void      simals_clock_command(INTSML, char*[]);
 void      simals_com_comp(INTSML, char*[10]);
 void      simals_compute_node_name(NODEPTR, char*);
