@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 #define	ELLIPSEPOINTS         30		/* number of lines in an ellipse */
 
 /* the state bits */
@@ -63,22 +68,17 @@ extern INTBIG      art_colorkey;					/* key for "ART_color" */
 extern INTBIG      art_degreeskey;					/* key for "ART_degrees" */
 extern INTBIG      art_patternkey;					/* key for "ART_pattern" */
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for technology routines */
 INTSML art_initprocess(TECHNOLOGY*, INTSML);
 void art_setmode(INTSML, char*[]);
 INTBIG art_request(char*, va_list);
-INTSML art_nodepolys(NODEINST*);
-INTSML art_nodeEpolys(NODEINST*);
-void art_shapenodepoly(NODEINST*, INTSML, POLYGON*);
-void art_shapeEnodepoly(NODEINST*, INTSML, POLYGON*);
+INTBIG art_nodepolys(NODEINST*, INTBIG*);
+INTBIG art_nodeEpolys(NODEINST*, INTBIG*);
+void art_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
+void art_shapeEnodepoly(NODEINST*, INTBIG, POLYGON*);
 void art_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);
-INTSML art_arcpolys(ARCINST*);
-void art_shapearcpoly(ARCINST*, INTSML, POLYGON*);
+INTBIG art_arcpolys(ARCINST*);
+void art_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
