@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /******************** DIMENSIONS ********************/
 
 /* quarter unit fractions */
@@ -433,39 +438,34 @@
 #define	AUNROUTED  (2|(1<<16))
 #define	ALLGEN     AUNIV,AINVIS,AUNROUTED
 
-extern INTSML tech_realpolys;	/* polygon count without displayable variables */
-
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
+extern INTBIG tech_realpolys;	/* polygon count without displayable variables */
 
 /* technology prototypes */
 INTSML    tech_doinitprocess(TECHNOLOGY*);
 INTSML    tech_doaddportsandvars(TECHNOLOGY*);
 INTSML    tech_initcurvedarc(ARCINST*, INTSML);
-INTSML    tech_curvedarcpiece(ARCINST*, INTSML, POLYGON*, TECH_ARCS**);
-void      tech_addheadarrow(POLYGON*, INTSML, INTBIG, INTBIG);
+INTSML    tech_curvedarcpiece(ARCINST*, INTBIG, POLYGON*, TECH_ARCS**);
+void      tech_addheadarrow(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG);
 void      tech_adddoubleheadarrow(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
 void      tech_add2linebody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-INTSML    tech_moscutcount(NODEINST*, INTSML, INTSML, INTSML, INTSML);
-INTSML    tech_inittrans(INTSML, NODEINST*);
+INTBIG    tech_moscutcount(NODEINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG*);
+INTBIG    tech_inittrans(INTBIG, NODEINST*);
 INTSML    tech_pinusecount(NODEINST*, ARCPROTO*);
-INTSML    tech_displayablenvars(NODEINST*);
+INTBIG    tech_displayablenvars(NODEINST*);
 VARIABLE *tech_filldisplayablenvar(NODEINST*, POLYGON*);
-INTSML    tech_displayablefacetvars(NODEPROTO *np);
+INTBIG    tech_displayablefacetvars(NODEPROTO *np);
 VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly);
-INTSML    tech_displayableportvars(PORTPROTO *pp);
+INTBIG    tech_displayableportvars(PORTPROTO *pp);
 VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly);
 void      tech_filltrans(POLYGON*, TECH_POLYGON**, TECH_SERPENT*, NODEINST*, INTBIG,
-			INTSML, TECH_PORTS*);
-void      tech_moscutpoly(NODEINST*, INTSML, INTBIG[]);
+			INTBIG, TECH_PORTS*);
+void      tech_moscutpoly(NODEINST*, INTBIG, INTBIG[]);
 void      tech_fillpoly(POLYGON*, TECH_POLYGON*, NODEINST*, INTBIG, INTSML);
 void      tech_filltransport(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTBIG,
 			INTBIG, INTBIG, INTBIG, INTBIG);
 void      tech_fillportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, TECH_NODES*, INTSML);
 void      tech_resetnegated(ARCINST*);
-INTSML    tech_displayableavars(ARCINST*);
+INTBIG    tech_displayableavars(ARCINST*);
 VARIABLE *tech_filldisplayableavar(ARCINST*, POLYGON*);
 void      tech_makearrow(ARCINST*, POLYGON*);
 INTBIG    tech_getextendfactor(INTBIG, INTBIG);
