@@ -35,9 +35,9 @@ extern "C"
 
 /* prototypes for local routines */
 INTSML mocmos_initprocess(TECHNOLOGY*, INTSML);
-INTSML mocmos_arcpolys(ARCINST*);
+INTBIG mocmos_arcpolys(ARCINST*);
 void mocmos_setmode(INTSML, char*[]);
-void mocmos_shapearcpoly(ARCINST*, INTSML, POLYGON*);
+void mocmos_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
