@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /* all of the primitives */
 extern TECHNOLOGY *sch_tech;			/* the technology */
 
@@ -70,19 +75,14 @@ extern INTBIG      sch_inductancekey;	/* key for "SCHEM_inductance" */
 extern INTBIG      sch_twoportkey;		/* key for "SCHEM_twoport_type" */
 extern INTBIG      sch_functionkey;		/* key for "SCHEM_function" */
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for technology routines */
-void sch_shapearcpoly(ARCINST*, INTSML, POLYGON*);
-INTSML sch_arcpolys(ARCINST*);
+void sch_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
+INTBIG sch_arcpolys(ARCINST*);
 void sch_shapeportpoly(NODEINST*, PORTPROTO*, POLYGON*, XARRAY, INTSML);
-INTSML sch_nodeEpolys(NODEINST*);
-void sch_shapeEnodepoly(NODEINST*, INTSML, POLYGON*);
-void sch_shapenodepoly(NODEINST*, INTSML, POLYGON*);
-INTSML sch_nodepolys(NODEINST*);
+INTBIG sch_nodeEpolys(NODEINST*, INTBIG*);
+void sch_shapeEnodepoly(NODEINST*, INTBIG, POLYGON*);
+void sch_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
+INTBIG sch_nodepolys(NODEINST*, INTBIG*);
 void sch_setmode(INTSML, char*[]);
 INTBIG sch_request(char*, va_list);
 INTSML sch_initprocess(TECHNOLOGY*, INTSML);
