@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /******************** CONSTANTS ********************/
 
 /* the meaning of NODEINST->userbits: (bit 0 to 6 (0177) used globally) */
@@ -74,7 +79,7 @@
 #define	ECHOBIND           040000000		/* set to echo bound commands in full */
 #define	MENUON            0100000000		/* set if menu is on */
 #define	SHOWXY            0200000000		/* set to display cursor rather than TECH/LAMBDA */
-#define	TTYNOMORE         0400000000		/* set to skip -More- handling */
+#define	TTYAUDIT          0400000000		/* set to log messages window */
 #define TERMBEEP         01000000000		/* set to enable terminal beep */
 
 /* the meaning of "aid:user.USER_optionflags" */
@@ -95,12 +100,19 @@
 #define	NO3DPERSPECTIVE       020000		/* set to turn off perspective in 3D view */
 #define	FLIPINTERACTIVECON    040000		/* set to flip the sense of the interactive constraint */
 #define	CENTEREDPRIMITIVES   0100000		/* set to place primitives by centers */
+#define	AUTOSWITCHTECHNOLOGY 0200000		/* set to switch technology when facet changes */
 
 /* special keys */
+#define CTRLCKEY                  03		/* the Control-C key */
+#define CTRLDKEY                  04		/* the Control-D key */
+#define	DELETEKEY                010		/* the DELETE key */
+#define	TABKEY                   011		/* the TAB key */
+#define	ESCKEY                   033		/* the Escape key */
 #define	LEFTARROWKEY             034		/* the Left Arrow key */
 #define	RIGHTARROWKEY            035		/* the Right Arrow key */
 #define	UPARROWKEY               036		/* the Up Arrow key */
 #define	DOWNARROWKEY             037		/* the Down Arrow key */
+#define	BACKSPACEKEY            0177		/* the BACKSPACE key */
 #define FUNCTIONF1              0216
 #define FUNCTIONF2              0217
 #define FUNCTIONF3              0220
@@ -179,6 +191,7 @@
 #define	SNAPMODEINTER          01600		/* snapping mode: any intersection */
 #define	NONOVERLAPPABLEDISPLAY 04000		/* set to disallow overlappable layers in display */
 #define	NONPERSISTENTCURNODE  010000		/* clear to have current node be persistent */
+#define	CURFACETCHANGED       020000		/* set if current facet changed */
 
 /* cursor definitions */
 #define	NORMALCURSOR               0		/* a normal arrow cursor */
@@ -204,7 +217,6 @@ extern INTSML     (*us_displayroutine)(POLYGON*, WINDOWPART*); /* routine for gr
 extern INTSML       us_cursorstate;			/* see defines above */
 extern INTSML       us_normalcursor;		/* default cursor to use */
 extern INTSML       us_optionschanged;		/* nonzero if options changed */
-extern AIDENTRY    *us_aid;					/* the USER aid object */
 extern INTBIG       us_layer_letters;		/* cached key for "USER_layer_letters" */
 extern INTBIG       us_highlighted;			/* cached key for "USER_highlighted" */
 extern INTBIG       us_highlightstack;		/* cached key for "USER_highlightstack" */
@@ -244,9 +256,16 @@ extern INTBIG       us_useroptions;			/* mirror for "USER_optionflags" */
 extern INTBIG       us_tinyratio;			/* mirror for "USER_tiny_lambda_per_pixel" */
 extern INTBIG       us_separatechar;		/* separating character in port names */
 
+/* file type descriptors */
+extern INTBIG us_filetypecadrc;				/* Startup file */
+extern INTBIG us_filetypecolormap;			/* Color map */
+extern INTBIG us_filetypehelp;				/* Help */
+extern INTBIG us_filetypelog;				/* Log */
+extern INTBIG us_filetypemacro;				/* Macro */
+extern INTBIG us_filetypenews;				/* News */
+
 /* internal state */
 extern INTBIG       us_state;				/* miscellaneous state of user interface */
-extern EDITOR      *us_editorfree;			/* top of free list of editors */
 
 /* user interface state */
 extern NODEPROTO   *us_curnodeproto;		/* current nodeproto */
@@ -271,6 +290,7 @@ extern INTBIG       us_lastmeasurex, us_lastmeasurey;	/* last measured distance
 extern INTSML       us_validmesaure;		/* nonzero if a measure was done */
 extern FILE        *us_logrecord;			/* logging record file */
 extern FILE        *us_logplay;				/* logging playback file */
+extern FILE        *us_termaudit;			/* messages window auditing file */
 extern INTSML       us_logflushfreq;		/* session logging flush frequency */
 extern INTBIG       us_quickkeycount;		/* number of quick keys in initial setup */
 extern char       **us_quickkeylist;		/* quick keys in initial setup */
@@ -506,11 +526,6 @@ extern struct commandinfo us_lcommand[];
 
 /******************** PROTOTYPES ********************/
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for tool interface */
 void us_init(INTBIG*, char*[], AIDENTRY*);
 void us_done(void);
@@ -638,7 +653,7 @@ INTSML         us_alreadyfacetcenter(NODEPROTO *np);
 INTSML         us_appendargs(USERCOM*);
 void           us_arrayfromfile(char *file);
 void           us_beginchanges(void);
-INTSML         us_bottomrecurse(NODEINST*, PORTPROTO*, INTSML);
+INTSML         us_bottomrecurse(NODEINST*, PORTPROTO*);
 USERCOM       *us_buildcommand(INTSML, char*[]);
 void           us_buildquickkeylist(void);
 void           us_buildtexthighpoly(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, POLYGON*);
@@ -655,7 +670,7 @@ char          *us_commandvarname(INTSML);
 NODEPROTO     *us_convertfacet(NODEPROTO*, TECHNOLOGY*);
 void           us_copylisttofacet(GEOM**, NODEPROTO*, NODEPROTO*, INTSML, INTSML);
 void           us_copyobjects(WINDOWPART*);
-NODEPROTO     *us_copyrecursively(NODEPROTO*, char*, LIBRARY*, VIEW*, INTSML, char*);
+NODEPROTO     *us_copyrecursively(NODEPROTO*, char*, LIBRARY*, VIEW*, INTSML, INTSML, char*);
 INTSML         us_copyvars(INTBIG fromaddr, INTBIG fromtype, INTBIG toaddr, INTBIG totype);
 void           us_coverimplant(void);
 void           us_createexplorerstruct(void);
@@ -673,7 +688,7 @@ char          *us_describeportbits(PORTPROTO*);
 char          *us_describestyle(INTBIG);
 char          *us_describetextdescript(INTBIG);
 void           us_docommands(FILE*, INTSML, char*);
-void           us_doexpand(NODEINST*, INTSML, INTSML);
+void           us_doexpand(NODEINST*, INTBIG, INTBIG);
 void           us_dofillet(void);
 void           us_dokillfacet(NODEPROTO *np);
 void           us_dopeek(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, WINDOWPART*);
@@ -688,12 +703,16 @@ void           us_drawhorizontalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG,
 void           us_drawmenu(INTSML, WINDOWFRAME*);
 void           us_drawmenuentry(INTBIG, INTBIG, char*);
 INTSML         us_drawnodeinst(NODEINST*, INTSML, XARRAY, INTSML, WINDOWPART*);
+void           us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w);
+void           us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w);
 void           us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
 void           us_drawverticalslider(WINDOWPART*, INTSML, INTSML, INTSML, INTSML);
 void           us_drawverticalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_drawwindow(WINDOWPART*, INTSML);
+void           us_dumppulldownmenus(void);
 void           us_editvariabletext(VARIABLE*, INTBIG, INTBIG, char*);
 void           us_endchanges(WINDOWPART*);
+void           us_ensurepropertechnology(NODEPROTO *facet, char *forcedtechnology, INTSML always);
 void           us_ensurewindow(NODEPROTO*);
 void           us_erasegeometry(NODEPROTO*);
 void           us_erasenodeinst(NODEINST*);
@@ -719,7 +738,9 @@ void           us_freebindingparse(COMMANDBINDING *commandbinding);
 void           us_freecomekmemory(void);
 void           us_freecomtvmemory(void);
 void           us_freediacommemory(void);
+void           us_freeedemacsmemory(void);
 void           us_freeeditor(EDITOR*);
+void           us_freeedpacmemory(void);
 void           us_freeedtecpmemory(void);
 void           us_freehighmemory(void);
 void           us_freemiscmemory(void);
@@ -727,6 +748,7 @@ void           us_freenetmemory(void);
 void           us_freeparsememory(void);
 void           us_freewindowmemory(void);
 void           us_freestatusmemory(void);
+void           us_freetrackmemory(void);
 void           us_freeusercom(USERCOM*);
 void           us_fullview(NODEPROTO*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
 INTBIG        *us_getallhighlighted(void);
@@ -744,10 +766,12 @@ void           us_gethightextcenter(HIGHLIGHT*, INTBIG*, INTBIG*, INTSML*);
 void           us_getlowleft(NODEINST*, INTBIG*, INTBIG*);
 VARIABLE      *us_getmacro(char*);
 MACROPACK     *us_getmacropack(char*);
+NODEINST      *us_getnodeonarcinst(GEOM**, PORTPROTO**, GEOM*, PORTPROTO*, INTBIG, INTBIG);
 UINTBIG        us_getobject(INTSML, INTSML);
 TECHNOLOGY    *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 HIGHLIGHT     *us_getonehighlight(void);
 INTSML         us_getonesnappoint(INTBIG *x, INTBIG *y);
+INTSML         us_getplacementangle(NODEPROTO *np);
 POPUPMENU     *us_getpopupmenu(char*);
 void           us_getquickkeylist(INTBIG *quickkeycount, char ***quickkeylist);
 void           us_getslide(INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG*, INTBIG*);
@@ -788,7 +812,7 @@ void           us_makenewportproto(NODEPROTO*, NODEINST*, PORTPROTO*, char*, INT
 INTSML         us_makescreen(INTBIG*, INTBIG*, INTBIG*, INTBIG*, WINDOWPART*);
 void           us_maketextpoly(char*, WINDOWPART*, INTBIG, INTBIG, NODEINST*, TECHNOLOGY*, INTBIG, POLYGON*);
 void           us_manhattantravel(NODEINST*, INTSML);
-void           us_manymove(GEOM**, NODEINST**, INTSML, INTBIG, INTBIG);
+void           us_manymove(GEOM**, NODEINST**, INTBIG, INTBIG, INTBIG);
 INTSML         us_modarcbits(INTSML, INTSML, char*, GEOM**);
 void           us_modifytextdescript(HIGHLIGHT*, INTBIG);
 void           us_movetext(HIGHLIGHT*, INTSML, char*[]);
@@ -797,6 +821,7 @@ INTSML         us_needwindow(void);
 void           us_nettravel(NODEINST*, INTBIG);
 MACROPACK     *us_newmacropack(char*);
 char          *us_nextvars(void);
+NODEPROTO     *us_nodetocreate(INTSML getcontents, NODEPROTO *facet);
 INTSML         us_nulldisplayroutine(POLYGON*, WINDOWPART*);
 INTSML         us_pagetword(INTSML(*)(COMCOMP**, INTSML*), void(*)(char*), void(*)(void), void(*)(void), INTSML);
 void           us_parsebinding(char*, COMMANDBINDING*);
@@ -828,7 +853,7 @@ char          *us_removeampersand(char *name);
 void           us_removegetfacets(void);
 void           us_removeubchange(NODEPROTO*);
 void           us_renameport(PORTPROTO*, char*);
-NODEINST      *us_replacenodeinst(NODEINST *oldni, NODEPROTO *newnp);
+NODEINST      *us_replacenodeinst(NODEINST *oldni, NODEPROTO *newnp, INTSML ignoreportnames);
 void           us_rgbtohsv(INTSML, INTSML, INTSML, float*, float*, float*);
 INTBIG         us_rotatedescript(GEOM*, INTBIG);
 INTBIG         us_rotatedescriptI(GEOM*, INTBIG);
@@ -858,9 +883,11 @@ void           us_setmultiplehighlight(char*, INTSML);
 void           us_setnodeangle(WINDOWFRAME*);
 void           us_setnodeproto(NODEPROTO*);
 void           us_setnodeprotocenter(INTBIG, INTBIG, NODEPROTO*);
+NODEPROTO     *us_setscrolltocurrentfacet(INTBIG scrollitem, INTSML curinstance,
+					INTSML forcecurlib, INTSML justcells);
 void           us_settechname(WINDOWFRAME*);
 void           us_settrace(NODEINST*, INTBIG*, INTSML);
-INTSML         us_setunexpand(NODEINST*, INTSML);
+INTBIG         us_setunexpand(NODEINST*, INTBIG);
 void           us_setwindowsimulation(WINDOWPART*, INTSML);
 INTSML         us_setxy(INTSML, INTSML);
 void           us_shadowarcproto(WINDOWFRAME*, ARCPROTO*);
@@ -923,6 +950,7 @@ void           us_wanttoread(char*);
 INTBIG         us_widestarcinst(ARCPROTO*, NODEINST*, PORTPROTO*);
 INTSML         us_windowcansplit(WINDOWPART*, WINDOWPART*, WINDOWPART*);
 void           us_windowfit(WINDOWFRAME*, INTSML, INTSML);
+void           us_writeprotoname(PORTPROTO*, INTSML, XARRAY, INTSML, INTSML, WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_yankonenode(NODEINST*);
 
 /* terminal interface */
