@@ -33,69 +33,71 @@ extern "C"
 {
 #endif
 
-INTSML us_3ddepthdlog(char*[]);
-void us_aboutdlog(char*);
-INTSML us_alignmentdlog(char*[]);
-INTSML us_annularringdlog(char*[]);
+INTSML us_3ddepthdlog();
+INTSML us_aboutdlog(void);
+INTSML us_alignmentdlog(void);
+INTSML us_annularringdlog(void);
 INTSML us_arcsizedlog(char*[]);
 INTSML us_areadlog(char*, char*[], char*);
 INTSML us_arraydlog(char*[]);
-INTSML us_artlookdlog(char*[]);
-INTSML us_attributesdlog(char*[]);
+INTSML us_artlookdlog(void);
+INTSML us_attributesdlog(void);
 INTSML us_capacitancedlog(char*[], char*);
 INTSML us_colormixdlog(char *overlayernames[]);
-INTSML us_copyfacetdlog(char*, char*[]);
+INTSML us_copyfacetdlog(char*);
 INTSML us_createtodlog(char*[]);
-INTSML us_defarcdlog(char*[]);
-INTSML us_defnodedlog(char*[]);
-INTSML us_deftextdlog(char*, char*[]);
-INTSML us_dependentlibdlog(char*[]);
-INTSML us_editfacetdlog(char*, char*[]);
-INTSML us_facetdlog(char*[]);
+INTSML us_defarcdlog(void);
+INTSML us_defnodedlog(void);
+INTSML us_deftextdlog(char*);
+INTSML us_dependentlibdlog(void);
+INTSML us_editfacetdlog(char*);
+INTSML us_facetdlog(void);
 INTSML us_facetlist(char*, char*[], INTSML);
 INTSML us_filedlog(COMCOMP*, char*[], char*, INTSML);
-INTSML us_frameoptionsdlog(char *[]);
+INTSML us_frameoptionsdlog(void);
 INTSML us_gaindlog(char*, char*[], char*);
-INTSML us_griddlog(char*[]);
+INTSML us_griddlog(void);
 void   us_givemessagedialog(char*);
-INTSML us_helpdlog(char*, char*[]);
-INTSML us_highlayerlog(char*[]);
-INTSML us_iconstyledlog(char*[]);
+INTSML us_helpdlog(char*);
+INTSML us_highlayerlog(void);
+INTSML us_iconstyledlog(void);
 INTSML us_inductancedlog(char*[], char*);
-INTSML us_lambdadlog(char*[]);
-INTSML us_librarypathdlog(char*[]);
+INTSML us_lambdadlog(void);
+INTSML us_librarypathdlog(void);
+INTSML us_libtotechnologydlog(void);
 INTSML us_menudlog(char*[]);
 INTSML us_newfacetdlog(char*[]);
 INTSML us_newviewdlog(char*[]);
 INTSML us_nodesizedlog(char*[]);
 INTSML us_noyesalwaysdlog(char*, char*[]);
 INTSML us_noyesdlog(char*, char*[]);
-INTSML us_oldlibrarydlog(char*[]);
-INTSML us_optionsavingdlog(char*[]);
-INTSML us_patterndlog(char*[]);
-INTSML us_placetextdlog(char*[]);
-INTSML us_plotoptionsdlog(char*[]);
-INTSML us_portdisplaydlog(char*[]);
+INTSML us_oldlibrarydlog(void);
+INTSML us_optionsavingdlog(void);
+INTSML us_patterndlog(void);
+INTSML us_placetextdlog(void);
+INTSML us_plotoptionsdlog(void);
+INTSML us_portdisplaydlog(void);
 INTSML us_portdlog(char*[]);
-INTSML us_quickkeydlog(char*[]);
+INTSML us_purelayernodedlog(char*[]);
+INTSML us_quickkeydlog(void);
 INTSML us_quitdlog(char*, char*[]);
-INTSML us_renamedlog(char*[]);
-INTSML us_replacedlog(char*[]);
+INTSML us_renamedlog(void);
+INTSML us_replacedlog(void);
 INTSML us_resistancedlog(char*, char*[], char*);
-INTSML us_selectoptdlog(char*[]);
-INTSML us_selectportnetdlog(char*[], INTSML);
-INTSML us_showdlog(char*[], INTSML);
+INTSML us_selectoptdlog(void);
+INTSML us_selectportnodenetdlog(INTSML);
+INTSML us_showdlog(INTSML);
 INTSML us_sourcedlog(char*[], char*);
 INTSML us_spreaddlog(char*[]);
 INTSML us_technologydlog(char*, char*[]);
-INTSML us_techoptdlog(char*[]);
-INTSML us_techvarsdlog(char*[]);
-INTSML us_tracedlog(char*[]);
-INTSML us_variablesdlog(char*[]);
+INTSML us_techoptdlog(void);
+INTSML us_techvarsdlog(void);
+INTSML us_tracedlog(void);
+INTSML us_variablesdlog(void);
 INTSML us_vccsdlog(char*[], char*);
-INTSML us_visiblelayersdlog(char*, char*[]);
+INTSML us_visiblelayersdlog(char*);
 INTSML us_widlendlog(char*[], char*);
-INTSML us_windowviewdlog(char *paramstart[]);
+INTSML us_windowviewdlog(void);
 INTSML us_yesnodlog(char*, char*[]);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
