@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /* the meaning of "EDTEC_option" on nodes */
 #define	LAYERCOLOR      1					/* color (layer facet) */
 #define	LAYERSTYLE      2					/* style (layer facet) */
@@ -188,6 +193,8 @@ extern char           **us_teclayer_letters;
 extern INTBIG          *us_tecdrc_min_unconnected_dist;
 extern INTBIG          *us_tecdrc_min_connected_dist;
 extern INTBIG          *us_tecdrc_min_width;
+extern INTSML           us_teceddrclayers;
+extern char           **us_teceddrclayernames;
 extern INTBIG          *us_tec3d_height;
 extern INTBIG          *us_tec3d_thickness;
 extern INTBIG           us_tecarc_count;
@@ -202,20 +209,15 @@ extern LIST us_teclayer_functions[];
 extern LIST us_tecarc_functions[];
 extern LIST us_tecnode_functions[];
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for intramodule routines */
 void     us_tecedgetbbox(NODEINST *ni, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 INTSML   us_tecedgetdrc(char *str, INTSML *connected, INTBIG *amt, INTSML *layer1,
 			INTSML *layer2, INTSML maxlayers, char **layernames);
 EXAMPLE *us_tecedgetexamples(NODEPROTO *np, INTSML isnode);
-void     us_teceditdumparcs(FILE *f, TECHNOLOGY *tech);
-void     us_teceditdumplayers(FILE *f, TECHNOLOGY *tech);
-void     us_teceditdumpnodes(FILE *f, TECHNOLOGY *tech);
-void     us_teceditdumpvars(FILE *f, TECHNOLOGY *tech);
+void     us_teceditdumparcs(FILE *f, TECHNOLOGY *tech, char *techname);
+void     us_teceditdumplayers(FILE *f, TECHNOLOGY *tech, char *techname);
+void     us_teceditdumpnodes(FILE *f, TECHNOLOGY *tech, char *techname);
+void     us_teceditdumpvars(FILE *f, TECHNOLOGY *tech, char *techname);
 INTSML   us_teceditfindsequence(LIBRARY **dependentlibs, INTSML dependentlibcount,
 			char *match, char *seqname, NODEPROTO ***sequence);
 INTSML   us_teceditgetdependents(LIBRARY *lib, LIBRARY ***liblist);
@@ -236,7 +238,7 @@ void     us_tecedmakenode(NODEPROTO *np, INTBIG func, INTSML serp, INTSML square
 void     us_tecedpointout(NODEINST *ni, NODEPROTO *np);
 char    *us_tecedsamplename(NODEPROTO *layernp);
 void     us_tecedswapports(INTSML *p1, INTSML *p2, TECH_NODES *tlist);
-void     us_tecfromlibinit(LIBRARY *lib, INTSML dumpc);
+void     us_tecfromlibinit(LIBRARY *lib, char *techname, INTSML dumpc);
 void     us_tecedfreeexamples(EXAMPLE *ne);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
