@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /********** General Constants ******************************************/
 
 #define TRUE				1
@@ -41,6 +46,8 @@
 #define TARGET_RSIM			4				/* output target is NETLISP for RSIM */
 #define TARGET_SILOS		5				/* output target is SILOS  (V.01)*/
 
+extern AIDENTRY *vhdl_aid;
+
 /********** Token Definitions ******************************************/
 
 #define NOTOKEN				-1
@@ -429,7 +436,7 @@ typedef struct Idbnamelist
  * Description: Header file for VHDL compiler including parse tree structures and
  *  constants.
  *    Modified January 3, 1989 for IEEE Standard syntax
- *  Allan G. Jost, TEchnical University of Nova Scotia
+ *  Allan G. Jost, Technical University of Nova Scotia
  */
 
 #define	PARSE_ERR		-1					/* parsing error */
@@ -939,11 +946,6 @@ typedef struct Iliteral
 
 #define NONUMERICLITERAL	0
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for tool interface */
 void           vhdl_init(INTBIG*, char*[], AIDENTRY*);
 void           vhdl_done(void);
@@ -980,6 +982,7 @@ SIMPLENAME    *vhdl_parsesimplename(void);
 SUBTYPEIND    *vhdl_parsesubtype_indication(void);
 TYPE          *vhdl_parsetype(void);
 void           vhdl_print(char *fstring, ...);
+void           vhdl_printoneline(char *fstring, ...);
 void           vhdl_reporterrormsg(TOKENLIST*, char*);
 SYMBOLTREE    *vhdl_searchsymbol(IDENTTABLE*, SYMBOLLIST*);
 INTSML         vhdl_semantic(void);
