@@ -185,11 +185,10 @@ INTSML io_readciflibrary(LIBRARY *lib)
 {
 	REGISTER FILE *f;
 	char *filename;
-	REGISTER INTBIG i;
-	REGISTER VARIABLE *var;
+	REGISTER INTBIG i, *curstate;
 
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var != NOVARIABLE && (var->addr&CIFINSQUARE) != 0) io_cifroundwires = 0;
+	curstate = io_getstatebits();
+	if ((curstate[0]&CIFINSQUARE) != 0) io_cifroundwires = 0;
 		else io_cifroundwires = 1;
 
 	/* initialize all lists and the searching routines */
@@ -199,16 +198,16 @@ INTSML io_readciflibrary(LIBRARY *lib)
 	if (io_initfind()) return(1);
 
 	/* get the cif file */
-	f = xopen(lib->libfile, FILETYPECIF, "", &filename);
+	f = xopen(lib->libfile, io_filetypecif, "", &filename);
 	if (f == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
 	if (setjmp(io_filerror))
 	{
-		ttyputerr("Error reading CIF");
+		ttyputerr(_("Error reading CIF"));
 		return(1);
 	}
 
@@ -230,39 +229,29 @@ INTSML io_readciflibrary(LIBRARY *lib)
 INTSML io_interpret(FILE *file)
 {
 	INTBIG comcount, left, right, bottom, top;
-	float fleft, fright, fbottom, ftop, lambda;
 
 	if (io_initparser())
 	{
-		ttyputerr("Error initializing parser");
+		ttyputerr(_("Error initializing parser"));
 		return(1);
 	}
 	if (io_initinterpreter())
 	{
-		ttyputerr("Error initializing interpreter");
+		ttyputerr(_("Error initializing interpreter"));
 		return(1);
 	}
 	if (io_infromfile(file)) return(1);
 	comcount = io_parsefile();		/* read in the cif */
 	(void)io_doneparser();
-	if (stopping("CIF input") != 0) return(1);
-	ttyputverbose("Total CIF commands: %ld",comcount);
+	if (stopping(STOPREASONCIF)) return(1);
+	ttyputverbose(_("Total CIF commands: %ld"), comcount);
 
 	if (io_fatalerrors() > 0) return(1);
 
-	lambda = (float)el_curtech->deflambda;
 	io_iboundbox(&left, &right, &bottom, &top);
 
 	/* construct a list: first step in the conversion */
 	(void)io_createlist();
-
-	fleft   = ((float)left)   / lambda;
-	fright  = ((float)right)  / lambda;
-	fbottom = ((float)bottom) / lambda;
-	ftop    = ((float)top)    / lambda;
-	ttyputverbose("The bounding box is %ld<=X<=%ld, %ld<=Y<=%ld", scalefromdispunit(fleft, DISPUNITCMIC),
-		scalefromdispunit(fright, DISPUNITCMIC), scalefromdispunit(fbottom, DISPUNITCMIC),
-			scalefromdispunit(ftop, DISPUNITCMIC));
 	return(0);
 }
 
@@ -280,7 +269,7 @@ INTSML io_listtonodes(LIBRARY *lib)
 	io_incell = NONODEPROTO;
 	for(io_curlist = io_ciflist; io_curlist != NOCIFLIST; io_curlist = io_curlist->next)
 	{
-		if (stopping("CIF input") != 0)
+		if (stopping(STOPREASONCIF))
 		{
 			if (io_verbose < 0) DiaDoneDialog();
 			return(1);
@@ -349,17 +338,16 @@ NODEPROTO *io_nodes_start(LIBRARY *lib)
 	cifcell->addr = newnodeproto(io_curnodeprotoname, lib);
 	if (cifcell->addr == NONODEPROTO)
 	{
-		ttyputerr("Cannot create the cell %s", io_curnodeprotoname);
+		ttyputerr(_("Cannot create the cell %s"), io_curnodeprotoname);
 		return(NONODEPROTO);
 	}
 
 	if (io_verbose < 0)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("Reading ");
-		(void)addstringtoinfstr(io_curnodeprotoname);
+		(void)formatinfstr(_("Reading %s"), io_curnodeprotoname);
 		DiaSetText(2, returninfstr());
-	} else if (io_verbose > 0) ttyputmsg("Reading %s", io_curnodeprotoname);
+	} else if (io_verbose > 0) ttyputmsg(_("Reading %s"), io_curnodeprotoname);
 	return(cifcell->addr);
 }
 
@@ -375,7 +363,7 @@ INTSML io_nodes_box(void)
 	if (node == NONODEPROTO)
 	{
 		layname = layername(el_curtech, cb->lay);
-		ttyputerr("Cannot find primitive to use for layer '%s' (number %d)",
+		ttyputerr(_("Cannot find primitive to use for layer '%s' (number %d)"),
 			layname, cb->lay);
 		return(1);
 	}
@@ -388,7 +376,7 @@ INTSML io_nodes_box(void)
 		scalefromdispunit((float)hy, DISPUNITCMIC), 0, (INTSML)r, io_curcell->addr) == NONODEINST)
 	{
 		layname = layername(el_curtech, cb->lay);
-		ttyputerr("Problems creating a box on layer %s in facet %s", layname,
+		ttyputerr(_("Problems creating a box on layer %s in facet %s"), layname,
 			describenodeproto(io_curcell->addr));
 		return(1);
 	}
@@ -418,7 +406,7 @@ INTSML io_nodes_poly(void)
 			scalefromdispunit((float)hy, DISPUNITCMIC), 0, 0, io_curcell->addr);
 	if (newni == NONODEINST)
 	{
-		ttyputerr("Problems creating a polygon on layer %d in facet %s", cp->lay,
+		ttyputerr(_("Problems creating a polygon on layer %d in facet %s"), cp->lay,
 			describenodeproto(io_curcell->addr));
 		return(1);
 	}
@@ -455,7 +443,7 @@ INTSML io_nodes_call(void)
 	cc = (CCALL *)io_curlist->member;
 	if ((cell = io_findcifcell(cc->cindex)) == NOCIFCELL)
 	{
-		ttyputerr("Referencing an undefined cell");
+		ttyputerr(_("Referencing an undefined cell"));
 		return(1);
 	}
 	rot = trans = 0;
@@ -496,7 +484,7 @@ INTSML io_nodes_call(void)
 			scalefromdispunit((float)t, DISPUNITCMIC), (INTSML)trans, (INTSML)rot, io_curcell->addr) ==
 				NONODEINST)
 	{
-		ttyputerr("Problems creating an instance of cell %s in facet %s",
+		ttyputerr(_("Problems creating an instance of cell %s in facet %s"),
 			describenodeproto(cell->addr), describenodeproto(io_curcell->addr));
 		return(1);
 	}
@@ -544,20 +532,21 @@ INTSML io_initfind(void)
 	REGISTER char *ch, *ch2;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *nodeinst;
-	REGISTER INTSML total, i, j, k;
+	REGISTER INTBIG total, i, j, k;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get the array of CIF names */
 	io_cifnames = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
 	if (io_cifnames == NOVARIABLE)
 	{
-		ttyputerr("There are no CIF layer names assigned in the %s technology", el_curtech->techname);
+		ttyputerr(_("There are no CIF layer names assigned in the %s technology"),
+			el_curtech->techname);
 		return(-1);
 	}
 	io_varlength = (INTSML)getlength(io_cifnames);
 	if (io_varlength < el_curtech->layercount)
 	{
-		ttyputerr("Warning: CIF layer information is bad for technology %s.  Use 'CIF Options' to fix it",
+		ttyputerr(_("Warning: CIF layer information is bad for technology %s.  Use 'CIF Options' to fix it"),
 			el_curtech->techname);
 		return(-1);
 	}
@@ -581,7 +570,7 @@ INTSML io_initfind(void)
 		nodeinst->highx = np->highx;
 		nodeinst->lowy  = np->lowy;
 		nodeinst->highy = np->highy;
-		i = nodepolys(nodeinst);
+		i = nodepolys(nodeinst, 0);
 		if (i != 1) continue;
 		shapenodepoly(nodeinst, 0, poly);
 		if (poly->layer < 0) continue;
@@ -607,7 +596,7 @@ INTSML io_initfind(void)
 			nodeinst->highx = np->highx;
 			nodeinst->lowy  = np->lowy;
 			nodeinst->highy = np->highy;
-			(void)nodepolys(nodeinst);
+			(void)nodepolys(nodeinst, 0);
 			shapenodepoly(nodeinst, 0, poly);
 			ch2 = ((char **)io_cifnames->addr)[poly->layer];
 			if (strcmp(ch, ch2) != 0) continue;
@@ -625,7 +614,7 @@ INTSML io_initfind(void)
 			nodeinst->highx = np->highx;
 			nodeinst->lowy  = np->lowy;
 			nodeinst->highy = np->highy;
-			j = nodepolys(nodeinst);
+			j = nodepolys(nodeinst, 0);
 			for(k=0; k<j; k++)
 			{
 				shapenodepoly(nodeinst, 0, poly);
@@ -667,7 +656,7 @@ INTBIG io_findlayernum(char *name)
 	}
 	(void)allocstring(&io_cifnotfoundlist[io_cifnotfoundcount], name, io_aid->cluster);
 	io_cifnotfoundcount++;
-	ttyputmsg("Layer %s not found", name);
+	ttyputmsg(_("Layer %s not found"), name);
 	return(-1);
 }
 
@@ -692,7 +681,7 @@ CIFCELL *io_newcifcell(void)
 	newcc = (CIFCELL *)emalloc((sizeof (CIFCELL)), io_aid->cluster);
 	if (newcc == (CIFCELL *) 0)
 	{
-		ttyputerr("Not enough memory allocated for CIFCELL");
+		ttyputerr(_("Not enough memory allocated for CIFCELL"));
 		return(NOCIFCELL);
 	}
 	newcc->nextcell = NOCIFCELL;
@@ -729,7 +718,7 @@ CIFLIST *io_newciflist(INTSML id)
 	newcl = (CIFLIST *)emalloc((sizeof (CIFLIST)), io_aid->cluster);
 	if (newcl == (CIFLIST *) 0)
 	{
-		ttyputerr("Not enough memory allocated for CIFLIST");
+		ttyputerr(_("Not enough memory allocated for CIFLIST"));
 		return(NOCIFLIST);
 	}
 	newcl->next = NOCIFLIST;
@@ -830,7 +819,7 @@ CTRANS *io_newctrans(void)
 	newct = (CTRANS *)emalloc((sizeof (CTRANS)), io_aid->cluster);
 	if (newct == (CTRANS *) 0)
 	{
-		ttyputerr("Not enough memory allocated for CTRANS");
+		ttyputerr(_("Not enough memory allocated for CTRANS"));
 		return(NOCTRANS);
 	}
 	newct->next = NOCTRANS;
@@ -946,14 +935,14 @@ void io_outputpolygon(INTSML lay, char *ppath)
 	cp->x = emalloc((lim * SIZEOFINTBIG), io_aid->cluster);
 	if (cp->x == 0)
 	{
-		ttyputerr("No memory for polygon");
+		ttyputnomemory();
 		cp->lim = 0;
 		return;
 	}
 	cp->y = emalloc((lim * SIZEOFINTBIG), io_aid->cluster);
 	if (cp->y == 0)
 	{
-		ttyputerr("No memory for polygon");
+		ttyputnomemory();
 		cp->lim = 0;
 		return;
 	}
