@@ -207,7 +207,7 @@ INTBIG io_doneinterpreter(void)
 {
 	if (io_nulllayererrors != 0)
 	{
-		io_report("output on null layer", FATALSEMANTIC);
+		io_report(_("output on null layer"), FATALSEMANTIC);
 	}
 
 	io_freestorage();
@@ -227,7 +227,7 @@ void io_idefstart(INTBIG symbol,INTBIG mtl,INTBIG div)
 	{
 		/* redefining this symbol */
 		char mess[300];
-		(void)sprintf(mess, "attempt to redefine symbol %lu (ignored)", symbol);
+		(void)sprintf(mess, _("attempt to redefine symbol %lu (ignored)"), symbol);
 		io_report(mess, ADVISORY);
 		io_cifignore = 1;
 		return;
@@ -236,7 +236,7 @@ void io_idefstart(INTBIG symbol,INTBIG mtl,INTBIG div)
 	io_cifdefinprog = 1;
 	if (mtl != 0 && div != 0) io_cifscalefactor = ((float) mtl)/((float) div); else
 	{
-		io_report("illegal scale factor, ignored", ADVISORY);
+		io_report(_("illegal scale factor, ignored"), ADVISORY);
 		io_cifscalefactor = 1.0;
 	}
 	io_cifbackuplayer = io_cifcurlayer;	/* save current layer */
@@ -271,7 +271,7 @@ void io_idefend(void)
 void io_ideletedef(INTBIG n)
 {
 	io_cifstatesince++;
-	io_report("DD not supported (ignored)", ADVISORY);
+	io_report(_("DD not supported (ignored)"), ADVISORY);
 }
 
 void io_ilayer(char *lname)
@@ -300,7 +300,7 @@ void io_iend(void)
 	if (io_cifnamepending)
 	{
 		efree((char *)io_cifnstored);
-		io_report("no instance to match name command", ADVISORY);
+		io_report(_("no instance to match name command"), ADVISORY);
 		io_cifnamepending = 0;
 	}
 }
@@ -361,7 +361,7 @@ void io_iwire(INTBIG width, char *a)
 	obj = (wire *)emalloc((length-1)*sizeof(point)+sizeof(wire), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_iwire", FATALINTERNAL);
+		io_report(_("no space: io_iwire"), FATALINTERNAL);
 		return;
 	}
 
@@ -412,14 +412,14 @@ void io_iflash(INTBIG diameter,point center)
 	}
 	if (diameter == 0)
 	{
-		io_report("flash with null diamter, ignored", ADVISORY);
+		io_report(_("flash with null diamter, ignored"), ADVISORY);
 		return;
 	}
 
 	obj = (flash *)emalloc(sizeof(flash), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_iflash", FATALINTERNAL);
+		io_report(_("no space: io_iflash"), FATALINTERNAL);
 		return;
 	}
 	obj->fl_type = FLASH;
@@ -460,14 +460,14 @@ void io_ipolygon(char *a)
 	}
 	if (length < 3)
 	{
-		io_report("polygon with < 3 pts in path, ignored", ADVISORY);
+		io_report(_("polygon with < 3 pts in path, ignored"), ADVISORY);
 		return;
 	}
 
 	obj = (polygon *)emalloc((length-1)*sizeof(point)+sizeof(polygon), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_ipolygon", FATALINTERNAL);
+		io_report(_("no space: io_ipolygon"), FATALINTERNAL);
 		return;
 	}
 
@@ -530,7 +530,7 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 	}
 	if (length == 0 || width == 0)
 	{
-		io_report("box with null length or width specified, ignored", ADVISORY);
+		io_report(_("box with null length or width specified, ignored"), ADVISORY);
 		return;
 	}
 
@@ -554,13 +554,13 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 		(xr == 0 && (length%2) == 0 && (width%2) == 0 &&
 		(center.x-halfw) == tl && (center.x+halfw) == tr &&
 		(center.y-halfl) == tb && (center.y+halfl) == tt)
-	 )
+	)
 	{
 		mbox *obj;
 		obj = (mbox *)emalloc(sizeof(mbox), io_aid->cluster);
 		if (obj == NIL)
 		{
-			io_report("no space: io_ibox", FATALINTERNAL);
+			io_report(_("no space: io_ibox"), FATALINTERNAL);
 			return;
 		}
 		obj->mb_type = MBOX;
@@ -592,7 +592,7 @@ void io_ibox(INTBIG length, INTBIG width, point center, INTBIG xr, INTBIG yr)
 		obj = (box *)emalloc(sizeof(box), io_aid->cluster);
 		if (obj == NIL)
 		{
-			io_report("no space: io_ibox", FATALINTERNAL);
+			io_report(_("no space: io_ibox"), FATALINTERNAL);
 			return;
 		}
 		obj->bo_type = RECTANGLE;
@@ -648,7 +648,7 @@ void io_icall(INTBIG symbol, char *list)
 		   case ROTATE:
 				io_rotate(temp.guts.ro.xrot, temp.guts.ro.yrot); break;
 		   default:
-				io_report("interpreter: no such transformation", FATALINTERNAL);
+				io_report(_("interpreter: no such transformation"), FATALINTERNAL);
 		}
 		io_appendtentry((tlist)newtlist, temp);	/* copy the list */
 	}
@@ -656,7 +656,7 @@ void io_icall(INTBIG symbol, char *list)
 	obj = (symcall *)emalloc(sizeof(symcall), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_icall", FATALINTERNAL);
+		io_report(_("no space: io_icall"), FATALINTERNAL);
 		io_poptrans();
 		return;
 	}
@@ -672,7 +672,7 @@ void io_icall(INTBIG symbol, char *list)
 	if (io_cifnamepending)
 	{
 		if (io_cifstatesince != 0)
-			io_report("statements between name and instance", ADVISORY);
+			io_report(_("statements between name and instance"), ADVISORY);
 		obj->sy_name = io_cifnstored;
 		io_cifnamepending = 0;
 	} else
@@ -696,17 +696,17 @@ void io_isymname(char *name)
 	if (io_cifignore) return;
 	if (!io_cifdefinprog)
 	{
-		io_report("no symbol to name", FATALSEMANTIC);
+		io_report(_("no symbol to name"), FATALSEMANTIC);
 		return;
 	}
 	if (*name == '\0')
 	{
-		io_report("null symbol name ignored", ADVISORY);
+		io_report(_("null symbol name ignored"), ADVISORY);
 		return;
 	}
 	if (io_cifnamed)
 	{
-		io_report("symbol is already named, new name ignored", FATALSEMANTIC);
+		io_report(_("symbol is already named, new name ignored"), FATALSEMANTIC);
 		return;
 	}
 	io_cifnamed = 1;
@@ -718,13 +718,13 @@ void io_iinstname(char *name)
 	if (io_cifignore) return;
 	if (*name == '\0')
 	{
-		io_report("null instance name ignored", ADVISORY);
+		io_report(_("null instance name ignored"), ADVISORY);
 		return;
 	}
 	if (io_cifnamepending)
 	{
 		efree((char *)io_cifnstored);
-		io_report("there is already a name pending, new name replaces it", ADVISORY);
+		io_report(_("there is already a name pending, new name replaces it"), ADVISORY);
 	}
 	io_cifnamepending = 1;
 	io_cifstatesince = 0;
@@ -740,13 +740,13 @@ void io_igeoname(char *name, point pt, INTBIG lay)
 	if (io_cifignore) return;
 	if (*name == '\0')
 	{
-		io_report("null geometry name ignored", ADVISORY);
+		io_report(_("null geometry name ignored"), ADVISORY);
 		return;
 	}
 	obj = (gname *)emalloc(sizeof(gname), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_igeoname", FATALINTERNAL);
+		io_report(_("no space: io_igeoname"), FATALINTERNAL);
 		return;
 	}
 
@@ -785,13 +785,13 @@ void io_ilabel(char *name, point pt)
 	if (io_cifignore) return;
 	if (*name == '\0')
 	{
-		io_report("null label ignored", ADVISORY);
+		io_report(_("null label ignored"), ADVISORY);
 		return;
 	}
 	obj = (label *)emalloc(sizeof(label), io_aid->cluster);
 	if (obj == NIL)
 	{
-		io_report("no space: io_ilabel", FATALINTERNAL);
+		io_report(_("no space: io_ilabel"), FATALINTERNAL);
 		return;
 	}
 
@@ -867,7 +867,7 @@ stentry *io_lookupsym(INTBIG sym)
 		io_cifstable[hadd] = (stentry *)emalloc(sizeof(stentry), io_aid->cluster);
 		if (io_cifstable[hadd] == NIL)
 		{
-			io_report("no space: io_lookupsym", FATALINTERNAL);
+			io_report(_("no space: io_lookupsym"), FATALINTERNAL);
 			return(0);
 		}
 		io_newstentry(io_cifstable[hadd], sym);
@@ -885,7 +885,7 @@ stentry *io_lookupsym(INTBIG sym)
 	old->st_overflow = (stentry *)emalloc(sizeof(stentry), io_aid->cluster);
 	if (old->st_overflow == NIL)
 	{
-		io_report("no space: io_lookupsym", FATALINTERNAL);
+		io_report(_("no space: io_lookupsym"), FATALINTERNAL);
 		return(0);
 	}
 	io_newstentry(old->st_overflow, sym);
@@ -924,7 +924,7 @@ void io_initmm(point foo)
 {
 	if (++io_cifmmptr >= MAXMMSTACK)
 	{
-		io_report("io_initmm: out of stack", FATALINTERNAL);
+		io_report(_("io_initmm: out of stack"), FATALINTERNAL);
 		return;
 	}
 	io_cifmmleft[io_cifmmptr] = foo.x;   io_cifmmright[io_cifmmptr] = foo.x;
@@ -933,7 +933,7 @@ void io_initmm(point foo)
 
 void io_donemm(void)
 {
-	if (io_cifmmptr < 0) io_report("io_donemm: pop from empty stack", FATALINTERNAL);
+	if (io_cifmmptr < 0) io_report(_("io_donemm: pop from empty stack"), FATALINTERNAL);
 		else io_cifmmptr--;
 }
 
@@ -976,14 +976,14 @@ void io_findcallbb(symcall *object)		/* find the bb for this particular call */
 	if (!thisst->st_defined)
 	{
 		char mess[50];
-		(void)sprintf(mess, "call to undefined symbol %lu", thisst->st_symnumber);
+		(void)sprintf(mess, _("call to undefined symbol %lu"), thisst->st_symnumber);
 		io_report(mess, FATALSEMANTIC);
 		return;
 	}
 	if (thisst->st_expanded)
 	{
 		char mess[50];
-		(void)sprintf(mess, "recursive call on symbol %lu", thisst->st_symnumber);
+		(void)sprintf(mess, _("recursive call on symbol %lu"), thisst->st_symnumber);
 		io_report(mess, FATALSEMANTIC);
 		return;
 	} else thisst->st_expanded = 1;		/* mark as under expansion */
@@ -1026,7 +1026,7 @@ static void io_findbb(stentry *sym)		/* find bb for sym */
 	if (ob == NIL)			/* empty symbol */
 	{
 		char mess[100];
-		(void)sprintf(mess, "symbol %lu has no geometry in it",
+		(void)sprintf(mess, _("symbol %lu has no geometry in it"),
 			sym->st_symnumber);
 		io_report(mess, ADVISORY);
 		sym->st_bb.l = 0;   sym->st_bb.r = 0;
@@ -1105,7 +1105,7 @@ void io_freeonedef(struct kludge *cur)
 			efree((char *)cur);
 			break;
 		default:
-			io_report("unknown def contents", FATALSEMANTIC);
+			io_report(_("unknown def contents"), FATALSEMANTIC);
 	}
 }
 
@@ -1145,7 +1145,7 @@ char io_inittrans(void)
 	io_cifstacktop = (transform)emalloc(sizeof(tmatrix), io_aid->cluster);
 	if (io_cifstacktop == NIL)
 	{
-		io_report("no space: io_inittrans", FATALINTERNAL);
+		io_report(_("no space: io_inittrans"), FATALINTERNAL);
 		return(1);
 	}
 	io_clear(io_cifstacktop);
@@ -1156,7 +1156,7 @@ char io_inittrans(void)
 	io_cifcarray = (context *)emalloc((CONTSIZE*sizeof(context)), io_aid->cluster);
 	if (io_cifcarray == NIL)
 	{
-		io_report("no space: intitrans", FATALINTERNAL);
+		io_report(_("no space: intitrans"), FATALINTERNAL);
 		return(1);
 	}
 	io_cifcarray[0].base = io_cifstacktop;
@@ -1211,7 +1211,7 @@ INTSML io_swapcontext(INTBIG id)
 {
 	if (id >= io_cifclength || io_cifcarray[id].refcount == 0)
 	{
-		io_report("illegal swap context", FATALINTERNAL);
+		io_report(_("illegal swap context"), FATALINTERNAL);
 		return(-1);
 	}
 	if (io_cifcurcontext == id) return(0);
@@ -1225,7 +1225,7 @@ INTSML io_increfcount(INTBIG id)
 {
 	if (id >= io_cifclength)
 	{
-		io_report("illegal context: io_increfcount", FATALINTERNAL);
+		io_report(_("illegal context: io_increfcount"), FATALINTERNAL);
 		return(-1);
 	}
 	io_cifcarray[id].refcount++;
@@ -1236,7 +1236,7 @@ INTSML io_decrefcount(INTBIG id)
 {
 	if (id >= io_cifclength || io_cifcarray[id].refcount == 0)
 	{
-		io_report("illegal context: io_decrefcount", FATALINTERNAL);
+		io_report(_("illegal context: io_decrefcount"), FATALINTERNAL);
 		return(-1);
 	}
 	io_cifcarray[id].refcount--;
@@ -1249,7 +1249,7 @@ void io_pushtrans(void)
 	{
 		io_cifstacktop->next = (transform)emalloc(sizeof(tmatrix), io_aid->cluster);
 		if (io_cifstacktop->next == NIL)
-			io_report("no space: io_pushtrans", FATALINTERNAL);
+			io_report(_("no space: io_pushtrans"), FATALINTERNAL);
 		io_clear(io_cifstacktop->next);
 		io_cifstacktop->next->prev = io_cifstacktop;
 		io_cifstacktop = io_cifstacktop->next;
@@ -1264,17 +1264,17 @@ void io_pushtrans(void)
 void io_poptrans(void)
 {
 	if (io_cifstacktop->prev != NIL) io_cifstacktop = io_cifstacktop->prev;
-		else io_report("pop, empty trans stack", FATALINTERNAL);
+		else io_report(_("pop, empty trans stack"), FATALINTERNAL);
 }
 
 static void io_matmult(transform l, transform r, transform result)
 {
 	if (l == NIL || r == NIL || result == NIL)
-		io_report("null arg to io_matmult", FATALINTERNAL);
+		io_report(_("null arg to io_matmult"), FATALINTERNAL);
 	if (result->multiplied)
 	{
 		io_dumpstack();
-		io_report("can't re-mult tmatrix", FATALINTERNAL);
+		io_report(_("can't re-mult tmatrix"), FATALINTERNAL);
 		return;
 	}
 	if (!r->multiplied)
@@ -1291,7 +1291,7 @@ static void io_mmult(transform l,transform r,transform result)
 {
 	if (l == NIL || r == NIL || result == NIL)
 	{
-		io_report("null arg to io_mmult", FATALINTERNAL);
+		io_report(_("null arg to io_mmult"), FATALINTERNAL);
 		return;
 	}
 	if (l->type == TIDENT) io_assign(r, result); else
@@ -1449,7 +1449,7 @@ point io_transpoint(point foo)
 void io_dumpstack(void)
 {
 	transform foo = io_cifstacktop;
-	ttyputmsg("current context is %u", io_cifcurcontext);
+	ttyputmsg(_("current context is %u"), io_cifcurcontext);
 	while (foo != NIL)
 	{
 		io_printmat(foo);
@@ -1584,9 +1584,9 @@ static itementry *io_newnode(void)		/* return a new itementry */
 		ans = (itementry *)emalloc(sizeof(itementry), io_aid->cluster);
 		if (ans == NIL)
 		{
-			io_report("io_newnode: no space", FATALINTERNAL);
+			io_report(_("io_newnode: no space"), FATALINTERNAL);
 			return(NIL);
-		} else return (ans);
+		} else return(ans);
 	}
 	ans = io_cifittop;
 	io_cifittop = io_cifittop->it_same;
@@ -1717,7 +1717,7 @@ void io_iboundbox(INTBIG *l, INTBIG *r, INTBIG *b, INTBIG *t)
 
 	if (h == NIL)
 	{
-		io_report("item list is empty!", ADVISORY);
+		io_report(_("item list is empty!"), ADVISORY);
 		return;
 	}
 
@@ -1762,7 +1762,7 @@ void io_iboundbox(INTBIG *l, INTBIG *r, INTBIG *b, INTBIG *t)
 
 INTSML io_createlist(void)
 {
-	if (!io_endseen()) ttyputmsg("missing End command, assumed");
+	if (!io_endseen()) ttyputmsg(_("missing End command, assumed"));
 	if (io_fatalerrors() > 0) return(-1);
 	io_sendlist(io_cifilist);		/* sendlist deletes nodes */
 	io_cifilist = NIL;
@@ -1872,7 +1872,7 @@ void io_item(objectptr object)		/* a bare item has been found */
 
 	if (object == NIL)
 	{
-		io_report("item: null object", FATALINTERNAL);
+		io_report(_("item: null object"), FATALINTERNAL);
 		return;
 	}
 	obj = (struct kludge *)object;
@@ -2107,7 +2107,7 @@ char *io_makepath(void)
 	a = (path)emalloc(sizeof(*a), io_aid->cluster);
 	if (a == NIL)
 	{
-		io_report("free storage exhausted", FATALINTERNAL);
+		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return(0);
 	}
 	a->pfirst = NIL;
@@ -2211,7 +2211,7 @@ char *io_maketlist(void)
 	a = (tlist)emalloc(sizeof(*a), io_aid->cluster);
 	if (a == NIL)
 	{
-		io_report("free storage exhausted", FATALINTERNAL);
+		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return(0);
 	}
 	a->tfirst = NIL;
@@ -2342,11 +2342,11 @@ void io_report(char *mess, INTBIG kind)
 
 	switch (kind)
 	{
-		case FATALINTERNAL: ttyputmsg("Fatal internal error: %s", mess);  break;
-		case FATALSYNTAX:   ttyputmsg("Syntax error: %s", mess);          break;
-		case FATALSEMANTIC: ttyputmsg("Error: %s", mess);                 break;
-		case FATALOUTPUT:   ttyputmsg("Output error: %s", mess);          break;
-		case ADVISORY:      ttyputmsg("Warning: %s", mess);               break;
+		case FATALINTERNAL: ttyputmsg(_("Fatal internal error: %s"), mess);  break;
+		case FATALSYNTAX:   ttyputmsg(_("Syntax error: %s"), mess);          break;
+		case FATALSEMANTIC: ttyputmsg(_("Error: %s"), mess);                 break;
+		case FATALOUTPUT:   ttyputmsg(_("Output error: %s"), mess);          break;
+		case ADVISORY:      ttyputmsg(_("Warning: %s"), mess);               break;
 		default:            ttyputmsg("%s", mess);                        break;
 	}
 
@@ -2401,7 +2401,7 @@ INTBIG io_initparser(void)
 
 INTBIG io_doneparser(void)
 {
-	if (!io_cifendisseen) io_report("missing End command", FATALSYNTAX);
+	if (!io_cifendisseen) io_report(_("missing End command"), FATALSYNTAX);
 	return(io_doneinput() || io_donetypes() || io_doneerror());
 }
 
@@ -2447,7 +2447,7 @@ static char io_semi(void)
 
 	io_blank();
 	if (io_peek() == ';') {(void) io_getch(); ans = 1; io_blank();}
-	return (ans);
+	return(ans);
 }
 
 static char io_sp(void)
@@ -2470,7 +2470,7 @@ static char *io_utext(void)
 
 	if ((user = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
 	{
-		io_report("free storage exhausted", FATALINTERNAL);
+		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return((char *)0);
 	}
 	*user = '\0';
@@ -2484,7 +2484,7 @@ static char *io_utext(void)
 			olduser = user;
 			user = (char *)emalloc(maxsize, io_aid->cluster);
 			if (user == NIL)
-				io_report("free storage exhausted", FATALINTERNAL);
+				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) user[i] = olduser[i];
 			efree(olduser);
 		}
@@ -2502,7 +2502,7 @@ static char *io_name(void)
 
 	if ((ntext = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
 	{
-		io_report("free storage exhausted", FATALINTERNAL);
+		io_report(_("free storage exhausted"), FATALINTERNAL);
 		return((char *) 0);
 	}
 	*ntext = '\0';
@@ -2520,7 +2520,7 @@ static char *io_name(void)
 			maxsize += 80;
 			oldntext = ntext;
 			if ((ntext = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
-				io_report("free storage exhausted", FATALINTERNAL);
+				io_report(_("free storage exhausted"), FATALINTERNAL);
 			for(i=0; i<maxsize-80; i++) ntext[i] = oldntext[i];
 			efree(oldntext);
 		}
@@ -2789,7 +2789,7 @@ INTBIG io_parsestatement(void)
 				command = COMMENT;
 				if ((comment = (char *)emalloc(maxsize, io_aid->cluster)) == NIL)
 				{
-					io_report("free storage exhausted", FATALINTERNAL);
+					io_report(_("free storage exhausted"), FATALINTERNAL);
 					break;
 				}
 
@@ -2820,7 +2820,7 @@ INTBIG io_parsestatement(void)
 						comment = (char *)emalloc(maxsize, io_aid->cluster);
 						if (comment == NIL)
 						{
-							io_report("free storage exhausted", FATALINTERNAL);
+							io_report(_("free storage exhausted"), FATALINTERNAL);
 							break;
 						}
 						for(i=0; i<maxsize-80; i++) comment[i] = oldcomment[i];
@@ -2840,7 +2840,7 @@ INTBIG io_parsestatement(void)
 				io_ciferrortype = NESTEND;
 				goto recover;
 			}
-			if (!io_endoffile()) io_report("more text follows end command", ADVISORY);
+			if (!io_endoffile()) io_report(_("more text follows end command"), ADVISORY);
 			io_cifendisseen = 1;
 			io_iend();
 			goto alldone;
@@ -2987,30 +2987,30 @@ alldone:		/* everyone exits here */
 recover:		/* errors come here */
 	switch (io_ciferrortype)
 	{
-		case NUMTOOBIG:  io_report("number too large", FATALSYNTAX); break;
-		case NOUNSIGNED: io_report("unsigned integer expected", FATALSYNTAX); break;
-		case NOSIGNED:   io_report("signed integer expected", FATALSYNTAX); break;
-		case NOSEMI:     io_report("missing ';' inserted", FATALSYNTAX); break;
-		case NOPATH:     io_report("no points in path", FATALSYNTAX); break;
-		case BADTRANS:   io_report("no such transformation command", FATALSYNTAX); break;
-		case BADUSER:    io_report("end of file inside user command", FATALSYNTAX); break;
-		case BADCOMMAND: io_report("unknown command encountered", FATALSYNTAX); break;
-		case INTERNAL:   io_report("parser can't find i routine", FATALINTERNAL); break;
-		case BADDEF:     io_report("no such define command", FATALSYNTAX); break;
-		case NOLAYER:    io_report("layer name expected", FATALSYNTAX); break;
-		case BADCOMMENT: io_report("end of file inside a comment", FATALSYNTAX); break;
-		case BADAXIS:    io_report("no such axis in mirror command", FATALSYNTAX); break;
-		case NESTDEF:    io_report("symbol definitions can't nest", FATALSYNTAX); break;
-		case NODEFSTART: io_report("DF without DS", FATALSYNTAX); break;
-		case NESTDD:     io_report("DD can't appear inside symbol definition", FATALSYNTAX); break;
-		case NOSPACE:    io_report("missing space in name command", FATALSYNTAX); break;
-		case NONAME:     io_report("no name in name command", FATALSYNTAX); break;
-		case NESTEND:    io_report("End command inside symbol definition", FATALSYNTAX); break;
-		case NOERROR:    io_report("error signaled but not reported", FATALINTERNAL); break;
-		default:         io_report("uncaught error", FATALSYNTAX);
+		case NUMTOOBIG:  io_report(_("number too large"), FATALSYNTAX); break;
+		case NOUNSIGNED: io_report(_("unsigned integer expected"), FATALSYNTAX); break;
+		case NOSIGNED:   io_report(_("signed integer expected"), FATALSYNTAX); break;
+		case NOSEMI:     io_report(_("missing ';' inserted"), FATALSYNTAX); break;
+		case NOPATH:     io_report(_("no points in path"), FATALSYNTAX); break;
+		case BADTRANS:   io_report(_("no such transformation command"), FATALSYNTAX); break;
+		case BADUSER:    io_report(_("end of file inside user command"), FATALSYNTAX); break;
+		case BADCOMMAND: io_report(_("unknown command encountered"), FATALSYNTAX); break;
+		case INTERNAL:   io_report(_("parser can't find i routine"), FATALINTERNAL); break;
+		case BADDEF:     io_report(_("no such define command"), FATALSYNTAX); break;
+		case NOLAYER:    io_report(_("layer name expected"), FATALSYNTAX); break;
+		case BADCOMMENT: io_report(_("end of file inside a comment"), FATALSYNTAX); break;
+		case BADAXIS:    io_report(_("no such axis in mirror command"), FATALSYNTAX); break;
+		case NESTDEF:    io_report(_("symbol definitions can't nest"), FATALSYNTAX); break;
+		case NODEFSTART: io_report(_("DF without DS"), FATALSYNTAX); break;
+		case NESTDD:     io_report(_("DD can't appear inside symbol definition"), FATALSYNTAX); break;
+		case NOSPACE:    io_report(_("missing space in name command"), FATALSYNTAX); break;
+		case NONAME:     io_report(_("no name in name command"), FATALSYNTAX); break;
+		case NESTEND:    io_report(_("End command inside symbol definition"), FATALSYNTAX); break;
+		case NOERROR:    io_report(_("error signaled but not reported"), FATALINTERNAL); break;
+		default:         io_report(_("uncaught error"), FATALSYNTAX);
 	}
 	if (io_ciferrortype != INTERNAL && io_ciferrortype != NOSEMI && io_flush(';') == EOF)
-		io_report("unexpected end of input file", FATALSYNTAX);
+		io_report(_("unexpected end of input file"), FATALSYNTAX);
 			else io_blank();
 	command = SYNTAXERROR;
 	io_ciferrorfound = 0;
@@ -3025,7 +3025,7 @@ INTSML io_parsefile(void)
 
 	for(;;)
 	{
-		if (stopping("CIF input") != 0) break;
+		if (stopping(STOPREASONCIF)) break;
 		com = io_parsestatement();
 		if (com == END || com == ENDFILE) break;
 		comcount++;
