@@ -182,16 +182,16 @@ INTSML io_writedxflibrary(LIBRARY *lib)
 	if (io_dxflayerkey == 0) io_dxflayerkey = makekey("IO_dxf_layer");
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate DXF output");
+		ttyputerr(_("Must be editing a facet to generate DXF output"));
 		return(1);
 	}
 	(void)strcpy(file, lib->curnodeproto->cell->cellname);
 	if (strcmp(&file[strlen(file)-4],".dxf") != 0) (void)strcat(file, ".dxf");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPEDXF, "DXF File", &truename);
+	io_fileout = xcreate(name, io_filetypedxf, _("DXF File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
@@ -256,7 +256,7 @@ INTSML io_writedxflibrary(LIBRARY *lib)
 
 	fprintf(io_fileout, "  0\nEOF\n");
 	xclose(io_fileout);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	return(0);
 }
 
@@ -323,10 +323,10 @@ void io_dxfwritefacet(NODEPROTO *np, INTSML subfacets)
 				{
 					/* get polygon */
 					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, io_aid->cluster);
-					i = nodepolys(ni);
+					i = nodepolys(ni, 0);
 					for(j=0; j<i; j++)
 					{
-						shapenodepoly(ni, (INTSML)j, poly);
+						shapenodepoly(ni, j, poly);
 						layername = ((char **)var->addr)[poly->layer];
 						if (*layername != 0) break;
 					}
@@ -466,33 +466,25 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 	FILE *io;
 	char *filename, *text, warning[256], countStr[50], **list;
 	INTSML groupID, err;
-	INTBIG len, i;
+	INTBIG len, i, *curstate;
 	NODEPROTO *np;
-	REGISTER VARIABLE *var;
 	FORWARDREF *fr, *nextfr;
 	extern DIALOG us_progressdialog;
 	NODEINST *ni;
 
 	/* parameters for reading files */
 	if (io_dxflayerkey == 0) io_dxflayerkey = makekey("IO_dxf_layer");
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE)
-	{
-		io_dxfreadalllayers = 0;
-		io_dxfflatteninput = 1;
-	} else
-	{
-		io_dxfreadalllayers = var->addr & DXFALLLAYERS;
-		io_dxfflatteninput = var->addr & DXFFLATTENINPUT;
-	}
+	curstate = io_getstatebits();
+	io_dxfreadalllayers = curstate[0] & DXFALLLAYERS;
+	io_dxfflatteninput = curstate[0] & DXFFLATTENINPUT;
 
 	/* examine technology for acceptable DXF layer names */
 	if (io_dxfgetacceptablelayers() != 0) return(1);
 
 	/* get the DXF file */
-	if ((io = xopen(lib->libfile, FILETYPEDXF, "", &filename)) == NULL)
+	if ((io = xopen(lib->libfile, io_filetypedxf, "", &filename)) == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
@@ -533,13 +525,13 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 	io_dxfinputmode = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) break;
+		if (stopping(STOPREASONDXF)) break;
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) break;
 
 		/* must have section change here */
 		if (groupID != 0)
 		{
-			ttyputerr("Expected group 0 (start section) at line %ld", io_dxfcurline);
+			ttyputerr(_("Expected group 0 (start section) at line %ld"), io_dxfcurline);
 			break;
 		}
 
@@ -551,7 +543,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 			if (io_dxfgetnextpair(io, &groupID, &text) != 0) break;
 			if (groupID != 2)
 			{
-				ttyputerr("Expected group 2 (name) at line %ld", io_dxfcurline);
+				ttyputerr(_("Expected group 2 (name) at line %ld"), io_dxfcurline);
 				err = 1;
 				break;
 			}
@@ -586,7 +578,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 				continue;
 			}
 		}
-		ttyputerr("Unknown section name (%s) at line %ld", text, io_dxfcurline);
+		ttyputerr(_("Unknown section name (%s) at line %ld"), text, io_dxfcurline);
 		err = 1;
 		break;
 	}
@@ -607,7 +599,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 			if (strcmp(np->cell->cellname, fr->refname) == 0) break;
 		if (np == NONODEPROTO)
 		{
-			ttyputmsg("Cannot find block '%s'", fr->refname);
+			ttyputmsg(_("Cannot find block '%s'"), fr->refname);
 		} else
 		{
 			if (io_dxfflatteninput != 0)
@@ -646,54 +638,54 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 		io_dxfreadsolids > 0 || io_dxfread3dfaces > 0 || io_dxfreadarcs > 0 ||
 		io_dxfreadtexts > 0 || io_dxfreadinserts > 0)
 	{
-		strcpy(warning, "Read");
+		strcpy(warning, _("Read"));
 		i = 0;
 		if (io_dxfreadpolylines > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d polylines", io_dxfreadpolylines);
+			sprintf(countStr, _(" %d polylines"), io_dxfreadpolylines);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadlines > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d lines", io_dxfreadlines);
+			sprintf(countStr, _(" %d lines"), io_dxfreadlines);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadcircles > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d circles", io_dxfreadcircles);
+			sprintf(countStr, _(" %d circles"), io_dxfreadcircles);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadsolids > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d solids", io_dxfreadsolids);
+			sprintf(countStr, _(" %d solids"), io_dxfreadsolids);
 			strcat(warning, countStr);
 		}
 		if (io_dxfread3dfaces > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d 3d faces", io_dxfread3dfaces);
+			sprintf(countStr, _(" %d 3d faces"), io_dxfread3dfaces);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadarcs > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d arcs", io_dxfreadarcs);
+			sprintf(countStr, _(" %d arcs"), io_dxfreadarcs);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadtexts > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d texts", io_dxfreadtexts);
+			sprintf(countStr, _(" %d texts"), io_dxfreadtexts);
 			strcat(warning, countStr);
 		}
 		if (io_dxfreadinserts > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d inserts", io_dxfreadinserts);
+			sprintf(countStr, _(" %d inserts"), io_dxfreadinserts);
 			strcat(warning, countStr);
 		}
 		ttyputmsg(warning);
@@ -701,24 +693,24 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 
 	if (io_dxfignoredpoints > 0 || io_dxfignoredattributes > 0 || io_dxfignoredattribdefs > 0)
 	{
-		strcpy(warning, "Ignored");
+		strcpy(warning, _("Ignored"));
 		i = 0;
 		if (io_dxfignoredpoints > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d points", io_dxfignoredpoints);
+			sprintf(countStr, _(" %d points"), io_dxfignoredpoints);
 			strcat(warning, countStr);
 		}
 		if (io_dxfignoredattributes > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d attributes", io_dxfignoredattributes);
+			sprintf(countStr, _(" %d attributes"), io_dxfignoredattributes);
 			strcat(warning, countStr);
 		}
 		if (io_dxfignoredattribdefs > 0)
 		{
 			if (i > 0) strcat(warning, ",");	i++;
-			sprintf(countStr, " %d attribute definitions", io_dxfignoredattribdefs);
+			sprintf(countStr, _(" %d attribute definitions"), io_dxfignoredattribdefs);
 			strcat(warning, countStr);
 		}
 		ttyputmsg(warning);
@@ -729,7 +721,7 @@ INTSML io_readdxflibrary(LIBRARY *lib)
 	if (len > 0)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("Ignored layers ");
+		(void)addstringtoinfstr(_("Ignored layers "));
 		for(i=0; i<len; i++)
 		{
 			if (i > 0) (void)addstringtoinfstr(", ");
@@ -794,7 +786,7 @@ INTSML io_dxfreadtablessection(FILE *io)
 	/* just ignore everything until the end-of-section */
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 
 		/* quit now if at the end of the table section */
@@ -815,7 +807,7 @@ INTSML io_dxfreadtablessection(FILE *io)
 		layer = 0;
 		for(;;)
 		{
-			if (stopping("DXF")) return(1);
+			if (stopping(STOPREASONDXF)) return(1);
 			if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 			if (groupID == 0 && strcmp(text, "ENDTAB") == 0) break;
 			if (groupID == 0 && strcmp(text, "LAYER") == 0)
@@ -922,14 +914,14 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 	/* read the blocks/entities section */
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 #ifdef PRESERVEDXF
 		io_dxfstartgathering();
 #endif
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		if (groupID != 0)
 		{
-			ttyputerr("Unknown group code (%d) at line %ld", groupID, io_dxfcurline);
+			ttyputerr(_("Unknown group code (%d) at line %ld"), groupID, io_dxfcurline);
 			return(1);
 		}
 
@@ -1009,7 +1001,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 			{
 				if (xrep != 1 || yrep != 1)
 				{
-					ttyputmsg("Cannot insert block '%s' repeated %dx%d times", pt, xrep, yrep);
+					ttyputmsg(_("Cannot insert block '%s' repeated %dx%d times"), pt, xrep, yrep);
 					continue;
 				}
 
@@ -1108,7 +1100,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 								yc = (y1 + y2) / 2;
 								if ((y1 == yc && x1 == xc) || (y2 == yc && x2 == xc))
 								{
-									ttyputerr("Domain error in polyline bulge computation");
+									ttyputerr(_("Domain error in polyline bulge computation"));
 									continue;
 								}
 								sa = atan2(y1-yc, x1-xc);
@@ -1165,7 +1157,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 							/* compute angles to the arc endpoints */
 							if ((y01 == ycf && x01 == xcf) || (y02 == ycf && x02 == xcf))
 							{
-								ttyputerr("Domain error in polyline computation");
+								ttyputerr(_("Domain error in polyline computation"));
 								continue;
 							}
 							sa = atan2(y01-ycf, x01-xcf);
@@ -1338,7 +1330,7 @@ INTSML io_dxfreadentities(FILE *io, LIBRARY *lib)
 			io_dxfread3dfaces++;
 			continue;
 		}
-		ttyputerr("Unknown entity type (%s) at line %ld", text, io_dxfcurline);
+		ttyputerr(_("Unknown entity type (%s) at line %ld"), text, io_dxfcurline);
 		return(1);
 	}
 	return(0);
@@ -1353,7 +1345,7 @@ INTSML io_dxfreadarcentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG *ra
 	*retLayer = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1382,7 +1374,7 @@ INTSML io_dxfreadblock(FILE *io, char **name)
 	saveMsg = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1409,7 +1401,7 @@ INTSML io_dxfreadcircleentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, INTBIG
 	*retLayer = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1442,7 +1434,7 @@ INTSML io_dxfreadinsertentity(FILE *io, INTBIG *x, INTBIG *y, INTBIG *z, char **
 	*xsca = *ysca = 1.0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1482,7 +1474,7 @@ INTSML io_dxfreadlineentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG
 	*lineType = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1518,7 +1510,7 @@ INTSML io_dxfreadpolylineentity(FILE *io, INTBIG **xp, INTBIG **yp, INTBIG **zp,
 	vertCount = vertLimit = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) break;
 		switch(groupID)
 		{
@@ -1609,7 +1601,7 @@ INTSML io_dxfreadsolidentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBI
 	factor = 1.0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1655,7 +1647,7 @@ INTSML io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 	gotxa = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1707,7 +1699,7 @@ INTSML io_dxfread3dfaceentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTB
 	*retLayer = 0;
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) return(1);
 		switch (groupID)
 		{
@@ -1744,7 +1736,7 @@ INTSML io_dxfignoreentity(FILE *io)
 
 	for(;;)
 	{
-		if (stopping("DXF")) return(1);
+		if (stopping(STOPREASONDXF)) return(1);
 		if (io_dxfgetnextpair(io, &groupID, &text) != 0) break;
 		if (groupID == 0) break;
 	}
@@ -1794,7 +1786,8 @@ INTSML io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float
 	{
 		if (ni->proto->primindex == 0)
 		{
-			ttyputmsg("Cannot insert block '%s'...it has inserts in it", onp->cell->cellname);
+			ttyputmsg(_("Cannot insert block '%s'...it has inserts in it"),
+				onp->cell->cellname);
 			return(1);
 		}
 		sx = roundfloat((float)(ni->highx-ni->lowx) * xsca);
@@ -1879,7 +1872,8 @@ NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca)
 	{
 		if (ni->proto->primindex == 0)
 		{
-			ttyputmsg("Cannot scale insert of block '%s'...it has inserts in it", onp->cell->cellname);
+			ttyputmsg(_("Cannot scale insert of block '%s'...it has inserts in it"),
+				onp->cell->cellname);
 			return(NONODEPROTO);
 		}
 		nni = newnodeinst(ni->proto, (INTBIG)(ni->lowx*xsca), (INTBIG)(ni->highx*xsca),
@@ -1977,13 +1971,13 @@ INTSML io_dxfgetnextpair(FILE *io, INTSML *groupID, char **text)
 		/* read a line and get the group ID */
 		if (io_dxfgetnextline(io, io_dxfline, 0) != 0)
 		{
-			ttyputerr("Unexpected end-of-file at line %ld", io_dxfcurline);
+			ttyputerr(_("Unexpected end-of-file at line %ld"), io_dxfcurline);
 			return(1);
 		}
 		for(pt = io_dxfline; *pt != 0; pt++)
 			if (*pt != ' ' && !isdigit(*pt))
 		{
-			ttyputerr("Invalid group ID on line %ld (%s)", io_dxfcurline, io_dxfline);
+			ttyputerr(_("Invalid group ID on line %ld (%s)"), io_dxfcurline, io_dxfline);
 			return(1);
 		}
 		*groupID = atoi(io_dxfline);
@@ -1994,7 +1988,7 @@ INTSML io_dxfgetnextpair(FILE *io, INTSML *groupID, char **text)
 		/* read a line and get the text */
 		if (io_dxfgetnextline(io, io_dxfline, 1) != 0)
 		{
-			ttyputerr("Unexpected end-of-file at line %ld", io_dxfcurline);
+			ttyputerr(_("Unexpected end-of-file at line %ld"), io_dxfcurline);
 			return(1);
 		}
 		*text = io_dxfline;
@@ -2010,7 +2004,7 @@ INTSML io_dxfgetnextpair(FILE *io, INTSML *groupID, char **text)
 				io_dxfinputmode = 2;
 				if (io_dxfgetnextline(io, io_dxfline, 1) != 0)
 				{
-					ttyputerr("Unexpected end-of-file at line %ld", io_dxfcurline);
+					ttyputerr(_("Unexpected end-of-file at line %ld"), io_dxfcurline);
 					return(1);
 				}
 				*text = io_dxfline;
@@ -2075,7 +2069,8 @@ INTSML io_dxfgetnextline(FILE *io, char *text, INTSML canBeBlank)
 		}
 		if (len >= MAXCHARSPERLINE)
 		{
-			ttyputerr("Warning: line %ld too long (%d character limit)", io_dxfcurline, MAXCHARSPERLINE);
+			ttyputerr(_("Warning: line %ld too long (%d character limit)"),
+				io_dxfcurline, MAXCHARSPERLINE);
 			return(1);
 		}
 		text[len] = 0;
@@ -2108,7 +2103,7 @@ INTSML io_dxfgetacceptablelayers(void)
 	var = getval((INTBIG)art_tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_dxf_layer_names");
 	if (var == NOVARIABLE)
 	{
-		ttyputerr("There are no DXF layer names in the %s technology", art_tech->techname);
+		ttyputerr(_("There are no DXF layer names in the %s technology"), art_tech->techname);
 		return(1);
 	}
 	list = (char **)var->addr;
@@ -2188,14 +2183,14 @@ char *io_dxfblockname(char *name)
 /* DXF Options */
 DIALOGITEM io_dxfoptionsdialogitems[] =
 {
- /*  1 */ {0, {144,344,168,416}, BUTTON, "OK"},
- /*  2 */ {0, {144,248,168,320}, BUTTON, "Cancel"},
+ /*  1 */ {0, {144,344,168,416}, BUTTON, N_("OK")},
+ /*  2 */ {0, {144,248,168,320}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,16,168,231}, SCROLL, ""},
- /*  4 */ {0, {8,240,24,320}, MESSAGE, "DXF Layer:"},
+ /*  4 */ {0, {8,240,24,320}, MESSAGE, N_("DXF Layer:")},
  /*  5 */ {0, {8,324,24,430}, EDITTEXT, ""},
- /*  6 */ {0, {32,240,48,430}, CHECK, "Input flattens hierarchy"}
+ /*  6 */ {0, {32,240,48,430}, CHECK, N_("Input flattens hierarchy")}
 };
-DIALOG io_dxfoptionsdialog = {{50,75,228,514}, "DXF Options", 6, io_dxfoptionsdialogitems};
+DIALOG io_dxfoptionsdialog = {{50,75,228,514}, N_("DXF Options"), 0, 6, io_dxfoptionsdialogitems};
 
 /*
  * special case for the "DXF Options" dialog
@@ -2205,10 +2200,10 @@ DIALOG io_dxfoptionsdialog = {{50,75,228,514}, "DXF Options", 6, io_dxfoptionsdi
  */
 void io_dxfoptionsdlog(void)
 {
-	INTBIG i, itemHit;
-	REGISTER INTBIG curstate;
+	REGISTER INTBIG i, itemHit, *curstate, nameschanged;
+	INTBIG newstate[NUMIOSTATEBITWORDS];
 	REGISTER char **layernames, *pt;
-	REGISTER VARIABLE *dxfvar, *var;
+	REGISTER VARIABLE *dxfvar;
 
 	if (DiaInitDialog(&io_dxfoptionsdialog) != 0) return;
 	DiaInitTextDialog(3, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, 0,
@@ -2230,11 +2225,12 @@ void io_dxfoptionsdlog(void)
 	}
 	DiaSelectLine(3, 0);
 	DiaSetText(5, layernames[0]);
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) curstate = 0; else curstate = var->addr;
-	if ((curstate&DXFFLATTENINPUT) != 0) DiaSetControl(6, 1);
+	curstate = io_getstatebits();
+	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
+	if ((curstate[0]&DXFFLATTENINPUT) != 0) DiaSetControl(6, 1);
 
 	/* loop until done */
+	nameschanged = 0;
 	for(;;)
 	{
 		itemHit = DiaNextHit();
@@ -2249,6 +2245,8 @@ void io_dxfoptionsdlog(void)
 		{
 			i = DiaGetCurLine(3);
 			pt = DiaGetText(5);
+			if (strcmp(pt, layernames[i]) == 0) continue;
+			nameschanged++;
 			(void)reallocstring(&layernames[i], pt, el_tempcluster);
 			(void)initinfstr();
 			(void)addstringtoinfstr(layername(el_curtech, (INTSML)i));
@@ -2267,13 +2265,14 @@ void io_dxfoptionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_dxf_layer_names",
-			(INTBIG)layernames, VSTRING|VISARRAY|
-				(el_curtech->layercount<<VLENGTHSH));
-		if (DiaGetControl(6) != 0) curstate |= DXFFLATTENINPUT; else
-			curstate &= ~DXFFLATTENINPUT;
-		(void)setvalkey((INTBIG)io_aid, VAID, io_state,
-			curstate, VINTEGER);
+		if (nameschanged != 0)
+			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_dxf_layer_names",
+				(INTBIG)layernames, VSTRING|VISARRAY|
+					(el_curtech->layercount<<VLENGTHSH));
+		if (DiaGetControl(6) != 0) newstate[0] |= DXFFLATTENINPUT; else
+			newstate[0] &= ~DXFFLATTENINPUT;
+		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
+		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
 	}
 	for(i=0; i<el_curtech->layercount; i++) efree(layernames[i]);
 	efree((char *)layernames);
