@@ -79,16 +79,16 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 	curfacet = lib->curnodeproto;
 	if (curfacet == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate EAGLE output");
+		ttyputerr(_("Must be editing a facet to generate EAGLE output"));
 		return(1);
 	}
 	(void)strcpy(file, curfacet->cell->cellname);
 	(void)strcat(file, ".txt");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPEEAGLE, "EAGLE File", &truename);
+	io_fileout = xcreate(name, io_filetypeeagle, _("EAGLE File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
@@ -141,7 +141,7 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 		if (lasten == NOEAGLENET || namesame(lasten->netname, en->netname) != 0)
 		{
 			if (lasten != NOEAGLENET) xprintf(io_fileout, ";\n");
-			xprintf(io_fileout, "Signal '%s'", en->netname);
+			xprintf(io_fileout, _("Signal '%s'"), en->netname);
 		} else
 		{
 			xprintf(io_fileout, "       '%s'", en->netname);
@@ -175,7 +175,7 @@ INTSML io_writeeaglelibrary(LIBRARY *lib)
 	xclose(io_fileout);
 
 	/* tell the user that the file is written */
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	return(0);
 }
 
@@ -277,14 +277,7 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 					xprintf(io_fileout, "ADD %s '%s%s'", (char *)varpackagetype->addr,
 						prefix, (char *)varpart->addr);
 				}
-#if 0
-				if (ni->rotation != 0 || ni->transpose != 0)
-					xprintf(io_fileout, " %sR%d", (ni->transpose != 0 ? "M" : ""), ni->rotation/10);
-				xprintf(io_fileout, " (%s %s)\n", latoa((ni->lowx + ni->highx) / 2),
-					latoa((ni->lowy + ni->highy) / 2));
-#else
 				xprintf(io_fileout, " (0 0)\n");
-#endif
 
 				/* record all networks */
 				name = (char *)varpart->addr;
@@ -305,12 +298,17 @@ void io_eagledumpfacet(NODEPROTO *curfacet, char *prefix)
 					if (net->temp1 != 0)
 					{
 						(void)allocstring(&en->netname, (char *)net->temp1, io_aid->cluster);
-					} else
+					} else if (net->namecount > 0)
 					{
 						(void)initinfstr();
 						(void)addstringtoinfstr(prefix);
 						(void)addstringtoinfstr(net->netname);
 						(void)allocstring(&en->netname, returninfstr(), io_aid->cluster);
+					} else
+					{
+						(void)initinfstr();
+						(void)formatinfstr("%sNET%ld", prefix, (INTBIG)net);
+						(void)allocstring(&en->netname, returninfstr(), io_aid->cluster);
 					}
 					(void)initinfstr();
 					(void)addstringtoinfstr(prefix);
