@@ -156,7 +156,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	char name[100], fname[100];
 	REGISTER NODEPROTO *lnp, *np;
 	REGISTER INTSML i, backannotate;
-	extern AIDENTRY *net_aid;
+	REGISTER INTBIG lambda, *curstate;
 	REGISTER LIBRARY *olib;
 	REGISTER TECHNOLOGY *tech;
 	INTBIG fun, rgrid;
@@ -166,9 +166,9 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	/* make sure network tool is on */
 	if ((net_aid->aidstate & AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the EDIF I/O command");
+		ttyputerr(_("...now reissue the EDIF I/O command"));
 		return(1);
 	}
 
@@ -179,7 +179,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate EDIF output");
+		ttyputerr(_("Must be editing a facet to generate EDIF output"));
 		return(1);
 	}
 
@@ -187,14 +187,15 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	io_edifospice_model = makekey("SIM_spice_model");
 
 	/* See if schematic view is requested */
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var != NOVARIABLE && (var->addr & EDIFSCHEMATIC) != 0)
+	lambda = lib->lambda[el_curtech->techindex];
+	curstate = io_getstatebits();
+	if ((curstate[0] & EDIFSCHEMATIC) != 0)
 	{
 		schematic_view = 1;
-		schematic_scale = 1.0 / ((double)el_curtech->deflambda);
-		meters_to_lambda = scaletodispunit(el_curtech->deflambda, DISPUNITCM) / 100;
+		schematic_scale = 1.0 / ((double)lambda);
+		meters_to_lambda = scaletodispunit(lambda, DISPUNITCM) / 100;
 	} else
-	schematic_view = 0;
+		schematic_view = 0;
 
 	(void)strcpy(name, io_ediftoken(np->cell->cellname));
 
@@ -212,13 +213,13 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	(void)sprintf(fname, "%s.edif", name);
 	if ((edif_stream = EO_open_stream(fname, 0)) == NOEO_STREAM)
 	{
-		/* ttyputerr("Cannot write %s", fname); */
+		/* ttyputerr(_("Cannot write %s"), fname); */
 		return(1);
 	}
 
 	/* write the header */
-	(void)sprintf(name, "Electric Design System v%s", el_version);
-	(void)EO_put_header(edif_stream, name, "EDIF Writer", lib->libname);
+	(void)sprintf(name, _("Electric Design System v%s"), el_version);
+	(void)EO_put_header(edif_stream, name, _("EDIF Writer"), lib->libname);
 
 	/* write the external primitive reference library, if any */
 	if (io_edifwritelibext(np) != 0)
@@ -235,7 +236,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 		if (io_edifsearch(np) != 0)
 		{
 			/* advise user that generic primitives are being used */
-			ttyputerr("WARNING: external primitive library undefined - using generic models");
+			ttyputerr(_("WARNING: external primitive library undefined - using generic models"));
 
 			/* write out all primitives used in the library */
 			EO_open_block(edif_stream, "library");
@@ -246,7 +247,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 			if (schematic_view)
 			{
 				EO_open_block(edif_stream, "scale");
-				EO_put_integer(edif_stream, io_edif_scale(el_curtech->deflambda));
+				EO_put_integer(edif_stream, io_edif_scale(lambda));
 				EO_put_float(edif_stream, meters_to_lambda);
 				EO_put_block(edif_stream, "unit", "DISTANCE");
 				EO_close_block(edif_stream, "scale");
@@ -298,7 +299,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 		if (schematic_view)
 		{
 			EO_open_block(edif_stream, "scale");
-			EO_put_integer(edif_stream, io_edif_scale(el_curtech->deflambda));
+			EO_put_integer(edif_stream, io_edif_scale(lambda));
 			EO_put_float(edif_stream, meters_to_lambda);
 			EO_put_block(edif_stream, "unit", "DISTANCE");
 			EO_close_block(edif_stream, "scale");
@@ -322,7 +323,7 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	if (schematic_view)
 	{
 		EO_open_block(edif_stream, "scale");
-		EO_put_integer(edif_stream, io_edif_scale(el_curtech->deflambda));
+		EO_put_integer(edif_stream, io_edif_scale(lambda));
 		EO_put_float(edif_stream, meters_to_lambda);
 		EO_put_block(edif_stream, "unit", "DISTANCE");
 		EO_close_block(edif_stream, "scale");
@@ -340,10 +341,10 @@ INTSML io_writeediflibrary(LIBRARY *lib)
 	EO_put_block(edif_stream, "libraryRef", io_ediftoken(lib->libname));
 
 	/* clean up */
-	ttyputmsg("%s written", edif_stream->filename);
+	ttyputmsg(_("%s written"), edif_stream->filename);
 	EO_close_stream(edif_stream);
 	if (backannotate != 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	return(0);
 }
 
@@ -432,7 +433,7 @@ void io_edifextsearch(NODEPROTO *np)
 			(void)initinfstr();
 			(void)addstringtoinfstr(libname);
 			(void)allocstring(&io_edifoextlibname[i], returninfstr(), io_aid->cluster);
-			ttyputmsg("External library %s, lib number %d", io_edifoextlibname[i], i);
+			ttyputmsg(_("External library %s, lib number %d"), io_edifoextlibname[i], i);
 		}
 		np->temp2 = i;
 		np->temp1++;
@@ -456,7 +457,7 @@ char *io_ediffind_path(NODEPROTO *np)
 	INTSML i;
 
 	/* initialize the local path name variable */
-	f = xopen("edifpath", FILETYPEEDIF, el_libdir, &filename);
+	f = xopen("edifpath", io_filetypeedif, el_libdir, &filename);
 	if (f != NULL)
 	{
 		for(ch = (char)xgetc(f), i = 0; ; ch = (char)xgetc(f), i++)
@@ -472,7 +473,7 @@ char *io_ediffind_path(NODEPROTO *np)
 				strcat(libpath, "edif");
 				strcat(libpath, sep);
 				strcat(libpath, "source");
-				etry = xopen(libpath, FILETYPEEDIF, el_libdir, &filename);
+				etry = xopen(libpath, io_filetypeedif, el_libdir, &filename);
 				if (etry != NULL)
 				{
 					libpath[i] = 0;
@@ -659,7 +660,8 @@ void io_edif_pt(INTBIG x, INTBIG y)
  */
 INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 {
-	INTSML fun, i, netcount, displaytotal, backannotate;
+	INTBIG i, netcount, displaytotal;
+	INTSML fun, backannotate;
 	NETWORK *net, *cnet, *onet;
 	VARIABLE *var;
 	NODEINST *ni;
@@ -679,7 +681,6 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 	static POLYGON *poly = NOPOLYGON;
 	static INTBIG EDIF_name_key = 0;
 	static INTBIG EDIF_array_key = 0;
-	extern AIDENTRY *net_aid;
 
 	if (EDIF_name_key == 0) EDIF_name_key = makekey("EDIF_name");
 	if (EDIF_array_key == 0) EDIF_array_key = makekey("EDIF_array");
@@ -687,7 +688,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 	/* stop if requested */
 	if (el_pleasestop != 0)
 	{
-		stopping("EDIF generation");
+		stopping(STOPREASONEDIF);
 		return(0);
 	}
 
@@ -796,7 +797,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 	EO_close_block(edif_stream, "interface");
 
 	if (diffcount != 0)
-		ttyputmsg("** WARNING - unmatched constructed differentialGroup property in %s",
+		ttyputmsg(_("** WARNING - unmatched constructed differentialGroup property in %s"),
 			describenodeproto(np));
 
 	/* list contents if expanding */
@@ -889,7 +890,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 							i = 0;
 							for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 								if (pi->proto == ni->proto->firstportproto) i++;
-							(void)sprintf(name, "%s%d", io_ediftoken(ni->proto->primname));
+							(void)sprintf(name, "%s%d", io_ediftoken(ni->proto->primname), i);
 							EO_put_identifier(edif_stream, name);
 						} else EO_put_identifier(edif_stream, io_edifdescribepriminst(ni, fun));
 						EO_put_block(edif_stream, "libraryRef", "lib0");
@@ -1003,14 +1004,14 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 							}
 
 							if (onet == NONETWORK)
-								ttyputmsg("** WARNING - no connection to %s port %s on %s in %s",
-									(((pp->userbits & STATEBITS) == INPORT) ? "input" : "vbias"),
+								ttyputmsg(_("** WARNING - no connection to %s port %s on %s in %s"),
+									(((pp->userbits & STATEBITS) == INPORT) ? _("input") : _("vbias")),
 										pp->protoname, describenodeinst(ni),
 											describenodeproto(ni->parent));
 							else if (onet->signals < pp->network->signals)
 								for (i = onet->signals; i != pp->network->signals; i++)
-									ttyputmsg("** WARNING - no connection to %s port %s (signal %d) on %s in %s",
-										((pp->userbits & STATEBITS) == INPORT ? "input" : "vbias"),
+									ttyputmsg(_("** WARNING - no connection to %s port %s (signal %d) on %s in %s"),
+										((pp->userbits & STATEBITS) == INPORT ? _("input") : _("vbias")),
 							 				pp->network->networklist[i]->netname, i,
 												 describenodeinst(ni), describenodeproto(ni->parent));
 						}
@@ -1246,7 +1247,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 										EO_put_block(edif_stream, "instanceRef",
 											io_edifwritecompname(ni, fun, 0));
 										EO_close_block(edif_stream, "portRef");
-									} else ttyputerr("Cannot handle primitives with bus pins");
+									} else ttyputerr(_("Cannot handle primitives with bus pins"));
 								}
 								cpp->temp1++;
 							}
@@ -1284,7 +1285,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 									EO_put_identifier(edif_stream, io_ediftoken(cnet->netname));
 								} else
 								{
-									ttyputerr("Proto bus width too narrow at %s {signal %d} in %s",
+									ttyputerr(_("Proto bus width too narrow at %s {signal %d} in %s"),
 										cpp->network->netname, i, describenodeproto(cpp->parent));
 									EO_put_identifier(edif_stream,
 										io_ediftoken(cpp->network->netname));
@@ -1319,7 +1320,7 @@ INTSML io_edifwritefacet(NODEPROTO *np, INTSML external)
 										io_ediftoken(cpp->network->netname));
 								} else
 								{
-									ttyputerr("Proto bus width too narrow at %s{signal %d}",
+									ttyputerr(_("Proto bus width too narrow at %s{signal %d}"),
 										cpp->network->netname);
 									EO_put_identifier(edif_stream,
 										io_ediftoken(cpp->network->netname));
@@ -1482,10 +1483,10 @@ INTSML io_edifwritelibext(NODEPROTO *np)
 	/* import the external library for this facet, if it exists */
 	var = getval((INTBIG) np, VNODEPROTO, VSTRING, "EDIF_external_lib");
 	if (var == NOVARIABLE) return(1);
-	f = xopen((char *)var->addr, FILETYPEEDIF, "", &filename);
+	f = xopen((char *)var->addr, io_filetypeedif, "", &filename);
 	if (f == NULL)
 	{
-		ttyputerr("Cannot find EDIF external reference file %s on facet %s",
+		ttyputerr(_("Cannot find EDIF external reference file %s on facet %s"),
 			(char *) var->addr, describenodeproto(np));
 		return(1);
 	}
@@ -1495,13 +1496,13 @@ INTSML io_edifwritelibext(NODEPROTO *np)
 		if (count <= 0) break;
 		if (xfwrite(buf, 1, count, edif_stream->file) != count)
 		{
-			ttyputerr("Error copying EDIF reference file %s", (char *) var->addr);
+			ttyputerr(_("Error copying EDIF reference file %s"), (char *) var->addr);
 			xclose(f);
 			return(1);
 		}
 	}
 	xclose(f);
-	ttyputmsg("Incorporated external EDIF reference file %s", (char *) var->addr);
+	ttyputmsg(_("Incorporated external EDIF reference file %s"), (char *) var->addr);
 	return(0);
 }
 
@@ -1583,10 +1584,10 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 
 	(void)strcpy(iname, name);
 	(void)strcat(iname, ".foot");
-	io_fileout = xcreate(iname, FILETYPEEDIF, "EDIF File", &truename);
+	io_fileout = xcreate(iname, io_filetypeedif, "EDIF File", &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", iname);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), iname);
 		return(1);
 	}
 
@@ -1598,8 +1599,8 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 	route /= 100;
 
 	/* write the header */
-	ttyputmsg("Writing footprint for cell %s\n", io_ediftoken(np->cell->cellname));
-	xprintf(io_fileout, "(footprint %.2fe-06\n", route);
+	ttyputmsg(_("Writing footprint for cell %s"), io_ediftoken(np->cell->cellname));
+	xprintf(io_fileout, _("(footprint %.2fe-06\n"), route);
 
 	/* identify the layout type from the schematic 'stopExpand' property */
 	var = NOVARIABLE;
@@ -1609,12 +1610,12 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 		var = getval((INTBIG) vnp, VNODEPROTO, VSTRING, "EDIF_stopExpand");
 	if (var != NOVARIABLE) cellType = (char *) var->addr; else
 	{
-		ttyputerr("cannot find stopExpand property on schematic view");
+		ttyputerr(_("cannot find stopExpand property on schematic view"));
 		var = getval((INTBIG) np, VNODEPROTO, VSTRING, "EDIF_stopExpand");
 		if (var != NOVARIABLE)
 		{
 			cellType = (char *) var->addr;
-			ttyputmsg(" - - (but it is attached to the layout)");
+			ttyputmsg(_(" - - (but it is attached to the layout)"));
 		} else cellType = "unknownLayoutRep";
 	}
 	if (namesamen(cellType, "subchip", 7) == 0) cellType = "subchip";
@@ -1660,7 +1661,7 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 			var = getvalkey((INTBIG) pp->subnodeinst, VNODEINST, VSTRING, access);
 			if (allports == 0 && var == NOVARIABLE)
 			{
-				ttyputmsg("Non-global port %s has no access direction", pp->protoname);
+				ttyputmsg(_("Non-global port %s has no access direction"), pp->protoname);
 				continue;
 			}
 		}
@@ -1673,13 +1674,13 @@ INTSML io_edifwritefootprint(NODEPROTO *np, char *name, INTBIG routegrid)
 		connections = io_edifwriteportpositions(pp, np->lowx, np->lowy, portAccess, routegrid);
 
 		if (connections == 0)
-			ttyputmsg("Non-global port %s has no connection access", pp->protoname);
+			ttyputmsg(_("Non-global port %s has no connection access"), pp->protoname);
 	}
 
 	/* finish up */
 	xprintf(io_fileout, ")))\n");
 	xclose(io_fileout);
-	ttyputmsg("%s written", iname);
+	ttyputmsg(_("%s written"), iname);
 
 	return(0);
 }
@@ -1886,7 +1887,7 @@ void io_edifsymbol_facet(NODEINST *ni, XARRAY prevtrans)
  */
 void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 {
-	INTSML i, j, displaytotal, low, high, istext;
+	INTBIG i, j, displaytotal, low, high, istext;
 	char *name;
 	XARRAY localtran, subrot, trans;
 	INTBIG bx, by, ux, uy, swap;
@@ -1933,7 +1934,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 	/* primitive nodeinst: ask the technology how to draw it */
 	if (np->primindex != 0)
 	{
-		high = nodepolys(ni);
+		high = nodepolys(ni, 0);
 
 		/* don't draw invisible pins */
 		if (np == gen_invispinprim) low = 1; else
@@ -2036,7 +2037,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
  */
 void io_edifsymbol_arcinst(ARCINST *ai, XARRAY trans)
 {
-	INTSML i, j, displaytotal;
+	INTBIG i, j, displaytotal;
 	INTBIG width;
 	VARIABLE *var;
 	char *name;
@@ -2220,7 +2221,7 @@ INTBIG io_edifsymbol_showpoly(POLYGON *obj)
 				EO_open_block(edif_stream, "textHeight");
 
 				/* 2 pixels = 0.0278 in or 36 double pixels per inch */
-				height = muldiv((el_curtech->deflambda * 10), (obj->font + 2), 36);
+				height = muldiv((el_curlib->lambda[el_curtech->techindex] * 10), (obj->font + 2), 36);
 				EO_put_integer(edif_stream, io_edif_scale(height));
 				EO_close_block(edif_stream, "figureGroupOverride");
 			} else EO_put_identifier(edif_stream, egraphic_text[EGART]);
@@ -2349,12 +2350,12 @@ EO_STREAM_PTR EO_open_stream(char *filename, INTBIG compress)
 	if ((stream = EO_alloc_stream()) == NOEO_STREAM) return(NOEO_STREAM);
 
 	/* open the file */
-	if ((stream->file = xcreate(filename, FILETYPEEDIF, "EDIF File", &truename)) == NULL)
+	if ((stream->file = xcreate(filename, io_filetypeedif, _("EDIF File"), &truename)) == NULL)
 	{
 		if (truename != 0)
 		{
-			ttyputerr("edifout: could not create stream <%s>\n", truename);
-			ttyputerr("Cannot write %s", truename);
+			ttyputerr(_("edifout: could not create stream <%s>"), truename);
+			ttyputerr(_("Cannot write %s"), truename);
 		}
 		(void)EO_free_stream(stream);
 		return(NOEO_STREAM);
@@ -2363,7 +2364,7 @@ EO_STREAM_PTR EO_open_stream(char *filename, INTBIG compress)
 	/* update filename - allocate name and initialize the structure */
 	if (allocstring(&stream->filename, truename, io_aid->cluster) != 0)
 	{
-		ttyputerr("edifout: no memory for stream name\n");
+		ttyputnomemory();
 		return(NOEO_STREAM);
 	}
 
@@ -2384,7 +2385,7 @@ INTBIG EO_close_stream(EO_STREAM_PTR stream)
 		if (stream->blkstack_ptr)
 		{
 			if (EO_close_block(stream, stream->blkstack[0]))
-			ttyputerr("edifout: internal error, closing stream <%s>\n", stream->filename);
+			ttyputerr(_("edifout: internal error, closing stream <%s>"), stream->filename);
 		}
 		if (stream->state == EO_OPENED)
 		{
@@ -2414,7 +2415,7 @@ INTBIG EO_open_block(EO_STREAM_PTR stream, char *keyword)
 		if (allocstring(&stream->blkstack[stream->blkstack_ptr++], keyword,
 			io_aid->cluster) != 0)
 		{
-			ttyputerr("edifout: no memory for stream stack\n");
+			ttyputnomemory();
 			return(1);
 		}
 
@@ -2586,7 +2587,7 @@ INTBIG EO_close_block(EO_STREAM_PTR stream, char *keyword)
 			}
 			if (depth > stream->blkstack_ptr)
 			{
-				ttyputerr("edifout: could not match keyword <%s>\n", keyword);
+				ttyputerr(_("edifout: could not match keyword <%s>"), keyword);
 				return(1);
 			}
 		}
@@ -2610,7 +2611,7 @@ EO_STREAM_PTR EO_alloc_stream(void)
 
 	if ((stream = (EO_STREAM_PTR)emalloc(sizeof (EO_STREAM), io_aid->cluster)) == NOEO_STREAM)
 	{
-		ttyputerr("edifout: no memory for stream structure\n");
+		ttyputnomemory();
 		return(NOEO_STREAM);
 	}
 
@@ -2633,7 +2634,7 @@ INTBIG EO_free_stream(EO_STREAM_PTR stream)
 
 	if (stream == NOEO_STREAM)
 	{
-		ttyputerr("edifout: internal error, no stream block\n");
+		ttyputerr(_("edifout: internal error, no stream block"));
 		return(1);
 	}
 
@@ -2651,7 +2652,7 @@ INTBIG EO_free_stream(EO_STREAM_PTR stream)
 		}
 		if (temp == NOEO_STREAM)
 		{
-			ttyputerr("edifout: internal error, can't find stream <%s>\n",
+			ttyputerr(_("edifout: internal error, can't find stream <%s>"),
 				(stream->filename?stream->filename:"noname"));
 		}
 	}
@@ -2666,8 +2667,6 @@ INTBIG EO_free_stream(EO_STREAM_PTR stream)
 
 char *EO_get_timestamp(char *buffer)
 {
-	static char *name[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
-		"Aug", "Sep", "Oct", "Nov", "Dec"};
 	static char get_timestamp_buf[81];
 	UINTBIG t;
 	char month[4];
@@ -2677,9 +2676,7 @@ char *EO_get_timestamp(char *buffer)
 	(void)sscanf(timetostring(t), "%*s %s %hd %hd:%hd:%hd %hd", &month[0], &day, &hour,
 		&min, &sec, &yr);
 
-	for (mon = 0; mon < 12; mon++)
-		if (namesame(name[mon], month) == 0) break;
-	mon++;
+	mon = (unsigned short)parsemonth(month);
 
 	/* now make the time string */
 	if (buffer)
@@ -2750,11 +2747,11 @@ char *EO_get_exp(double val)
 /* EDIF Options */
 DIALOGITEM io_edifoptionsdialogitems[] =
 {
- /*  1 */ {0, {32,120,56,192}, BUTTON, "OK"},
- /*  2 */ {0, {32,16,56,88}, BUTTON, "Cancel"},
- /*  3 */ {0, {8,8,24,200}, CHECK, "Use Schematic View"}
+ /*  1 */ {0, {32,120,56,192}, BUTTON, N_("OK")},
+ /*  2 */ {0, {32,16,56,88}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,24,200}, CHECK, N_("Use Schematic View")}
 };
-DIALOG io_edifoptionsdialog = {{50,75,115,284}, "EDIF Options", 3, io_edifoptionsdialogitems};
+DIALOG io_edifoptionsdialog = {{50,75,115,284}, N_("EDIF Options"), 0, 3, io_edifoptionsdialogitems};
 
 /*
  * special case for the "EDIF Options" dialog
@@ -2762,14 +2759,13 @@ DIALOG io_edifoptionsdialog = {{50,75,115,284}, "EDIF Options", 3, io_edifoption
  */
 void io_edifoptionsdlog(void)
 {
-	INTBIG itemHit;
-	REGISTER INTBIG curstate;
-	REGISTER VARIABLE *var;
+	REGISTER INTBIG itemHit, i, *curstate;
+	INTBIG newstate[NUMIOSTATEBITWORDS];
 
 	if (DiaInitDialog(&io_edifoptionsdialog) != 0) return;
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) curstate = 0; else curstate = var->addr;
-	if ((curstate&EDIFSCHEMATIC) != 0) DiaSetControl(3, 1);
+	curstate = io_getstatebits();
+	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
+	if ((curstate[0]&EDIFSCHEMATIC) != 0) DiaSetControl(3, 1);
 
 	/* loop until done */
 	for(;;)
@@ -2785,10 +2781,10 @@ void io_edifoptionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(3) != 0) curstate |= EDIFSCHEMATIC; else
-			curstate &= ~EDIFSCHEMATIC;
-		(void)setvalkey((INTBIG)io_aid, VAID, io_state,
-			curstate, VINTEGER);
+		if (DiaGetControl(3) != 0) newstate[0] |= EDIFSCHEMATIC; else
+			newstate[0] &= ~EDIFSCHEMATIC;
+		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
+		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
 	}
 	DiaDoneDialog();
 }
