@@ -95,15 +95,15 @@
 #define BESTTHRESH           0.001			/* 1/1000 of a millimeter */
 #define WORSTTHRESH          0.1			/* 1/10 of a millimeter */
 
-static char  *io_dbuffer= 0, *io_empty;		/* for buffering output data  */
-static INTSML io_gds_curlayer;				/* Current layer for gds output */
-static INTBIG io_gds_pos;					/* Position of next byte in the buffer */
-static INTBIG io_gds_block;					/* Number data buffers output so far */
-static FILE  *io_gds_outfd;					/* File descriptor for output */
-static INTBIG io_gds_outputstate;			/* current output state */
-static INTSML io_gds_polypoints;			/* number of allowable points on a polygon */
-static double io_gds_scale;					/* constant */
-static INTBIG io_gds_layerkey;				/* key for "IO_gds_layer" */
+static char   *io_dbuffer= 0, *io_empty;	/* for buffering output data  */
+static INTSML  io_gds_curlayer;				/* Current layer for gds output */
+static INTBIG  io_gds_pos;					/* Position of next byte in the buffer */
+static INTBIG  io_gds_block;				/* Number data buffers output so far */
+static FILE   *io_gds_outfd;				/* File descriptor for output */
+static INTBIG *io_gds_outputstate;			/* current output state */
+static INTSML  io_gds_polypoints;			/* number of allowable points on a polygon */
+static double  io_gds_scale;				/* constant */
+static INTBIG  io_gds_layerkey;				/* key for "IO_gds_layer" */
 
 /* prototypes for local routines */
 void io_gdswritecell(NODEPROTO*);
@@ -161,7 +161,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	/* create the proper disk file for the GDS II */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate GDS output");
+		ttyputerr(_("Must be editing a facet to generate GDS output"));
 		return(1);
 	}
 
@@ -172,17 +172,16 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	(void)allocstring(&name, truepath(returninfstr()), el_tempcluster);
 
 	/* get the file */
-	io_gds_outfd = xcreate(name, FILETYPEGDS, "GDS File", &truename);
+	io_gds_outfd = xcreate(name, io_filetypegds, _("GDS File"), &truename);
 	if (io_gds_outfd == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		efree(name);
 		return(1);
 	}
 
 	/* get current output state */
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) io_gds_outputstate = 0; else io_gds_outputstate = var->addr;
+	io_gds_outputstate = io_getstatebits();
 
 	/* get the number of allowable points on a polygon */
 	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_gds_polypoints");
@@ -200,7 +199,7 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 		tech->temp2 = (var == NOVARIABLE ? 0 : var->addr);
 
 		/* if ignoring DRC mask layer, delete Generic technology layer names */
-		if (tech == gen_tech && (io_gds_outputstate&GDSOUTADDDRC) == 0) tech->temp1 = 0;
+		if (tech == gen_tech && (io_gds_outputstate[0]&GDSOUTADDDRC) == 0) tech->temp1 = 0;
 	}
 
 	/* make sure key for individual layer overrides is set */
@@ -208,10 +207,10 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 
 	/* warn if current technology has no GDS layers */
 	if (el_curtech->temp1 == 0)
-		ttyputmsg("Warning: there are no GDS II layers defined for the %s technology",
+		ttyputmsg(_("Warning: there are no GDS II layers defined for the %s technology"),
 			el_curtech->techname);
 
-	if ((io_gds_outputstate&GDSOUTMERGE) != 0) mrginit();
+	if ((io_gds_outputstate[0]&GDSOUTMERGE) != 0) mrginit();
 
 	io_gds_initialize();
 	io_gds_bgnlib(lib->curnodeproto);
@@ -226,10 +225,10 @@ INTSML io_writegdslibrary(LIBRARY *lib)
 	io_gds_header(HDR_ENDLIB, 0);
 	io_gds_closefile();
 
-	if ((io_gds_outputstate&GDSOUTMERGE) != 0) mrgterm();
+	if ((io_gds_outputstate[0]&GDSOUTMERGE) != 0) mrgterm();
 
 	/* tell the user that the file is written */
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	efree(name);
 	return(0);
 }
@@ -240,7 +239,7 @@ void io_gdswritecell(NODEPROTO *np)
 	REGISTER ARCINST *subar;
 	REGISTER NODEPROTO *subnt, *onp;
 	REGISTER VARIABLE *layervar, *var;
-	REGISTER INTSML i, j, displaytotal;
+	REGISTER INTBIG i, j, displaytotal;
 	REGISTER INTBIG offx, offy, laynum, bestthresh, worstthresh;
 	XARRAY trans;
 	INTBIG xpos, ypos, bx, by, fx, fy, tx, ty;
@@ -434,7 +433,7 @@ void io_gdswritecell(NODEPROTO *np)
 
 					/* write out the node the text is attached to */
 					/* RLW - Queen's */
-					i = nodepolys(subno);
+					i = nodepolys(subno, 0);
 					for (j=0; j<i; j++)
 					{
 						shapenodepoly(subno, j, poly);
@@ -444,7 +443,7 @@ void io_gdswritecell(NODEPROTO *np)
 			} else
 			{
 				/* write a primitive nodeinst */
-				i = nodepolys(subno);
+				i = nodepolys(subno, 0);
 				for(j=0; j<i; j++)
 				{
 					shapenodepoly(subno, j, poly);
@@ -530,7 +529,7 @@ void io_gdswritecell(NODEPROTO *np)
 			io_outputgdspoly(subar->proto->tech, poly, 0, offx, offy, el_matid, layervar);
 		}
 	}
-	if ((io_gds_outputstate&GDSOUTMERGE) != 0)
+	if ((io_gds_outputstate[0]&GDSOUTMERGE) != 0)
 		mrgdonefacet(io_gds_write_polygon);
 
 	io_gds_header(HDR_ENDSTR, 0);
@@ -595,7 +594,7 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 				/* find the center of this polygon, inside the cell */
 				xform((xl+xh)/2, (yl+yh)/2, &xpos, &ypos, trans);
 
-				if ((io_gds_outputstate&GDSOUTMERGE) != 0 && angle%900 == 0)
+				if ((io_gds_outputstate[0]&GDSOUTMERGE) != 0 && angle%900 == 0)
 				{
 					/* do polygon format output */
 					if (angle%1800 == 0)
@@ -626,11 +625,11 @@ void io_outputgdspoly(TECHNOLOGY *tech, POLYGON *poly, INTSML angle, INTBIG offx
 
 			/* non-manhattan or worse .. direct output */
 			if (bloat != 0 && poly->count > 4)
-				ttyputmsg("Warning: complex polygon cannot be bloated");
+				ttyputmsg(_("Warning: complex polygon cannot be bloated"));
 			xformpoly(poly, trans); /* was missing in 4.05 (SRP) */
 			if (poly->count == 1)
 			{
-				ttyputerr("Single point cannot be written in GDS-II");
+				ttyputerr(_("Single point cannot be written in GDS-II"));
 				break;
 			}
 
@@ -754,16 +753,14 @@ void io_gds_bgnstr(NODEPROTO *np)
 /* Output date array, converted from a date integer */
 void io_gds_date(UINTBIG *val)
 {
-	static char *mon[12] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
-		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
-	char buffer[28];
-	INTSML date[6], month;
+	char buffer[28], save;
+	INTSML date[6];
 
 	(void)strcpy(buffer, timetostring(*val));
 	date[0] = (INTSML)myatoi(&buffer[20]);      /* year */
-	for (month=0; month<12; month++)
-		if (namesamen(&buffer[4], mon[month], 3) == 0) break;
-	date[1] = month + 1;
+	save = buffer[7];   buffer[7] = 0;
+	date[1] = (INTSML)parsemonth(&buffer[4]);	/* month */
+	buffer[7] = save;
 	date[2] = (INTSML)myatoi(&buffer[8]);       /* day */
 	date[3] = (INTSML)myatoi(&buffer[11]);      /* hours */
 	date[4] = (INTSML)myatoi(&buffer[14]);      /* minutes */
@@ -801,7 +798,7 @@ void io_gds_header(INTSML header, INTSML p1)
 			count = HDR_N_UNITS;
 			break;
 		default:
-			ttyputerr("No entry for header 0x%x", header);
+			ttyputerr(_("No entry for header 0x%x"), header);
 			return;
 	}
 	io_gds_int2((INTSML)count);
@@ -1003,7 +1000,7 @@ void io_gds_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 	/* check the number of points on the polygon */
 	if (count > io_gds_polypoints)
-		ttyputerr("WARNING: Polygon has too many points (%d)", count);
+		ttyputerr(_("WARNING: Polygon has too many points (%d)"), count);
 
 	if (gds_poly == NOPOLYGON) gds_poly = allocstaticpolygon(4, io_aid->cluster);
 	if (count > gds_poly->limit) (void)extendpolygon(gds_poly, count);
@@ -1041,7 +1038,7 @@ char *io_gds_makename(char *str)
 		}
 		(void)addtoinfstr(ch);
 	}
-	return (returninfstr());
+	return(returninfstr());
 }
 
 /*
@@ -1076,11 +1073,11 @@ void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 	/* scale the exponent and mantissa */
 	for (; temp < 0.0625 && exponent > 0; exponent--) temp *= 16.0;
 
-	if (exponent == 0) ttyputerr("Exponent underflow");
+	if (exponent == 0) ttyputerr(_("Exponent underflow"));
 
 	for (; temp >= 1 && exponent < 128; exponent++) temp /= 16.0;
 
-	if (exponent > 127) ttyputerr("Exponent overflow");
+	if (exponent > 127) ttyputerr(_("Exponent overflow"));
 
 	/* set the sign */
 	if (sign == -1) exponent |= 0x80;;
@@ -1097,23 +1094,23 @@ void io_gds_cvfloat8(double *a, UINTBIG *m, UINTBIG *n)
 /* GDS Options */
 DIALOGITEM io_gdsoptionsdialogitems[] =
 {
- /*  1 */ {0, {224,344,248,416}, BUTTON, "OK"},
- /*  2 */ {0, {224,248,248,320}, BUTTON, "Cancel"},
+ /*  1 */ {0, {224,344,248,416}, BUTTON, N_("OK")},
+ /*  2 */ {0, {224,248,248,320}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,16,248,231}, SCROLL, ""},
- /*  4 */ {0, {8,240,24,320}, MESSAGE, "GDS Layer:"},
+ /*  4 */ {0, {8,240,24,320}, MESSAGE, N_("GDS Layer:")},
  /*  5 */ {0, {8,324,24,430}, EDITTEXT, ""},
- /*  6 */ {0, {32,240,48,464}, CHECK, "Input Includes Text"},
- /*  7 */ {0, {56,240,72,464}, CHECK, "Input Expands Facets"},
- /*  8 */ {0, {80,240,96,464}, CHECK, "Input Instantiates Arrays"},
- /*  9 */ {0, {128,240,144,464}, CHECK, "Output Merges Boxes"},
- /* 10 */ {0, {152,240,168,430}, MESSAGE, "Output Arc Conversion:"},
- /* 11 */ {0, {176,250,192,394}, MESSAGE, "Maximum arc angle:"},
+ /*  6 */ {0, {32,240,48,464}, CHECK, N_("Input Includes Text")},
+ /*  7 */ {0, {56,240,72,464}, CHECK, N_("Input Expands Facets")},
+ /*  8 */ {0, {80,240,96,464}, CHECK, N_("Input Instantiates Arrays")},
+ /*  9 */ {0, {128,240,144,464}, CHECK, N_("Output Merges Boxes")},
+ /* 10 */ {0, {152,240,168,430}, MESSAGE, N_("Output Arc Conversion:")},
+ /* 11 */ {0, {176,250,192,394}, MESSAGE, N_("Maximum arc angle:")},
  /* 12 */ {0, {176,396,192,464}, EDITTEXT, ""},
- /* 13 */ {0, {200,250,216,394}, MESSAGE, "Maximum arc sag:"},
+ /* 13 */ {0, {200,250,216,394}, MESSAGE, N_("Maximum arc sag:")},
  /* 14 */ {0, {200,396,216,464}, EDITTEXT, ""},
- /* 15 */ {0, {104,240,120,464}, CHECK, "Input Ignores Unknown Layers"}
+ /* 15 */ {0, {104,240,120,464}, CHECK, N_("Input Ignores Unknown Layers")}
 };
-DIALOG io_gdsoptionsdialog = {{50,75,307,548}, "GDS Options", 15, io_gdsoptionsdialogitems};
+DIALOG io_gdsoptionsdialog = {{50,75,307,548}, N_("GDS Options"), 0, 15, io_gdsoptionsdialogitems};
 
 /*
  * special case for the "GDS Options" dialog
@@ -1129,11 +1126,10 @@ DIALOG io_gdsoptionsdialog = {{50,75,307,548}, "GDS Options", 15, io_gdsoptionsd
  */
 void io_gdsoptionsdlog(void)
 {
-	INTBIG i, itemHit;
-	REGISTER INTBIG *layernumbers, curstate, val;
-	INTBIG arcres, arcsag;
+	REGISTER INTBIG i, itemHit, *layernumbers, *curstate, val, newres, newsag, numberschanged;
+	INTBIG arcres, arcsag, newstate[NUMIOSTATEBITWORDS];
 	char buf[50];
-	REGISTER VARIABLE *var, *gdsvar;
+	REGISTER VARIABLE *gdsvar;
 
 	if (DiaInitDialog(&io_gdsoptionsdialog) != 0) return;
 	DiaInitTextDialog(3, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, 0,
@@ -1155,18 +1151,19 @@ void io_gdsoptionsdlog(void)
 	DiaSelectLine(3, 0);
 	sprintf(buf, "%ld", layernumbers[0]);
 	DiaSetText(5, buf);
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) curstate = 0; else curstate = var->addr;
-	if ((curstate&GDSINTEXT) != 0) DiaSetControl(6, 1);
-	if ((curstate&GDSINEXPAND) != 0) DiaSetControl(7, 1);
-	if ((curstate&GDSINARRAYS) != 0) DiaSetControl(8, 1);
-	if ((curstate&GDSOUTMERGE) != 0) DiaSetControl(9, 1);
-	if ((curstate&GDSINIGNOREUKN) != 0) DiaSetControl(15, 1);
+	curstate = io_getstatebits();
+	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
+	if ((curstate[0]&GDSINTEXT) != 0) DiaSetControl(6, 1);
+	if ((curstate[0]&GDSINEXPAND) != 0) DiaSetControl(7, 1);
+	if ((curstate[0]&GDSINARRAYS) != 0) DiaSetControl(8, 1);
+	if ((curstate[0]&GDSOUTMERGE) != 0) DiaSetControl(9, 1);
+	if ((curstate[0]&GDSINIGNOREUKN) != 0) DiaSetControl(15, 1);
 	getcontoursegmentparameters(&arcres, &arcsag);
 	DiaSetText(12, frtoa(arcres*WHOLE/10));
 	DiaSetText(14, latoa(arcsag));
 
 	/* loop until done */
+	numberschanged = 0;
 	for(;;)
 	{
 		itemHit = DiaNextHit();
@@ -1187,6 +1184,8 @@ void io_gdsoptionsdlog(void)
 		{
 			i = DiaGetCurLine(3);
 			val = atoi(DiaGetText(5));
+			if (val == layernumbers[i]) continue;
+			numberschanged++;
 			layernumbers[i] = val;
 			(void)initinfstr();
 			(void)addstringtoinfstr(layername(el_curtech, (INTSML)i));
@@ -1199,24 +1198,26 @@ void io_gdsoptionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(6) != 0) curstate |= GDSINTEXT; else
-			curstate &= ~GDSINTEXT;
-		if (DiaGetControl(7) != 0) curstate |= GDSINEXPAND; else
-			curstate &= ~GDSINEXPAND;
-		if (DiaGetControl(8) != 0) curstate |= GDSINARRAYS; else
-			curstate &= ~GDSINARRAYS;
-		if (DiaGetControl(9) != 0) curstate |= GDSOUTMERGE; else
-			curstate &= ~GDSOUTMERGE;
-		if (DiaGetControl(15) != 0) curstate |= GDSINIGNOREUKN; else
-			curstate &= ~GDSINIGNOREUKN;
-		(void)setvalkey((INTBIG)io_aid, VAID, io_state,
-			curstate, VINTEGER);
-		setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_gds_layer_numbers",
-			(INTBIG)layernumbers, VINTEGER|VISARRAY|
-				(el_curtech->layercount<<VLENGTHSH));
-		arcres = atofr(DiaGetText(12)) * 10 / WHOLE;
-		arcsag = atola(DiaGetText(14));
-		setcontoursegmentparameters(arcres, arcsag);
+		if (DiaGetControl(6) != 0) newstate[0] |= GDSINTEXT; else
+			newstate[0] &= ~GDSINTEXT;
+		if (DiaGetControl(7) != 0) newstate[0] |= GDSINEXPAND; else
+			newstate[0] &= ~GDSINEXPAND;
+		if (DiaGetControl(8) != 0) newstate[0] |= GDSINARRAYS; else
+			newstate[0] &= ~GDSINARRAYS;
+		if (DiaGetControl(9) != 0) newstate[0] |= GDSOUTMERGE; else
+			newstate[0] &= ~GDSOUTMERGE;
+		if (DiaGetControl(15) != 0) newstate[0] |= GDSINIGNOREUKN; else
+			newstate[0] &= ~GDSINIGNOREUKN;
+		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
+		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
+		if (numberschanged != 0)
+			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_gds_layer_numbers",
+				(INTBIG)layernumbers, VINTEGER|VISARRAY|
+					(el_curtech->layercount<<VLENGTHSH));
+		newres = atofr(DiaGetText(12)) * 10 / WHOLE;
+		newsag = atola(DiaGetText(14));
+		if (newres != arcres || newsag != arcsag)
+			setcontoursegmentparameters(newres, newsag);
 	}
 	efree((char *)layernumbers);
 	DiaDoneDialog();
