@@ -106,10 +106,10 @@ INTSML io_readleflibrary(LIBRARY *lib)
 	extern DIALOG us_progressdialog;
 
 	/* open the file */
-	fp = xopen(lib->libfile, FILETYPELEF, "", &filename);
+	fp = xopen(lib->libfile, io_filetypelef, "", &filename);
 	if (fp == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
@@ -124,7 +124,7 @@ INTSML io_readleflibrary(LIBRARY *lib)
 		return(1);
 	}
 	DiaPercent(1, 0);
-	DiaSetText(2, "Reading LEF file...");
+	DiaSetText(2, _("Reading LEF file..."));
 	io_leflineno = 0;
 	io_leflinepos = 0;
 	io_lefline[0] = 0;
@@ -135,8 +135,8 @@ INTSML io_readleflibrary(LIBRARY *lib)
 	/* clean up */
 	DiaDoneDialog();
 	xclose(fp);
-	if (ret == 0) ttyputmsg("LEF file %s is read", lib->libfile); else
-		ttyputmsg("Error reading LEF file %s", lib->libfile);
+	if (ret == 0) ttyputmsg(_("LEF file %s is read"), lib->libfile); else
+		ttyputmsg(_("Error reading LEF file %s"), lib->libfile);
 	return(0);
 }
 
@@ -276,7 +276,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 	layername = io_lefgetkeyword(f);
 	if (layername == 0)
 	{
-		ttyputerr("EOF parsing LAYER header");
+		ttyputerr(_("EOF parsing LAYER header"));
 		return(1);
 	}
 	io_lefparselayer(layername, &afunc, &layerfunc);
@@ -292,7 +292,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing LAYER");
+			ttyputerr(_("EOF parsing LAYER"));
 			return(1);
 		}
 
@@ -307,7 +307,7 @@ INTSML io_lefreadlayer(FILE *f, LIBRARY *lib)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading WIDTH");
+				ttyputerr(_("EOF reading WIDTH"));
 				return(1);
 			}
 			v = (float)atof(key);
@@ -345,7 +345,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 	cellname = io_lefgetkeyword(f);
 	if (cellname == 0)
 	{
-		ttyputerr("EOF parsing MACRO header");
+		ttyputerr(_("EOF parsing MACRO header"));
 		return(1);
 	}
 	(void)initinfstr();
@@ -355,7 +355,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 	facet = newnodeproto(cellname, lib);
 	if (facet == NONODEPROTO)
 	{
-		ttyputerr("Cannot create facet '%s'", cellname);
+		ttyputerr(_("Cannot create facet '%s'"), cellname);
 		return(1);
 	}
 
@@ -365,7 +365,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing MACRO");
+			ttyputerr(_("EOF parsing MACRO"));
 			return(1);
 		}
 
@@ -389,7 +389,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading ORIGIN X");
+				ttyputerr(_("EOF reading ORIGIN X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -398,7 +398,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading ORIGIN Y");
+				ttyputerr(_("EOF reading ORIGIN Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -412,7 +412,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			ni = newnodeinst(gen_facetcenterprim, blx, bhx, bly, bhy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr("Line %d: Cannot create facet center node", io_leflineno);
+				ttyputerr(_("Line %d: Cannot create facet center node"), io_leflineno);
 				return(1);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
@@ -424,7 +424,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading SIZE X");
+				ttyputerr(_("EOF reading SIZE X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -433,19 +433,19 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading SIZE 'BY'");
+				ttyputerr(_("EOF reading SIZE 'BY'"));
 				return(1);
 			}
 			if (namesame(key, "BY") != 0)
 			{
-				ttyputerr("Line %d: Expected 'by' in SIZE", io_leflineno);
+				ttyputerr(_("Line %d: Expected 'by' in SIZE"), io_leflineno);
 				return(1);
 			}
 
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading SIZE Y");
+				ttyputerr(_("EOF reading SIZE Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -466,7 +466,7 @@ INTSML io_lefreadmacro(FILE *f, LIBRARY *lib)
 			continue;
 		}
 
-		ttyputerr("Line %d: Unknown MACRO keyword (%s)", io_leflineno, key);
+		ttyputerr(_("Line %d: Unknown MACRO keyword (%s)"), io_leflineno, key);
 		return(1);
 	}
 	return(0);
@@ -502,7 +502,7 @@ INTSML io_lefreadvia(FILE *f, LIBRARY *lib)
 	if (key == 0) return(1);
 	if (namesame(key, "DEFAULT") != 0)
 	{
-		ttyputerr("Expected 'DEFAULT' after VIA name");
+		ttyputerr(_("Expected 'DEFAULT' after VIA name"));
 		return(1);
 	}
 
@@ -599,7 +599,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 	key = io_lefgetkeyword(f);
 	if (key == 0)
 	{
-		ttyputerr("EOF parsing PIN name");
+		ttyputerr(_("EOF parsing PIN name"));
 		return(1);
 	}
 	strcpy(pinname, key);
@@ -610,7 +610,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing PIN");
+			ttyputerr(_("EOF parsing PIN"));
 			return(1);
 		}
 
@@ -633,14 +633,14 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading USE clause");
+				ttyputerr(_("EOF reading USE clause"));
 				return(1);
 			}
 			if (namesame(key, "POWER") == 0) usebits = PWRPORT; else
 			if (namesame(key, "GROUND") == 0) usebits = GNDPORT; else
 			if (namesame(key, "CLOCK") == 0) usebits = CLKPORT; else
 			{
-				ttyputerr("Line %d: Unknown USE keyword (%s)",
+				ttyputerr(_("Line %d: Unknown USE keyword (%s)"),
 					io_leflineno, key);
 			}
 			if (io_lefignoretosemicolon(f, "USE") != 0) return(1);
@@ -652,14 +652,14 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading DIRECTION clause");
+				ttyputerr(_("EOF reading DIRECTION clause"));
 				return(1);
 			}
 			if (namesame(key, "INPUT") == 0) portbits = INPORT; else
 			if (namesame(key, "OUTPUT") == 0) portbits = OUTPORT; else
 			if (namesame(key, "INOUT") == 0) portbits = BIDIRPORT; else
 			{
-				ttyputerr("Line %d: Unknown DIRECTION keyword (%s)",
+				ttyputerr(_("Line %d: Unknown DIRECTION keyword (%s)"),
 					io_leflineno, key);
 			}
 			if (io_lefignoretosemicolon(f, "DIRECTION") != 0) return(1);
@@ -674,7 +674,7 @@ INTSML io_lefreadpin(FILE *f, NODEPROTO *facet)
 			continue;
 		}
 
-		ttyputerr("Line %d: Unknown PIN keyword (%s)", io_leflineno, key);
+		ttyputerr(_("Line %d: Unknown PIN keyword (%s)"), io_leflineno, key);
 		return(1);
 	}
 	return(0);
@@ -705,7 +705,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing PORT");
+			ttyputerr(_("EOF parsing PORT"));
 			return(1);
 		}
 
@@ -719,7 +719,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading LAYER clause");
+				ttyputerr(_("EOF reading LAYER clause"));
 				return(1);
 			}
 			io_lefparselayer(key, &afunc, &layerfunc);
@@ -735,7 +735,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading WIDTH clause");
+				ttyputerr(_("EOF reading WIDTH clause"));
 				return(1);
 			}
 			width = (float)atof(key);
@@ -748,13 +748,13 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		{
 			if (plnp == NONODEPROTO)
 			{
-				ttyputerr("Line %d: No layers for RECT", io_leflineno);
+				ttyputerr(_("Line %d: No layers for RECT"), io_leflineno);
 				return(1);
 			}
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT low X");
+				ttyputerr(_("EOF reading RECT low X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -763,7 +763,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT low Y");
+				ttyputerr(_("EOF reading RECT low Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -772,7 +772,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT high X");
+				ttyputerr(_("EOF reading RECT high X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -781,7 +781,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT high Y");
+				ttyputerr(_("EOF reading RECT high Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -795,7 +795,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			ni = newnodeinst(plnp, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr("Line %d: Cannot create pin for RECT", io_leflineno);
+				ttyputerr(_("Line %d: Cannot create pin for RECT"), io_leflineno);
 				return(1);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
@@ -814,7 +814,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 		{
 			if (ap == NOARCPROTO)
 			{
-				ttyputerr("Line %d: No layers for PATH", io_leflineno);
+				ttyputerr(_("Line %d: No layers for PATH"), io_leflineno);
 				return(1);
 			}
 			for(i=0; ; i++)
@@ -822,7 +822,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				key = io_lefgetkeyword(f);
 				if (key == 0)
 				{
-					ttyputerr("EOF reading PATH clause");
+					ttyputerr(_("EOF reading PATH clause"));
 					return(1);
 				}
 				if (strcmp(key, ";") == 0) break;
@@ -831,7 +831,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				key = io_lefgetkeyword(f);
 				if (key == 0)
 				{
-					ttyputerr("EOF reading PATH clause");
+					ttyputerr(_("EOF reading PATH clause"));
 					return(1);
 				}
 				y = (float)atof(key);
@@ -863,7 +863,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading VIA clause");
+				ttyputerr(_("EOF reading VIA clause"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -872,7 +872,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading VIA clause");
+				ttyputerr(_("EOF reading VIA clause"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -899,7 +899,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				afunc2 = APMETAL5;
 			} else
 			{
-				ttyputerr("Line %d: Unknown VIA type (%s)", io_leflineno, key);
+				ttyputerr(_("Line %d: Unknown VIA type (%s)"), io_leflineno, key);
 				return(1);
 			}
 			ap1 = io_lefgetarc(afunc1);
@@ -920,7 +920,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			}
 			if (pin == NONODEPROTO)
 			{
-				ttyputerr("Line %d: No Via in current technology connects %s to %s",
+				ttyputerr(_("Line %d: No Via in current technology connects %s to %s"),
 					io_leflineno, arcfunctionname((INTSML)afunc1),
 					arcfunctionname((INTSML)afunc2));
 				return(1);
@@ -934,14 +934,14 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr("Line %d: Cannot create VIA for PATH", io_leflineno);
+				ttyputerr(_("Line %d: Cannot create VIA for PATH"), io_leflineno);
 				return(1);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 			continue;
 		}
 
-		ttyputerr("Line %d: Unknown PORT keyword (%s)", io_leflineno, key);
+		ttyputerr(_("Line %d: Unknown PORT keyword (%s)"), io_leflineno, key);
 		return(1);
 	}
 
@@ -993,7 +993,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 			lp->ni[i] = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
 			if (lp->ni[i] == NONODEINST)
 			{
-				ttyputerr("Line %d: Cannot create pin for PATH", io_leflineno);
+				ttyputerr(_("Line %d: Cannot create pin for PATH"), io_leflineno);
 				return(1);
 			}
 			endobjectchange((INTBIG)lp->ni[i], VNODEINST);
@@ -1019,7 +1019,7 @@ INTSML io_lefreadport(FILE *f, NODEPROTO *facet, char *portname, INTBIG portbits
 				lp->ni[1], lp->ni[1]->proto->firstportproto, lp->x[1], lp->y[1], facet);
 		if (ai == NOARCINST)
 		{
-			ttyputerr("Line %d: Cannot create arc for PATH", io_leflineno);
+			ttyputerr(_("Line %d: Cannot create arc for PATH"), io_leflineno);
 			return(1);
 		}
 	}
@@ -1074,7 +1074,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing OBS");
+			ttyputerr(_("EOF parsing OBS"));
 			return(1);
 		}
 
@@ -1085,13 +1085,13 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading LAYER clause");
+				ttyputerr(_("EOF reading LAYER clause"));
 				return(1);
 			}
 			io_lefparselayer(key, &arcfunc, &lfunc);
 			if (lfunc == LFUNKNOWN)
 			{
-				ttyputerr("Line %d: Unknown layer name (%s)", io_leflineno, key);
+				ttyputerr(_("Line %d: Unknown layer name (%s)"), io_leflineno, key);
 				return(1);
 			}
 			np = io_lefgetnode(lfunc);
@@ -1104,13 +1104,13 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 		{
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("Line %d: No layers for RECT", io_leflineno);
+				ttyputerr(_("Line %d: No layers for RECT"), io_leflineno);
 				return(1);
 			}
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT low X");
+				ttyputerr(_("EOF reading RECT low X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -1119,7 +1119,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT low Y");
+				ttyputerr(_("EOF reading RECT low Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -1128,7 +1128,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT high X");
+				ttyputerr(_("EOF reading RECT high X"));
 				return(1);
 			}
 			x = (float)atof(key);
@@ -1137,7 +1137,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			key = io_lefgetkeyword(f);
 			if (key == 0)
 			{
-				ttyputerr("EOF reading RECT high Y");
+				ttyputerr(_("EOF reading RECT high Y"));
 				return(1);
 			}
 			y = (float)atof(key);
@@ -1151,7 +1151,7 @@ INTSML io_lefreadobs(FILE *f, NODEPROTO *facet)
 			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				ttyputerr("Line %d: Cannot create node for RECT", io_leflineno);
+				ttyputerr(_("Line %d: Cannot create node for RECT"), io_leflineno);
 				return(1);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
@@ -1171,7 +1171,7 @@ INTSML io_lefignoretosemicolon(FILE *f, char *command)
 		key = io_lefgetkeyword(f);
 		if (key == 0)
 		{
-			ttyputerr("EOF parsing %s", command);
+			ttyputerr(_("EOF parsing %s"), command);
 			return(1);
 		}
 		if (strcmp(key, ";") == 0) break;
@@ -1231,7 +1231,7 @@ NODEPROTO *io_lefgetnode(INTBIG lfunc)
 	np = getpurelayernode(el_curtech, -1, lfunc);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Line %d: Layer not in current technology",
+		ttyputerr(_("Line %d: Layer not in current technology"),
 			io_leflineno);
 		return(NONODEPROTO);
 	}
@@ -1246,7 +1246,7 @@ ARCPROTO *io_lefgetarc(INTBIG afunc)
 		if (((INTSML)((ap->userbits&AFUNCTION)>>AFUNCTIONSH)) == afunc) break;
 	if (ap == NOARCPROTO)
 	{
-		ttyputerr("Line %d: Layer %s not in current technology",
+		ttyputerr(_("Line %d: Layer %s not in current technology"),
 			io_leflineno, arcfunctionname((INTSML)afunc));
 		return(NOARCPROTO);
 	}
