@@ -88,16 +88,16 @@ INTSML io_writellibrary(LIBRARY *lib)
 	/* create the proper disk file for the L */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate L output");
+		ttyputerr(_("Must be editing a facet to generate L output"));
 		return(1);
 	}
 	(void)strcpy(file, lib->curnodeproto->cell->cellname);
 	(void)strcat(file, ".L");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPEL, "L File", &truename);
+	io_fileout = xcreate(name, io_filetypel, _("L File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
@@ -108,13 +108,13 @@ INTSML io_writellibrary(LIBRARY *lib)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
 	if (io_l_writefacet(lib->curnodeproto) != 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	/* clean up */
 	xclose(io_fileout);
 
 	/* tell the user that the file is written */
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 
 	return(0);
 }
@@ -136,7 +136,6 @@ INTSML io_l_writefacet(NODEPROTO *np)
 	char *extra, line[50];
 	INTBIG xpos, ypos, len, wid, lx, hx, ly, hy;
 	REGISTER ARCPROTO **aplist;
-	extern AIDENTRY *net_aid;
 
 	/* if there are any sub-facets that have not been written, write them */
 	backannotate = 0;
@@ -221,7 +220,7 @@ INTSML io_l_writefacet(NODEPROTO *np)
 			i = nodefunction(subno, &extra);
 			if (i == NPPIN)
 			{
-				/* if pin is exported, don't write separate node statement */
+				/* if pin is an export, don't write separate node statement */
 				if (subno->firstportexpinst != NOPORTEXPINST) continue;
 				for(j=0; io_lports[j].arcfunct != 0; j++)
 					if ((INTSML)(((subno->proto->firstportproto->connects[0]->userbits&
@@ -328,7 +327,7 @@ INTSML io_l_writefacet(NODEPROTO *np)
 			if (subar->width != defaultarcwidth(subar->proto))
 				xprintf(io_fileout, " W=%s", latoa(subar->width-arcwidthoffset(subar)));
 
-			/* write the starting node name (use port name if pin is exported) */
+			/* write the starting node name (use port name if pin is an export) */
 			if (subno->firstportexpinst != NOPORTEXPINST && nodefunction(subno, &extra) == NPPIN)
 				xprintf(io_fileout, " %s",
 						io_l_fixname(subno->firstportexpinst->exportproto->protoname)); else
@@ -407,7 +406,7 @@ INTSML io_l_writefacet(NODEPROTO *np)
 				if (segdist >= 0) xprintf(io_fileout, "=%s", latoa(segdist));
 			} else xprintf(io_fileout, " TO");
 
-			/* write the terminating node name (use port name if pin is exported) */
+			/* write the terminating node name (use port name if pin is an export) */
 			if (oni->firstportexpinst != NOPORTEXPINST && nodefunction(oni, &extra) == NPPIN)
 				xprintf(io_fileout, " %s",
 					io_l_fixname(oni->firstportexpinst->exportproto->protoname)); else
@@ -445,7 +444,7 @@ char *io_l_name(NODEINST *ni)
 
 	var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 	if (var != NOVARIABLE) return(io_l_fixname((char *)var->addr));
-	ttyputerr("L generation warning: no name on node %s", describenodeinst(ni));
+	ttyputerr(_("L generation warning: no name on node %s"), describenodeinst(ni));
 	(void)sprintf(line, "c%ld", ni->temp1);
 	return(line);
 }
