@@ -85,9 +85,9 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	INTSML err, ix, swid, shei;
 	INTBIG hlx, hhx, hly, hhy, gridlx, gridly, gridx, gridy, cx, cy, prod1, prod2, i,
 		revy, slx, shx, sly, shy, ulx, uhx, uly, uhy, sxs, sys, dxs, dys, saver, saveg,
-		saveb, white;
+		saveb, white, *curstate;
 	VARIABLE *var;
-	REGISTER VARIABLE *varstate, *varred, *vargreen, *varblue;
+	REGISTER VARIABLE *varred, *vargreen, *varblue;
 	static POLYGON *poly = NOPOLYGON;
 	static THPrint hPrint = 0;
 	TPPrPort plotwin;
@@ -98,7 +98,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("No current facet to plot");
+		ttyputerr(_("No current facet to plot"));
 		return(1);
 	}
 
@@ -114,16 +114,25 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	}
 
 	/* see if focusing on highlighted area */
-	varstate = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (varstate != NOVARIABLE && (varstate->addr&PLOTFOCUS) != 0)
+	curstate = io_getstatebits();
+	if ((curstate[0]&PLOTFOCUS) != 0)
 	{
-		onp = (NODEPROTO *)askaid(us_aid, "get-highlighted-area", (INTBIG)&hlx,
-			(INTBIG)&hhx, (INTBIG)&hly, (INTBIG)&hhy);
-		if (onp == NONODEPROTO)
-			ttyputerr("Warning: no highlighted area; plotting entire facet"); else
+		if ((curstate[0]&PLOTFOCUSDPY) != 0)
 		{
-			slx = hlx;   shx = hhx;
-			sly = hly;   shy = hhy;
+			slx = el_curwindowpart->screenlx;
+			shx = el_curwindowpart->screenhx;
+			sly = el_curwindowpart->screenly;
+			shy = el_curwindowpart->screenhy;
+		} else
+		{
+			onp = (NODEPROTO *)askaid(us_aid, "get-highlighted-area", (INTBIG)&hlx,
+				(INTBIG)&hhx, (INTBIG)&hly, (INTBIG)&hhy);
+			if (onp == NONODEPROTO)
+				ttyputerr(_("Warning: no highlighted area; plotting entire facet")); else
+			{
+				slx = hlx;   shx = hhx;
+				sly = hly;   shy = hhy;
+			}
 		}
 	}
 
@@ -131,7 +140,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	PrOpen();
 	if ((err = PrError()) != noErr)
 	{
-		ttyputerr("Printer error %d", err);
+		ttyputerr(_("Printer error %d"), err);
 		return(1);
 	}
 
@@ -142,13 +151,13 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		hPrint = (THPrint)NewHandle(sizeof (TPrint));
 		if (hPrint == 0)
 		{
-			ttyputerr("Cannot allocate print record");
+			ttyputerr(_("Cannot allocate print record"));
 			return(1);
 		}
 		PrintDefault(hPrint);
 		if ((err = PrError()) != noErr)
 		{
-			ttyputerr("Printer error %d", err);
+			ttyputerr(_("Printer error %d"), err);
 			return(1);
 		}
 		if (!PrStlDialog(hPrint)) return(1);
@@ -158,7 +167,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		PrValidate(hPrint);
 		if ((err = PrError()) != noErr)
 		{
-			ttyputerr("Printer error %d", err);
+			ttyputerr(_("Printer error %d"), err);
 			return(1);
 		}
 	}
@@ -171,7 +180,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	PrOpenPage(plotwin, 0);
 	if (PrError())
 	{
-		ttyputerr("Error opening print page");
+		ttyputerr(_("Error opening print page"));
 		return(1);
 	}
 	SetPort((WindowPtr)plotwin);
@@ -233,7 +242,7 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 		{
 			PrPicFile(hPrint, 0, 0, 0, &prstat);
 			if (PrError())
-				ttyputerr("Error queuing print page");
+				ttyputerr(_("Error queuing print page"));
 		}
 		PrClose();
 		
@@ -334,15 +343,14 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 	(void)askaid(us_aid, "display-to-routine", io_plotpoly);
 
 	/* put out dates if requested */
-	if (varstate != NOVARIABLE && (varstate->addr&PLOTDATES) != 0)
+	if ((curstate[0]&PLOTDATES) != 0)
 	{
 		/* create the polygon if it doesn't exist */
 		if (poly == NOPOLYGON) poly = allocstaticpolygon(1, io_aid->cluster);
 
 		/* plot facet name */
 		(void)initinfstr();
-		(void)addstringtoinfstr("Facet: ");
-		(void)addstringtoinfstr(describenodeproto(np));
+		(void)formatinfstr(_("Facet: %s"), describenodeproto(np));
 		poly->string = returninfstr();
 		poly->xv[0] = np->highx;
 		poly->yv[0] = np->lowy;
@@ -355,16 +363,14 @@ INTSML io_writequickdrawlibrary(LIBRARY *lib)
 
 		/* plot creation date */
 		(void)initinfstr();
-		(void)addstringtoinfstr("Created: ");
-		(void)addstringtoinfstr(timetostring(np->creationdate));
+		(void)formatinfstr(_("Created: %s"), timetostring(np->creationdate));
 		poly->string = returninfstr();
 		poly->yv[0] = np->lowy + (np->highy-np->lowy) / 20;
 		(void)io_plotpoly(poly, el_curwindowpart);
 
 		/* plot revision date */
 		(void)initinfstr();
-		(void)addstringtoinfstr("Revised: ");
-		(void)addstringtoinfstr(timetostring(np->revisiondate));
+		(void)formatinfstr(_("Revised: %s"), timetostring(np->revisiondate));
 		poly->string = returninfstr();
 		poly->yv[0] = np->lowy + (np->highy-np->lowy) / 10;
 		(void)io_plotpoly(poly, el_curwindowpart);
@@ -430,9 +436,7 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 	unsigned char pat[8];
 	Rect r;
 	static POLYGON *polyspline = NOPOLYGON;
-	static WINDOWPART *cachedwindow = NOWINDOWPART;
-	static NODEPROTO *cachedfacet = NONODEPROTO;
-	static TECHNOLOGY *cachedtech = NOTECHNOLOGY;
+	REGISTER TECHNOLOGY *tech;
 
 	/* ignore null layers */
 	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return(1);
@@ -684,16 +688,8 @@ INTSML io_plotpoly(POLYGON *poly, WINDOWPART *win)
 		case TEXTTOPRIGHT:
 		case TEXTBOTRIGHT:
 		case TEXTBOX:
-			if (win != cachedwindow || win->curnodeproto != cachedfacet)
-			{
-				cachedwindow = win;
-				cachedfacet = win->curnodeproto;
-				cachedtech = NOTECHNOLOGY;
-				if (cachedfacet != NONODEPROTO)
-					cachedtech = whattech(cachedfacet);
-			}
-			if (cachedtech == NOTECHNOLOGY) cachedtech = el_curtech;
-			font = truefontsize(poly->font, io_plotwindow, cachedtech);
+			tech = win->curnodeproto->tech;
+			font = truefontsize(poly->font, io_plotwindow, tech);
 			getbbox(poly, &xl, &xh, &yl, &yh);
 			io_plottext(poly->style, xl, xh, yl, yh, font, poly->string);
 			break;
@@ -915,8 +911,7 @@ void io_maccopyhighlighted(void)
 	uly = sly;   uhy = shy;
 	(void)us_makescreen(&ulx, &uly, &uhx, &uhy, el_curwindowpart);
 
-#if 0
-	/* this will make a color copy in the clipboard */
+#if 0		/* this will make a color copy in the clipboard */
 	{
 		Rect sr;
 		CGrafPtr window;
