@@ -363,11 +363,11 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	if (io_maxinputline == 0)
 		if (io_grabbuffers(1000) != 0) return(1);
 
-	io_txtindata.textfilein = xopen(truepath(lib->libfile), FILETYPETLIB,
+	io_txtindata.textfilein = xopen(truepath(lib->libfile), io_filetypetlib,
 		el_libdir, &filename);
 	if (io_txtindata.textfilein == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
@@ -386,10 +386,9 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 				}
 			}
 			(void)initinfstr();
-			(void)addstringtoinfstr("Reading library ");
-			(void)addstringtoinfstr(lib->libname);
+			(void)formatinfstr(_("Reading library %s"), lib->libname);
 			DiaSetText(3, returninfstr());
-			DiaSetText(2, "Initializing...");
+			DiaSetText(2, _("Initializing..."));
 			DiaPercent(1, 0);
 		}
 	} else io_txtindata.filelength = 0;
@@ -398,7 +397,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	pp = (char *)setjmp(io_filerror);
 	if (pp != 0)
 	{
-		ttyputerr("Error: %s on line %ld, keyword '%s'", pp,
+		ttyputerr(_("Error: %s on line %ld, keyword '%s'"), pp,
 			io_txtindata.linenumber, io_keyword);
 		xclose(io_txtindata.textfilein);
 		if (io_verbose < 0 && io_txtindata.filelength > 0) DiaDoneDialog();
@@ -412,8 +411,8 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	j = strlen(pp);
 	if (j > 4 && namesame(&pp[j-4], ".txt") == 0) j -= 4;
 	for(i=0; i<j; i++) (void)addtoinfstr(pp[i]);
-	if (allocstring(&lib->libname, returninfstr(), lib->cluster) != 0)
-		longjmp(io_filerror, (INTBIG)"No memory");
+	if (reallocstring(&lib->libname, returninfstr(), lib->cluster) != 0)
+		longjmp(io_filerror, (INTBIG)_("No memory"));
 
 	io_txtindata.curlib = lib;
 	eraselibrary(lib);
@@ -432,7 +431,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 		/* get keyword from file */
 		if (io_getkeyword()) break;
 		pp = io_keyword;   while (*pp != 0) pp++;
-		if (pp[-1] != ':') longjmp(io_filerror, (INTBIG)"Missing colon");
+		if (pp[-1] != ':') longjmp(io_filerror, (INTBIG)_("Missing colon"));
 		pp[-1] = 0;
 
 		if (reportcount++ > REPORTRATE)
@@ -458,17 +457,17 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 		for(i=0; table[i].matchstring != 0; i++)
 			if (strcmp(table[i].matchstring, io_keyword) == 0) break;
 		if (table[i].matchstring == 0)
-			longjmp(io_filerror, (INTBIG)"Unknown keyword");
+			longjmp(io_filerror, (INTBIG)_("Unknown keyword"));
 
 		/* get argument to routine and call it */
-		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)"EOF too soon");
+		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)_("EOF too soon"));
 		(*(table[i].routine))();
 	}
 	xclose(io_txtindata.textfilein);
 	if (io_verbose < 0 && io_txtindata.filelength > 0)
 	{
 		DiaPercent(1, 100);
-		DiaSetText(2, "Cleaning up...");
+		DiaSetText(2, _("Cleaning up..."));
 	}
 
 	/* set the former version number on the library */
@@ -481,11 +480,11 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	/* fill in any lambda values that are not specified */
 	oldunit = ((io_txtindata.curlib->userbits & LIBUNITS) >> LIBUNITSSH) << INTERNALUNITSSH;
 	if (oldunit == (el_units&INTERNALUNITS)) num = den = 1; else
-		db_getinternalunitscale(&num, &den, el_units, (INTSML)oldunit);
+		db_getinternalunitscale(&num, &den, el_units, oldunit);
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 	{
 		lambda = io_txtindata.curlib->lambda[tech->techindex];
-		if (lambda == 0) lambda = tech->deflambda; else
+		if (lambda == 0) lambda = el_curlib->lambda[tech->techindex]; else
 			lambda = muldiv(lambda, den, num);
 		io_txtindata.curlib->lambda[tech->techindex] = lambda;
 	}
@@ -493,14 +492,14 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 	/* if this is to be the current library, adjust technologies */
 	if (io_txtindata.curlib == el_curlib)
 		for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
-			changelambda(tech->deflambda, io_txtindata.curlib->lambda[tech->techindex], tech);
+			changetechnologylambda(tech, io_txtindata.curlib->lambda[tech->techindex]);
 
 	/* create clusters for the cells */
 	for(c = io_txtindata.curlib->firstcell; c != NOCELL; c = c->nextcell)
 	{
 		c->cluster = alloccluster(c->cellname);
 		if (c->cluster == NOCLUSTER)
-			longjmp(io_filerror, (INTBIG)"No cluster memory");
+			longjmp(io_filerror, (INTBIG)_("No cluster memory"));
 	}
 
 	/* handle recent libraries version 4 or later */
@@ -530,7 +529,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 
 		/* get memory for groups of cells */
 		list = (NODEPROTO **)emalloc(((sizeof (NODEPROTO *)) * largestcluster), el_tempcluster);
-		if (list == 0) longjmp(io_filerror, (INTBIG)"No memory");
+		if (list == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 
 		/* combine names that are the same */
 		for(i=1; i<assoc; i++)
@@ -554,7 +553,7 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 				{
 					efree(np->cell->cellname);
 					freecell(np->cell);
-				} else ttyputmsg("Facet %s did not stand alone!", np->cell->cellname);
+				} else ttyputmsg(_("Facet %s did not stand alone!"), np->cell->cellname);
 
 				/* set the cell pointer correctly */
 				np->cell = list[0]->cell;
@@ -572,21 +571,21 @@ INTSML io_doreadtextlibrary(LIBRARY *lib, INTSML newprogress)
 
 	/* print any variable-related error messages */
 	if (io_txtindata.nodeinsterror != 0)
-		ttyputmsg("Warning: %ld invalid NODEINST pointers", io_txtindata.nodeinsterror);
+		ttyputmsg(_("Warning: %ld invalid NODEINST pointers"), io_txtindata.nodeinsterror);
 	if (io_txtindata.arcinsterror != 0)
-		ttyputmsg("Warning: %ld invalid ARCINST pointers", io_txtindata.arcinsterror);
+		ttyputmsg(_("Warning: %ld invalid ARCINST pointers"), io_txtindata.arcinsterror);
 	if (io_txtindata.portprotoerror != 0)
-		ttyputmsg("Warning: %ld invalid PORTPROTO pointers", io_txtindata.portprotoerror);
+		ttyputmsg(_("Warning: %ld invalid PORTPROTO pointers"), io_txtindata.portprotoerror);
 	if (io_txtindata.portarcinsterror != 0)
-		ttyputmsg("Warning: %ld PORTARCINST pointers not restored", io_txtindata.portarcinsterror);
+		ttyputmsg(_("Warning: %ld PORTARCINST pointers not restored"), io_txtindata.portarcinsterror);
 	if (io_txtindata.portexpinsterror != 0)
-		ttyputmsg("Warning: %ld PORTEXPINST pointers not restored", io_txtindata.portexpinsterror);
+		ttyputmsg(_("Warning: %ld PORTEXPINST pointers not restored"), io_txtindata.portexpinsterror);
 	if (io_txtindata.geomerror != 0)
-		ttyputmsg("Warning: %ld GEOM pointers not restored", io_txtindata.geomerror);
+		ttyputmsg(_("Warning: %ld GEOM pointers not restored"), io_txtindata.geomerror);
 	if (io_txtindata.rtnodeerror != 0)
-		ttyputmsg("Warning: %ld RTNODE pointers not restored", io_txtindata.rtnodeerror);
+		ttyputmsg(_("Warning: %ld RTNODE pointers not restored"), io_txtindata.rtnodeerror);
 	if (io_txtindata.libraryerror != 0)
-		ttyputmsg("Warning: LIBRARY pointers not restored", io_txtindata.libraryerror);
+		ttyputmsg(_("Warning: LIBRARY pointers not restored"), io_txtindata.libraryerror);
 
 	if (io_txtindata.mainfacet != -1 && io_txtindata.mainfacet < io_txtindata.facetcount)
 		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.mainfacet]; else
@@ -611,7 +610,7 @@ INTSML io_getkeyword(void)
 		{
 			io_txtindata.linenumber++;
 			if (io_verbose == 0 && io_txtindata.linenumber%1000 == 0)
-				ttyputmsg("%ld lines read", io_txtindata.linenumber);
+				ttyputmsg(_("%ld lines read"), io_txtindata.linenumber);
 			continue;
 		}
 		if (c != ' ') break;
@@ -643,7 +642,7 @@ INTSML io_getkeyword(void)
 	{
 		io_txtindata.linenumber++;
 		if (io_verbose == 0 && io_txtindata.linenumber%1000 == 0)
-			ttyputmsg("%ld lines read", io_txtindata.linenumber);
+			ttyputmsg(_("%ld lines read"), io_txtindata.linenumber);
 	}
 	io_keyword[cindex] = 0;
 	return(0);
@@ -661,7 +660,7 @@ INTSML io_grabbuffers(INTBIG size)
 	p = (char *)emalloc((size+1), io_aid->cluster);
 	if (p == 0)
 	{
-		ttyputerr("No memory for input buffer");
+		ttyputnomemory();
 		return(1);
 	}
 
@@ -890,9 +889,9 @@ void io_getvar(void)
 	for(i=0; i<count; i++)
 	{
 		/* read the first keyword with the name, type, and descriptor */
-		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)"EOF in variables");
+		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)_("EOF in variables"));
 		if (io_keyword[strlen(io_keyword)-1] != ':')
-			longjmp(io_filerror, (INTBIG)"Missing ':' in variable");
+			longjmp(io_filerror, (INTBIG)_("Missing ':' in variable"));
 
 		/* get the variable name */
 		j = initinfstr();
@@ -906,7 +905,7 @@ void io_getvar(void)
 			if (*pt == '(' || *pt == '[' || *pt == ':') break;
 			j += addtoinfstr(*pt);
 		}
-		if (j != 0) longjmp(io_filerror, (INTBIG)"No memory");
+		if (j != 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 		key = makekey(returninfstr());
 
 		/* get optional length */
@@ -917,7 +916,7 @@ void io_getvar(void)
 		} else len = -1;
 
 		/* get type */
-		if (*pt != '[') longjmp(io_filerror, (INTBIG)"Missing '[' in variable");
+		if (*pt != '[') longjmp(io_filerror, (INTBIG)_("Missing '[' in variable"));
 		type = myatoi(&pt[1]);
 
 		/* get the descriptor */
@@ -925,23 +924,23 @@ void io_getvar(void)
 		if (*pt == ',') descript = myatoi(&pt[1]); else descript = 0;
 
 		/* get value */
-		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)"EOF in variables");
+		if (io_getkeyword()) longjmp(io_filerror, (INTBIG)_("EOF in variables"));
 		if ((type&VISARRAY) != 0)
 		{
 			if (len < 0)
 			{
 				len = (type&VLENGTH) >> VLENGTHSH;
 				store = emalloc((len * SIZEOFINTBIG), el_tempcluster);
-				if (store == 0) longjmp(io_filerror, (INTBIG)"No memory");
+				if (store == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 			} else
 			{
 				store = emalloc(((len+1) * SIZEOFINTBIG), el_tempcluster);
-				if (store == 0) longjmp(io_filerror, (INTBIG)"No memory");
+				if (store == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 				store[len] = -1;
 			}
 			pt = io_keyword;
 			if (*pt++ != '[')
-				longjmp(io_filerror, (INTBIG)"Missing '[' in variable array");
+				longjmp(io_filerror, (INTBIG)_("Missing '[' in variable array"));
 			for(j=0; j<len; j++)
 			{
 				/* string arrays must be handled specially */
@@ -969,7 +968,7 @@ void io_getvar(void)
 					while (*pt != ',' && *pt != ']' && *pt != 0) pt++;
 				}
 				if (*pt == 0)
-					longjmp(io_filerror, (INTBIG)"Short array specification");
+					longjmp(io_filerror, (INTBIG)_("Short array specification"));
 				*pt++ = 0;
 				if ((type&VTYPE) == VGENERAL)
 				{
@@ -989,7 +988,7 @@ void io_getvar(void)
 			{
 				nextvarchangequiet();
 				var = setvalkey(naddr, ntype, key, (INTBIG)store, type);
-				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)"No memory");
+				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)_("No memory"));
 				var->textdescript = descript;
 			}
 			efree((char *)store);
@@ -1000,7 +999,7 @@ void io_getvar(void)
 			{
 				nextvarchangequiet();
 				var = setvalkey(naddr, ntype, key, ret, type);
-				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)"No memory");
+				if (var == NOVARIABLE) longjmp(io_filerror, (INTBIG)_("No memory"));
 				var->textdescript = descript;
 			}
 		}
@@ -1065,9 +1064,9 @@ INTBIG io_decode(char *name, INTBIG type)
 			/* parse primitive nodeproto name */
 			np = getnodeproto(name);
 			if (np == NONODEPROTO)
-				longjmp(io_filerror, (INTBIG)"Unknown node prototype");
+				longjmp(io_filerror, (INTBIG)_("Unknown node prototype"));
 			if (np->primindex == 0)
-				longjmp(io_filerror, (INTBIG)"Unknown node prototype");
+				longjmp(io_filerror, (INTBIG)_("Unknown node prototype"));
 			return((INTBIG)np);
 		case VPORTARCINST:
 			io_txtindata.portarcinsterror++;   break;
@@ -1121,14 +1120,14 @@ void io_libcc(void)
 	/* allocate a list of node prototypes for this library */
 	io_txtindata.nodeprotolist = (NODEPROTO **)emalloc(((sizeof (NODEPROTO *)) * io_txtindata.facetcount),
 		el_tempcluster);
-	if (io_txtindata.nodeprotolist == 0) longjmp(io_filerror, (INTBIG)"No memory");
+	if (io_txtindata.nodeprotolist == 0) longjmp(io_filerror, (INTBIG)_("No memory"));
 	for(i=0; i<io_txtindata.facetcount; i++)
 	{
 		c = alloccell(io_txtindata.curlib->cluster);
-		if (c == NOCELL) longjmp(io_filerror, (INTBIG)"No memory for facets");
+		if (c == NOCELL) longjmp(io_filerror, (INTBIG)_("No memory for facets"));
 		io_txtindata.nodeprotolist[i] = allocnodeproto(io_txtindata.curlib->cluster);
 		if (io_txtindata.nodeprotolist[i] == NONODEPROTO)
-			longjmp(io_filerror, (INTBIG)"No memory for facets");
+			longjmp(io_filerror, (INTBIG)_("No memory for facets"));
 		io_txtindata.nodeprotolist[i]->cell = c;
 		c->firstincell = io_txtindata.nodeprotolist[i];
 		c->nextcell = NOCELL;
@@ -1136,7 +1135,6 @@ void io_libcc(void)
 		c->lib = io_txtindata.curlib;
 		io_txtindata.nodeprotolist[i]->cellview = el_unknownview;
 		io_txtindata.nodeprotolist[i]->newestversion = io_txtindata.nodeprotolist[i];
-		io_txtindata.nodeprotolist[i]->tech = NOTECHNOLOGY;
 		io_txtindata.nodeprotolist[i]->primindex = 0;
 		io_txtindata.nodeprotolist[i]->firstportproto = NOPORTPROTO;
 		io_txtindata.nodeprotolist[i]->firstnodeinst = NONODEINST;
@@ -1144,7 +1142,7 @@ void io_libcc(void)
 
 		/* create geometry structure in the facet */
 		if (geomstructure(io_txtindata.nodeprotolist[i]) != 0)
-			longjmp(io_filerror, (INTBIG)"No memory for geometry structure");
+			longjmp(io_filerror, (INTBIG)_("No memory for geometry structure"));
 	}
 	if (io_txtindata.facetcount == 0) io_txtindata.curlib->firstcell = NOCELL; else
 		io_txtindata.curlib->firstcell = io_txtindata.nodeprotolist[0]->cell;
@@ -1180,16 +1178,16 @@ void io_libvie(void)
 
 	pt = io_keyword;
 	while (*pt != 0 && *pt != '{') pt++;
-	if (*pt != '{') longjmp(io_filerror, (INTBIG)"Missing view abbreviation");
+	if (*pt != '{') longjmp(io_filerror, (INTBIG)_("Missing view abbreviation"));
 	*pt++ = 0;
 	len = strlen(pt);
-	if (pt[len-1] != '}') longjmp(io_filerror, (INTBIG)"View abbreviation bad");
+	if (pt[len-1] != '}') longjmp(io_filerror, (INTBIG)_("View abbreviation bad"));
 	pt[len-1] = 0;
 	v = getview(io_keyword);
 	if (v == NOVIEW)
 	{
 		v = allocview();
-		if (v == NOVIEW) longjmp(io_filerror, (INTBIG)"No memory");
+		if (v == NOVIEW) longjmp(io_filerror, (INTBIG)_("No memory"));
 		(void)allocstring(&v->viewname, io_keyword, db_cluster);
 		(void)allocstring(&v->sviewname, pt, db_cluster);
 		if (namesamen(io_keyword, "Schematic-Page-", 15) == 0)
@@ -1199,7 +1197,7 @@ void io_libvie(void)
 	} else
 	{
 		if (namesame(v->sviewname, pt) != 0)
-			longjmp(io_filerror, (INTBIG)"View abbreviation inconsistent");
+			longjmp(io_filerror, (INTBIG)_("View abbreviation inconsistent"));
 	}
 	pt[-1] = '{';   pt[len-1] = '}';
 }
@@ -1230,10 +1228,9 @@ void io_celnam(void)
 		if (io_verbose < 0 && io_txtindata.filelength > 0)
 		{
 			(void)initinfstr();
-			(void)addstringtoinfstr("Reading ");
-			(void)addstringtoinfstr(io_keyword);
+			(void)formatinfstr(_("Reading %s"), io_keyword);
 			DiaSetText(2, returninfstr());
-		} else ttyputmsg("Reading %s", io_keyword);
+		} else ttyputmsg(_("Reading %s"), io_keyword);
 	}
 	io_txtindata.curnodeproto->cellview = el_unknownview;
 	pt = io_keyword;
@@ -1243,7 +1240,7 @@ void io_celnam(void)
 		*pt = 0;
 		if (allocstring(&io_txtindata.curnodeproto->cell->cellname, io_keyword,
 			io_txtindata.curlib->cluster) != 0)
-				longjmp(io_filerror, (INTBIG)"No memory for facet name");
+				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 		pt++;
 		pt[strlen(pt)-1] = 0;
 		for(v = el_views; v != NOVIEW; v = v->nextview)
@@ -1253,7 +1250,7 @@ void io_celnam(void)
 	{
 		if (allocstring(&io_txtindata.curnodeproto->cell->cellname, io_keyword,
 			io_txtindata.curlib->cluster) != 0)
-				longjmp(io_filerror, (INTBIG)"No memory for facet name");
+				longjmp(io_filerror, (INTBIG)_("No memory for facet name"));
 	}
 }
 
@@ -1286,8 +1283,7 @@ void io_celrev(void)
  */
 void io_celext(void)
 {
-	INTBIG k, len, insx, insy;
-	REGISTER INTSML filetype;
+	INTBIG k, len, insx, insy, filetype;
 	REGISTER LIBRARY *elib;
 	REGISTER char *libname, *pt;
 	char *filename, *libfile, *oldline2, *oldline3;
@@ -1311,11 +1307,11 @@ void io_celext(void)
 	(void)addstringtoinfstr(skippath(libfile));
 	libname = returninfstr();
 	len = strlen(libname);
-	filetype = FILETYPETLIB;
+	filetype = io_filetypetlib;
 	if (len > 5 && namesame(&libname[len-5], ".elib") == 0)
 	{
 		libname[len-5] = 0;
-		filetype = FILETYPEBLIB;
+		filetype = io_filetypeblib;
 	} else
 	{
 		if (len > 4 && namesame(&libname[len-4], ".txt") == 0) libname[len-4] = 0;
@@ -1328,13 +1324,11 @@ void io_celext(void)
 		if (io != 0)
 		{
 			xclose(io);
-			ttyputmsg("Reading referenced library %s", libfile);
+			ttyputmsg(_("Reading referenced library %s"), libfile);
 		} else
 		{
 			(void)initinfstr();
-			(void)addstringtoinfstr("Reference library '");
-			(void)addstringtoinfstr(libname);
-			(void)addstringtoinfstr("'");
+			(void)formatinfstr(_("Reference library '%s'"), libname);
 			pt = fileselect(returninfstr(), filetype, "");
 			if (pt != 0) strcpy(libfile, pt);
 		}
@@ -1392,7 +1386,7 @@ void io_celext(void)
 			(void)addstringtoinfstr(io_txtindata.curnodeproto->cellview->sviewname);
 			(void)addtoinfstr('}');
 		}
-		ttyputerr("Cannot find facet %s in library %s..creating dummy verision",
+		ttyputerr(_("Cannot find facet %s in library %s..creating dummy verision"),
 			returninfstr(), elib->libname);
 	} else
 	{
@@ -1403,7 +1397,7 @@ void io_celext(void)
 			np->lowy != io_txtindata.curnodeproto->lowy ||
 			np->highy != io_txtindata.curnodeproto->highy)
 		{
-			ttyputerr("Warning: facet %s in library %s has been modified",
+			ttyputerr(_("Warning: facet %s in library %s has been modified"),
 				describenodeproto(np), elib->libname);
 			np = NONODEPROTO;
 		}
@@ -1512,7 +1506,7 @@ void io_tech(void)
 	REGISTER TECHNOLOGY *tech;
 
 	tech = io_gettechnology(io_keyword);
-	if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)"Unknown technology");
+	if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)_("Unknown technology"));
 	io_txtindata.curtech = tech;
 }
 
@@ -1560,15 +1554,15 @@ void io_celnoc(void)
 	if (io_txtindata.nodeinstcount == 0) return;
 	io_txtindata.nodelist = (NODEINST **)emalloc(((sizeof (NODEINST *)) * io_txtindata.nodeinstcount),
 		el_tempcluster);
-	if (io_txtindata.nodelist == 0) longjmp(io_filerror, (INTBIG)"No memory for nodeinsts");
+	if (io_txtindata.nodelist == 0) longjmp(io_filerror, (INTBIG)_("No memory for nodeinsts"));
 	geomlist = (GEOM **)emalloc(((sizeof (GEOM *)) * io_txtindata.nodeinstcount), el_tempcluster);
-	if (geomlist == 0) longjmp(io_filerror, (INTBIG)"No memory for nodeinsts");
+	if (geomlist == 0) longjmp(io_filerror, (INTBIG)_("No memory for nodeinsts"));
 	for(i=0; i<io_txtindata.nodeinstcount; i++)
 	{
 		ni = allocnodeinst(io_txtindata.curlib->cluster);
 		geomlist[i] = allocgeom(io_txtindata.curlib->cluster);
 		if (ni == NONODEINST || geomlist[i] == NOGEOM)
-			longjmp(io_filerror, (INTBIG)"No memory for nodeinsts");
+			longjmp(io_filerror, (INTBIG)_("No memory for nodeinsts"));
 		io_txtindata.nodelist[i] = ni;
 		ni->parent = io_txtindata.curnodeproto;
 		ni->firstportarcinst = NOPORTARCINST;
@@ -1598,15 +1592,15 @@ void io_celarc(void)
 	if (io_txtindata.arcinstcount == 0) return;
 	io_txtindata.arclist = (ARCINST **)emalloc(((sizeof (ARCINST *)) * io_txtindata.arcinstcount),
 		el_tempcluster);
-	if (io_txtindata.arclist == 0) longjmp(io_filerror, (INTBIG)"No memory for arcinsts");
+	if (io_txtindata.arclist == 0) longjmp(io_filerror, (INTBIG)_("No memory for arcinsts"));
 	geomlist = (GEOM **)emalloc(((sizeof (GEOM *)) * io_txtindata.arcinstcount), el_tempcluster);
-	if (geomlist == 0) longjmp(io_filerror, (INTBIG)"No memory for arcinsts");
+	if (geomlist == 0) longjmp(io_filerror, (INTBIG)_("No memory for arcinsts"));
 	for(i=0; i<io_txtindata.arcinstcount; i++)
 	{
 		ai = allocarcinst(io_txtindata.curlib->cluster);
 		geomlist[i] = allocgeom(io_txtindata.curlib->cluster);
 		if (ai == NOARCINST || geomlist[i] == NOGEOM)
-			longjmp(io_filerror, (INTBIG)"No memory for arcinsts");
+			longjmp(io_filerror, (INTBIG)_("No memory for arcinsts"));
 		io_txtindata.arclist[i] = ai;
 		ai->parent = io_txtindata.curnodeproto;
 		ai->geom = geomlist[i];
@@ -1632,12 +1626,12 @@ void io_celptc(void)
 	if (io_txtindata.portprotocount == 0) return;
 	io_txtindata.portprotolist = (PORTPROTO **)emalloc(((sizeof (PORTPROTO *)) * io_txtindata.portprotocount),
 		el_tempcluster);
-	if (io_txtindata.portprotolist == 0) longjmp(io_filerror, (INTBIG)"No memory for port prototypes");
+	if (io_txtindata.portprotolist == 0) longjmp(io_filerror, (INTBIG)_("No memory for port prototypes"));
 	for(i=0; i<io_txtindata.portprotocount; i++)
 	{
 		io_txtindata.portprotolist[i] = allocportproto(io_txtindata.curlib->cluster);
 		if (io_txtindata.portprotolist[i] == NOPORTPROTO)
-			longjmp(io_filerror, (INTBIG)"No memory for port prototypes");
+			longjmp(io_filerror, (INTBIG)_("No memory for port prototypes"));
 		io_txtindata.portprotolist[i]->parent = io_txtindata.curnodeproto;
 	}
 
@@ -1661,7 +1655,7 @@ void io_celdon(void)
 
 	/* verify facet name */
 	if (namesame(io_keyword, io_txtindata.curnodeproto->cell->cellname) != 0)
-		ttyputmsg("Warning: facet '%s' wants to be '%s'",
+		ttyputmsg(_("Warning: facet '%s' wants to be '%s'"),
 			io_txtindata.curnodeproto->cell->cellname, io_keyword);
 
 	/* silly hack: convert arcinst->end->portarcinst pointers */
@@ -1745,7 +1739,7 @@ void io_nodtyp(void)
 		{
 			*pt = 0;
 			tech = io_gettechnology(line);
-			if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)"Unknown technology");
+			if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)_("Unknown technology"));
 			*pt++ = ':';
 			line = pt;
 		} else tech = io_txtindata.curtech;
@@ -1772,7 +1766,7 @@ void io_nodtyp(void)
 		}
 		if (io_txtindata.curnodeinst->proto != NONODEPROTO) return;
 
-		longjmp(io_filerror, (INTBIG)"Unknown node prototype");
+		longjmp(io_filerror, (INTBIG)_("Unknown node prototype"));
 	}
 }
 
@@ -1911,7 +1905,7 @@ void io_porarc(void)
 	REGISTER PORTARCINST *pi;
 
 	pi = allocportarcinst(io_txtindata.curlib->cluster);
-	if (pi == NOPORTARCINST) longjmp(io_filerror, (INTBIG)"No memory");
+	if (pi == NOPORTARCINST) longjmp(io_filerror, (INTBIG)_("No memory"));
 	pi->proto = io_txtindata.curportproto;
 	db_addportarcinst(io_txtindata.curnodeinst, pi);
 	pi->conarcinst = io_txtindata.arclist[atoi(io_keyword)];
@@ -1927,7 +1921,7 @@ void io_porexp(void)
 	REGISTER PORTEXPINST *pe;
 
 	pe = allocportexpinst(io_txtindata.curlib->cluster);
-	if (pe == NOPORTEXPINST) longjmp(io_filerror, (INTBIG)"No memory");
+	if (pe == NOPORTEXPINST) longjmp(io_filerror, (INTBIG)_("No memory"));
 	pe->proto = io_txtindata.curportproto;
 	db_addportexpinst(io_txtindata.curnodeinst, pe);
 	pe->exportproto = io_txtindata.portprotolist[atoi(io_keyword)];
@@ -1962,7 +1956,7 @@ void io_arctyp(void)
 	{
 		*pt = 0;
 		tech = io_gettechnology(line);
-		if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)"Unknown technology");
+		if (tech == NOTECHNOLOGY) longjmp(io_filerror, (INTBIG)_("Unknown technology"));
 		*pt++ = ':';
 		line = pt;
 	} else tech = io_txtindata.curtech;
@@ -1982,7 +1976,7 @@ void io_arctyp(void)
 		return;
 	}
 
-	longjmp(io_filerror, (INTBIG)"Invalid arc prototype");
+	longjmp(io_filerror, (INTBIG)_("Invalid arc prototype"));
 }
 
 /*
@@ -2041,7 +2035,7 @@ void io_endpt(void)
 	REGISTER PORTPROTO *pp;
 
 	pp = io_getport(io_keyword,io_txtindata.curarcinst->end[io_txtindata.curarcend].nodeinst->proto);
-	if (pp == NOPORTPROTO) longjmp(io_filerror, (INTBIG)"Unknown port prototype name");
+	if (pp == NOPORTPROTO) longjmp(io_filerror, (INTBIG)_("Unknown port prototype name"));
 	io_txtindata.curarcinst->end[io_txtindata.curarcend].portarcinst = (PORTARCINST *)pp;
 }
 
@@ -2106,7 +2100,7 @@ void io_newpt(void)
 void io_ptnam(void)
 {
 	if (allocstring(&io_txtindata.curportproto->protoname, io_keyword, io_txtindata.curlib->cluster) != 0)
-		longjmp(io_filerror, (INTBIG)"No memory for portproto name");
+		longjmp(io_filerror, (INTBIG)_("No memory for portproto name"));
 }
 
 /*
@@ -2133,7 +2127,7 @@ void io_ptspt(void)
 	REGISTER PORTPROTO *pp;
 
 	pp = io_getport(io_keyword, io_txtindata.curportproto->subnodeinst->proto);
-	if (pp == NOPORTPROTO) longjmp(io_filerror, (INTBIG)"Unknown port prototype name");
+	if (pp == NOPORTPROTO) longjmp(io_filerror, (INTBIG)_("Unknown port prototype name"));
 	io_txtindata.curportproto->subportproto = pp;
 }
 
