@@ -64,10 +64,10 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 	if (strcmp(name, ".elib") == 0) *name = 0;
 	(void)strcat(file, ".txt");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPETLIB, "Readable Dump File", &truename);
+	io_fileout = xcreate(name, io_filetypetlib, _("Readable Dump File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
@@ -250,7 +250,7 @@ INTSML io_writetextlibrary(LIBRARY *lib)
 
 	/* clean up and return */
 	xclose(io_fileout);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	lib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
 	return(0);
 }
