@@ -104,11 +104,12 @@ TECH_ARRAY *com_conv_layer;
 /* Compaction Options */
 DIALOGITEM com_optionsdialogitems[] =
 {
- /*  1 */ {0, {36,92,60,156}, BUTTON, "OK"},
- /*  2 */ {0, {36,8,60,72}, BUTTON, "Cancel"},
- /*  3 */ {0, {8,8,24,154}, CHECK, "Allow spreading"}
+ /*  1 */ {0, {64,92,88,156}, BUTTON, N_("OK")},
+ /*  2 */ {0, {64,8,88,72}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,24,154}, CHECK, N_("Allow spreading")},
+ /*  4 */ {0, {32,8,48,154}, CHECK, N_("Verbose")}
 };
-DIALOG com_optionsdialog = {{50,75,119,243}, "Compaction Options", 3, com_optionsdialogitems};
+DIALOG com_optionsdialog = {{50,75,147,243}, N_("Compaction Options"), 0, 4, com_optionsdialogitems};
 
 /* prototypes for local routines */
 void com_buildtechnologies(void);
@@ -118,9 +119,9 @@ LINE *com_sort(LINE*, INTSML);
 void com_computeline_hi_and_low(LINE*, INTSML);
 INTSML com_lineup_firstrow(LINE*, LINE*, INTSML, INTBIG);
 INTSML com_findleastlow(LINE*, INTSML);
-INTSML com_compact(LINE*, LINE*, INTSML, INTSML);
-INTBIG com_checkinst(OBJECT*, LINE*, INTSML, OBJECT**);
-INTBIG com_minseparate(OBJECT*, INTSML, POLYGON*, TECHNOLOGY*, INTSML, LINE*, INTSML, OBJECT**);
+INTSML com_compact(LINE*, LINE*, INTSML, INTSML, NODEPROTO*);
+INTBIG com_checkinst(OBJECT*, LINE*, INTSML, OBJECT**, POLYLIST **, POLYLIST **, NODEPROTO*);
+INTBIG com_minseparate(OBJECT*, INTSML, POLYLIST*, LINE*, INTSML, OBJECT**, POLYLIST **, NODEPROTO*);
 INTBIG com_check(INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTSML, INTSML, OBJECT*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTSML);
 INTSML com_cropnodeinst(POLYLIST*, INTBIG*, INTBIG*, INTBIG*, INTBIG*, INTSML, INTSML);
 INTSML com_in_bound(INTBIG, INTBIG, INTBIG, INTBIG);
@@ -147,14 +148,14 @@ void comp_optionsdlog(void);
 
 /* the COMPACTOR aid table */
 static COMCOMP comcp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	NOBACKUP, 0, " \t", "facet to be rechecked", "default is current facet"};
+	NOBACKUP, 0, " \t", M_("facet to be rechecked"), M_("default is current facet")};
 static KEYWORD comnotopt[] =
 {
 	{"spread",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP comnotp = {comnotopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, 0, " \t", "Compactor negative action", 0};
+	NOBACKUP, 0, " \t", M_("Compactor negative action"), 0};
 static KEYWORD comhvopt[] =
 {
 	{"horizontal",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -162,7 +163,7 @@ static KEYWORD comhvopt[] =
 	TERMKEY
 };
 static COMCOMP comhvp = {comhvopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, 0, " \t", "Compactor direction", 0};
+	NOBACKUP, 0, " \t", M_("Compactor direction"), 0};
 static KEYWORD comopt[] =
 {
 	{"check",          2,{&comhvp,&comcp,NOKEY,NOKEY,NOKEY}},
@@ -172,10 +173,8 @@ static KEYWORD comopt[] =
 	TERMKEY
 };
 COMCOMP com_compactp = {comopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Compactor action", "show defaults"};
+	0, " \t", M_("Compactor action"), M_("show defaults")};
 
-
-extern AIDENTRY *net_aid, *us_aid;
 AIDENTRY *com_aid;
 INTBIG    com_spread;				/* cached key for "COM_spread" */
 INTSML    com_debug;
@@ -220,7 +219,8 @@ void com_buildtechnologies(void)
 	REGISTER INTBIG layer;
 
 	/* first free the former list of layer conversions */
-	for(cur_tech_array = com_conv_layer; cur_tech_array != NOTECHARRAY; cur_tech_array = next_techarray)
+	for(cur_tech_array = com_conv_layer; cur_tech_array != NOTECHARRAY;
+		cur_tech_array = next_techarray)
 	{
 		next_techarray = cur_tech_array->nexttecharray;
 		efree((char *)cur_tech_array->layer);
@@ -265,7 +265,8 @@ void com_done(void)
 	REGISTER TECH_ARRAY *cur_tech_array, *next_techarray;
 
 	/* first free the former list of layer conversions */
-	for(cur_tech_array = com_conv_layer; cur_tech_array != NOTECHARRAY; cur_tech_array = next_techarray)
+	for(cur_tech_array = com_conv_layer; cur_tech_array != NOTECHARRAY;
+		cur_tech_array = next_techarray)
 	{
 		next_techarray = cur_tech_array->nexttecharray;
 		efree((char *)cur_tech_array->layer);
@@ -285,7 +286,7 @@ void com_slice(void)
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
 		return;
 	}
@@ -298,9 +299,9 @@ void com_slice(void)
 
 	if (!change)
 	{
-		 ttyputmsg("No further change.  Compactor turned off");
+		 ttyputmsg(_("No further change.  Compactor turned off"));
 		 aidturnoff(com_aid, 0);
-	} else setactivity("Compaction");
+	} else setactivity(_("Compaction"));
 }
 
 INTSML com_set(INTSML count, char *par[])
@@ -315,8 +316,8 @@ INTSML com_set(INTSML count, char *par[])
 		var = getvalkey((INTBIG)com_aid, VAID, VINTEGER, com_spread);
 		if (var != NOVARIABLE)
 		{
-			if (var->addr != 0) ttyputmsg("Compactor will spread if necessary"); else
-				ttyputmsg("Compactor will not spread designs");
+			if (var->addr != 0) ttyputmsg(_("Compactor will spread if necessary")); else
+				ttyputmsg(_("Compactor will not spread designs"));
 		}
 		return(0);
 	}
@@ -326,10 +327,11 @@ INTSML com_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			count = ttygetparam("COMPACTOR negate option:", &comnotp, MAXPARS-1, &par[1]) + 1;
+			count = ttygetparam(_("COMPACTOR negate option:"), &comnotp, MAXPARS-1,
+				&par[1]) + 1;
 			if (count <= 1)
 			{
-				ttyputerr("Aborted");
+				ttyputerr(_("Aborted"));
 				return(1);
 			}
 		}
@@ -337,17 +339,17 @@ INTSML com_set(INTSML count, char *par[])
 		if (namesamen(pp, "spread", l) == 0)
 		{
 			(void)setvalkey((INTBIG)com_aid, VAID, com_spread, 0, VINTEGER|VDONTSAVE);
-			ttyputverbose("Compactor will not spread designs");
+			ttyputverbose(_("Compactor will not spread designs"));
 			return(0);
 		}
-		ttyputerr("Bad TELLAID COMPACTION NOT option: %s", pp);
+		ttyputbadusage("tellaid compaction not");
 		return(1);
 	}
 
 	if (namesamen(pp, "spread", l) == 0)
 	{
 		(void)setvalkey((INTBIG)com_aid, VAID, com_spread, 1, VINTEGER|VDONTSAVE);
-		ttyputverbose("Compactor will spread if necessary");
+		ttyputverbose(_("Compactor will spread if necessary"));
 		return(0);
 	}
 
@@ -356,20 +358,20 @@ INTSML com_set(INTSML count, char *par[])
 		/* make sure network tool is on */
 		if ((net_aid->aidstate&AIDON) == 0)
 		{
-			ttyputerr("Network tool must be running...turning it on");
+			ttyputerr(_("Network tool must be running...turning it on"));
 			aidturnon(net_aid, 0);
-			ttyputerr("...now reissue the compaction command");
+			ttyputerr(_("...now reissue the compaction command"));
 			return(1);
 		}
 
 		if (count <= 1)
 		{
-			ttyputmsg("Do you want horizontal or vertical compaction? ");
+			ttyputmsg(_("Do you want horizontal or vertical compaction? "));
 			i = (INTSML)ttygetchar();
 			if (i == (INTSML)'v' || i == (INTSML)'V') com_do_axis = VERTICAL; else
 				if (i == (INTSML)'h' || i == (INTSML)'H') com_do_axis = HORIZONTAL; else
 			{
-				ttyputerr("Unknown compaction axis: '%c', expected 'v' or 'h'", i);
+				ttyputerr(_("Unknown compaction axis: '%c', expected 'v' or 'h'"), i);
 				return(1);
 			}
 		} else
@@ -378,7 +380,7 @@ INTSML com_set(INTSML count, char *par[])
 			if (namesamen(pp, "horizontal", l) == 0) com_do_axis = HORIZONTAL; else
 			if (namesamen(pp, "vertical", l) == 0) com_do_axis = VERTICAL; else
 			{
-				ttyputerr("Unknown compaction direction: %s", pp);
+				ttyputbadusage("tellaid compaction check");
 				return(1);
 			}
 		}
@@ -388,12 +390,12 @@ INTSML com_set(INTSML count, char *par[])
 			np = getnodeproto(par[2]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No facet named %s", par[2]);
+				ttyputerr(_("No facet named %s"), par[2]);
 				return(1);
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr("Can only compact facets, not primitives");
+				ttyputerr(_("Can only compact facets, not primitives"));
 				return(1);
 			}
 		} else
@@ -401,13 +403,13 @@ INTSML com_set(INTSML count, char *par[])
 			np = getcurfacet();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No current facet");
+				ttyputerr(_("No current facet"));
 				return(1);
 			}
 		}
 
 		(void)com_examineonefacet(np, com_do_axis, 0);
-		ttyputmsg("Facet %s compacted", describenodeproto(np));
+		ttyputmsg(_("Facet %s compacted"), describenodeproto(np));
 		return(0);
 	}
 
@@ -416,15 +418,15 @@ INTSML com_set(INTSML count, char *par[])
 		if (com_debug == 0)
 		{
 			com_debug = 1;
-			ttyputmsg("Compactor will print debugging information");
+			ttyputmsg(_("Compactor will print debugging information"));
 		} else
 		{
 			com_debug = 0;
-			ttyputmsg("Compactor will not print debugging information");
+			ttyputmsg(_("Compactor will not print debugging information"));
 		}
 		return(0);
 	}
-	ttyputerr("Bad TELLAID COMPACTION option: %s", pp);
+	ttyputbadusage("tellaid compaction");
 	return(1);
 }
 
@@ -445,11 +447,11 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	REGISTER INTSML i, change;
 	REGISTER INTBIG max;
 
-	if (stopping("COMPACTOR") != 0) return(0);
+	if (stopping(STOPREASONCOMPACT)) return(0);
 
 	if (np == NONODEPROTO)
 	{
-		ttyputmsg("No current facet to compact");
+		ttyputmsg(_("No current facet to compact"));
 		return(0);
 	}
 
@@ -457,15 +459,15 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	com_maxboundary = 0;
 	for(i=0; i<el_curtech->layercount; i++)
 	{
-		max = maxdrcsurround(el_curtech, i);
+		max = maxdrcsurround(el_curtech, np->cell->lib, i);
 		if (max > com_maxboundary) com_maxboundary = max;
 	}
 	if (com_maxboundary < 0) com_maxboundary = 0;
 
 	if (verbose != 0)
 	{
-		if (axis == HORIZONTAL) ttyputmsg("Doing a horizontal compaction"); else
-			ttyputmsg("Doing a vertical compaction");
+		if (axis == HORIZONTAL) ttyputmsg(_("Doing a horizontal compaction")); else
+			ttyputmsg(_("Doing a vertical compaction"));
 	}
 
 	/* number ports of cell "np" in the "temp1" field */
@@ -521,7 +523,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 				(void)addstringtoinfstr(describearcinst(cur_object->inst.ai)); else
 					(void)addstringtoinfstr(describenodeinst(cur_object->inst.ni));
 		}
-		ttyputmsg("Arcs that stretch:%s", returninfstr());
+		ttyputmsg(_("Arcs that stretch:%s"), returninfstr());
 	}
 
 	/* sort the compacting line of objects */
@@ -530,10 +532,10 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	/* print the merged structure */
 	if (com_debug != 0)
 	{
-		if (axis == VERTICAL) ttyputmsg("Bottom-to-top:"); else
-			ttyputmsg("Left-to-right:");
+		if (axis == VERTICAL) ttyputmsg(_("Bottom-to-top:")); else
+			ttyputmsg(_("Left-to-right:"));
 		for(cur_line = linecomp; cur_line != NOLINE; cur_line = cur_line->nextline)
-			ttyputmsg("  Line: %s", com_describeline(cur_line));
+			ttyputmsg(_("  Line: %s"), com_describeline(cur_line));
 	}
 
 	/* compute bounds for each line */
@@ -549,7 +551,7 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 	/* do the compaction */
 	com_lowbound = com_findleastlow(linecomp, axis);
 	change = com_lineup_firstrow(linecomp, linestretch, axis, com_lowbound);
-	change = com_compact(linecomp, linestretch, axis, change);
+	change = com_compact(linecomp, linestretch, axis, change, np);
 
 	/* restore rigidity if no changes were made */
 	if (change == 0) com_undo_fixed_nonfixed(linecomp, linestretch);
@@ -565,7 +567,8 @@ INTSML com_examineonefacet(NODEPROTO *np, INTSML axis, INTSML verbose)
 
 /******************** SUPPORT ROUTINES ********************/
 
-void com_createobjects(NODEINST *ni, INTSML axis, OBJECT **thisobject, OBJECT **otherobject)
+void com_createobjects(NODEINST *ni, INTSML axis, OBJECT **thisobject,
+	OBJECT **otherobject)
 {
 	REGISTER OBJECT *new_object, *second_object;
 	REGISTER PORTARCINST *pi;
@@ -602,7 +605,8 @@ void com_createobjects(NODEINST *ni, INTSML axis, OBJECT **thisobject, OBJECT **
 
 		new_object = com_make_ai_object(ai, NOOBJECT, el_matid, axis, 0,0,0,0);
 
-		second_object = com_make_ni_object(other_end, NOOBJECT, el_matid, axis, 0,0,0,0);
+		second_object = com_make_ni_object(other_end, NOOBJECT, el_matid,
+			axis, 0,0,0,0);
 
 		if (axis == HORIZONTAL)
 		{
@@ -638,7 +642,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 	INTSML axis, INTBIG low1, INTBIG high1, INTBIG low2, INTBIG high2)
 {
 	REGISTER OBJECT *new_object;
-	REGISTER INTSML j, tot;
+	REGISTER INTBIG j, tot;
 	INTBIG lx, hx, ly, hy;
 	REGISTER POLYGON *poly;
 
@@ -691,7 +695,8 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 		}
 
 		/* add the polygon */
-		com_add_poly_polylist(poly, new_object, (INTSML)ai->temp1, ai->proto->tech);
+		com_add_poly_polylist(poly, new_object, (INTSML)ai->temp1,
+			ai->proto->tech);
 	}
 	return(new_object);
 }
@@ -711,7 +716,7 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 	XARRAY trans, t1, temp;
 	INTBIG lx, hx, ly, hy;
 	REGISTER INTBIG pindex;
-	REGISTER INTSML j, tot;
+	REGISTER INTBIG j, tot;
 	REGISTER NODEINST *subni;
 	REGISTER ARCINST *subai;
 	REGISTER POLYGON *poly;
@@ -768,15 +773,19 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 		}
 
 		/* include polygons from those nodes and arcs in the protection frame */
-		for(subni = ni->proto->firstnodeinst; subni != NONODEINST; subni = subni->nextnodeinst)
-			(void)com_make_ni_object(subni, new_object, trans, axis, low1, high1, low2, high2);
-		for(subai = ni->proto->firstarcinst; subai != NOARCINST; subai = subai->nextarcinst)
-			(void)com_make_ai_object(subai, new_object, trans, axis, low1, high1, low2, high2);
+		for(subni = ni->proto->firstnodeinst; subni != NONODEINST;
+			subni = subni->nextnodeinst)
+				(void)com_make_ni_object(subni, new_object, trans, axis,
+					low1, high1, low2, high2);
+		for(subai = ni->proto->firstarcinst; subai != NOARCINST;
+			subai = subai->nextarcinst)
+				(void)com_make_ai_object(subai, new_object, trans, axis,
+					low1, high1, low2, high2);
 	} else
 	{
 		makerot(ni, temp);
 		transmult(temp, newtrans, trans);
-		tot = nodeEpolys(ni);
+		tot = nodeEpolys(ni, 0);
 		for(j=0; j<tot; j++)
 		{
 			poly = allocpolygon(4, com_aid->cluster);
@@ -830,7 +839,7 @@ void com_fillnode(NODEINST *ni)
 		pp->temp1 = pi->conarcinst->temp1;
 	}
 
-	/* set network numbers from exported ports */
+	/* set network numbers from exports */
 	for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 	{
 		pp = pe->proto;
@@ -867,7 +876,7 @@ LINE *com_sort(LINE *line, INTSML axis)
 
 	if (line == NOLINE)
 	{
-		ttyputerr("Error: com_sort called with null argument");
+		ttyputerr(_("Error: com_sort called with null argument"));
 		return(NOLINE);
 	}
 
@@ -939,7 +948,8 @@ void com_computeline_hi_and_low(LINE *line, INTSML axis)
 
 	/* find smallest and highest vals for the each object */
 	first_time = 1;
-	for(cur_object = line->firstobject; cur_object != NOOBJECT; cur_object = cur_object->nextobject)
+	for(cur_object = line->firstobject; cur_object != NOOBJECT;
+		cur_object = cur_object->nextobject)
 	{
 		if (cur_object->insttype == OBJARCINST) continue;
 		if (first_time)
@@ -982,7 +992,7 @@ INTSML com_lineup_firstrow(LINE *line, LINE *other_line, INTSML axis, INTBIG low
 	if (i > 0)
 	{
 		if (com_debug != 0)
-			ttyputmsg("Lining up the first row to low edge %s", latoa(lowbound));
+			ttyputmsg(_("Lining up the first row to low edge %s"), latoa(lowbound));
 		if (axis == HORIZONTAL) change = com_move(line, i, 0, change); else
 			change = com_move(line, 0, i, change);
 		com_fixed_nonfixed(line, other_line);
@@ -1022,11 +1032,14 @@ INTSML com_findleastlow(LINE *line, INTSML axis)
 	return((INTSML)low);
 }
 
-INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change)
+INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change,
+	NODEPROTO *facet)
 {
 	REGISTER LINE *cur_line, *prev_line;
-	REGISTER OBJECT *cur_object, *thisreason, *otherreason;
-	OBJECT *reason;
+	REGISTER OBJECT *cur_object, *thisoreason, *otheroreason;
+	REGISTER POLYLIST *thispreason, *otherpreason;
+	OBJECT *oreason;
+	POLYLIST *preason, *opreason;
 	REGISTER INTBIG this_motion, best_motion, spread;
 	REGISTER VARIABLE *var;
 
@@ -1039,27 +1052,31 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change)
 	{
 		/* look at every object in the line that may compact */
 		best_motion = DEFAULT_VAL;
-		thisreason = otherreason = NOOBJECT;
+		thisoreason = otheroreason = NOOBJECT;
 		for(cur_object = cur_line->firstobject; cur_object != NOOBJECT;
 			cur_object = cur_object->nextobject)
 		{
 			/* look at all previous lines */
-			for(prev_line = cur_line->prevline; prev_line != NOLINE; prev_line = prev_line->prevline)
+			for(prev_line = cur_line->prevline; prev_line != NOLINE;
+				prev_line = prev_line->prevline)
 			{
 				/* no need to test this line if it is farther than best motion */
-				if (best_motion != DEFAULT_VAL && cur_line->low - prev_line->high > best_motion)
-					continue;
+				if (best_motion != DEFAULT_VAL &&
+					cur_line->low - prev_line->high > best_motion) continue;
 
 				/* simple object compaction */
-				this_motion = com_checkinst(cur_object, prev_line, axis, &reason);
+				this_motion = com_checkinst(cur_object, prev_line, axis,
+					&oreason, &opreason, &preason, facet);
 				if (this_motion == DEFAULT_VAL) continue;
 				if (best_motion == DEFAULT_VAL || this_motion < best_motion)
 				{
 					best_motion = this_motion;
-					if (reason != NOOBJECT)
+					if (oreason != NOOBJECT)
 					{
-						thisreason = reason;
-						otherreason = cur_object;
+						thisoreason = oreason;
+						otheroreason = cur_object;
+						thispreason = opreason;
+						otherpreason = preason;
 					}
 				}
 			}
@@ -1069,18 +1086,32 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change)
 		{
 			/* no constraints: allow overlap */
 			best_motion = cur_line->low - com_lowbound;
-			if (com_debug != 0) ttyputmsg("Default motion %s", latoa(best_motion));
+#if 0
+			if (com_debug != 0) ttyputmsg(_("Default motion %s"), latoa(best_motion));
+#endif
 		}
 		if (com_debug != 0)
 		{
-			ttyputmsg("Moving object '%s' by %s", com_describeline(cur_line), latoa(best_motion));
-			if (thisreason != NOOBJECT && otherreason != NOOBJECT)
+			ttyputmsg(_("Moving object '%s' by %s"), com_describeline(cur_line),
+				latoa(best_motion));
+			if (thisoreason != NOOBJECT && otheroreason != NOOBJECT)
 			{
 				(void)initinfstr();
-				(void)addstringtoinfstr("  Limit is ");
-				(void)addstringtoinfstr(com_describeobject(thisreason));
-				(void)addstringtoinfstr(" to ");
-				(void)addstringtoinfstr(com_describeobject(otherreason));
+				if (thispreason->poly->tech != otherpreason->poly->tech ||
+					thispreason->poly->layer != otherpreason->poly->layer)
+				{
+					(void)formatinfstr(_("  Limit is %s, layer %s to %s, layer %s"),
+						com_describeobject(thisoreason),
+							layername(thispreason->poly->tech, thispreason->poly->layer),
+								com_describeobject(otheroreason),
+									layername(otherpreason->poly->tech,
+										otherpreason->poly->layer));
+				} else
+				{
+					(void)formatinfstr(_("  Limit is %s to %s, layer %s"),
+						com_describeobject(thisoreason), com_describeobject(otheroreason),
+							layername(thispreason->poly->tech, thispreason->poly->layer));
+				}
 				ttyputmsg("%s", returninfstr());
 			}
 		}
@@ -1095,17 +1126,20 @@ INTSML com_compact(LINE *line, LINE *other_line, INTSML axis, INTSML change)
 	return(change);
 }
 
-INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **reason)
+INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **oreason,
+	POLYLIST **opreason, POLYLIST **preason, NODEPROTO *facet)
 {
 	REGISTER INTSML pindex, layer;
 	REGISTER INTBIG this_motion, best_motion;
 	REGISTER POLYGON *poly;
 	REGISTER POLYLIST *polys;
-	OBJECT *subreason;
+	POLYLIST *subpreason;
+	OBJECT *suboreason;
 
 	best_motion = DEFAULT_VAL;
-	*reason = NOOBJECT;
-	for(polys = object->firstpolylist; polys != NOPOLYLIST; polys = polys->nextpolylist)
+	*oreason = NOOBJECT;
+	for(polys = object->firstpolylist; polys != NOPOLYLIST;
+		polys = polys->nextpolylist)
 	{
 		poly = polys->poly;
 		pindex = polys->networknum;
@@ -1114,13 +1148,15 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **reason)
 		layer = com_convertpintonode_layer(poly->layer, polys->tech);
 
 		/* find distance line can move toward this poly */
-		this_motion = com_minseparate(object, layer, poly, polys->tech, pindex, line, axis,
-			&subreason);
+		this_motion = com_minseparate(object, layer, polys, line, axis,
+			&suboreason, &subpreason, facet);
 		if (this_motion == DEFAULT_VAL) continue;
 		if (best_motion == DEFAULT_VAL || this_motion < best_motion)
 		{
 			best_motion = this_motion;
-			*reason = subreason;
+			*oreason = suboreason;
+			*opreason = subpreason;
+			*preason = polys;
 		}
 	}
 	return(best_motion);
@@ -1134,29 +1170,36 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTSML axis, OBJECT **reason)
  * overlap).  The object "reason" is set to the object that is causing the
  * constraint.
  */
-INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *tech,
-	INTSML nindex, LINE *line, INTSML axis, OBJECT **reason)
+INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYLIST *npolys,
+	LINE *line, INTSML axis, OBJECT **oreason, POLYLIST **preason,
+	NODEPROTO *facet)
 {
-	REGISTER INTBIG bound, dist, con, geom_lo, ai_hi, ni_hi, best_motion, this_motion;
-	REGISTER INTSML pindex, layer;
-	REGISTER POLYGON *poly;
+	REGISTER INTBIG bound, dist, con, geom_lo, ai_hi, ni_hi,
+		best_motion, this_motion, fun;
+	REGISTER INTSML pindex, nindex, layer;
+	REGISTER POLYGON *poly, *npoly;
 	INTBIG lx, hx, ly, hy, xl, xh, yl, yh;
 	REGISTER OBJECT *cur_object;
 	REGISTER POLYLIST *polys;
+	REGISTER TECHNOLOGY *tech;
 
-	*reason = NOOBJECT;
+	*oreason = NOOBJECT;
+	npoly = npolys->poly;
+	tech = npolys->tech;
+	nindex = npolys->networknum;
 
 	/* see how far around the box it is necessary to search */
-	bound = maxdrcsurround(tech, nlayer);
+	bound = maxdrcsurround(tech, facet->cell->lib, nlayer);
 
 	/* if there is no separation, allow them to sit on top of each other */
 	if (bound < 0) return(DEFAULT_VAL);
 
 	/* can only handle orthogonal rectangles for now */
-	if (isbox(obj, &lx, &hx, &ly, &hy) == 0) return(bound);
+	if (isbox(npoly, &lx, &hx, &ly, &hy) == 0) return(bound);
 
 	best_motion = DEFAULT_VAL;
-	if (axis == HORIZONTAL) geom_lo = object->lowx; else geom_lo = object->lowy;
+	if (axis == HORIZONTAL) geom_lo = object->lowx; else
+		geom_lo = object->lowy;
 
 	/* search the line */
 	for(cur_object = line->firstobject; cur_object != NOOBJECT;
@@ -1184,7 +1227,7 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 					pindex = polys->networknum;
 
 					/* see whether the two objects are electrically connected */
-					if (pindex == -1 || nindex == -1 || pindex == nindex) con = 1;
+					if (pindex == nindex && pindex != -1) con = 1;
 						else con = 0;
 					if (isbox(poly, &xl, &xh, &yl, &yh) == 0)
 					{
@@ -1193,21 +1236,44 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 						if (this_motion < best_motion || best_motion == DEFAULT_VAL)
 						{
 							best_motion = this_motion;
-							*reason = cur_object;
+							*oreason = cur_object;
+							*preason = polys;
 						}
 						continue;
 					}
 
 					/* see how close they can get */
-					dist = drcmindistance(tech, nlayer, layer, (INTSML)con);
+					dist = drcmindistance(tech, facet->cell->lib, nlayer,
+						layer, (INTSML)con);
 					if (dist < 0) continue;
 
+					/*
+					 * special rule for ignoring distance:
+					 *   the layers are the same and either:
+					 *     they connect and are *NOT* contact layers
+					 *   or:
+					 *     they don't connect and are implant layers (substrate/well)
+					 */
+					if (nlayer == layer)
+					{
+						fun = layerfunction(tech, nlayer) & LFTYPE;
+						if (con != 0)
+						{
+							if (layeriscontact(fun) == 0) continue;
+						} else
+						{
+							if (fun == LFSUBSTRATE || fun == LFWELL ||
+								fun == LFIMPLANT) continue;
+						}
+					}
+
 					/*
 					 * if the two layers are located on the y-axis so
 					 * that there is no necessary contraint between them
 					 */
 					if ((axis == HORIZONTAL && !com_in_bound(ly-dist, hy+dist, yl, yh)) ||
-						(axis == VERTICAL && !com_in_bound(lx-dist, hx+dist, xl, xh))) continue;
+						(axis == VERTICAL && !com_in_bound(lx-dist, hx+dist, xl, xh)))
+							continue;
 
 					/* check the distance */
 					this_motion = com_check(nlayer, nindex, object, xl, xh, yl,
@@ -1216,7 +1282,8 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 					if (this_motion < best_motion || best_motion == DEFAULT_VAL)
 					{
 						best_motion = this_motion;
-						*reason = cur_object;
+						*oreason = cur_object;
+						*preason = polys;
 					}
 				}
 			}
@@ -1251,13 +1318,15 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 						if (this_motion < best_motion || best_motion == DEFAULT_VAL)
 						{
 							best_motion = this_motion;
-							*reason = cur_object;
+							*oreason = cur_object;
+							*preason = polys;
 						}
 						continue;
 					}
 
 					/* see how close they can get */
-					dist = drcmindistance(tech, nlayer, poly->layer, (INTSML)con);
+					dist = drcmindistance(tech, facet->cell->lib, nlayer,
+						poly->layer, (INTSML)con);
 					if (dist < 0) continue;
 
 					/*
@@ -1265,7 +1334,8 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 					 * that there is no necessary contraint between them
 					 */
 					if ((axis == HORIZONTAL && !com_in_bound(ly-dist, hy+dist, yl, yh)) ||
-						(axis == VERTICAL && !com_in_bound(lx-dist, hx+dist, xl, xh))) continue;
+						(axis == VERTICAL && !com_in_bound(lx-dist, hx+dist, xl, xh)))
+							continue;
 
 					/* check the distance */
 					this_motion = com_check(nlayer, nindex, object, xl, xh, yl,
@@ -1274,7 +1344,8 @@ INTBIG com_minseparate(OBJECT *object, INTSML nlayer, POLYGON *obj, TECHNOLOGY *
 					if (this_motion < best_motion || best_motion == DEFAULT_VAL)
 					{
 						best_motion = this_motion;
-						*reason = cur_object;
+						*oreason = cur_object;
+						*preason = polys;
 					}
 				}
 			}
@@ -1298,20 +1369,22 @@ INTBIG com_check(INTSML layer1, INTSML index1, OBJECT *object1, INTBIG lx1, INTB
 	/* crop out parts of a box covered by a similar layer on the other node */
 	if (object1->insttype == OBJNODEINST)
 	{
-		if (com_cropnodeinst(object1->firstpolylist, &lx2, &hx2, &ly2, &hy2, layer2, index2))
-			return(DEFAULT_VAL);
+		if (com_cropnodeinst(object1->firstpolylist, &lx2, &hx2, &ly2, &hy2,
+			layer2, index2))
+				return(DEFAULT_VAL);
 	}
 	if (object2->insttype == OBJNODEINST)
 	{
-		if (com_cropnodeinst(object2->firstpolylist, &lx1, &hx1, &ly1, &hy1, layer1, index1))
-			return(DEFAULT_VAL);
+		if (com_cropnodeinst(object2->firstpolylist, &lx1, &hx1, &ly1, &hy1,
+			layer1, index1))
+				return(DEFAULT_VAL);
 	}
 
 	/* now compare the box extents */
 	if (axis == HORIZONTAL)
 	{
-		if (hy1+dist>ly2 && ly1-dist<hy2) return(lx2 - hx1 - dist);
-	} else if (hx1+dist>lx2 && lx1-dist<hx2) return(ly2 - hy1 - dist);
+		if (hy1+dist > ly2 && ly1-dist < hy2) return(lx2 - hx1 - dist);
+	} else if (hx1+dist > lx2 && lx1-dist < hx2) return(ly2 - hy1 - dist);
 	return(DEFAULT_VAL);
 }
 
@@ -1322,14 +1395,15 @@ INTBIG com_check(INTSML layer1, INTSML index1, OBJECT *object1, INTBIG lx1, INTB
  * are checked.  The routine returns non-zero if the bounds are reduced
  * to nothing.
  */
-INTSML com_cropnodeinst(POLYLIST *polys, INTBIG *bx, INTBIG *by, INTBIG *ux, INTBIG *uy,
-	INTSML nlayer, INTSML nindex)
+INTSML com_cropnodeinst(POLYLIST *polys, INTBIG *bx, INTBIG *by,
+	INTBIG *ux, INTBIG *uy, INTSML nlayer, INTSML nindex)
 {
 	INTBIG xl, xh, yl, yh;
 	REGISTER INTBIG temp;
 	REGISTER POLYLIST *cur_polys;
 
-	for(cur_polys = polys; cur_polys != NOPOLYLIST; cur_polys = cur_polys->nextpolylist)
+	for(cur_polys = polys; cur_polys != NOPOLYLIST;
+		cur_polys = cur_polys->nextpolylist)
 	{
 		if (cur_polys->networknum != nindex) continue;
 		if (cur_polys->poly->layer != nlayer) continue;
@@ -1390,7 +1464,8 @@ void com_undo_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 			cur_object = cur_object->nextobject)
 				if (cur_object->insttype == OBJARCINST)
 					(void)(*el_curconstraint->setobject)
-						((INTBIG)cur_object->inst.ai, VARCINST, CHANGETYPEREMOVETEMP, 0);
+						((INTBIG)cur_object->inst.ai, VARCINST,
+							CHANGETYPEREMOVETEMP, 0);
 	}
 	for(cur_line = nfixline; cur_line != NOLINE; cur_line = cur_line->nextline)
 	{
@@ -1398,7 +1473,8 @@ void com_undo_fixed_nonfixed(LINE *fixline, LINE *nfixline)
 			cur_object = cur_object->nextobject)
 				if (cur_object->insttype == OBJARCINST)
 					(void)(*el_curconstraint->setobject)
-						((INTBIG)cur_object->inst.ai, VARCINST, CHANGETYPEREMOVETEMP, 0);
+						((INTBIG)cur_object->inst.ai, VARCINST,
+							CHANGETYPEREMOVETEMP, 0);
 	}
 }
 
@@ -1444,7 +1520,8 @@ void com_slide(LINE *line)
 			if (cur_object->insttype == OBJARCINST)
 			{
 				ai = cur_object->inst.ai;
-				ai->userbits = (ai->userbits & ~CANTSLIDE) | (ai->temp2&CANTSLIDE);
+				ai->userbits = (ai->userbits & ~CANTSLIDE) |
+					(ai->temp2&CANTSLIDE);
 			}
 		}
 	}
@@ -1469,7 +1546,8 @@ INTSML com_move(LINE *line, INTBIG movex, INTBIG movey, INTSML change)
 		change = 1;
 	}
 
-	for(cur_object = line->firstobject; cur_object != NOOBJECT; cur_object = cur_object->nextobject)
+	for(cur_object = line->firstobject; cur_object != NOOBJECT;
+		cur_object = cur_object->nextobject)
 	{
 		if (cur_object->insttype == OBJNODEINST)
 		{
@@ -1480,13 +1558,15 @@ INTSML com_move(LINE *line, INTBIG movex, INTBIG movey, INTSML change)
 		}
 	}
 
-	for(cur_object = line->firstobject; cur_object != NOOBJECT; cur_object = cur_object->nextobject)
+	for(cur_object = line->firstobject; cur_object != NOOBJECT;
+		cur_object = cur_object->nextobject)
 	{
 		cur_object->lowx -= movex;
 		cur_object->highx -= movex;
 		cur_object->lowy -= movey;
 		cur_object->highy -= movey;
-		for(polys = cur_object->firstpolylist; polys != NOPOLYLIST; polys = polys->nextpolylist)
+		for(polys = cur_object->firstpolylist; polys != NOPOLYLIST;
+			polys = polys->nextpolylist)
 		{
 			for(i=0; i<polys->poly->count; i++)
 			{
@@ -1516,7 +1596,8 @@ INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
 	/* make sure range of layers is valid */
 	if (layer >= tech->layercount)
 	{
-		ttyputmsg("Compactor cannot find layer %d of technology %s", layer, tech->techname);
+		ttyputmsg(_("Compactor cannot find layer %d of technology %s"),
+			layer, tech->techname);
 		return(layer);
 	}
 
@@ -1528,7 +1609,7 @@ INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
 	/* no technology: warn and return */
 	if (cur_technology == NOTECHARRAY)
 	{
-		ttyputmsg("Compactor cannot find technology %s", tech->techname);
+		ttyputmsg(_("Compactor cannot find technology %s"), tech->techname);
 		return(layer);
 	}
 
@@ -1538,8 +1619,8 @@ INTSML com_convertpintonode_layer(INTSML layer, TECHNOLOGY *tech)
 	/* make sure conversion is valid */
 	if (newlay >= tech->layercount)
 	{
-		ttyputmsg("Converted layer %d to bogus layer %d in technology %s", layer, newlay,
-			tech->techname);
+		ttyputmsg(_("Converted layer %d to bogus layer %d in technology %s"),
+			layer, newlay, tech->techname);
 		return(layer);
 	}
 	return(newlay);
@@ -1564,11 +1645,11 @@ void com_subsmash(NODEPROTO *topfacet)
 		if (ai->temp1 != 0) continue;
 
 		/* see if this arc connects to a port */
-		for(pp = topfacet->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
+		for(pp = topfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			if (pp->network == ai->network)
 		{
 			/* propagate port numbers into all connecting arcs */
-			for(oai=topfacet->firstarcinst; oai!=NOARCINST; oai=oai->nextarcinst)
+			for(oai = topfacet->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 				if (oai->network == ai->network) oai->temp1 = pp->temp1;
 			break;
 		}
@@ -1577,7 +1658,7 @@ void com_subsmash(NODEPROTO *topfacet)
 		if (pp == NOPORTPROTO)
 		{
 			/* copy new net number to all of these connected arcs */
-			for(oai=topfacet->firstarcinst; oai!=NOARCINST; oai=oai->nextarcinst)
+			for(oai = topfacet->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 				if (oai->network == ai->network) oai->temp1 = com_flatindex;
 			com_flatindex++;
 		}
@@ -1717,25 +1798,25 @@ char *com_describeobject(OBJECT *cur_object)
 /*
  * special case for the "Compaction Options" dialog
  * Allow spreading = 3 (check)
+ * Verbose         = 4 (check)
  */
 void comp_optionsdlog(void)
 {
-	REGISTER INTBIG itemHit;
-	REGISTER INTBIG val;
+	REGISTER INTBIG itemHit, spread, origspread;
 	REGISTER VARIABLE *var;
-	extern AIDENTRY *com_aid;
 
 	if (DiaInitDialog(&com_optionsdialog) != 0) return;
 	var = getval((INTBIG)com_aid, VAID, VINTEGER, "COM_spread");
-	if (var == NOVARIABLE) val = 0; else val = var->addr;
-	if (val != 0) DiaSetControl(3, 1);
+	if (var == NOVARIABLE) origspread = 0; else origspread = var->addr;
+	if (origspread != 0) DiaSetControl(3, 1);
+	if (com_debug != 0) DiaSetControl(4, 1);
 
 	/* loop until done */
 	for(;;)
 	{
 		itemHit = DiaNextHit();
 		if (itemHit == OK || itemHit == CANCEL) break;
-		if (itemHit == 3)
+		if (itemHit == 3 || itemHit == 4)
 		{
 			DiaSetControl(itemHit, 1 - DiaGetControl(itemHit));
 			continue;
@@ -1744,9 +1825,12 @@ void comp_optionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(3) != 0) val = 1; else
-			val = 0;
-		(void)setval((INTBIG)com_aid, VAID, "COM_spread", val, VINTEGER);
+		if (DiaGetControl(3) != 0) spread = 1; else
+			spread = 0;
+		if (spread != origspread)
+			(void)setval((INTBIG)com_aid, VAID, "COM_spread", spread, VINTEGER);
+		if (DiaGetControl(4) != 0) com_debug = 1; else
+			com_debug = 0;
 	}
 	DiaDoneDialog();
 }
