@@ -53,7 +53,7 @@ static KEYWORD leopt[] =
 	TERMKEY
 };
 COMCOMP le_tablep = {leopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Logical effort action", "show defaults"};
+	0, " \t", M_("Logical effort action"), M_("show defaults")};
 
 #define MAXITERATIONS  10
 #define MAXSTAGEEFFORT  3.0
@@ -97,34 +97,34 @@ typedef struct Ilenode
 /* Logical Effort Options dialog */
 DIALOGITEM le_leoptionsdialogitems[] =
 {
- /*  1 */ {0, {96,180,120,244}, BUTTON, "OK"},
- /*  2 */ {0, {96,12,120,76}, BUTTON, "Cancel"},
- /*  3 */ {0, {8,8,24,160}, MESSAGE, "Maximum Stage Gain"},
+ /*  1 */ {0, {96,180,120,244}, BUTTON, N_("OK")},
+ /*  2 */ {0, {96,12,120,76}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,24,160}, MESSAGE, N_("Maximum Stage Gain")},
  /*  4 */ {0, {8,168,24,220}, EDITTEXT, ""},
- /*  5 */ {0, {36,8,52,244}, CHECK, "Display intermediate capacitances"},
- /*  6 */ {0, {64,8,80,192}, CHECK, "Highlight components"}
+ /*  5 */ {0, {36,8,52,244}, CHECK, N_("Display intermediate capacitances")},
+ /*  6 */ {0, {64,8,80,192}, CHECK, N_("Highlight components")}
 };
-DIALOG le_leoptionsdialog = {{75,75,206,329}, "Logical Effort Options", 6, le_leoptionsdialogitems};
+DIALOG le_leoptionsdialog = {{75,75,206,329}, N_("Logical Effort Options"), 0, 6, le_leoptionsdialogitems};
 
 /* Logical Effort Capacitance dialog */
 DIALOGITEM le_capacitancedialogitems[] =
 {
- /*  1 */ {0, {36,132,60,200}, BUTTON, "OK"},
- /*  2 */ {0, {36,8,60,76}, BUTTON, "Cancel"},
- /*  3 */ {0, {8,8,24,100}, MESSAGE, "Capacitance:"},
+ /*  1 */ {0, {36,132,60,200}, BUTTON, N_("OK")},
+ /*  2 */ {0, {36,8,60,76}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,24,100}, MESSAGE, N_("Capacitance:")},
  /*  4 */ {0, {8,108,24,200}, EDITTEXT, ""}
 };
-DIALOG le_capacitancedialog = {{75,75,146,286}, "Logical Effort Capacitance", 4, le_capacitancedialogitems};
+DIALOG le_capacitancedialog = {{75,75,146,286}, N_("Logical Effort Capacitance"), 0, 4, le_capacitancedialogitems};
 
 /* Logical Effort effort dialog */
-DIALOGITEM us_logeffortdialogitems[] =
+DIALOGITEM le_logeffortdialogitems[] =
 {
- /*  1 */ {0, {40,128,64,192}, BUTTON, "OK"},
- /*  2 */ {0, {40,12,64,76}, BUTTON, "Cancel"},
- /*  3 */ {0, {8,8,24,116}, MESSAGE, "Logical Effort:"},
+ /*  1 */ {0, {40,128,64,192}, BUTTON, N_("OK")},
+ /*  2 */ {0, {40,12,64,76}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {8,8,24,116}, MESSAGE, N_("Logical Effort:")},
  /*  4 */ {0, {8,128,24,192}, EDITTEXT, ""}
 };
-DIALOG us_logeffortdialog = {{75,75,149,281}, "Logical Effort", 4, us_logeffortdialogitems};
+DIALOG le_logeffortdialog = {{75,75,149,281}, N_("Logical Effort"), 0, 4, le_logeffortdialogitems};
 
 #define DISPLAYCAPACITANCE  01
 #define HIGHLIGHTCOMPONENTS 02
@@ -218,7 +218,7 @@ INTSML le_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputerr("Usage: tellaid logeffort (analyze-path | analyze-facet | set-options | set-capacitance | set-node-effort)");
+		ttyputusage("tellaid logeffort (analyze-path | analyze-facet | set-options | set-capacitance | set-node-effort)");
 		return(0);
 	}
 
@@ -262,7 +262,7 @@ INTSML le_set(INTSML count, char *par[])
 		return(0);
 	}
 
-	ttyputerr("Bad TELLAID LOGEFFORT option: %s", pp);
+	ttyputbadusage("tellaid logeffort");
 	return(1);
 }
 
@@ -272,8 +272,8 @@ INTSML le_set(INTSML count, char *par[])
 void le_setoptions(void)
 {
 	INTBIG itemHit;
-	INTBIG state;
-	float maxstageeffort;
+	INTBIG state, newstate;
+	float maxstageeffort, newmaxstageeffort;
 	REGISTER VARIABLE *var;
 	char line[50];
 
@@ -301,13 +301,15 @@ void le_setoptions(void)
 	}
 	if (itemHit == OK)
 	{
-		if (DiaGetControl(5) != 0) state |= DISPLAYCAPACITANCE; else
-			state &= ~DISPLAYCAPACITANCE;
-		if (DiaGetControl(6) != 0) state |= HIGHLIGHTCOMPONENTS; else
-			state &= ~HIGHLIGHTCOMPONENTS;
-		(void)setvalkey((INTBIG)le_aid, VAID, le_state, state, VINTEGER);
-		maxstageeffort = (float)atof(DiaGetText(4));
-		(void)setvalkey((INTBIG)le_aid, VAID, le_maximumstageeffort, castint(maxstageeffort), VFLOAT);
+		newstate = 0;
+		if (DiaGetControl(5) != 0) newstate |= DISPLAYCAPACITANCE;
+		if (DiaGetControl(6) != 0) newstate |= HIGHLIGHTCOMPONENTS;
+		if (newstate != state)
+			(void)setvalkey((INTBIG)le_aid, VAID, le_state, newstate, VINTEGER);
+		newmaxstageeffort = (float)atof(DiaGetText(4));
+		if (newmaxstageeffort != maxstageeffort)
+			(void)setvalkey((INTBIG)le_aid, VAID, le_maximumstageeffort,
+				castint(newmaxstageeffort), VFLOAT);
 	}
 	DiaDoneDialog();
 }
@@ -326,7 +328,7 @@ void le_setcapacitance(void)
 	ai = (ARCINST *)askaid(us_aid, "get-arc");
 	if (ai == NOARCINST)
 	{
-		ttyputerr("Select an arc first");
+		ttyputerr(_("Select an arc first"));
 		return;
 	}
 	if (DiaInitDialog(&le_capacitancedialog) != 0) return;
@@ -377,7 +379,7 @@ void le_setlogicaleffort(void)
 	ni = (NODEINST *)askaid(us_aid, "get-node");
 	if (ni == NONODEINST)
 	{
-		ttyputerr("Select a node first");
+		ttyputerr(_("Select a node first"));
 		return;
 	}
 	type = le_getgatetype(ni, &inputs);
@@ -386,7 +388,7 @@ void le_setlogicaleffort(void)
 	statle.ni = ni;
 	statle.inputs = inputs;
 	e = le_getlogeffort(&statle);
-	if (DiaInitDialog(&us_logeffortdialog) != 0) return;
+	if (DiaInitDialog(&le_logeffortdialog) != 0) return;
 
 	sprintf(line, "%g", e);
 	DiaSetText(-4, line);
@@ -472,7 +474,7 @@ void le_analyzepath(void)
 	/* compute the electrical effort along the path */
 	Cin = le_firstlenode->cin;
 	Cout = pathend->cout;
-	ttyputmsg("Capacitance starts at %g, ends at %g", Cin, Cout);
+	ttyputmsg(_("Capacitance starts at %g, ends at %g"), Cin, Cout);
 	if (Cin == 0.0) return;
 	H = Cout / Cin;
 
@@ -486,12 +488,12 @@ void le_analyzepath(void)
 
 	/* compute the stage effort */
 	fhat = pow(F, 1/N);
-	ttyputmsg("Optimum stage effort is %g", fhat);
+	ttyputmsg(_("Optimum stage effort is %g"), fhat);
 	if (fhat == 0.0) return;
 
 	/* compute the minimum path delay */
 	Dhat = N * fhat + P;
-	ttyputmsg("Minimum path delay is %g", Dhat);
+	ttyputmsg(_("Minimum path delay is %g"), Dhat);
 
 	/* determine whether or not to set capacitance values */
 	var = getvalkey((INTBIG)le_aid, VAID, VINTEGER, le_state);
@@ -537,7 +539,6 @@ void le_gatherfacet(INTBIG show)
 	REGISTER NODEPROTO *np;
 	REGISTER NETWORK *net;
 	REGISTER PORTARCINST *pi, *opi;
-	char line[50];
 	LENODE *le, *ole;
 	double cap;
 
@@ -689,7 +690,7 @@ void le_gatherfacet(INTBIG show)
 						/* configure output on node "le" */
 						if (oinport == 0)
 						{
-							ttyputerr("Node %s and %s drive the same network",
+							ttyputerr(_("Node %s and %s drive the same network"),
 								le_describenode(le), le_describenode(ole));
 							continue;
 						}
@@ -708,19 +709,15 @@ void le_gatherfacet(INTBIG show)
 	first = 0;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
-		if (first != 0) (void)addtoinfstr('/');
+		if (first != 0) (void)addtoinfstr('\n');
 		first++;
-		(void)addstringtoinfstr("FACET=");
-		(void)addstringtoinfstr(describenodeproto(np));
-		(void)addstringtoinfstr(" FROM=");
-		(void)sprintf(line, "0%o", (INTBIG)le->ni->geom);
-		(void)addstringtoinfstr(line);
-		(void)addstringtoinfstr(";-1;0");
+		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+			describenodeproto(np), (INTBIG)le->ni->geom);
 	}
 	(void)askaid(us_aid, "show-multiple", (INTBIG)returninfstr());
 
 	/* display the connection sites */
-	arrowsize = el_curtech->deflambda * 2;
+	arrowsize = lambdaoffacet(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
 		if (le->piin != NOPORTARCINST)
@@ -836,10 +833,10 @@ void le_analyzefacet(void)
 	}
 	if (changemade != 0)
 	{
-		ttyputerr("WARNING: After %d iterations, analysis is still not stable", MAXITERATIONS);
+		ttyputerr(_("WARNING: After %d iterations, analysis is still not stable"), MAXITERATIONS);
 	} else if (changeneeded != 0)
 	{
-		ttyputerr("WARNING: Unable to find solution with maximum stage effort of %g", maxstageeffort);
+		ttyputerr(_("WARNING: Unable to find solution with maximum stage effort of %g"), maxstageeffort);
 	}
 
 	/* determine whether or not to set capacitance values */
@@ -881,7 +878,6 @@ void le_gatherpath(INTBIG show)
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTARCINST *pi;
-	char line[50];
 	double c, cstart, cend;
 	GEOM **list;
 	LENODE *le, *newle, *nextle, *lastle;
@@ -895,7 +891,7 @@ void le_gatherpath(INTBIG show)
 	list = (GEOM **)askaid(us_aid, "get-all-objects");
 	if (list[0] == NOGEOM || list[1] == NOGEOM || list[2] != NOGEOM)
 	{
-		ttyputerr("Select two objects at the ends of a path");
+		ttyputerr(_("Select two objects at the ends of a path"));
 		return;
 	}
 
@@ -937,7 +933,7 @@ void le_gatherpath(INTBIG show)
 	}
 	if (ret == NONODEINST)
 	{
-		ttyputerr("No path exists between these nodes");
+		ttyputerr(_("No path exists between these nodes"));
 		return;
 	}
 
@@ -977,9 +973,9 @@ void le_gatherpath(INTBIG show)
 		}
 	}
 	if (agree != 0 && disagree != 0)
-		ttyputmsg("Directionality of path is conflicting");
+		ttyputmsg(_("Directionality of path is conflicting"));
 	if (agree == 0 && disagree == 0)
-		ttyputmsg("Directionality of path is unknown");
+		ttyputmsg(_("Directionality of path is unknown"));
 	if (disagree != 0)
 	{
 		/* reverse the path */
@@ -1012,7 +1008,7 @@ void le_gatherpath(INTBIG show)
 	/* describe the nodes in the path */
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
-		ttyputmsg("%s: LogEffort=%g Parasitics=%g Cin=%g Cout=%g Branching=%g",
+		ttyputmsg(_("%s: LogEffort=%g Parasitics=%g Cin=%g Cout=%g Branching=%g"),
 			le_describenode(le), le->logeffort, le->parasitics, le->cin, le->cout,
 				le->branching);
 	}
@@ -1024,29 +1020,21 @@ void le_gatherpath(INTBIG show)
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->temp2 == 0) continue;
-		if (first != 0) (void)addtoinfstr('/');
+		if (first != 0) (void)addtoinfstr('\n');
 		first++;
-		(void)addstringtoinfstr("FACET=");
-		(void)addstringtoinfstr(describenodeproto(np));
-		(void)addstringtoinfstr(" FROM=");
-		(void)sprintf(line, "0%o", (INTBIG)ni->geom);
-		(void)addstringtoinfstr(line);
-		(void)addstringtoinfstr(";-1;0");
+		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+			describenodeproto(np), (INTBIG)ni->geom);
 	}
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp2 == 0) continue;
-		(void)addtoinfstr('/');
-		(void)addstringtoinfstr("FACET=");
-		(void)addstringtoinfstr(describenodeproto(np));
-		(void)addstringtoinfstr(" FROM=");
-		(void)sprintf(line, "0%o", (INTBIG)ai->geom);
-		(void)addstringtoinfstr(line);
-		(void)addstringtoinfstr(";-1;0");
+		(void)addtoinfstr('\n');
+		(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+			describenodeproto(np), (INTBIG)ai->geom);
 	}
 	(void)askaid(us_aid, "show-multiple", (INTBIG)returninfstr());
 
-	arrowsize = el_curtech->deflambda * 2;
+	arrowsize = lambdaoffacet(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
 		if (le->piin != NOPORTARCINST)
@@ -1163,7 +1151,7 @@ void le_unwind(NODEINST *start, NODEINST *prev)
 			le_lastlenode = le;
 			break;
 		default:
-			ttyputmsg("Sorry, cannot analyze %s nodes", nodefunctionname(func, start));
+			ttyputmsg(_("Sorry, cannot analyze %s nodes"), nodefunctionname(func, start));
 			break;
 	}
 	if (le != NOLENODE)
@@ -1341,37 +1329,37 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 		case NPBUFFER:
 			if (inputnegates+outputnegates == 0)
 			{
-				ttyputmsg("Cannot handle BUFFER gates, only INVERTER");
+				ttyputmsg(_("Cannot handle BUFFER gates, only INVERTER"));
 			} else if (inputnegates+outputnegates != 1)
 			{
-				ttyputmsg("Cannot handle INVERTER gates that invert more than once");
+				ttyputmsg(_("Cannot handle INVERTER gates that invert more than once"));
 			} else gatetype = LEINVERTER;
 			break;
 
 		case NPGATEAND:
 			if (inputnegates != 0)
 			{
-				ttyputmsg("Cannot handle AND gates with inverted inputs");
+				ttyputmsg(_("Cannot handle AND gates with inverted inputs"));
 			} else if (outputnegates == 0)
 			{
-				ttyputmsg("Cannot handle AND gates, only NAND");
+				ttyputmsg(_("Cannot handle AND gates, only NAND"));
 			} else gatetype = LENAND;
 			break;
 
 		case NPGATEOR:
 			if (inputnegates != 0)
 			{
-				ttyputmsg("Cannot handle OR gates with inverted inputs");
+				ttyputmsg(_("Cannot handle OR gates with inverted inputs"));
 			} else if (outputnegates == 0)
 			{
-				ttyputmsg("Cannot handle OR gates, only NOR");
+				ttyputmsg(_("Cannot handle OR gates, only NOR"));
 			} else gatetype = LENOR;
 			break;
 
 		case NPGATEXOR:
 			if (inputnegates != 0)
 			{
-				ttyputmsg("Cannot handle XOR gates with inverted inputs");
+				ttyputmsg(_("Cannot handle XOR gates with inverted inputs"));
 			} else
 			{
 				if (outputnegates != 0) gatetype = LEXNOR; else
@@ -1382,28 +1370,28 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 		case NPTRANMOS:
 			if (inputnegates != 0 || outputnegates != 0)
 			{
-				ttyputmsg("Cannot negate inputs to transistors");
+				ttyputmsg(_("Cannot negate inputs to transistors"));
 			} else gatetype = LENMOS;
 			break;
 
 		case NPTRAPMOS:
 			if (inputnegates != 0 || outputnegates != 0)
 			{
-				ttyputmsg("Cannot negate inputs to transistors");
+				ttyputmsg(_("Cannot negate inputs to transistors"));
 			} else gatetype = LEPMOS;
 			break;
 
 		case NPCONPOWER:
 			if (inputnegates != 0 || outputnegates != 0)
 			{
-				ttyputmsg("Cannot negate inputs to power");
+				ttyputmsg(_("Cannot negate inputs to power"));
 			} else gatetype = LEPOWER;
 			break;
 
 		case NPCONGROUND:
 			if (inputnegates != 0 || outputnegates != 0)
 			{
-				ttyputmsg("Cannot negate inputs to ground");
+				ttyputmsg(_("Cannot negate inputs to ground"));
 			} else gatetype = LEGROUND;
 			break;
 
@@ -1414,7 +1402,7 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 			break;
 
 		default:
-			ttyputmsg("Sorry, cannot handle %s nodes", nodefunctionname(func, ni));
+			ttyputmsg(_("Sorry, cannot handle %s nodes"), nodefunctionname(func, ni));
 			break;
 	}
 
@@ -1432,25 +1420,25 @@ char *le_describenode(LENODE *le)
 	switch (le->type)
 	{
 		case LEINVERTER:
-			(void)addstringtoinfstr("inverter");
+			(void)addstringtoinfstr(_("inverter"));
 			break;
 		case LENAND:
-			(void)addstringtoinfstr("nand");
+			(void)addstringtoinfstr(_("nand"));
 			break;
 		case LENOR:
-			(void)addstringtoinfstr("nor");
+			(void)addstringtoinfstr(_("nor"));
 			break;
 		case LEXOR:
-			(void)addstringtoinfstr("xor");
+			(void)addstringtoinfstr(_("xor"));
 			break;
 		case LEXNOR:
-			(void)addstringtoinfstr("xnor");
+			(void)addstringtoinfstr(_("xnor"));
 			break;
 		case LENMOS:
-			(void)addstringtoinfstr("nMOS");
+			(void)addstringtoinfstr(_("nMOS"));
 			break;
 		case LEPMOS:
-			(void)addstringtoinfstr("pMOS");
+			(void)addstringtoinfstr(_("pMOS"));
 			break;
 		default:
 			(void)addstringtoinfstr(describenodeproto(le->ni->proto));
@@ -1508,12 +1496,12 @@ double le_getlogeffort(LENODE *le)
 				case 3: return(12.0);
 				case 4: return(32.0);
 			}
-			ttyputmsg("Cannot handle %d-input XOR gates");
+			ttyputmsg(_("Cannot handle %d-input XOR gates"));
 			return(0.0);
 		case LENMOS:     return(1.0/3.0);
 		case LEPMOS:     return(2.0/3.0);
 	}
-	ttyputmsg("Sorry, node %s has unknown type", describenodeinst(le->ni));
+	ttyputmsg(_("Sorry, node %s has unknown type"), describenodeinst(le->ni));
 	return(0.0);
 }
 
@@ -1533,7 +1521,7 @@ double le_getparasitics(LENODE *le)
 		case LENMOS:     return(1.0);		/* probably not right!!! */
 		case LEPMOS:     return(1.0);		/* probably not right!!! */
 	}
-	ttyputmsg("Sorry, node %s has unknown type", describenodeinst(le->ni));
+	ttyputmsg(_("Sorry, node %s has unknown type"), describenodeinst(le->ni));
 	return(0.0);
 }
 
