@@ -35,7 +35,7 @@
  *   PNET *pnet;
  *   INTSML components, nets, powernets, groundnets;
  *   pcomp = net_makepseudo(facet, &components, &nets, &powernets, &groundnets,
- *	&pnet, hierarchical, sortports, useequiv);
+ *	&pnet, hierarchical, sortports, useequiv, ignorepwrgnd, checkfacetoverrides);
  *   .....
  *        do something with the network in "pcomp" and "pnet"
  *   .....
@@ -61,7 +61,8 @@ static INTSML    net_pseudonode;	/* net number for pseudonetworks */
 static NODEINST *net_toplevelinst;	/* actual top-instance associated with this node */
 
 /* prototypes for local routines */
-PCOMP *net_buildpseudo(NODEPROTO*, PCOMP*, PNET**, PNET**, INTSML*, PNET**, INTSML, INTSML, INTSML);
+PCOMP *net_buildpseudo(NODEPROTO*, PCOMP*, PNET**, PNET**, INTSML*, PNET**,
+					   INTSML, INTSML, INTSML, INTSML, INTSML);
 PNET *net_newpnet(PNET**);
 PCOMP *net_allocpcomp(void);
 void net_freepcomp(PCOMP*);
@@ -106,20 +107,53 @@ void net_freeflatmemory(void)
  * and return the list.  Returns the number of pseudo-components in "components",
  * the number of pseudo-nets in "nets", the number of power nets in "powernets",
  * and the number of ground nets in "groundnets".  Extraction is done
- * hierarchically if "comphier" is nonzero.  Ports are sorted alphabetically
+ * hierarchically if "comphier" is nonzero.  A set of default options are in
+ * "sortports", "useequivs", and "ignorepwrgnd".  Ports are sorted alphabetically
  * in each component if "sortports" is nonzero.  Equivalences are used if
- * "useequivs" is nonzero.  Returns NOPCOMP if there is an error
+ * "useequivs" is nonzero.  Power and ground nets are ignored if "ignorepwrgnd"
+ * is nonzero.  If "checkfacetoverrides" is nonzero, each facet is checked to see
+ * whether these options are overridden for that facet.
+ * Returns NOPCOMP if there is an error
  */
 PCOMP *net_makepseudo(NODEPROTO *facet, INTSML *components, INTSML *nets, INTSML *powernets,
-	INTSML *groundnets, PNET **pnetlist, INTSML comphier, INTSML sortports, INTSML useequivs)
+	INTSML *groundnets, PNET **pnetlist, INTSML comphier, INTSML sortports, INTSML useequivs,
+	INTSML ignorepwrgnd, INTSML checkfacetoverrides)
 {
 	REGISTER PCONN *w;
 	REGISTER PCOMP *pcomp, *pcomplist, *p;
-	REGISTER INTSML list, i;
+	REGISTER INTSML list, i, localsortports, localuseequivs, localignorepwrgnd;
 	PNET *power, *ground;
 	REGISTER PNET *net;
+	REGISTER VARIABLE *var;
 	REGISTER PORTPROTO *pp, *opp;
 
+	/* see if the current facet overrides the options */
+	localsortports = sortports;
+	localuseequivs = useequivs;
+	localignorepwrgnd = ignorepwrgnd;
+	if (checkfacetoverrides != 0)
+	{
+		var = getvalkey((INTBIG)facet, VNODEPROTO, VINTEGER, net_ncc_optionskey);
+		if (var != NOVARIABLE)
+		{
+			if ((var->addr&NCCUSEPORTNAMESOVER) != 0)
+			{
+				if ((var->addr&NCCUSEPORTNAMES) != 0) localsortports = 1; else
+					localsortports = 0;
+			}
+			if ((var->addr&NCCUNIFYPORTNAMESOVER) != 0)
+			{
+				if ((var->addr&NCCUNIFYPORTNAMES) != 0) localuseequivs = 1; else
+					localuseequivs = 0;
+			}
+			if ((var->addr&NCCIGNOREPWRGNDOVER) != 0)
+			{
+				if ((var->addr&NCCIGNOREPWRGND) != 0) localignorepwrgnd = 1; else
+					localignorepwrgnd = 0;
+			}
+		}
+	}
+
 	/* first create net numbers external to this facet */
 	net_pseudonode = 0;
 	*pnetlist = NOPNET;
@@ -129,6 +163,10 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTSML *components, INTSML *nets, INTSML
 	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->temp1 != (INTBIG)NOPNET) continue;
+#if 0
+		if (localignorepwrgnd != 0 &&
+			((pp->userbits&STATEBITS) == PWRPORT || (pp->userbits&STATEBITS) == GNDPORT))
+				continue;
 		net = net_newpnet(pnetlist);
 		if (net == NOPNET) return(NOPCOMP);
 		if ((pp->userbits&STATEBITS) == PWRPORT)
@@ -140,7 +178,29 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTSML *components, INTSML *nets, INTSML
 			net->flags = GROUNDNET;
 			ground = net;
 		}
+#else
+		if ((pp->userbits&STATEBITS) == PWRPORT)
+		{
+			if (localignorepwrgnd != 0) net = net_allocpnet(); else
+				net = net_newpnet(pnetlist);
+			if (net == NOPNET) return(NOPCOMP);
+			net->flags = POWERNET;
+			power = net;
+		} else if ((pp->userbits&STATEBITS) == GNDPORT)
+		{
+			if (localignorepwrgnd != 0) net = net_allocpnet(); else
+				net = net_newpnet(pnetlist);
+			if (net == NOPNET) return(NOPCOMP);
+			net->flags = GROUNDNET;
+			ground = net;
+		} else
+		{
+			net = net_newpnet(pnetlist);
+			if (net == NOPNET) return(NOPCOMP);
+		}
+#endif
 		net->flags |= EXPORTEDNET;
+		net->network = pp->network;
 		net->realport = pp;
 		pp->temp1 = (INTBIG)net;
 		for(opp = pp->nextportproto; opp != NOPORTPROTO; opp = opp->nextportproto)
@@ -152,11 +212,11 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTSML *components, INTSML *nets, INTSML
 	begintraversehierarchy();
 	net_toplevelinst = NONODEINST;
 	pcomplist = net_buildpseudo(facet, NOPCOMP, &power, &ground, components,
-		pnetlist, comphier, sortports, useequivs);
+		pnetlist, comphier, sortports, useequivs, ignorepwrgnd, checkfacetoverrides);
 	if (pcomplist == 0) return(NOPCOMP);
 	if (*components == 0)
 	{
-		ttyputmsg("There are no components to associate in facet %s", describenodeproto(facet));
+		ttyputmsg(_("There are no components to associate in facet %s"), describenodeproto(facet));
 		return(NOPCOMP);
 	}
 
@@ -210,7 +270,7 @@ PCOMP *net_makepseudo(NODEPROTO *facet, INTSML *components, INTSML *nets, INTSML
  */
 PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 	PNET **ground, INTSML *components, PNET **pnetlist, INTSML compare_hierarchically,
-	INTSML sortports, INTSML useequivs)
+	INTSML sortports, INTSML useequivs, INTSML ignorepwrgnd, INTSML checkfacetoverrides)
 {
 	REGISTER PCOMP *pcomp;
 	REGISTER PCONN *pswap;
@@ -219,21 +279,57 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai, *oai;
 	REGISTER NODEINST *ni;
-	REGISTER INTSML fun, i, toldshort, swap, still, toplevel, flattenit;
+	REGISTER INTSML fun, i, toldshort, swap, still, toplevel, flattenit,
+		localsortports, localuseequivs, localignorepwrgnd;
 	REGISTER NODEPROTO *realnp;
 	REGISTER PNET *net;
+	REGISTER VARIABLE *var;
 	REGISTER EQUIV *e;
 
+	/* get options */
+	localsortports = sortports;
+	localuseequivs = useequivs;
+	localignorepwrgnd = ignorepwrgnd;
+	if (checkfacetoverrides != 0)
+	{
+		var = getvalkey((INTBIG)facet, VNODEPROTO, VINTEGER, net_ncc_optionskey);
+		if (var != NOVARIABLE)
+		{
+			if ((var->addr&NCCUSEPORTNAMESOVER) != 0)
+			{
+				if ((var->addr&NCCUSEPORTNAMES) != 0) localsortports = 1; else
+					localsortports = 0;
+			}
+			if ((var->addr&NCCUNIFYPORTNAMESOVER) != 0)
+			{
+				if ((var->addr&NCCUNIFYPORTNAMES) != 0) localuseequivs = 1; else
+					localuseequivs = 0;
+			}
+			if ((var->addr&NCCIGNOREPWRGNDOVER) != 0)
+			{
+				if ((var->addr&NCCIGNOREPWRGND) != 0) localignorepwrgnd = 1; else
+					localignorepwrgnd = 0;
+			}
+		}
+	}
+
 	if (net_toplevelinst == NONODEINST) toplevel = 1; else
 		toplevel = 0;
 
 	/* place pseudo-netnumbers on all arcs, taken from ports */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	{
 		ai->temp1 = (INTBIG)NOPNET;
+		ai->temp2 = 0;
+	}
 	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
-			if (ai->network == pp->network) ai->temp1 = pp->temp1;
+		{
+			if (ai->network != pp->network) continue;
+			ai->temp1 = pp->temp1;
+			ai->temp2 = 1;
+		}
 	}
 
 	/* spread power and ground information from appropriate nodes */
@@ -247,8 +343,10 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 			net = *power;
 			if (net == NOPNET)
 			{
-				net = net_newpnet(pnetlist);
+				if (localignorepwrgnd != 0) net = net_allocpnet(); else
+					net = net_newpnet(pnetlist);
 				net->realport = NOPORTPROTO;
+				net->network = NONETWORK;
 				net->flags = POWERNET;
 				*power = net;
 			}
@@ -258,8 +356,10 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 			net = *ground;
 			if (net == NOPNET)
 			{
-				net = net_newpnet(pnetlist);
+				if (localignorepwrgnd != 0) net = net_allocpnet(); else
+					net = net_newpnet(pnetlist);
 				net->realport = NOPORTPROTO;
+				net->network = NONETWORK;
 				net->flags = GROUNDNET;
 				*ground = net;
 			}
@@ -267,30 +367,41 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			ai = pi->conarcinst;
-			if (ai->temp1 != (INTBIG)NOPNET)
+			if (ai->temp2 != 0)
 			{
 				if (ai->temp1 != (INTBIG)net)
 				{
-					ttyputerr("Warning: power/ground node connected to non-power/ground port in facet %s",
+					ttyputerr(_("Warning: power/ground node connected to non-power/ground port in facet %s"),
 						describenodeproto(facet));
 				}
 			}
 			ai->temp1 = (INTBIG)net;
+			ai->temp2 = 1;
 			for(oai = facet->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
-				if (oai->network == ai->network) oai->temp1 = ai->temp1;
+			{
+				if (oai->network != ai->network) continue;
+				oai->temp1 = ai->temp1;
+				oai->temp2 = 1;
+			}
 		}
 	}
 
 	/* generate new pseudo-netnumbers for arcs not connected to ports */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
-		if (ai->temp1 != (INTBIG)NOPNET) continue;
+		if (ai->temp2 != 0) continue;
 		net = net_newpnet(pnetlist);
 		if (net == NOPNET) return(0);
 		ai->temp1 = (INTBIG)net;
+		ai->temp2 = 1;
 		net->realport = NOPORTPROTO;
+		net->network = ai->network;
 		for(oai = ai->nextarcinst; oai != NOARCINST; oai = oai->nextarcinst)
-			if (oai->network == ai->network) oai->temp1 = ai->temp1;
+		{
+			if (oai->network != ai->network) continue;
+			oai->temp1 = ai->temp1;
+			oai->temp2 = 1;
+		}
 	}
 
 	/* search every component in the facet */
@@ -303,7 +414,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 		flattenit = 0;
 		if (ni->proto->primindex == 0 && compare_hierarchically != 0) flattenit = 1;
 
-		if (flattenit != 0 && useequivs != 0)
+		if (flattenit != 0 && localuseequivs != 0)
 		{
 			/* see if this is equivalenced */
 			for(e = net_firstequiv; e != NOEQUIV; e = e->nextequiv)
@@ -338,7 +449,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 					if (pi->proto->network == pp->network) break;
 				if (pi != NOPORTARCINST) realpp->temp1 = pi->conarcinst->temp1; else
 				{
-					/* see if the port is exported */
+					/* see if the port is an export */
 					for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 						if (pe->proto->network == pp->network) break;
 					if (pe != NOPORTEXPINST) realpp->temp1 = pe->exportproto->temp1; else
@@ -346,6 +457,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 						net = net_newpnet(pnetlist);
 						if (net == NOPNET) return(0);
 						net->realport = NOPORTPROTO;
+						net->network = pp->network;
 						if ((pp->userbits&STATEBITS) == PWRPORT)
 						{
 							net->flags = POWERNET;
@@ -367,7 +479,8 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 			/* recurse into the facet */
 			downhierarchy(ni);
 			initiallist = net_buildpseudo(realnp, initiallist, power, ground,
-				components, pnetlist, compare_hierarchically, sortports, useequivs);
+				components, pnetlist, compare_hierarchically, sortports, useequivs,
+					ignorepwrgnd, checkfacetoverrides);
 			uphierarchy();
 			if (initiallist == 0) return(0);
 			continue;
@@ -384,6 +497,9 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 			if (fun == NPCONGROUND && *ground != NOPNET) continue;
 		}
 
+		/* ignore power and ground components if requested */
+		if (localignorepwrgnd != 0 && (fun == NPCONPOWER || fun == NPCONGROUND)) continue;
+
 		/* create a pseudo-component */
 		pcomp = net_allocpcomp();
 		if (pcomp == NOPCOMP) return(0);
@@ -399,6 +515,10 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 		pcomp->wirecount = 0;
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
+			/* ignore power and ground ports if requested */
+			if (localignorepwrgnd != 0 &&
+				((pp->userbits&STATEBITS) == PWRPORT || (pp->userbits&STATEBITS) == GNDPORT)) continue;
+
 			/* special case for isolated ports */
 			if ((pp->userbits&PORTISOLATED) != 0)
 			{
@@ -447,6 +567,10 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 		pcomp->wirecount = 0;
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
+			/* ignore power and ground ports if requested */
+			if (localignorepwrgnd != 0 &&
+				((pp->userbits&STATEBITS) == PWRPORT || (pp->userbits&STATEBITS) == GNDPORT)) continue;
+
 			/* special case for isolated ports */
 			if ((pp->userbits&PORTISOLATED) != 0)
 			{
@@ -490,8 +614,11 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 						(ai->end[1].portarcinst == pi && (ai->userbits&REVERSEEND) != 0))
 							pcomp->state[pcomp->wirecount] = NEGATEDPORT;
 				}
-				if ((pcomp->netnumbers[pcomp->wirecount]->flags&EXPORTEDNET) != 0)
-					pcomp->state[pcomp->wirecount] |= EXPORTEDPORT;
+				if (pcomp->netnumbers[pcomp->wirecount] != NOPNET)
+				{
+					if ((pcomp->netnumbers[pcomp->wirecount]->flags&EXPORTEDNET) != 0)
+						pcomp->state[pcomp->wirecount] |= EXPORTEDPORT;
+				}
 				break;
 			}
 			if (pcomp->netnumbers[pcomp->wirecount] == NOPNET)
@@ -509,13 +636,14 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 				net = net_newpnet(pnetlist);
 				if (net == NOPNET) return(0);
 				net->realport = NOPORTPROTO;
+				net->network = NONETWORK;
 				pcomp->netnumbers[pcomp->wirecount] = net;
 			}
 			pcomp->wirecount++;
 		}
 
 		/* sort the list if requested */
-		if (sortports != 0)
+		if (localsortports != 0)
 		{
 			still = 1;
 			while (still != 0)
@@ -555,7 +683,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 				{
 					if ((pcomp->netnumbers[i]->flags&GROUNDNET) != 0 && toldshort == 0)
 					{
-						ttyputerr("Power and ground are shorted in %s", describenodeproto(facet));
+						ttyputerr(_("Power and ground are shorted in %s"), describenodeproto(facet));
 						toldshort++;
 					}
 					pcomp->netnumbers[i]->flags |= POWERNET;
@@ -565,7 +693,7 @@ PCOMP *net_buildpseudo(NODEPROTO *facet, PCOMP *initiallist, PNET **power,
 				{
 					if ((pcomp->netnumbers[i]->flags&POWERNET) != 0 && toldshort == 0)
 					{
-						ttyputerr("Power and ground are shorted in %s", describenodeproto(facet));
+						ttyputerr(_("Power and ground are shorted in %s"), describenodeproto(facet));
 						toldshort++;
 					}
 					pcomp->netnumbers[i]->flags |= GROUNDNET;
@@ -591,8 +719,6 @@ PNET *net_newpnet(PNET **pnetlist)
 
 	p = net_allocpnet();
 	if (p == 0) return(NOPNET);
-	p->flags = 0;
-	p->realport = NOPORTPROTO;
 	net_pseudonode++;
 	p->nextpnet = *pnetlist;
 	*pnetlist = p;
@@ -673,6 +799,7 @@ PNET *net_allocpnet(void)
 	}
 
 	p->flags = 0;
+	p->realport = NOPORTPROTO;
 	return(p);
 }
 
