@@ -32,6 +32,7 @@
 #if PLAAID
 
 #include "global.h"
+#include "pla.h"
 #include "placmos.h"
 
 NODEINST *plac_decode_bufs(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, NODEPROTO*, INTBIG,
@@ -54,7 +55,7 @@ NODEPROTO *plac_decode_gen(LIBRARY *library, NODEPROTO *pmos_np, NODEPROTO *nmos
 
 	X = p_ni->geom->highx - p_ni->geom->lowx;  /* CHG */
 	if (X < 0) X = -X;
-	X = X + 0 +  12*el_curtech->deflambda; /* SEPRATION */
+	X = X + 0 +  12*pla_lam; /* SEPARATION */
 
 	n_ni = plac_make_instance(decode_np, nmos_np, X, 0, FALSE);
 	if (n_ni == NONODEINST) return(NONODEPROTO);
@@ -88,7 +89,7 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 	var = getval((INTBIG)pmos_np, VNODEPROTO, VINTEGER, "PLA_access_rows");
 	if (var != NOVARIABLE) rows = (INTBIG)((INTBIG *)var->addr); else
 	{
-		ttyputerr("ACCESS_rows defaulting to 2");
+		ttyputerr(_("ACCESS_rows defaulting to 2"));
 		rows = 2;
 	}
 
@@ -104,9 +105,9 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 		if ((limit == 0) || ((rows % 4) != 0))  limit = limit + 1;
 		cnt = 0;
 		if (INPUTS == TRUE) Y = lowy - diff; else Y = highy;
-		Y -= 13*el_curtech->deflambda;
-		if ((rows %4) == 0) X_offset = lowx - 18*el_curtech->deflambda; else
-			X_offset = lowx - 38*el_curtech->deflambda;
+		Y -= 13*pla_lam;
+		if ((rows %4) == 0) X_offset = lowx - 18*pla_lam; else
+			X_offset = lowx - 38*pla_lam;
 		(void)sprintf(a_name, "PWR.m-2.w");
 		(void)sprintf(i_name, "PWR.m-2.e");
 		pwr_w_pp = getportproto(buf_np, a_name);
@@ -118,10 +119,10 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 		for (i= limit; i > 0; i--)
 		{
 			newno = plac_make_instance(decode_np, buf_np,
-				i*50*el_curtech->deflambda + X_offset, Y, FALSE);
+				i*50*pla_lam + X_offset, Y, FALSE);
 			if (newno == NONODEINST) return(NONODEINST);
 			newno_2 = plac_make_instance(decode_np, buf_np,
-				X + i*50*el_curtech->deflambda + X_offset, Y, FALSE);
+				X + i*50*pla_lam + X_offset, Y, FALSE);
 			if (newno_2 == NONODEINST) return(NONODEINST);
 			if (INPUTS != TRUE)
 			{
@@ -147,16 +148,16 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 				/* get wired */
 				if ((pwr_w_pp != NOPORTPROTO) && (pwr_e_pp != NOPORTPROTO))
 				{
-					plac_wire("Metal-2", 14*el_curtech->deflambda, last_p_ni,
+					plac_wire("Metal-2", 14*pla_lam, last_p_ni,
 						pwr_w_pp, newno, pwr_e_pp, decode_np);
-					plac_wire("Metal-2", 14*el_curtech->deflambda, last_n_ni,
+					plac_wire("Metal-2", 14*pla_lam, last_n_ni,
 						pwr_w_pp, newno_2, pwr_e_pp, decode_np);
 				}
 				if ((gnd_w_pp != NOPORTPROTO) && (gnd_e_pp != NOPORTPROTO))
 				{
-					plac_wire("Metal-2", 14*el_curtech->deflambda, last_n_ni,
+					plac_wire("Metal-2", 14*pla_lam, last_n_ni,
 						gnd_w_pp, newno, gnd_e_pp, decode_np);
-					plac_wire("Metal-2", 14*el_curtech->deflambda, last_n_ni,
+					plac_wire("Metal-2", 14*pla_lam, last_n_ni,
 						gnd_w_pp, newno_2, gnd_e_pp, decode_np);
 				}
 				last_p_ni = newno;
@@ -169,11 +170,11 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 				p_pp = getportproto(pmos_np, a_name);
 				n_pp = getportproto(buf_np, i_name);
 				if ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
-					plac_wire("Polysilicon", 2*el_curtech->deflambda, p_ni, p_pp,
+					plac_wire("Polysilicon", 2*pla_lam, p_ni, p_pp,
 						newno, n_pp, decode_np);
 				p_pp = getportproto(nmos_np, a_name);
 				if ((n_pp != NOPORTPROTO) && (p_pp != NOPORTPROTO))
-					plac_wire("Polysilicon", 2*el_curtech->deflambda, n_ni, p_pp,
+					plac_wire("Polysilicon", 2*pla_lam, n_ni, p_pp,
 						newno_2, n_pp, decode_np);
 			}
 			cnt += 4;
@@ -181,13 +182,13 @@ NODEINST *plac_decode_bufs(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_n
 	}
 	if ((pwr_w_pp != NOPORTPROTO) && (pwr_e_pp != NOPORTPROTO))
 	{
-		plac_wire("Metal-2", 14*el_curtech->deflambda, last_n_ni, pwr_w_pp,
+		plac_wire("Metal-2", 14*pla_lam, last_n_ni, pwr_w_pp,
 			first_p_ni, pwr_e_pp, decode_np);
 		(void)newportproto(decode_np, last_p_ni, pwr_w_pp, "PWR.m-2.w");
 	}
 	if ((gnd_w_pp != NOPORTPROTO) && (gnd_e_pp != NOPORTPROTO))
 	{
-		plac_wire("Metal-2", 14*el_curtech->deflambda, last_n_ni, gnd_w_pp,
+		plac_wire("Metal-2", 14*pla_lam, last_n_ni, gnd_w_pp,
 			first_p_ni, gnd_e_pp, decode_np);
 		(void)newportproto(decode_np, last_p_ni, gnd_w_pp, "GND.m-2.w");
 	}
@@ -235,7 +236,7 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	while ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
 	{
 		/* Connect them up here */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, p_pp, n_ni, n_pp, decode_np);
+		plac_wire("Metal-1", 4*pla_lam, p_ni, p_pp, n_ni, n_pp, decode_np);
 
 		/* now find the next ports */
 		cnt += 1;
@@ -251,22 +252,22 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	(void)sprintf(name, "PWR%d.m-1.s", 0);
 	n_pp = getportproto(pmos_np, name);
 	if ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
-		plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, p_pp, p_ni, n_pp, decode_np);
+		plac_wire("Metal-1", 4*pla_lam, p_ni, p_pp, p_ni, n_pp, decode_np);
 	portposition(p_ni, n_pp, &p_X, &p_Y);
-	pm_ni_1 = plac_make_Pin(decode_np, p_X-13*el_curtech->deflambda, p_Y,
-		6*el_curtech->deflambda, "Metal-1-Metal-2-Con");
+	pm_ni_1 = plac_make_Pin(decode_np, p_X-13*pla_lam, p_Y,
+		6*pla_lam, "Metal-1-Metal-2-Con");
 	if (pm_ni_1 == NONODEINST) return(1);
-	plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, n_pp, pm_ni_1,
+	plac_wire("Metal-1", 4*pla_lam, p_ni, n_pp, pm_ni_1,
 		pm_ni_1->proto->firstportproto, decode_np);
 	if (INPUTS != TRUE) /* Buffers are at the top of the facet */
 	{
 		pwr_pp = getportproto(first_buf->proto, "PWR.m-2.w");
-		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*el_curtech->deflambda,
-			p_Y+24*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-2-Pin");
+		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*pla_lam,
+			p_Y+24*pla_lam, 14*pla_lam, "Metal-2-Pin");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, first_buf, pwr_pp,
+		plac_wire("Metal-2", 14*pla_lam, first_buf, pwr_pp,
 			pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 	}
 	n_pp = p_pp;
@@ -277,7 +278,7 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	while ((p_pp != NOPORTPROTO) && (n_pp != NOPORTPROTO))
 	{
 		/* Connect them up here */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, p_pp, p_ni, n_pp, decode_np);
+		plac_wire("Metal-1", 4*pla_lam, p_ni, p_pp, p_ni, n_pp, decode_np);
 
 		/* now find the next ports */
 		cnt += 1;
@@ -288,14 +289,14 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 			(void)sprintf(name, "PWR%ld.m-1.s", pwr_cnt);
 			p_pp = getportproto(pmos_np, name);
 			if (p_pp != NOPORTPROTO)
-				plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, p_pp, p_ni, n_pp, decode_np);
+				plac_wire("Metal-1", 4*pla_lam, p_ni, p_pp, p_ni, n_pp, decode_np);
 			portposition(p_ni, p_pp, &p_X, &p_Y);
-			pm_ni_2 = plac_make_Pin(decode_np, p_X-13*el_curtech->deflambda, p_Y,
-				6*el_curtech->deflambda, "Metal-1-Metal-2-Con");
+			pm_ni_2 = plac_make_Pin(decode_np, p_X-13*pla_lam, p_Y,
+				6*pla_lam, "Metal-1-Metal-2-Con");
 			if (pm_ni_2 == NONODEINST) return(1);
-			plac_wire("Metal-1", 4*el_curtech->deflambda, p_ni, p_pp, pm_ni_2,
+			plac_wire("Metal-1", 4*pla_lam, p_ni, p_pp, pm_ni_2,
 				pm_ni_2->proto->firstportproto, decode_np);
-			plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+			plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 				pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 			pm_ni_1 = pm_ni_2;
 			n_pp = p_pp;
@@ -306,12 +307,12 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	if (INPUTS == TRUE) /* Buffers are at the top of the facet */
 	{
 		pwr_pp = getportproto(first_buf->proto, "PWR.m-2.w");
-		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*el_curtech->deflambda,
-			p_Y-24*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-2-Pin");
+		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*pla_lam,
+			p_Y-24*pla_lam, 14*pla_lam, "Metal-2-Pin");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, first_buf, pwr_pp,
+		plac_wire("Metal-2", 14*pla_lam, first_buf, pwr_pp,
 			pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 	}
 
@@ -319,20 +320,20 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	(void)sprintf(name, "GND%d.m-1.n", 0);
 	n_pp = getportproto(nmos_np, name);
 	portposition(n_ni, n_pp, &p_X, &p_Y);
-	pm_ni_1 = plac_make_Pin(decode_np, p_X+13*el_curtech->deflambda, p_Y,
-		6*el_curtech->deflambda, "Metal-1-Metal-2-Con");
+	pm_ni_1 = plac_make_Pin(decode_np, p_X+13*pla_lam, p_Y,
+		6*pla_lam, "Metal-1-Metal-2-Con");
 	if (pm_ni_1 == NONODEINST) return(1);
-	plac_wire("Metal-1", 4*el_curtech->deflambda, n_ni, n_pp, pm_ni_1,
+	plac_wire("Metal-1", 4*pla_lam, n_ni, n_pp, pm_ni_1,
 		pm_ni_1->proto->firstportproto, decode_np);
 	if (INPUTS != TRUE) /* Buffers are at the top of the facet */
 	{
 		pwr_pp = getportproto(last_buf->proto, "GND.m-2.e");
-		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*el_curtech->deflambda,
-			p_Y+90*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-2-Pin");
+		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*pla_lam,
+			p_Y+90*pla_lam, 14*pla_lam, "Metal-2-Pin");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, last_buf, pwr_pp,
+		plac_wire("Metal-2", 14*pla_lam, last_buf, pwr_pp,
 			pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 	}
 	cnt = 1;
@@ -342,12 +343,12 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	{
 		/* Connect them up here */
 		portposition(n_ni, n_pp, &p_X, &p_Y);
-		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*el_curtech->deflambda, p_Y,
-			6*el_curtech->deflambda, "Metal-1-Metal-2-Con");
+		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*pla_lam, p_Y,
+			6*pla_lam, "Metal-1-Metal-2-Con");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-1", 4*el_curtech->deflambda, n_ni, n_pp, pm_ni_2,
+		plac_wire("Metal-1", 4*pla_lam, n_ni, n_pp, pm_ni_2,
 			pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 		pm_ni_1 = pm_ni_2;
 		cnt++;
@@ -357,12 +358,12 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 	if (INPUTS == TRUE) /* Buffers are at the bottom of the facet */
 	{
 		pwr_pp = getportproto(last_buf->proto, "GND.m-2.e");
-		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*el_curtech->deflambda,
-			p_Y-90*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-2-Pin");
+		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*pla_lam,
+			p_Y-90*pla_lam, 14*pla_lam, "Metal-2-Pin");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-2", 14*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Metal-2", 14*el_curtech->deflambda, last_buf, pwr_pp,
+		plac_wire("Metal-2", 14*pla_lam, last_buf, pwr_pp,
 			pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 	}
 
@@ -382,12 +383,12 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 		columns = columns/2;
 	} else
 	{
-		ttyputerr("DATA_cols defaulting to 2");
+		ttyputerr(_("DATA_cols defaulting to 2"));
 		columns = 2;
 	}
 
-	init_offset = 8*el_curtech->deflambda;
-	sep = 7*el_curtech->deflambda;
+	init_offset = 8*pla_lam;
+	sep = 7*pla_lam;
 	cnt = 0;
 	(void)sprintf(name, "ACCESS%ld.m-1.%c", cnt, ac_side);
 	p_pp = getportproto(pmos_np, name);
@@ -407,22 +408,22 @@ INTSML plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np,
 			Y = n_Y - init_offset - in_cnt*sep;
 			O_Y = Y - (columns - in_cnt - 1)*sep;
 		}
-		pm_ni_1 = plac_make_Pin(decode_np, p_X, Y, 6*el_curtech->deflambda,
+		pm_ni_1 = plac_make_Pin(decode_np, p_X, Y, 6*pla_lam,
 			"Metal-1-Polysilicon-Con");
 		if (pm_ni_1 == NONODEINST) return(1);
-		pm_ni_2 = plac_make_Pin(decode_np, n_X, Y, 6*el_curtech->deflambda,
+		pm_ni_2 = plac_make_Pin(decode_np, n_X, Y, 6*pla_lam,
 			"Metal-1-Polysilicon-Con");
 		if (pm_ni_2 == NONODEINST) return(1);
-		plac_wire("Metal-1", 4*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-1", 4*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
-		plac_wire("Polysilicon", 2*el_curtech->deflambda, p_ni, p_pp, pm_ni_1,
+		plac_wire("Polysilicon", 2*pla_lam, p_ni, p_pp, pm_ni_1,
 			pm_ni_1->proto->firstportproto, decode_np);
-		plac_wire("Polysilicon", 2*el_curtech->deflambda, n_ni, n_pp, pm_ni_2,
+		plac_wire("Polysilicon", 2*pla_lam, n_ni, n_pp, pm_ni_2,
 			pm_ni_2->proto->firstportproto, decode_np);
 
-		pm_ni_1 = plac_make_Pin(decode_np, n_X, O_Y, 4*el_curtech->deflambda, "Metal-1-Pin");
+		pm_ni_1 = plac_make_Pin(decode_np, n_X, O_Y, 4*pla_lam, "Metal-1-Pin");
 		if (pm_ni_1 == NONODEINST) return(1);
-		plac_wire("Metal-1", 4*el_curtech->deflambda, pm_ni_1,
+		plac_wire("Metal-1", 4*pla_lam, pm_ni_1,
 			pm_ni_1->proto->firstportproto, pm_ni_2, pm_ni_2->proto->firstportproto, decode_np);
 		(void)sprintf(name, "INPUT%ld.m-1.%c", in_cnt, side);
 		(void)newportproto(decode_np, pm_ni_1, pm_ni_1->proto->firstportproto, name);
