@@ -32,6 +32,7 @@
 #if PLAAID
 
 #include "global.h"
+#include "pla.h"
 #include "placmos.h"
 
 /* prototypes for local routines */
@@ -51,14 +52,14 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 	INTBIG eof, i, X_offset, Y_offset, Y_M_offset, row;
 
 	Y = 0;
-	X = 3 * el_curtech->deflambda;
-	X_offset = PLAC_X_SEP * el_curtech->deflambda;
-	Y_offset = PLAC_Y_SEP * el_curtech->deflambda;
-	Y_M_offset = PLAC_Y_MIR_SEP * el_curtech->deflambda;
+	X = 3 * pla_lam;
+	X_offset = PLAC_X_SEP * pla_lam;
+	Y_offset = PLAC_Y_SEP * pla_lam;
+	Y_M_offset = PLAC_Y_MIR_SEP * pla_lam;
 	nmos_one = getnodeproto("nmos_one");
 	if (nmos_one == NONODEPROTO)
 	{
-		ttyputerr("Unable to find prototype called nmos_one");
+		ttyputerr(_("Unable to find prototype called nmos_one"));
 		return(NONODEPROTO);
 	}
 
@@ -67,7 +68,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 	eof = plac_read_hw(file, &height, &width, &height_in, &width_in);
 	if (eof == EOF)
 	{
-		ttyputerr("Error reading height and width");
+		ttyputerr(_("Error reading height and width"));
 		return(NONODEPROTO);
 	}
 
@@ -86,13 +87,13 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 
 	row_1[0] = -1;
 	row_2[0] = -1;
-	Y = -el_curtech->deflambda - Y_offset;
+	Y = -pla_lam - Y_offset;
 
 	X = X_offset;
 	row = 0;
 	read_rows = 0;
 
-	ttyputmsg("Finished setup, about to read and generate");
+	ttyputmsg(_("Finished setup, about to read and generate"));
 	while ((read_rows < height_in) && (eof != EOF))
 	{
 		/* read in the two rows first */
@@ -113,7 +114,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 			/* place a nmos_one facet.  Connect to ground and facet up above */
 			if (((i % 5) == 0) && (i != 0)) /* put in ground strap */
 			{
-				if (plac_gnd_strap(i, (X_offset*i)+(3*el_curtech->deflambda), Y,
+				if (plac_gnd_strap(i, (X_offset*i)+(3*pla_lam), Y,
 					row, pla_array_facet, nmos_one) != 0) return(NONODEPROTO);
 			} else
 			{
@@ -135,7 +136,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 		}
 
 		/* Now put the poly metal contact at on the other side of the row */
-		if (plac_complete_row(row, X_offset*width+0*el_curtech->deflambda, Y,
+		if (plac_complete_row(row, X_offset*width+0*pla_lam, Y,
 			nmos_one, pla_array_facet) != 0) return(NONODEPROTO);
 		if ((read_rows % 4) == 0) Y = Y - Y_offset;
 
@@ -144,9 +145,9 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 		row++;
 		Y = Y - 2*Y_offset;
 	}
-	X = 3*el_curtech->deflambda;
-	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset+el_curtech->deflambda; else
-		Y = Y + Y_offset+el_curtech->deflambda;
+	X = 3*pla_lam;
+	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset+pla_lam; else
+		Y = Y + Y_offset+pla_lam;
 	if (plac_finish_columns(width, X, Y, X_offset, nmos_one, pla_array_facet) != 0)
 		return(NONODEPROTO);
 
@@ -155,8 +156,8 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 
 	X1 = pla_array_facet->lowx;
 	X2 = pla_array_facet->highx;
-	Y1 = pla_array_facet->lowy - el_curtech->deflambda;
-	Y2 = pla_array_facet->highy + el_curtech->deflambda;
+	Y1 = pla_array_facet->lowy - pla_lam;
+	Y2 = pla_array_facet->highy + pla_lam;
 	if (newnodeinst(np, X1, X2, Y1, Y2, 0, 0, pla_array_facet) == NONODEINST)
 		return(NONODEPROTO);
 
@@ -176,7 +177,7 @@ INTSML plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_a
 
 	/* put in Substrate contact first */
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-		Y+11*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-1-Well-Con");
+		Y+11*pla_lam, 14*pla_lam, "Metal-1-Well-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* wire in the first ground strap */
@@ -184,7 +185,7 @@ INTSML plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_a
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst,
+	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* only put this in a column list */
@@ -194,7 +195,7 @@ INTSML plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_a
 	/* put in metal diffusion contact */
 	new_item = plac_newUCITEM();
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-		Y+el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-1-D-Active-Con");
+		Y+pla_lam, 14*pla_lam, "Metal-1-D-Active-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* wire in the first ground strap */
@@ -202,14 +203,14 @@ INTSML plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_a
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst,
+	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* connect to last row object */
 	if (plac_row_list[row][1].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][1].lastitem->nodeinst->proto->firstportproto; else
 			last_col_pp = getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, "GND.d.s");
-	plac_wire("D-active", 14*el_curtech->deflambda, plac_row_list[row][1].lastitem->nodeinst,
+	plac_wire("D-active", 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* insert into row and column lists */
@@ -245,18 +246,18 @@ INTSML plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG ro
 			last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto, "OUT.m-1.n");
 
 	/* connect to last column object */
-	plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst, last_col_pp,
+	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
 		ni, ni_col_pp, pla_array_facet);
 
 	/* connect to last ground object */
 	if (plac_row_list[row][1].lastitem == NOUCITEM)
 	{
-		ttyputerr("No UCITEM at row %ld", row);
+		ttyputerr(_("No UCITEM at row %ld"), row);
 		return(1);
 	}
 	if (plac_row_list[row][1].lastitem->nodeinst == NONODEINST)
 	{
-		ttyputerr("No NODEINST at row_1 %ld", row);
+		ttyputerr(_("No NODEINST at row_1 %ld"), row);
 		return(1);
 	}
 
@@ -265,11 +266,11 @@ INTSML plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG ro
 			last_col_pp =  getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, "GND.d.s");
 	if (last_col_pp == NOPORTPROTO)
 	{
-		ttyputerr("No NODEPROTO for GND.d.s", row);
+		ttyputerr(_("No NODEPROTO for GND.d.s"), row);
 		return(1);
 	}
 	ni_col_pp = getportproto(ni->proto, "GND.d.s");
-	plac_wire("D-active", 14*el_curtech->deflambda, plac_row_list[row][1].lastitem->nodeinst,
+	plac_wire("D-active", 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
 		last_col_pp, ni, ni_col_pp, pla_array_facet);
 
 	/* connect to last GATE object */
@@ -304,8 +305,8 @@ INTSML plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 	char name[40];
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+6*el_curtech->deflambda,
-		6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+6*pla_lam,
+		6*pla_lam, "Metal-1-Polysilicon-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* connect to last GATE object */
@@ -332,8 +333,8 @@ INTSML plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-4*el_curtech->deflambda,
-		6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-4*pla_lam,
+		6*pla_lam, "Metal-1-Polysilicon-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* connect to last GATE object */
@@ -377,7 +378,7 @@ INTSML plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		{
 			(void)sprintf(name, "GND%ld.m-1.n", gnd_cnt);
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 14*el_curtech->deflambda, "Metal-1-Well-Con");
+				X_offset * i + X, Y, 14*pla_lam, "Metal-1-Well-Con");
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(1);
 			gnd_cnt++;
 		} else
@@ -385,7 +386,7 @@ INTSML plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 			/* must be a data pin, don't count ground pins */
 			(void)sprintf(name, "DATA%ld.m-1.n", (i - gnd_cnt));
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*el_curtech->deflambda, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(1);
 		}
 		(void)newportproto(pla_array_facet, plac_col_list[i].firstitem->nodeinst,
@@ -403,7 +404,7 @@ INTSML plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 
 	/*   Y = Y - Y_offset; */
 	limit = (height_in/2) + (height_in % 2);
-	ttyputmsg("Height limit is %ld", limit);
+	ttyputmsg(_("Height limit is %ld"), limit);
 	for (i = 0; i < limit; i++)
 	{
 		if (((i % 2) == 0) && (i != 0)) Y = Y - Y_offset;
@@ -412,7 +413,7 @@ INTSML plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 
 		/* put in Substrate contact first */
 		new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-			Y-Y_M_offset+10*el_curtech->deflambda, 14*el_curtech->deflambda, "Metal-1-Well-Con");
+			Y-Y_M_offset+10*pla_lam, 14*pla_lam, "Metal-1-Well-Con");
 		if (new_item->nodeinst == NONODEINST) return(1);
 
 		/* wire in the first ground strap */
@@ -420,7 +421,7 @@ INTSML plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[0].lastitem->nodeinst,
+		plac_wire("Metal-1", 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		/* only put this in a column list */
@@ -435,15 +436,15 @@ INTSML plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 		plac_row_list[i][2].lastitem =  plac_row_list[i][2].firstitem;
 
 		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X-7*el_curtech->deflambda, Y-5*el_curtech->deflambda,
-				6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+			X-7*pla_lam, Y-5*pla_lam,
+				6*pla_lam, "Metal-1-Polysilicon-Con");
 		if (plac_row_list[i][0].firstitem->nodeinst == NONODEINST) return(1);
 		plac_row_list[i][1].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X, Y-Y_M_offset, 14*el_curtech->deflambda, "Metal-1-D-Active-Con");
+			X, Y-Y_M_offset, 14*pla_lam, "Metal-1-D-Active-Con");
 		if (plac_row_list[i][1].firstitem->nodeinst == NONODEINST) return(1);
 		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X-7*el_curtech->deflambda, Y-15*el_curtech->deflambda,
-				6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+			X-7*pla_lam, Y-15*pla_lam,
+				6*pla_lam, "Metal-1-Polysilicon-Con");
 		if (plac_row_list[i][2].firstitem->nodeinst == NONODEINST) return(1);
 
 		/* wire in the first ground strap */
@@ -451,7 +452,7 @@ INTSML plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[0].lastitem->nodeinst,
+		plac_wire("Metal-1", 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
 			last_col_pp, plac_row_list[i][1].lastitem->nodeinst, ni_col_pp, pla_array_facet);
 		plac_col_list[0].lastitem->bottomitem = plac_row_list[i][1].lastitem;
 		plac_col_list[0].lastitem = plac_col_list[0].lastitem->bottomitem;
@@ -479,7 +480,7 @@ INTSML plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		{
 			(void)sprintf(name, "GND%ld.m-1.s", gnd_cnt);
 			new_item->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset*i+X, Y, 14*el_curtech->deflambda, "Metal-1-Well-Con");
+				X_offset*i+X, Y, 14*pla_lam, "Metal-1-Well-Con");
 			if (new_item->nodeinst == NONODEINST) return(1);
 			last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 			gnd_cnt++;
@@ -488,7 +489,7 @@ INTSML plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 			/* must be a data pin, don't count ground pins */
 			(void)sprintf(name, "DATA%ld.m-1.s", (i - gnd_cnt));
 			new_item->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*el_curtech->deflambda, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
 			if (new_item->nodeinst == NONODEINST) return(1);
 			if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one)
 				last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto; else
@@ -500,7 +501,7 @@ INTSML plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		ni_col_pp = new_item->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst,
+		plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		/* only put this in a column list */
