@@ -32,6 +32,7 @@
 #if PLAAID
 
 #include "global.h"
+#include "pla.h"
 #include "placmos.h"
 
 /* prototypes for local routines */
@@ -51,15 +52,15 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 	INTBIG eof, i, X_offset, Y_offset, Y_M_offset, row;
 
 	Y = 0;
-	X = 3*el_curtech->deflambda;
-	X_offset = PLAC_X_SEP*el_curtech->deflambda;
-	Y_offset = PLAC_Y_SEP*el_curtech->deflambda;
-	Y_M_offset = PLAC_Y_MIR_SEP * el_curtech->deflambda;
+	X = 3*pla_lam;
+	X_offset = PLAC_X_SEP*pla_lam;
+	Y_offset = PLAC_Y_SEP*pla_lam;
+	Y_M_offset = PLAC_Y_MIR_SEP * pla_lam;
 
 	pmos_one = getnodeproto("pmos_one");
 	if (pmos_one == NONODEPROTO)
 	{
-		ttyputerr("Unable to find prototype called pmos_one");
+		ttyputerr(_("Unable to find prototype called pmos_one"));
 		return(NONODEPROTO);
 	}
 
@@ -68,7 +69,7 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 	eof = plac_read_hw(file, &height, &width, &height_in, &width_in);
 	if (eof == EOF)
 	{
-		ttyputerr("Error reading height and width");
+		ttyputerr(_("Error reading height and width"));
 		return(NONODEPROTO);
 	}
 
@@ -87,12 +88,12 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 
 	row_1[0] = -1;
 	row_2[0] = -1;
-	Y = 3*el_curtech->deflambda - Y_offset;
-	X = X_offset + 4*el_curtech->deflambda;
+	Y = 3*pla_lam - Y_offset;
+	X = X_offset + 4*pla_lam;
 	row = 0;
 	read_rows = 0;
 
-	ttyputmsg("Finished setup, about to read and generate");
+	ttyputmsg(_("Finished setup, about to read and generate"));
 	while ((read_rows < height_in) && (eof != EOF))
 	{
 		/* read in the two rows first */
@@ -112,7 +113,7 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 			/* place a pmos_one facet and connect to power, and facet up above */
 			if (((i % 5) == 0) && (i != 0)) /* put in power strap */
 			{
-				if (plac_pwr_strap(i, ((X_offset*i)+(3*el_curtech->deflambda)), Y,
+				if (plac_pwr_strap(i, ((X_offset*i)+(3*pla_lam)), Y,
 					pla_array_facet) != 0) return(NONODEPROTO);
 			} else
 			{
@@ -120,20 +121,20 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 				if ((row_1[i] == 1) && (row_1[0] != -1))
 				{
 					/* make an instance of a pmos_one  */
-					if (plac_pmos_make_one(i, ((i*X_offset)+(6*el_curtech->deflambda)), Y, 0, row,
+					if (plac_pmos_make_one(i, ((i*X_offset)+(6*pla_lam)), Y, 0, row,
 						pmos_one, pla_array_facet) != 0) return(NONODEPROTO);
 				}
 				if ((row_2[i] == 1) && (row_2[0] != -1))
 				{
 					/* make an instance of a pmos_one  */
-					if (plac_pmos_make_one(i, ((i*X_offset)+(6*el_curtech->deflambda)),
+					if (plac_pmos_make_one(i, ((i*X_offset)+(6*pla_lam)),
 						Y-Y_M_offset, 2, row, pmos_one, pla_array_facet) != 0) return(NONODEPROTO);
 				}
 			}
 		}
 
 		/* Now put the poly metal contact at on the other side of the row */
-		if (plac_pmos_complete_row(row, ((X_offset*width)+(0*el_curtech->deflambda)),
+		if (plac_pmos_complete_row(row, ((X_offset*width)+(0*pla_lam)),
 			Y, pmos_one, pla_array_facet) != 0) return(NONODEPROTO);
 
 		if ((read_rows % 4) == 0) Y = Y - Y_offset;
@@ -143,9 +144,9 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, char facet_name[])
 		row++;
 		Y = Y - 2*Y_offset;
 	}
-	X = 3*el_curtech->deflambda;
-	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset-3*el_curtech->deflambda; else
-		Y = Y + Y_offset-3*el_curtech->deflambda;
+	X = 3*pla_lam;
+	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset-3*pla_lam; else
+		Y = Y + Y_offset-3*pla_lam;
 	if (plac_pmos_finish_columns(width, X, Y, X_offset, pmos_one, pla_array_facet) != 0)
 		return(NONODEPROTO);
 
@@ -172,7 +173,7 @@ INTSML plac_pmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 			/* put in a Power pin every 5th position */
 			(void)sprintf(name, "PWR%ld.m-1.n", pwr_cnt);
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 14*el_curtech->deflambda, "Metal-1-Substrate-Con");
+				X_offset * i + X, Y, 14*pla_lam, "Metal-1-Substrate-Con");
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(1);
 			pwr_cnt++;
 		} else
@@ -180,7 +181,7 @@ INTSML plac_pmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 			/* must be a data pin, don't count power pins */
 			(void)sprintf(name, "DATA%ld.m-1.n", (i - pwr_cnt));
 			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*el_curtech->deflambda, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(1);
 		}
 		(void)newportproto(pla_array_facet, plac_col_list[i].firstitem->nodeinst,
@@ -207,8 +208,7 @@ INTSML plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 
 		/* put in Substrate contact first */
 		new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-			Y-Y_M_offset+10*el_curtech->deflambda, 14*el_curtech->deflambda,
-				"Metal-1-Substrate-Con");
+			Y-Y_M_offset+10*pla_lam, 14*pla_lam, "Metal-1-Substrate-Con");
 		if (new_item->nodeinst == NONODEINST) return(1);
 
 		/* wire in the first power strap */
@@ -216,7 +216,7 @@ INTSML plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 		/* only put this in a column list */
 		ni_col_pp = new_item->nodeinst->proto->firstportproto;
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
-		plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[0].lastitem->nodeinst,
+		plac_wire("Metal-1", 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		plac_col_list[0].lastitem->bottomitem = new_item;
@@ -228,12 +228,10 @@ INTSML plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset
 		plac_row_list[i][2].lastitem =  plac_row_list[i][2].firstitem;
 
 		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X-7*el_curtech->deflambda, Y-5*el_curtech->deflambda,
-				6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+			X-7*pla_lam, Y-5*pla_lam, 6*pla_lam, "Metal-1-Polysilicon-Con");
 		if (plac_row_list[i][0].firstitem->nodeinst == NONODEINST) return(1);
 		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
-			X-7*el_curtech->deflambda, Y-15*el_curtech->deflambda,
-				6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+			X-7*pla_lam, Y-15*pla_lam, 6*pla_lam, "Metal-1-Polysilicon-Con");
 		if (plac_row_list[i][2].firstitem->nodeinst == NONODEINST) return(1);
 
 		Y = Y - 2*Y_offset;
@@ -249,15 +247,15 @@ INTSML plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_facet)
 	new_item = plac_newUCITEM();
 
 	/* put in Substrate contact first */
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+7*el_curtech->deflambda,
-		14*el_curtech->deflambda, "Metal-1-Substrate-Con");
+	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+7*pla_lam,
+		14*pla_lam, "Metal-1-Substrate-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* wire in the first power strap and connect to last column object */
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
-	plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst,
+	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 	/* only put this in a column list */
@@ -281,7 +279,7 @@ INTSML plac_pmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG row_pos, INTBIG r
 		last_col_pp = plac_col_list[i].firstitem->nodeinst->proto->firstportproto; else
 			last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto, "OUT.m-1.s");
 
-	plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst, last_col_pp,
+	plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
 		ni, ni_col_pp, pla_array_facet);
 
 	/* connect to last GATE object */
@@ -314,7 +312,7 @@ INTSML plac_pmos_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *uc_one,
 
 	new_item = plac_newUCITEM();
 	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
-		Y+2*el_curtech->deflambda, 6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+		Y+2*pla_lam, 6*pla_lam, "Metal-1-Polysilicon-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* connect to last GATE object */
@@ -341,8 +339,8 @@ INTSML plac_pmos_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *uc_one,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-8*el_curtech->deflambda,
-		6*el_curtech->deflambda, "Metal-1-Polysilicon-Con");
+	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-8*pla_lam,
+		6*pla_lam, "Metal-1-Polysilicon-Con");
 	if (new_item->nodeinst == NONODEINST) return(1);
 
 	/* connect to last GATE object */
@@ -386,7 +384,7 @@ INTSML plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offse
 		{
 			(void)sprintf(name, "PWR%ld.m-1.s", pwr_cnt);
 			new_item->nodeinst = plac_make_Pin(pla_array_facet, X_offset * i + X, Y,
-				14*el_curtech->deflambda, "Metal-1-Substrate-Con");
+				14*pla_lam, "Metal-1-Substrate-Con");
 			if (new_item->nodeinst == NONODEINST) return(1);
 			last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 			pwr_cnt++;
@@ -395,7 +393,7 @@ INTSML plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offse
 			/* must be a data pin, don't count power pins */
 			(void)sprintf(name, "DATA%ld.m-1.s", (i - pwr_cnt));
 			new_item->nodeinst = plac_make_Pin(pla_array_facet,
-				X_offset * i + X, Y, 4*el_curtech->deflambda, "Metal-1-Pin");
+				X_offset * i + X, Y, 4*pla_lam, "Metal-1-Pin");
 			if (new_item->nodeinst == NONODEINST) return(1);
 			if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one)
 				last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto; else
@@ -407,7 +405,7 @@ INTSML plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offse
 		ni_col_pp = new_item->nodeinst->proto->firstportproto;
 
 		/* connect to last column object */
-		plac_wire("Metal-1", 4*el_curtech->deflambda, plac_col_list[i].lastitem->nodeinst,
+		plac_wire("Metal-1", 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
 			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
 
 		/* only put this in a column list */
