@@ -115,11 +115,11 @@ void ro_mimicstitch(INTSML forced)
 		if (ro_mimiccreate(ai) == 0)
 		{
 			/* nothing was wired */
-			if (forced != 0) ttyputmsg("No wires mimiced");
+			if (forced != 0) ttyputmsg(_("No wires mimiced"));
 		}
 		elapsed = endtimer();
 		if ((options&MIMICINTERACTIVE) == 0 && elapsed >= 2.0)
-			ttyputmsg("Mimicing took %g seconds", elapsed);
+			ttyputmsg(_("Mimicing took %g seconds"), elapsed);
 	}
 }
 
@@ -180,7 +180,7 @@ void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
 		deleted++;
 	}
 	if (deleted != 0)
-		ttyputmsg("MIMIC ROUTING: deleted %ld %s", deleted, makeplural("wire", deleted));
+		ttyputmsg(_("MIMIC ROUTING: deleted %ld %s"), deleted, makeplural(_("wire"), deleted));
 }
 
 /*
@@ -212,7 +212,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 		LIKELYDIFFNODETYPE|LIKELYDIFFPORT|LIKELYDIFFNODESIZE	/* different ports, node type and size */
 	};
 
-	ttyputmsg("Mimicing last arc...");
+	ttyputmsg(_("Mimicing last arc..."));
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(5, ro_aid->cluster);
@@ -259,7 +259,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 			i++;
 		}
 	}
-	if (stopping("Routing") != 0) return(count);
+	if (stopping(STOPREASONROUTING)) return(count);
 
 	/* search from both ends */
 	for(end=0; end<2; end++)
@@ -297,7 +297,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				stopcheck++;
 				if ((stopcheck%50) == 0)
 				{
-					if (stopping("Routing") != 0)
+					if (stopping(STOPREASONROUTING))
 					{
 						/* free memory for mimicing */
 						while (firstpossiblearc != NOPOSSIBLEARC)
@@ -473,7 +473,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				if (pa->situation != situations[i]) continue;
 				if (pa->x1 == pa->x2 && pa->y1 == pa->y2)
 				{
-					dist = el_curtech->deflambda;
+					dist = el_curlib->lambda[el_curtech->techindex];
 					(void)askaid(us_aid, "show-area", pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
 						(INTBIG)facet);
 				} else
@@ -482,7 +482,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				}
 				total++;
 			}
-			sprintf(question, "Create %ld %s shown here?", total, makeplural("wire", total));
+			sprintf(question, _("Create %ld %s shown here?"), total, makeplural(_("wire"), total));
 			total = ttygetparam(question, &us_yesnop, 5, pars);
 			(void)askaid(us_aid, "up-stack");
 			if (total > 0 && namesamen(pars[0], "no", strlen(pars[0])) == 0) continue;
@@ -501,7 +501,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 				pa->ni1, pa->pp1, pa->x1, pa->y1, pa->ni2, pa->pp2, pa->x2, pa->y2, facet);
 			if (newai == NOARCINST)
 			{
-				ttyputerr("Problem creating arc");
+				ttyputerr(_("Problem creating arc"));
 				return(count);
 			}
 			endobjectchange((INTBIG)newai, VARCINST);
@@ -518,7 +518,7 @@ INTBIG ro_mimiccreate(ARCINST *ai)
 		ro_freepossiblearc(pa);
 	}
 	if (count != 0)
-		ttyputmsg("MIMIC ROUTING: added %ld %s", count, makeplural("wire", count));
+		ttyputmsg(_("MIMIC ROUTING: added %ld %s"), count, makeplural(_("wire"), count));
 	return(count);
 }
 
