@@ -218,7 +218,7 @@ static KEYWORD ro_riveropt[] =
 	TERMKEY
 };
 static COMCOMP ro_riverp = {ro_riveropt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, 0, " \t", "River-routing action", 0};
+	NOBACKUP, 0, " \t", M_("River-routing action"), 0};
 
 /******** prototypes for local routines ********/
 
@@ -471,7 +471,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 	if (listp == NULLRDESC)
 	{
 		/* need at least one point */
-		ttyputerr("River router: Not enought points");
+		ttyputerr(_("River router: Not enought points"));
 		return(NO);
 	}
 
@@ -479,7 +479,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 	for(llist = listp; llist; llist=llist->next) listlast = llist;
 	if (!listlast->from || !listlast->to)
 	{
-		ttyputerr("River router: Not the same number of points");
+		ttyputerr(_("River router: Not the same number of points"));
 		return(NO);	/* not the same number of points */
 	}
 
@@ -518,7 +518,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 		val2 = ro_rrinfo.toline = ro_rrinfo.toline*tmatrix->t22;
 	} else
 	{
-		ttyputerr("River router: Not between two parallel lines");
+		ttyputerr(_("River router: Not between two parallel lines"));
 		return(NO);		/* not on manhattan parallel lines */
 	}
 
@@ -534,7 +534,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			if ((llist->from->x > llist->next->from->x && llist->to->x < llist->next->to->x) ||
 				(llist->from->x < llist->next->from->x && llist->to->x > llist->next->to->x))
 			{
-				ttyputerr("River router: Connections may not cross");
+				ttyputerr(_("River router: Connections may not cross"));
 				return(NO);
 			}
 		} else
@@ -542,7 +542,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			if ((llist->from->y > llist->next->from->y && llist->to->y < llist->next->to->y) ||
 				(llist->from->y < llist->next->from->y && llist->to->y > llist->next->to->y))
 			{
-				ttyputerr("River router: Connections may not cross");
+				ttyputerr(_("River router: Connections may not cross"));
 				return(NO);
 			}
 		}
@@ -571,7 +571,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			diff1 = abs(lastfrom->first - llist->from->first);
 			if (diff1 < width+space)
 			{
-				ttyputerr("River router: Ports not design rule distance apart");
+				ttyputerr(_("River router: Ports not design rule distance apart"));
 				return(NO);
 			}
 		}
@@ -580,7 +580,7 @@ INTSML ro_check_points(RDESC *listp, INTBIG width, INTBIG space)
 			diff2 = abs(lastto->first - llist->to->first);
 			if (diff2 < width+space)
 			{
-				ttyputerr("River router: Ports not design rule distance apart");
+				ttyputerr(_("River router: Ports not design rule distance apart"));
 				return(NO);
 			}
 		}		/* not far enough apart */
@@ -646,12 +646,12 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			default:
 			case SIDE2:
 			case SIDE3:
-				ttyputerr("River router: Improper sides for bottom right ports");
+				ttyputerr(_("River router: Improper sides for bottom right ports"));
 				return(NO);
 			case SIDE4:
 				if (fromside1)
 				{
-					ttyputerr("River router: Improper ordering of bottom right ports");
+					ttyputerr(_("River router: Improper ordering of bottom right ports"));
 					return(NO);
 				}
 				break;
@@ -661,7 +661,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE1:
 			case SIDE4:
 			default:
-				ttyputerr("River router: Improper sides for top right ports");
+				ttyputerr(_("River router: Improper sides for top right ports"));
 				return(NO);
 			case SIDE2:
 				if (!toside2) botoffs2 = ro_rrinfo.fromline+co1+(width/2);
@@ -671,7 +671,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE3:
 				if (toside2)
 				{
-					ttyputerr("River router: Improper ordering of top right ports");
+					ttyputerr(_("River router: Improper ordering of top right ports"));
 					return(NO);
 				}
 				break;
@@ -686,7 +686,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE1:
 				if (fromside2)
 				{
-					ttyputerr("River router: Improper Ordering of Bottom Left Ports");
+					ttyputerr(_("River router: Improper Ordering of Bottom Left Ports"));
 					return(NO);
 				}
 				break;
@@ -696,7 +696,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE3:
 			case SIDE4:
 			default:
-				ttyputerr("River router: Improper sides for Bottom Left Ports");
+				ttyputerr(_("River router: Improper sides for Bottom Left Ports"));
 				return(NO);
 		}
 		switch (l->to->side)
@@ -704,7 +704,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 			case SIDE1:
 			case SIDE2:
 			default:
-				ttyputerr("River router: Improper sides for Top Left Ports");
+				ttyputerr(_("River router: Improper sides for Top Left Ports"));
 				return(NO);
 			case SIDE3:
 				toside3 = YES;
@@ -716,7 +716,7 @@ INTSML ro_check_structured_points(RDESC *right, RDESC *left, INTBIG co1, INTBIG
 						else botoffs4 += space+width;
 				} else
 				{
-					ttyputerr("River router: Improper Ordering of Top Left Ports");
+					ttyputerr(_("River router: Improper Ordering of Top Left Ports"));
 					return(NO);
 				}
 				toside4 = YES;
@@ -1090,7 +1090,7 @@ INTSML ro_sorted_rivrot(ARCPROTO *layerdesc, RDESC *listr, INTBIG width,
 	if (fixedheight > 0 && height > fixedheight)
 	{
 		/* can't make it in fixed height */
-		ttyputerr("River router: Unable to route in %s wide channel, need %s", latoa(fixedheight),
+		ttyputerr(_("River router: Unable to route in %s wide channel, need %s"), latoa(fixedheight),
 			latoa(height));
 		return(NO);
 	}
@@ -1208,7 +1208,6 @@ void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
 {
 	RPATH *path;
 	REGISTER RPOINT *rp, *prev;
-	extern AIDENTRY *us_aid;
 
 	path = rd->path;
 
@@ -1233,9 +1232,8 @@ void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
 void ro_makepseudogeometry(NODEPROTO *facet)
 {
 	RDESC *q;
-	extern AIDENTRY *us_aid;
 
-	ttyputmsg("Routing bounds %s <= X <= %s   %s <= Y <= %s", latoa(ro_rrinfo.llx),
+	ttyputmsg(_("Routing bounds %s <= X <= %s   %s <= Y <= %s"), latoa(ro_rrinfo.llx),
 		latoa(ro_rrinfo.urx), latoa(ro_rrinfo.lly), latoa(ro_rrinfo.ury));
 
 	/* remove highlighting */
@@ -1428,7 +1426,7 @@ void ro_kill_wires(NODEPROTO *np)
 		{
 			startobjectchange((INTBIG)ai, VARCINST);
 			if (killarcinst(ai))
-				ttyputmsg("River router: Error occured while killing arc");
+				ttyputmsg(_("River router: Error occured while killing arc"));
 		}
 	}
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1436,7 +1434,7 @@ void ro_kill_wires(NODEPROTO *np)
 		if (ni->temp1 != 0 && ro_isunroutedpin(ni))
 		{
 			if (ro_delnodeinst(ni))
-				ttyputmsg("River router: Error occured while killing node");
+				ttyputmsg(_("River router: Error occured while killing node"));
 		}
 	}
 }
@@ -1444,7 +1442,6 @@ void ro_kill_wires(NODEPROTO *np)
 void ro_makethegeometry(NODEPROTO *np)
 {
 	RDESC *q;
-	extern AIDENTRY *us_aid;
 
 	(void)askaid(us_aid, "clear");
 	ro_clear_flags(np);
@@ -1610,7 +1607,7 @@ void ro_swap_points(RDESC *r)
 	INTBIG tmpe;
 
 	if (r->from->side != SIDE1 || r->to->side != SIDE3)
-		ttyputerr("River router: Unexpected side designation");
+		ttyputerr(_("River router: Unexpected side designation"));
 
 	tmp = r->from;   r->from = r->to;
 	r->to = tmp;
@@ -1699,7 +1696,6 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTSML *tot)
 	GEOM **list;
 	ARCINST *ai;
 	INTSML i, total, wireadded;
-	extern AIDENTRY *us_aid;
 
 	/* get list of all highlighted arcs */
 	list = (GEOM **)askaid(us_aid, "get-all-arcs");
@@ -1773,16 +1769,15 @@ INTSML ro_findwires(NODEPROTO *np)
 	INTSML total;
 	RDESC *thelist;
 	REGISTER VARIABLE *var;
-	extern AIDENTRY *us_aid;
 
 	ro_initialize();
 	if (np->primindex != 0)
 	{
-		ttyputerr("River router cannot route primitives");
+		ttyputerr(_("River router cannot route primitives"));
 		return(NO);
 	}
 
-	curtech = whattech(np);
+	curtech = np->tech;
 
 	/* initialize the list of possible arc prototypes for routing */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -1830,10 +1825,10 @@ INTSML ro_findwires(NODEPROTO *np)
 
 	if (wantap == NOARCPROTO)
 	{
-		ttyputerr("River router: Cannot find arc that will connect");
+		ttyputerr(_("River router: Cannot find arc that will connect"));
 		return(NO);
 	}
-	ttyputmsg("River routing with %s arcs", describearcproto(wantap));
+	ttyputmsg(_("River routing with %s arcs"), describearcproto(wantap));
 
 	ro_figureoutrails(total);   ro_set_wires_to_rails(thelist);
 
@@ -1845,8 +1840,8 @@ INTSML ro_findwires(NODEPROTO *np)
 	ai->length = 10000;
 	(void)arcpolys(ai);
 	shapearcpoly(ai, 0, poly);
-	amt = drcmindistance(ai->proto->tech, poly->layer, poly->layer, 0);
-	if (amt < 0) amt = ai->proto->tech->deflambda;
+	amt = drcmindistance(ai->proto->tech, np->cell->lib, poly->layer, poly->layer, 0);
+	if (amt < 0) amt = lambdaofarc(ai);
 	return(ro_unsorted_rivrot(wantap, thelist, ai->width, amt, amt, amt, 0));
 }
 
@@ -1858,7 +1853,7 @@ INTSML ro_move_instance(void)
 	ni = ro_rrmovefacet.topfacet;
 	if (ro_rrmovefacet.facetvalid != CVALID || ni == NONODEINST)
 	{
-		ttyputmsg("River router: Cannot determine facet to move");
+		ttyputmsg(_("River router: Cannot determine facet to move"));
 		return(NO);
 	}
 
@@ -1879,7 +1874,7 @@ INTSML ro_query_user(void)
 	/* wait for user response */
 	for(;;)
 	{
-		count = ttygetparam("River-route option: ", &ro_riverp, MAXPARS, par);
+		count = ttygetparam(_("River-route option: "), &ro_riverp, MAXPARS, par);
 		if (count == 0) continue;
 		switch (par[0][0])
 		{
