@@ -61,7 +61,7 @@ int Sc_extract(int count, char *pars[])
 	char	buf[40];
 
 	if (sc_curcell == NULL)
-		return( Sc_seterrmsg(SC_NOCELL) );
+		return(Sc_seterrmsg(SC_NOCELL));
 	sc_curcell->nilist = NULL;
 	Sc_make_nilist(sc_curcell->niroot, sc_curcell);
 	Sc_extract_clear_flag(sc_curcell->nilist);
@@ -72,7 +72,7 @@ int Sc_extract(int count, char *pars[])
 			return(err);
 
 	/* get ground nodes */
-	sc_curcell->ground = (SCEXTNODE *)emalloc( sizeof(SCEXTNODE), sc_aid->cluster);
+	sc_curcell->ground = (SCEXTNODE *)emalloc(sizeof(SCEXTNODE), sc_aid->cluster);
 	if (sc_curcell->ground == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	if (allocstring(&sc_curcell->ground->name, "ground", sc_aid->cluster))
@@ -118,7 +118,7 @@ int Sc_extract(int count, char *pars[])
 		plist->port->ext_node = sc_curcell->ground;
 
 	/* get power nodes */
-	sc_curcell->power = (SCEXTNODE *)emalloc( sizeof(SCEXTNODE), sc_aid->cluster);
+	sc_curcell->power = (SCEXTNODE *)emalloc(sizeof(SCEXTNODE), sc_aid->cluster);
 	if (sc_curcell->power == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	if (allocstring(&sc_curcell->power->name, "power", sc_aid->cluster))
@@ -268,7 +268,7 @@ int Sc_extract_snake(SCNITREE *nodeA, SCNIPORT *portA, SCCONLIST *cl, SCEXTNODE
 			continue;
 		if (portA && portA->ext_node)
 		{
-			if ( !(cl->portB && cl->portB->ext_node) )
+			if (!(cl->portB && cl->portB->ext_node))
 			{
 				if ((err = Sc_extract_add_node(portA->ext_node, cl->nodeB,
 					cl->portB, simnode, &common)))
@@ -401,7 +401,7 @@ void Sc_extract_find_power(SCNITREE *ntp, SCCELL *vars)
 					}
 					for (port = ntp->power; port; port = port->next)
 					{
-						plist = (SCEXTPORT *)emalloc( sizeof(SCEXTPORT), sc_aid->cluster);
+						plist = (SCEXTPORT *)emalloc(sizeof(SCEXTPORT), sc_aid->cluster);
 						if (plist == 0)
 						{
 							(void)Sc_seterrmsg(SC_NOMEMORY);
@@ -439,13 +439,13 @@ void Sc_extract_print_nodes(SCCELL *vars)
 	i = 0;
 	if (vars->ground)
 	{
-		ttyputmsg("Node %d  %s:", i, vars->ground->name);
+		ttyputmsg(_("Node %d  %s:"), i, vars->ground->name);
 		for (plist = vars->ground->firstport; plist; plist = plist->next)
 		{
 			switch (plist->node->type)
 			{
 				case SCSPECIALCELL:
-					portname = "Special";
+					portname = _("Special");
 					break;
 				case SCCOMPLEXCELL:
 					portname = ((SCPORT *)(plist->port->port))->name;
@@ -454,7 +454,7 @@ void Sc_extract_print_nodes(SCCELL *vars)
 					portname = Sc_leaf_port_name(plist->port->port);
 					break;
 				default:
-					portname = "Unknown";
+					portname = _("Unknown");
 					break;
 			}
 			ttyputmsg("    %-20s    %s", plist->node->name, portname);
@@ -464,13 +464,13 @@ void Sc_extract_print_nodes(SCCELL *vars)
 
 	if (vars->power)
 	{
-		ttyputmsg("Node %d  %s:", i, vars->power->name);
+		ttyputmsg(_("Node %d  %s:"), i, vars->power->name);
 		for (plist = vars->power->firstport; plist; plist = plist->next)
 		{
 			switch (plist->node->type)
 			{
 				case SCSPECIALCELL:
-					portname = "Special";
+					portname = _("Special");
 					break;
 				case SCCOMPLEXCELL:
 					portname = ((SCPORT *)(plist->port->port))->name;
@@ -479,7 +479,7 @@ void Sc_extract_print_nodes(SCCELL *vars)
 					portname = Sc_leaf_port_name(plist->port->port);
 					break;
 				default:
-					portname = "Unknown";
+					portname = _("Unknown");
 					break;
 			}
 			ttyputmsg("    %-20s    %s", plist->node->name, portname);
@@ -489,13 +489,13 @@ void Sc_extract_print_nodes(SCCELL *vars)
 
 	for (simnode = vars->ex_nodes; simnode; simnode = simnode->next)
 	{
-		ttyputmsg("Node %d  %s:", i, simnode->name);
+		ttyputmsg(_("Node %d  %s:"), i, simnode->name);
 		for (plist = simnode->firstport; plist; plist = plist->next)
 		{
 			switch (plist->node->type)
 			{
 				case SCSPECIALCELL:
-					portname = "Special";
+					portname = _("Special");
 					break;
 				case SCCOMPLEXCELL:
 					portname = ((SCPORT *)(plist->port->port))->name;
@@ -504,7 +504,7 @@ void Sc_extract_print_nodes(SCCELL *vars)
 					portname = Sc_leaf_port_name(plist->port->port);
 					break;
 				default:
-					portname = "Unknown";
+					portname = _("Unknown");
 					break;
 			}
 			ttyputmsg("    %-20s    %s", plist->node->name, portname);
@@ -539,11 +539,11 @@ int Sc_extract_collect_unconnected(SCNITREE *nptr, SCCELL *cell)
 				{
 					if (port->ext_node == NULL)
 					{
-						ext = (SCEXTNODE *)emalloc( sizeof(SCEXTNODE), sc_aid->cluster);
+						ext = (SCEXTNODE *)emalloc(sizeof(SCEXTNODE), sc_aid->cluster);
 						if (ext == 0)
 							return(Sc_seterrmsg(SC_NOMEMORY));
 						ext->name = (char *)NULL;
-						eport = (SCEXTPORT *)emalloc( sizeof(SCEXTPORT), sc_aid->cluster);
+						eport = (SCEXTPORT *)emalloc(sizeof(SCEXTPORT), sc_aid->cluster);
 						if (eport == 0)
 						{
 							efree((char *)ext);
