@@ -40,17 +40,17 @@
 
 static char *sc_placeblerb[] =
 {
-	"************ QUISC PLACEMENT MODULE - VERSION 1.00",
-	"Cluster Tree Creation:",
-	"    o  Maxi-cut Algorithm",
-	"    o  Minimum use for best pair choice for equal weight",
-	"Cluster Tree Sorting:",
-	"    o  Top-down cluster tree sort",
-	"    o  Bottom-up cluster tree sort",
-	"Net Balancing:",
-	"    o  Independent routing channels",
-	"    o  Cross refencing of trunks to improve speed",
-	"    o  Effective calculation of rows in costing",
+	N_("************ QUISC PLACEMENT MODULE - VERSION 1.00"),
+	N_("Cluster Tree Creation:"),
+	N_("    o  Maxi-cut Algorithm"),
+	N_("    o  Minimum use for best pair choice for equal weight"),
+	N_("Cluster Tree Sorting:"),
+	N_("    o  Top-down cluster tree sort"),
+	N_("    o  Bottom-up cluster tree sort"),
+	N_("Net Balancing:"),
+	N_("    o  Independent routing channels"),
+	N_("    o  Cross refencing of trunks to improve speed"),
+	N_("    o  Effective calculation of rows in costing"),
 	0
 } ;
 
@@ -151,22 +151,22 @@ int Sc_place(int count, char *pars[])
 		l = strlen(pars[0]);
 		l = maxi(l, 2);
 		if (namesamen(pars[0], "set-control", l) == 0)
-			return( Sc_place_set_control(count - 1, &pars[1]) );
+			return(Sc_place_set_control(count - 1, &pars[1]));
 		if (namesamen(pars[0], "show-control", l) == 0)
 		{
 			Sc_place_show_control();
 			return(SC_NOERROR);
 		}
-		return( Sc_seterrmsg(SC_PLACE_XCMD, pars[0]) );
+		return(Sc_seterrmsg(SC_PLACE_XCMD, pars[0]));
 	}
 
 	/* check to see if currently working in a cell */
 	if (sc_curcell == NULL)
-		return( Sc_seterrmsg(SC_NOCELL) );
+		return(Sc_seterrmsg(SC_NOCELL));
 
 	/* create placement structure */
 	(void)Sc_free_placement(sc_curcell->placement);
-	place = (SCPLACE *)emalloc( sizeof(SCPLACE), sc_aid->cluster);
+	place = (SCPLACE *)emalloc(sizeof(SCPLACE), sc_aid->cluster);
 	if (place == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	sc_curcell->placement = place;
@@ -182,10 +182,10 @@ int Sc_place(int count, char *pars[])
 
 	/* DO PLACEMENT */
 	for (i = 0; sc_placeblerb[i]; i++)
-		ttyputverbose(sc_placeblerb[i]);
+		ttyputverbose(_(sc_placeblerb[i]));
 	if (sc_placecontrol.stats_flag)
 		Sc_place_show_control();
-	ttyputmsg("Starting PLACEMENT...");
+	ttyputmsg(_("Starting PLACEMENT..."));
 	(void)Sc_cpu_time(TIME_RESET);
 
 	/* create clusters of cells */
@@ -195,7 +195,7 @@ int Sc_place(int count, char *pars[])
 
 	if (sc_gcluster == NULL)
 	{
-		ttyputmsg("ERROR - No cells found to place.  Aborting.");
+		ttyputmsg(_("ERROR - No cells found to place.  Aborting."));
 		return(SC_NOERROR);
 	}
 
@@ -215,11 +215,11 @@ int Sc_place(int count, char *pars[])
 		sc_curcell)))
 			return(err);
 	efree((char *)cllist);
-	ttyputverbose("    Time to create Cluster Tree  =  %s seconds.",
+	ttyputverbose(_("    Time to create Cluster Tree  =  %s seconds."),
 		Sc_cpu_time(TIME_REL));
 	if (sc_placecontrol.stats_flag)
 	{
-		ttyputmsg("************ Initial placement of Clusters");
+		ttyputmsg(_("************ Initial placement of Clusters"));
 		Sc_place_print_cluster_tree(sc_gcluster_tree, 0);
 	}
 	place->size_rows = place->size_inst / place->num_rows;
@@ -231,13 +231,13 @@ int Sc_place(int count, char *pars[])
 			return(err);
 		if (sc_placecontrol.stats_flag)
 		{
-			ttyputmsg("************ Placement of Clusters after Sorting");
+			ttyputmsg(_("************ Placement of Clusters after Sorting"));
 			Sc_place_print_cluster_tree(sc_gcluster_tree, 0);
 		}
 	}
 
 	/* create first row structure */
-	row = (SCROWLIST *)emalloc( sizeof(SCROWLIST), sc_aid->cluster);
+	row = (SCROWLIST *)emalloc(sizeof(SCROWLIST), sc_aid->cluster);
 	if (row == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	row->start = NULL;
@@ -256,7 +256,7 @@ int Sc_place(int count, char *pars[])
 	Sc_place_number_placement(sc_curcell->placement->rows);
 	if (sc_placecontrol.stats_flag)
 	{
-		ttyputmsg("************ Placement before Net Balancing");
+		ttyputmsg(_("************ Placement before Net Balancing"));
 		Sc_place_show_placement(sc_curcell->placement->rows);
 	}
 	Sc_free_cluster_tree(sc_gcluster_tree);
@@ -267,18 +267,18 @@ int Sc_place(int count, char *pars[])
 		if ((err = Sc_place_net_balance(sc_curcell->placement->rows,
 			sc_curcell)))
 				return(err);
-		ttyputmsg("    Time to do Net Balancing =  %s seconds.",
+		ttyputmsg(_("    Time to do Net Balancing =  %s seconds."),
 			Sc_cpu_time(TIME_REL));
 		if (sc_placecontrol.stats_flag)
 		{
-			ttyputmsg("************ Placement after Net Balancing");
+			ttyputmsg(_("************ Placement after Net Balancing"));
 			Sc_place_show_placement(sc_curcell->placement->rows);
 		}
 	}
 
 	/* print process time for placement */
 	Sc_place_reorder_rows(sc_curcell->placement->rows);
-	ttyputmsg("Done (time = %s seconds)", Sc_cpu_time(TIME_ABS));
+	ttyputmsg(_("Done (time = %s seconds)"), Sc_cpu_time(TIME_ABS));
 
 	return(SC_NOERROR);
 }
@@ -373,11 +373,11 @@ int Sc_place_set_control(int count, char *pars[])
 				sc_placecontrol.net_balance_flag = FALSE;
 				continue;
 			}
-			return( Sc_seterrmsg(SC_PLACE_SET_XCMD, pars[numcmd]) );
+			return(Sc_seterrmsg(SC_PLACE_SET_XCMD, pars[numcmd]));
 		}
 	} else
 	{
-		return( Sc_seterrmsg(SC_PLACE_SET_NOCMD) );
+		return(Sc_seterrmsg(SC_PLACE_SET_NOCMD));
 	}
 
 	Sc_place_show_control();
@@ -398,35 +398,35 @@ void Sc_place_show_control(void)
 {
 	char	*str1;
 
-	ttyputverbose("************ PLACEMENT CONTROL STRUCTURE");
+	ttyputverbose(_("************ PLACEMENT CONTROL STRUCTURE"));
 	if (sc_placecontrol.stats_flag)
 	{
-		str1 = "TRUE";
+		str1 = _("TRUE");
 	} else
 	{
-		str1 = "FALSE";
+		str1 = _("FALSE");
 	}
-	ttyputverbose("Print statistics  =  %-s", str1);
+	ttyputverbose(_("Print statistics  =  %-s"), str1);
 	if (sc_placecontrol.sort_flag)
 	{
-		str1 = "TRUE";
+		str1 = _("TRUE");
 	} else
 	{
-		str1 = "FALSE";
+		str1 = _("FALSE");
 	}
-	ttyputverbose("Sort cluster tree =  %-s", str1);
-	ttyputverbose("Number of rows    =  %d", ScGetParameter(SC_PARAM_PLACE_NUM_ROWS));
+	ttyputverbose(_("Sort cluster tree =  %-s"), str1);
+	ttyputverbose(_("Number of rows    =  %d"), ScGetParameter(SC_PARAM_PLACE_NUM_ROWS));
 	if (sc_placecontrol.net_balance_flag)
 	{
-		str1 = "TRUE";
+		str1 = _("TRUE");
 	} else
 	{
-		str1 = "FALSE";
+		str1 = _("FALSE");
 	}
-	ttyputverbose("Net balancing     =  %-s", str1);
-	ttyputverbose("Net balace limit  =  %d",
+	ttyputverbose(_("Net balancing     =  %-s"), str1);
+	ttyputverbose(_("Net balace limit  =  %d"),
 		sc_placecontrol.net_balance_limit);
-	ttyputverbose("Vertical cost X   =  %d",
+	ttyputverbose(_("Vertical cost X   =  %d"),
 		sc_placecontrol.vertical_cost);
 }
 
@@ -458,18 +458,18 @@ int Sc_place_create_clusters(SCCLUSTER **clusters, SCCELL *cell)
 	Sc_place_total_cell_size(cell->nilist, &num, &size, &height);
 	if (!num)
 	{
-		ttyputmsg("WARNING - No leaf cells found for placement.");
+		ttyputmsg(_("WARNING - No leaf cells found for placement."));
 		return(SC_NOERROR);
 	}
 	avg_size = size / num;
 	avg_height = height / num;
 	if (sc_placecontrol.stats_flag)
 	{
-		ttyputmsg("************ Cell Statistics");
-		ttyputmsg("    Number of cells         = %d", num);
-		ttyputmsg("    Total length            = %d", size);
-		ttyputmsg("    Average size of cells   = %d", avg_size);
-		ttyputmsg("    Average height of cells = %d", avg_height);
+		ttyputmsg(_("************ Cell Statistics"));
+		ttyputmsg(_("    Number of cells         = %d"), num);
+		ttyputmsg(_("    Total length            = %d"), size);
+		ttyputmsg(_("    Average size of cells   = %d"), avg_size);
+		ttyputmsg(_("    Average height of cells = %d"), avg_height);
 	}
 	cell->placement->num_inst = num;
 	cell->placement->size_inst = size;
@@ -488,7 +488,7 @@ int Sc_place_create_clusters(SCCLUSTER **clusters, SCCELL *cell)
 				warn = TRUE;
 			continue;
 		}
-		cluster = (SCCLUSTER *)emalloc( sizeof(SCCLUSTER), sc_aid->cluster);
+		cluster = (SCCLUSTER *)emalloc(sizeof(SCCLUSTER), sc_aid->cluster);
 		if (cluster == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		cluster->node = node;
@@ -502,8 +502,8 @@ int Sc_place_create_clusters(SCCLUSTER **clusters, SCCELL *cell)
 	}
 	if (warn)
 	{
-		ttyputmsg("WARNING - At least one complex cell found during Create_Clusters.");
-		ttyputmsg("        - Probable cause:  Forgot to do 'PULL' command.");
+		ttyputmsg(_("WARNING - At least one complex cell found during Create_Clusters."));
+		ttyputmsg(_("        - Probable cause:  Forgot to do 'PULL' command."));
 	}
 
 	*clusters = clusterlist;
@@ -575,7 +575,7 @@ int Sc_place_create_cluster_tree(SCCLUSTERTREE **ctree, SCCLUSTER *clusters[],
 	nstart = NULL;
 	for (i = 0; i < size; i++)
 	{
-		node = (SCCLUSTERTREE *)emalloc( sizeof(SCCLUSTERTREE), sc_aid->cluster);
+		node = (SCCLUSTERTREE *)emalloc(sizeof(SCCLUSTERTREE), sc_aid->cluster);
 		if (node == 0)
 		{
 			return(Sc_seterrmsg(SC_NOMEMORY));
@@ -651,7 +651,7 @@ int Sc_place_create_ctree_recurse(SCCLUSTERTREE **aroot, SCCLUSTERTREE *nodes,
 		return(err);
 
 	/* recurse up a level */
-	return( Sc_place_create_ctree_recurse(aroot, nstart, cell) );
+	return(Sc_place_create_ctree_recurse(aroot, nstart, cell));
 }
 
 /***********************************************************************
@@ -724,9 +724,9 @@ int Sc_place_ctree_num_connects(SCCLUSTERTREE *nodes, SCCLCONNECT **clist, SCCEL
 
 			if (common)
 			{
-				newcon = (SCCLCONNECT *)emalloc( sizeof(SCCLCONNECT), sc_aid->cluster);
+				newcon = (SCCLCONNECT *)emalloc(sizeof(SCCLCONNECT), sc_aid->cluster);
 				if (newcon == NULL)
-					return( Sc_seterrmsg(SC_NOMEMORY) );
+					return(Sc_seterrmsg(SC_NOMEMORY));
 				newcon->node[0] = nodes;
 				newcon->node[1] = nextnode;
 				newcon->count = common;
@@ -873,7 +873,7 @@ int Sc_place_ctree_sort_connects(SCCLCONNECT *list, SCCLCONNECT **gstart)
 	if (list)
 	{
 		pold = list;
-		for (pp = list->next; pp; )
+		for (pp = list->next; pp;)
 		{
 			if (pp->count > pold->count)
 			{
@@ -942,7 +942,7 @@ int Sc_place_ctree_pair(SCCLUSTERTREE *nodes, SCCLCONNECT *nconnects,
 
 	/* go through connection list */
 	newstart = NULL;
-	for (connect = nconnects; connect; )
+	for (connect = nconnects; connect;)
 	{
 		/* if either placed, continue */
 		if (connect->node[0]->bits & SCBITS_PLACED ||
@@ -991,10 +991,10 @@ int Sc_place_ctree_pair(SCCLUSTERTREE *nodes, SCCLCONNECT *nconnects,
 	if (!nconnects)
 	{
 		/* create new cluster tree node */
-		newnode = (SCCLUSTERTREE *)emalloc( sizeof(SCCLUSTERTREE), sc_aid->cluster);
+		newnode = (SCCLUSTERTREE *)emalloc(sizeof(SCCLUSTERTREE), sc_aid->cluster);
 		if (newnode == 0)
 		{
-			return( Sc_seterrmsg(SC_NOMEMORY) );
+			return(Sc_seterrmsg(SC_NOMEMORY));
 		}
 		newnode->cluster = NULL;
 		newnode->bits = 0;
@@ -1012,13 +1012,13 @@ int Sc_place_ctree_pair(SCCLUSTERTREE *nodes, SCCLCONNECT *nconnects,
 	/* add any remaining tree nodes as singular nodes */
 	for (tptr = nodes; tptr; tptr = tptr->next)
 	{
-		if ( !(tptr->bits & SCBITS_PLACED) )
+		if (!(tptr->bits & SCBITS_PLACED))
 		{
 			/* create new cluster tree node */
-			newnode = (SCCLUSTERTREE *)emalloc( sizeof(SCCLUSTERTREE), sc_aid->cluster);
+			newnode = (SCCLUSTERTREE *)emalloc(sizeof(SCCLUSTERTREE), sc_aid->cluster);
 			if (newnode == 0)
 			{
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			}
 			newnode->cluster = NULL;
 			newnode->bits = 0;
@@ -1086,9 +1086,9 @@ int Sc_place_best_pair(SCCLCONNECT *connect, SCCLCONNECT **bconnect)
 			nlist->count++;
 		} else
 		{
-			nlist = (struct Itemp *)emalloc( sizeof(struct Itemp), sc_aid->cluster);
+			nlist = (struct Itemp *)emalloc(sizeof(struct Itemp), sc_aid->cluster);
 			if (nlist == NULL)
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			nlist->node = nconnect->node[0];
 			nlist->count = 1;
 			nlist->ref = nconnect;
@@ -1105,9 +1105,9 @@ int Sc_place_best_pair(SCCLCONNECT *connect, SCCLCONNECT **bconnect)
 			nlist->count++;
 		} else
 		{
-			nlist = (struct Itemp *)emalloc( sizeof(struct Itemp), sc_aid->cluster);
+			nlist = (struct Itemp *)emalloc(sizeof(struct Itemp), sc_aid->cluster);
 			if (nlist == NULL)
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			nlist->node = nconnect->node[1];
 			nlist->count = 1;
 			nlist->ref = nconnect;
@@ -1177,7 +1177,7 @@ void Sc_place_print_cluster_tree(SCCLUSTERTREE *node, int level)
 	}
 	if (node->cluster)
 	{
-		ttyputmsg("%sCell %s", spacer, node->cluster->node->name);
+		ttyputmsg(_("%sCell %s"), spacer, node->cluster->node->name);
 	} else
 	{
 		ttyputmsg("%s%-2d**%s", spacer, level, trailer);
@@ -1229,23 +1229,23 @@ int Sc_place_sort_cluster_tree(SCCLUSTERTREE *ctree, SCCELL *cell)
 
 	sc_currentcost = Sc_place_cost_cluster_tree(sc_gcluster_tree, trunks, cell);
 	if (sc_placecontrol.stats_flag)
-		ttyputverbose("***** Cost of placement before cluster sorting = %d",
+		ttyputverbose(_("***** Cost of placement before cluster sorting = %d"),
 			sc_currentcost);
 
 	/* call top-down swapper */
 	if ((err = Sc_place_sort_swapper_top_down(ctree, trunks, cell)))
 		return(err);
-	ttyputverbose("    Time for Top-Down Sort       =  %s seconds.",
+	ttyputverbose(_("    Time for Top-Down Sort       =  %s seconds."),
 		Sc_cpu_time(TIME_REL));
 
 	/* call bottom-up swapper */
 	if ((err = Sc_place_sort_swapper_bottom_up(ctree, trunks, cell)))
 		return(err);
-	ttyputverbose("    Time for Bottom_Up Sort      =  %s seconds.",
+	ttyputverbose(_("    Time for Bottom_Up Sort      =  %s seconds."),
 		Sc_cpu_time(TIME_REL));
 
 	if (sc_placecontrol.stats_flag)
-		ttyputverbose("***** Cost of placement after cluster sorting = %d",
+		ttyputverbose(_("***** Cost of placement after cluster sorting = %d"),
 			sc_currentcost);
 
 	for (newtrunk = trunks; newtrunk; newtrunk = nexttrunk)
@@ -1448,9 +1448,9 @@ int Sc_place_cost_cluster_tree(SCCLUSTERTREE *ctree, SCNBTRUNK *trunks, SCCELL *
 
 	for (pport = cell->ports; pport; pport = pport->next)
 	{
-		if ( !(pport->bits & SCPORTDIRMASK) )
+		if (!(pport->bits & SCPORTDIRMASK))
 			continue;
-		if ( !(ntrunk = (SCNBTRUNK *)pport->node->ports->ext_node->ptr) )
+		if (!(ntrunk = (SCNBTRUNK *)pport->node->ports->ext_node->ptr))
 			continue;
 		if (pport->bits & SCPORTDIRUP)
 		{
@@ -1520,7 +1520,7 @@ void Sc_place_cost_cluster_tree_2(SCCLUSTERTREE *ctree, SCNBTRUNK *trunks, int *
 	{
 		for (port = ctree->cluster->node->ports; port; port = port->next)
 		{
-			if ( !(ntrunk = (SCNBTRUNK *)port->ext_node->ptr) )
+			if (!(ntrunk = (SCNBTRUNK *)port->ext_node->ptr))
 				continue;
 			if (ntrunk->minx < 0)
 				ntrunk->minx = *pos + port->xpos;
@@ -1607,7 +1607,7 @@ int Sc_place_add_cluster_to_row(SCCLUSTER *cluster, SCROWLIST *row, SCPLACE *pla
 
 	if (cluster->node->type != SCLEAFCELL)
 		return(SC_NOERROR);
-	newplace = (SCNBPLACE *)emalloc( sizeof(SCNBPLACE), sc_aid->cluster);
+	newplace = (SCNBPLACE *)emalloc(sizeof(SCNBPLACE), sc_aid->cluster);
 	if (newplace == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	newplace->cell = cluster->node;
@@ -1626,9 +1626,9 @@ int Sc_place_add_cluster_to_row(SCCLUSTER *cluster, SCROWLIST *row, SCPLACE *pla
 	old_condition = place->size_rows - row->row_size;
 	new_condition = place->size_rows - (row->row_size + cluster->node->size);
 	if ((row->row_num + 1) < place->num_rows &&
-		abs(old_condition) < abs(new_condition) )
+		abs(old_condition) < abs(new_condition))
 	{
-		row2 = (SCROWLIST *)emalloc( sizeof(SCROWLIST), sc_aid->cluster);
+		row2 = (SCROWLIST *)emalloc(sizeof(SCROWLIST), sc_aid->cluster);
 		if (row2 == 0)
 			return(Sc_seterrmsg(SC_NOMEMORY));
 		row2->start = NULL;
@@ -1723,7 +1723,7 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 		/* create trunk list for each channel */
 		for (nlist = cell->ex_nodes; nlist; nlist = nlist->next)
 		{
-			ntrunk = (SCNBTRUNK *)emalloc( sizeof(SCNBTRUNK), sc_aid->cluster);
+			ntrunk = (SCNBTRUNK *)emalloc(sizeof(SCNBTRUNK), sc_aid->cluster);
 			if (ntrunk == NULL)
 				return(Sc_seterrmsg(SC_NOMEMORY));
 			ntrunk->ext_node = nlist;
@@ -1765,7 +1765,7 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 
 	/* report current placement evaluation */
 	if (sc_placecontrol.stats_flag)
-		ttyputmsg("Evaluation before Net-Balancing  = %d",
+		ttyputmsg(_("Evaluation before Net-Balancing  = %d"),
 			Sc_place_nb_cost(cell->placement->rows, channel, cell));
 
 	/* do the net balance for each cell */
@@ -1778,7 +1778,7 @@ int Sc_place_net_balance(SCROWLIST *row, SCCELL *cell)
 
 	/* report new evaluation */
 	if (sc_placecontrol.stats_flag)
-		ttyputmsg("Evaluation after Net-Balancing   = %d",
+		ttyputmsg(_("Evaluation after Net-Balancing   = %d"),
 			Sc_place_nb_cost(cell->placement->rows, channel, cell));
 
 	for (newchan = channel; newchan; newchan = nextnewchan)
@@ -2019,7 +2019,7 @@ int Sc_place_nb_cost(SCROWLIST *rows, SCCHANNEL *channels, SCCELL *cell)
 		for (port = nplace->cell->ports; port; port = port->next)
 		{
 			/* find the correct trunk */
-			if ( !(ntrunk = (SCNBTRUNK *)port->ext_node->ptr) )
+			if (!(ntrunk = (SCNBTRUNK *)port->ext_node->ptr))
 				continue;
 			for (i = nchan->number; i; i--)
 				ntrunk = ntrunk->same;
@@ -2380,8 +2380,8 @@ void Sc_place_show_placement(SCROWLIST *rows)
 
 	for (row = rows; row; row = row->next)
 	{
-		ttyputmsg("For Row #%d, size %d:", row->row_num, row->row_size);
-		for (inst = row->start; inst != row->end; )
+		ttyputmsg(_("For Row #%d, size %d:"), row->row_num, row->row_size);
+		for (inst = row->start; inst != row->end;)
 		{
 			ttyputmsg("    %8d    %-s", inst->xpos, inst->cell->name);
 			if (row->row_num % 2)
