@@ -88,10 +88,11 @@ void simals_build_actel_command(INTSML count, char *par[])
 	INTSML len, i, filecount;
 	char *filename, line[MAXCHRS], **filelist;
 	REGISTER char *pt, *start;
+	static INTBIG filetypeacteltab = -1;
 
 	if (count == 0)
 	{
-		ttyputerr("Usage: tellaid simulation als build-actel-model TABLEFILE");
+		ttyputusage("tellaid simulation als build-actel-model TABLEFILE");
 		return;
 	}
 	len = strlen(par[0]);
@@ -100,10 +101,9 @@ void simals_build_actel_command(INTSML count, char *par[])
 	filecount = filesindirectory(par[0], &filelist);
 	if (filecount == 0)
 	{
-		ttyputerr("There are no files in directory '%s'", par[0]);
+		ttyputerr(_("There are no files in directory '%s'"), par[0]);
 		return;
 	}
-
 	for(i=0; i<filecount; i++)
 	{
 		(void)initinfstr();
@@ -111,10 +111,12 @@ void simals_build_actel_command(INTSML count, char *par[])
 		(void)addtoinfstr(DIRSEP);
 		(void)addstringtoinfstr(filelist[i]);
 		pt = returninfstr();
-		io = xopen(pt, FILETYPEACTELTAB, "", &filename);
+		if (filetypeacteltab < 0)
+			filetypeacteltab = setupfiletype("tab", "*.tab", MACFSTAG('TEXT'), 0, "actel", _("QuickPartTable"));
+		io = xopen(pt, filetypeacteltab, "", &filename);
 		if (io == 0)
 		{
-			ttyputerr("Cannot find Actel file %s", pt);
+			ttyputerr(_("Cannot find Actel file %s"), pt);
 			break;
 		}
 		for(;;)
@@ -201,7 +203,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 								if (strcmp(ap->paramname, start) == 0) break;
 							if (ap == 0)
 							{
-								ttyputerr("In model %s, symbol %s not found in parameter lists",
+								ttyputerr(_("In model %s, symbol %s not found in parameter lists"),
 									name, start);
 								return;
 							}
@@ -232,7 +234,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 								if (strcmp(ap->paramname, start) == 0) break;
 							if (ap == 0)
 							{
-								ttyputerr("In model %s, symbol %s not found in parameter lists",
+								ttyputerr(_("In model %s, symbol %s not found in parameter lists"),
 									name, start);
 								return;
 							}
@@ -259,7 +261,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 					if (*pt == ';') break;
 					if (*pt == ':') { pt += 2;   doinginput = 0;   continue; }
 					if (*pt == ',') { pt++;   continue; }
-					ttyputerr("In model %s, missing comma in Actel symbol list", name);
+					ttyputerr(_("In model %s, missing comma in Actel symbol list"), name);
 					return;
 				}
 
@@ -353,7 +355,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				while (*pt == ' ' || *pt == '\t') pt++;
 				if (*pt == ';') break;
 				if (*pt == ',') { pt++;   continue; }
-				ttyputerr("In model %s, missing comma in Actel input list", name);
+				ttyputerr(_("In model %s, missing comma in Actel input list"), name);
 				return;
 			}
 			continue;
@@ -380,7 +382,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				while (*pt == ' ' || *pt == '\t') pt++;
 				if (*pt == ';') break;
 				if (*pt == ',') { pt++;   continue; }
-				ttyputerr("In model %s, missing comma in Actel output list", name);
+				ttyputerr(_("In model %s, missing comma in Actel output list"), name);
 				return;
 			}
 			continue;
@@ -408,7 +410,7 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 				while (*pt == ' ' || *pt == '\t') pt++;
 				if (*pt == ';') break;
 				if (*pt == ',') { pt++;   continue; }
-				ttyputerr("In model %s, missing comma in Actel biput list", name);
+				ttyputerr(_("In model %s, missing comma in Actel biput list"), name);
 				return;
 			}
 			continue;
@@ -445,12 +447,12 @@ void simals_makeactelmodel(char *name, FILE *io, LIBRARY *lib)
 	np = newnodeproto(facetname, lib);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Cannot create facet %s", facetname);
+		ttyputerr(_("Cannot create facet %s"), facetname);
 		return;
 	}
 	stringarraytotextfacet(sa, np, 1);
 	killstringarray(sa);
-	ttyputmsg("Created %s", describenodeproto(np));
+	ttyputmsg(_("Created %s"), describenodeproto(np));
 }
 
 INTSML simals_fgets(char *line, INTSML limit, FILE *file)
@@ -500,12 +502,12 @@ void simals_clock_command(INTSML count, char *par[])
 
 	if (sim_window_isactive(&np) == 0)
 	{
-		ttyputerr("No simulator active");
+		ttyputerr(_("No simulator active"));
 		return;
 	}
 	if (count < 1)
 	{
-		ttyputerr("Usage: tellaid simulation als clock NODENAME (freq | period | custom)");
+		ttyputusage("tellaid simulation als clock NODENAME (freq | period | custom)");
 		return;
 	}
 
@@ -513,7 +515,7 @@ void simals_clock_command(INTSML count, char *par[])
 	nodehead = simals_find_node(par[0]);
 	if (! nodehead)
 	{
-		ttyputerr("ERROR: Unable to find node %s", par[0]);
+		ttyputerr(_("ERROR: Unable to find node %s"), par[0]);
 		return;
 	}
 
@@ -529,13 +531,13 @@ void simals_clock_command(INTSML count, char *par[])
 	{
 		if (count < 3)
 		{
-			ttyputerr("Usage: tellaid simulation als clock NODENAME %s PERIOD", par[1]);
+			ttyputusage("tellaid simulation als clock NODENAME frequency/period PERIOD");
 			return;
 		}
 		time = (float)atof(par[2]);
 		if (time <= 0.0)
 		{
-			ttyputerr("Clock timing parameter must be greater than 0");
+			ttyputerr(_("Clock timing parameter must be greater than 0"));
 			return;
 		}
 
@@ -589,14 +591,14 @@ void simals_clock_command(INTSML count, char *par[])
 
 	if (namesamen(par[1], "custom", l) != 0)
 	{
-		ttyputerr("Bad TELLAID SIMULATION ALS CLOCK option: %s", par[1]);
+		ttyputbadusage("tellaid simulation als clock");
 		return;
 	}
 
 	/* handle custom clock specification */
 	if (count < 7)
 	{
-		ttyputerr("Usage: tellaid simulation als clock custom RAN STR CY (L D) *");
+		ttyputusage("tellaid simulation als clock custom RAN STR CY (L D) *");
 		return;
 	}
 
@@ -663,8 +665,12 @@ void simals_erase_model(void)
 	NODEPTR node, nextnode;
 	STATPTR statptr, nextstatptr;
 
+	/* reset miscellaneous simulation variables */
+	simals_linkfront = 0;
+	simals_linkback = 0;
+
 	/* loop through all test vectors */
-	simals_clearallvectors();
+	simals_clearallvectors(1);
 
 	/* loop throuth all cells in flattened network */
 	if (simals_cellroot != 0)
@@ -857,28 +863,40 @@ void simals_erase_model(void)
 	simals_modroot = 0;
 }
 
-void simals_clearallvectors(void)
+/*
+ * Routine to clear all test vectors (even the power and ground vectors if "pwrgnd"
+ * is nonzero).
+ */
+void simals_clearallvectors(INTSML pwrgnd)
 {
-	LINKPTR sethead, vecthead, nextvec;
+	LINKPTR thisset, vecthead, nextvec, nextset, lastset;
 	ROWPTR clokhead;
 
-	while (simals_setroot)
+	lastset = 0;
+	for(thisset = simals_setroot; thisset != 0; thisset = nextset)
 	{
-		sethead = simals_setroot;
-		simals_setroot = simals_setroot->right;
-		if (sethead->type == 'C')
+		nextset = thisset->right;
+		if (pwrgnd != 0 || thisset->strength != VDD_STRENGTH)
 		{
-			clokhead = (ROWPTR)sethead->ptr;
-			for (vecthead = (LINKPTR)clokhead->inptr; vecthead; vecthead = nextvec)
+			if (thisset->type == 'C')
 			{
-				nextvec = vecthead->right;
-				simals_free_link_mem(vecthead);
+				clokhead = (ROWPTR)thisset->ptr;
+				for (vecthead = (LINKPTR)clokhead->inptr; vecthead; vecthead = nextvec)
+				{
+					nextvec = vecthead->right;
+					simals_free_link_mem(vecthead);
+				}
+				efree((char *)clokhead);
 			}
-			efree((char *)clokhead);
+			simals_free_link_mem(thisset);
+
+			if (lastset == 0) simals_setroot = nextset; else
+				lastset->right = nextset;
+		} else
+		{
+			lastset = thisset;
 		}
-		simals_free_link_mem(sethead);
 	}
-	simals_setroot = 0;
 }
 
 void simals_erase_submod(CONPTR conhead)
@@ -924,18 +942,18 @@ void simals_go_command(INTSML count, char *par[])
 
 	if (sim_window_isactive(&np) == 0)
 	{
-		ttyputerr("No simulator active");
+		ttyputerr(_("No simulator active"));
 		return;
 	}
 	if (count < 1)
 	{
-		ttyputerr("Must specify simulation time");
+		ttyputerr(_("Must specify simulation time"));
 		return;
 	}
 	max = (float)atof(par[0]);
 	if (max <= 0.0)
 	{
-		ttyputerr("Simulation time must be greater than 0 seconds");
+		ttyputerr(_("Simulation time must be greater than 0 seconds"));
 		return;
 	}
 	sim_window_settimerange(0.0, max);
@@ -953,9 +971,7 @@ void simals_go_command(INTSML count, char *par[])
  */
 void simals_help_command(void)
 {
-	char *par[5];
-
-	(void)us_helpdlog("ALS", par);
+	(void)us_helpdlog("ALS");
 }
 
 /****************************** LEVEL ******************************/
@@ -977,12 +993,12 @@ void simals_level_command(INTSML count, char *par[])
 
 	if (sim_window_isactive(&np) == 0)
 	{
-		ttyputerr("No simulator active");
+		ttyputerr(_("No simulator active"));
 		return;
 	}
 	if (count < 1)
 	{
-		ttyputerr("Missing LEVEL option");
+		ttyputusage("tellaid simulation als level OPTION");
 		return;
 	}
 
@@ -991,32 +1007,32 @@ void simals_level_command(INTSML count, char *par[])
 	{
 		if (simals_levelptr == 0)
 		{
-			ttyputerr("No simulation is running");
+			ttyputerr(_("No simulation is running"));
 			return;
 		}
 		cellptr = simals_levelptr->parent;
 		if (! cellptr)
 		{
-			ttyputerr("ERROR: Currently at top level of hierarchy");
+			ttyputerr(_("ERROR: Currently at top level of hierarchy"));
 			return;
 		}
 	} else if (namesamen(pp, "set", l) == 0)
 	{
 		if (count < 2)
 		{
-			count = ttygetparam("Instance to simulate: ", &sim_alslevelsp, 3, &par[1]) + 1;
+			count = ttygetparam(_("Instance to simulate: "), &sim_alslevelsp, 3, &par[1]) + 1;
 			if (count < 2) return;
 		}
 		simals_convert_to_upper(par[1]);
 		cellptr = simals_find_level(par[1]);
 		if (! cellptr)
 		{
-			ttyputerr("ERROR: Unable to find level %s", par[1]);
+			ttyputerr(_("ERROR: Unable to find level %s"), par[1]);
 			return;
 		}
 	} else
 	{
-		ttyputerr("Bad level option: %s", pp);
+		ttyputbadusage("tellaid simulation als level");
 		return;
 	}
 
@@ -1047,22 +1063,22 @@ void simals_print_command(INTSML count, char *par[])
 
 	if (count < 1)
 	{
-		ttyputerr("Missing PRINT option");
+		ttyputusage("tellaid simulation als print OPTION");
 		return;
 	}
 	l = strlen(pp = par[0]);
 
 	if (namesamen(pp, "size", l) == 0 && l >= 2)
 	{
-		ttyputmsg("Number of Primitive Elements in Database = %ld", simals_pseq);
-		ttyputmsg("Number of Nodes in Database = %ld", simals_nseq);
+		ttyputmsg(_("Number of Primitive Elements in Database = %ld"), simals_pseq);
+		ttyputmsg(_("Number of Nodes in Database = %ld"), simals_nseq);
 		return;
 	}
 
 	if (namesamen(pp, "vector", l) == 0 && l >= 1)
 	{
 		linkhead = simals_setroot;
-		ttyputmsg("** VECTOR LINKLIST **");
+		ttyputmsg(_("** VECTOR LINKLIST **"));
 		while (linkhead)
 		{
 			switch (linkhead->type)
@@ -1070,7 +1086,7 @@ void simals_print_command(INTSML count, char *par[])
 				case 'N':
 					nodehead = (NODEPTR)linkhead->ptr;
 					simals_trans_number_to_state(linkhead->state, s1);
-					ttyputmsg("***** vector: $N%ld, state = %s, strength = %s, time = %g, priority = %d",
+					ttyputmsg(_("***** vector: $N%ld, state = %s, strength = %s, time = %g, priority = %d"),
 						nodehead->num, s1, simals_strengthstring(linkhead->strength),
 							linkhead->time, linkhead->priority);
 					break;
@@ -1078,16 +1094,16 @@ void simals_print_command(INTSML count, char *par[])
 					stathead = (STATPTR)linkhead->ptr;
 					nodehead = stathead->nodeptr;
 					simals_trans_number_to_state(linkhead->state, s1);
-					ttyputmsg("***** function: $N%ld, state = %s, strength = %s, time = %g, priority = %d",
+					ttyputmsg(_("***** function: $N%ld, state = %s, strength = %s, time = %g, priority = %d"),
 						nodehead->num, s1, simals_strengthstring(linkhead->strength),
 							linkhead->time, linkhead->priority);
 					break;
 				case 'R':
-					ttyputmsg("***** rowptr = %ld, time = %g, priority = %d",
+					ttyputmsg(_("***** rowptr = %ld, time = %g, priority = %d"),
 						linkhead->ptr, linkhead->time, linkhead->priority);
 					break;
 				case 'C':
-					ttyputmsg("***** clokptr = %ld, time = %g, priority = %d",
+					ttyputmsg(_("***** clokptr = %ld, time = %g, priority = %d"),
 						linkhead->ptr, linkhead->time, linkhead->priority);
 			}
 			linkhead = linkhead->right;
@@ -1097,66 +1113,55 @@ void simals_print_command(INTSML count, char *par[])
 
 	if (namesamen(pp, "netlist", l) == 0 && l >= 1)
 	{
-		ttyputmsg("** NETWORK DESCRIPTION **");
+		ttyputmsg(_("** NETWORK DESCRIPTION **"));
 		for (primhead = simals_primroot; primhead; primhead = primhead->next)
 		{
-			if (stopping("Display")) return;
+			if (stopping(STOPREASONDISPLAY)) return;
 			switch (primhead->type)
 			{
 				case 'F':
 					(void)initinfstr();
-					(void)addstringtoinfstr("FUNCTION ");
-					(void)sprintf(s1, "%ld", primhead->num);
-					(void)addstringtoinfstr(s1);
-					(void)addstringtoinfstr(": ");
-					(void)addstringtoinfstr(primhead->name);
-					(void)addstringtoinfstr("(");
+					(void)formatinfstr(_("FUNCTION %ld%s: %s("), primhead->num, s1,
+						primhead->name);
 					for (exhead = primhead->exptr; exhead; exhead=exhead->next)
 					{
 						if (exhead != primhead->exptr) (void)addstringtoinfstr(", ");
-						(void)sprintf(s1, "N%ld", exhead->nodeptr->num);
-						(void)addstringtoinfstr(s1);
+						(void)formatinfstr("N%ld", exhead->nodeptr->num);
 					}
 					ttyputmsg("%s", returninfstr());
 					(void)initinfstr();
-					(void)addstringtoinfstr("  Event Driving Inputs:");
+					(void)addstringtoinfstr(_("  Event Driving Inputs:"));
 					funchead = (FUNCPTR)primhead->ptr;
 					for (exhead = funchead->inptr; exhead; exhead=exhead->next)
-					{
-						(void)sprintf(s1, " N%ld", exhead->nodeptr->num);
-						(void)addstringtoinfstr(s1);
-					}
+						(void)formatinfstr(" N%ld", exhead->nodeptr->num);
 					ttyputmsg("%s", returninfstr());
 					(void)initinfstr();
-					(void)addstringtoinfstr("  Output Ports:");
+					(void)addstringtoinfstr(_("  Output Ports:"));
 					for (exhead = primhead->exptr; exhead; exhead=exhead->next)
 					{
 						if (exhead->node_name)
-						{
-							(void)sprintf(s1, " N%ld", ((STATPTR)exhead->node_name)->nodeptr->num);
-							(void)addstringtoinfstr(s1);
-						}
+							(void)formatinfstr(" N%ld", ((STATPTR)exhead->node_name)->nodeptr->num);
 					}
 					ttyputmsg("%s", returninfstr());
-					ttyputmsg("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g", funchead->delta,
+					ttyputmsg(_("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g"), funchead->delta,
 						funchead->linear, funchead->exp, funchead->random, funchead->abs);
-					ttyputmsg("  Firing Priority = %d", primhead->priority);
+					ttyputmsg(_("  Firing Priority = %d"), primhead->priority);
 					break;
 				case 'G':
-					ttyputmsg("GATE %ld: %s  LEVEL: %s", primhead->num, primhead->name,
-						(primhead->level == NULL) ? "null" : primhead->level);
+					ttyputmsg(_("GATE %ld: %s  LEVEL: %s"), primhead->num, primhead->name,
+						(primhead->level == NULL) ? _("null") : primhead->level);
 					for (rowhead = (ROWPTR)primhead->ptr; rowhead; rowhead=rowhead->next)
 					{
-						ttyputmsg("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g", rowhead->delta,
+						ttyputmsg(_("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g"), rowhead->delta,
 							rowhead->linear, rowhead->exp, rowhead->random, rowhead->abs);
-						ttyputmsg("  Delay type: %s", (rowhead->delay == NULL) ? "null" : rowhead->delay);
+						ttyputmsg(_("  Delay type: %s"), (rowhead->delay == NULL) ? _("null") : rowhead->delay);
 						simals_print_in_entry(rowhead);
 						simals_print_out_entry(rowhead);
 					}
-					ttyputmsg("  Firing Priority = %d", primhead->priority);
+					ttyputmsg(_("  Firing Priority = %d"), primhead->priority);
 					break;
 				default:
-					ttyputerr("Illegal primitive type '%c', database is bad", primhead->type);
+					ttyputerr(_("Illegal primitive type '%c', database is bad"), primhead->type);
 					break;
 			}
 		}
@@ -1165,7 +1170,7 @@ void simals_print_command(INTSML count, char *par[])
 
 	if (namesamen(pp, "xref", l) == 0 && l >= 1)
 	{
-		ttyputmsg("** CROSS REFERENCE TABLE **");
+		ttyputmsg(_("** CROSS REFERENCE TABLE **"));
 		simals_print_xref_entry(simals_levelptr, 0);
 		return;
 	}
@@ -1174,25 +1179,25 @@ void simals_print_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: print state NODENAME");
+			ttyputusage("tellaid simulation als print state NODENAME");
 			return;
 		}
 		simals_convert_to_upper(par[1]);
 		nodehead = simals_find_node(par[1]);
 		if (nodehead == 0)
 		{
-			ttyputerr("ERROR: Unable to find node %s", par[1]);
+			ttyputerr(_("ERROR: Unable to find node %s"), par[1]);
 			return;
 		}
 
 		simals_trans_number_to_state(nodehead->new_state, s1);
-		ttyputmsg("Node %s: State = %s, Strength = %s", par[1], s1,
+		ttyputmsg(_("Node %s: State = %s, Strength = %s"), par[1], s1,
 			simals_strengthstring(nodehead->new_strength));
 		stathead = nodehead->statptr;
 		while (stathead)
 		{
 			simals_trans_number_to_state(stathead->new_state, s1);
-			ttyputmsg("Primitive %ld:    State = %s, Strength = %s", stathead->primptr->num,
+			ttyputmsg(_("Primitive %ld:    State = %s, Strength = %s"), stathead->primptr->num,
 				s1, simals_strengthstring(stathead->new_strength));
 			stathead = stathead->next;
 		}
@@ -1202,26 +1207,26 @@ void simals_print_command(INTSML count, char *par[])
 	if (namesamen(pp, "instances", l) == 0 && l >= 1)
 	{
 		simals_compute_path_name(simals_levelptr, s1);
-		ttyputmsg("Instances at level: %s", s1);
+		ttyputmsg(_("Instances at level: %s"), s1);
 		for (cellhead = simals_levelptr->child; cellhead; cellhead = cellhead->next)
 		{
-			if (stopping("Display")) break;
-			ttyputmsg("Name: %s, Model: %s", cellhead->inst_name, cellhead->model_name);
+			if (stopping(STOPREASONDISPLAY)) break;
+			ttyputmsg(_("Name: %s, Model: %s"), cellhead->inst_name, cellhead->model_name);
 		}
 		return;
 	}
-	ttyputerr("Unknown PRINT option: %s", pp);
+	ttyputbadusage("tellaid simulation als print");
 }
 
 char *simals_strengthstring(INTSML strength)
 {
 	switch (strength)
 	{
-		case NODE_STRENGTH: return("node");
-		case GATE_STRENGTH: return("gate");
-		case VDD_STRENGTH:  return("power");
+		case NODE_STRENGTH: return(_("node"));
+		case GATE_STRENGTH: return(_("gate"));
+		case VDD_STRENGTH:  return(_("power"));
 	}
-	return("off");
+	return(_("off"));
 }
 
 /*
@@ -1245,7 +1250,7 @@ void simals_print_in_entry(ROWPTR rowhead)
 
 	flag = 0;
 	(void)initinfstr();
-	(void)addstringtoinfstr("  Input: ");
+	(void)addstringtoinfstr(_("  Input: "));
 
 	for (iohead = rowhead->inptr; iohead; iohead = iohead->next)
 	{
@@ -1297,7 +1302,7 @@ void simals_print_out_entry(ROWPTR rowhead)
 
 	flag = 0;
 	(void)initinfstr();
-	(void)addstringtoinfstr("  Output: ");
+	(void)addstringtoinfstr(_("  Output: "));
 
 	for (iohead = rowhead->outptr; iohead; iohead = iohead->next)
 	{
@@ -1349,15 +1354,15 @@ void simals_print_xref_entry(CONPTR cellhead, INTBIG tab)
 	EXPTR   exhead;
 	CONPTR  subcell;
 
-	if (stopping("Display")) return;
+	if (stopping(STOPREASONDISPLAY)) return;
 	simals_compute_path_name(cellhead, s1);
 	for (i = 0; i < tab; ++i) tabsp[i] = ' ';
 	tabsp[tab] = 0;
-	ttyputmsg("%sLevel: %s, Model: %s", tabsp, s1, cellhead->model_name);
+	ttyputmsg(_("%sLevel: %s, Model: %s"), tabsp, s1, cellhead->model_name);
 
 	for (exhead = cellhead->exptr; exhead; exhead = exhead->next)
 	{
-		if (stopping("Display")) return;
+		if (stopping(STOPREASONDISPLAY)) return;
 		k = 0;
 		for (i=0; i<12; i++)
 		{
@@ -1371,7 +1376,7 @@ void simals_print_xref_entry(CONPTR cellhead, INTBIG tab)
 			}
 		}
 		if (k == 0) ttyputmsg("%s%14s --> N%ld", tabsp, exhead->node_name, exhead->nodeptr->num); else
-			ttyputmsg("%s%14s --> N%ld ( %s)", tabsp, exhead->node_name, exhead->nodeptr->num, returninfstr());
+			ttyputmsg("%s%14s --> N%ld (%s)", tabsp, exhead->node_name, exhead->nodeptr->num, returninfstr());
 	}
 
 	if (simals_instbuf[simals_instptr[1]] == 'X') return;
@@ -1393,7 +1398,7 @@ void simals_seed_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputerr("Usage: seed (reset | no-reset)");
+		ttyputusage("tellaid simulation als seed (reset | no-reset)");
 		return;
 	}
 	if (namesamen(par[0], "reset", strlen(par[0])) == 0)
@@ -1420,19 +1425,19 @@ void simals_set_command(INTSML count, char *par[])
 
 	if (sim_window_isactive(&np) == 0)
 	{
-		ttyputerr("No simulator active");
+		ttyputerr(_("No simulator active"));
 		return;
 	}
 	if (count < 4)
 	{
-		ttyputerr("Usage: set NODE LEVEL STRENGTH TIME");
+		ttyputusage("tellaid simulation als set NODE LEVEL STRENGTH TIME");
 		return;
 	}
 	simals_convert_to_upper(par[0]);
 	nodehead = simals_find_node(par[0]);
 	if (! nodehead)
 	{
-		ttyputerr("ERROR: Unable to find node %s", par[0]);
+		ttyputerr(_("ERROR: Unable to find node %s"), par[0]);
 		return;
 	}
 
@@ -1451,7 +1456,7 @@ void simals_set_command(INTSML count, char *par[])
 	sethead->right = 0;
 	simals_insert_set_list(sethead);
 
-	ttyputmsg("Node '%s' scheduled, state = %s, strength = %s, time = %g", par[0], par[1],
+	ttyputmsg(_("Node '%s' scheduled, state = %s, strength = %s, time = %g"), par[0], par[1],
 		simals_strengthstring(strength), time);
 	simals_initialize_simulator(0);
 }
@@ -1472,7 +1477,7 @@ void simals_trace_command(INTSML count, char *par[])
 
 	if (count < 1)
 	{
-		ttyputerr("Missing TRACE option");
+		ttyputusage("tellaid simulation als trace OPTION");
 		return;
 	}
 	l = strlen(pp = par[0]);
@@ -1486,7 +1491,7 @@ void simals_trace_command(INTSML count, char *par[])
 		(void)setvalkey((INTBIG)sim_aid, VAID, simals_no_update, 1, VINTEGER);
 		return;
 	}
-	ttyputerr("Unknown TRACE option: %s", pp);
+	ttyputbadusage("tellaid simulation als trace");
 }
 
 /****************************** VECTOR ******************************/
@@ -1506,12 +1511,12 @@ void simals_vector_command(INTSML count, char *par[])
 
 	if (sim_window_isactive(&np) == 0)
 	{
-		ttyputerr("No simulator active");
+		ttyputerr(_("No simulator active"));
 		return;
 	}
 	if (count < 1)
 	{
-		ttyputerr("Missing VECTOR option");
+		ttyputusage("tellaid simulation als vector OPTION");
 		return;
 	}
 	l = strlen(pp = par[0]);
@@ -1520,13 +1525,13 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: vector load FILENAME");
+			ttyputusage("tellaid simulation als vector load FILENAME");
 			return;
 		}
-		vin = xopen(par[1], FILETYPEALSVEC, "", &filename);
+		vin = xopen(par[1], sim_filetypealsvec, "", &filename);
 		if (! vin)
 		{
-			ttyputerr("ERROR: Can't open %s", par[1]);
+			ttyputerr(_("ERROR: Can't open %s"), par[1]);
 			return;
 		}
 
@@ -1570,7 +1575,7 @@ void simals_vector_command(INTSML count, char *par[])
 				nodehead = simals_find_node(&(simals_instbuf[simals_instptr[1]]));
 				if (! nodehead)
 				{
-					ttyputerr("ERROR: Unable to find node %s",
+					ttyputerr(_("ERROR: Unable to find node %s"),
 						&(simals_instbuf[simals_instptr[1]]));
 					flag = 1;
 					continue;
@@ -1633,7 +1638,7 @@ void simals_vector_command(INTSML count, char *par[])
 				nodehead = simals_find_node(&(simals_instbuf[simals_instptr[1]]));
 				if (! nodehead)
 				{
-					ttyputerr("ERROR: Unable to find node %s",
+					ttyputerr(_("ERROR: Unable to find node %s"),
 						&(simals_instbuf[simals_instptr[1]]));
 					flag = 1;
 					continue;
@@ -1658,7 +1663,7 @@ void simals_vector_command(INTSML count, char *par[])
 	if (namesamen(pp, "new", l) == 0)
 	{
 		/* clear all vectors */
-		simals_clearallvectors();
+		simals_clearallvectors(0);
 		simals_initialize_simulator(0);
 		return;
 	}
@@ -1667,13 +1672,13 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: vector save FILENAME");
+			ttyputusage("tellaid simulation als vector save FILENAME");
 			return;
 		}
-		vout = xcreate(par[1], FILETYPEALSVEC, "Vector File", &truename);
+		vout = xcreate(par[1], sim_filetypealsvec, _("Vector File"), &truename);
 		if (vout == 0)
 		{
-			if (truename != 0) ttyputerr("ERROR: Can't create %s", truename);
+			if (truename != 0) ttyputerr(_("ERROR: Can't create %s"), truename);
 			return;
 		}
 
@@ -1685,20 +1690,20 @@ void simals_vector_command(INTSML count, char *par[])
 					clokhead = (ROWPTR)sethead->ptr;
 					vecthead = (LINKPTR)clokhead->inptr;
 					simals_compute_node_name((NODEPTR)vecthead->ptr, s1);
-					xprintf(vout,"CLOCK %s D=%g L=%g E=%g ", s1, clokhead->delta,
+					xprintf(vout, "CLOCK %s D=%g L=%g E=%g ", s1, clokhead->delta,
 						clokhead->linear, clokhead->exp);
-					xprintf(vout,"STRENGTH=%d TIME=%g CYCLES=%ld\n", vecthead->strength,
+					xprintf(vout, "STRENGTH=%d TIME=%g CYCLES=%ld\n", vecthead->strength,
 						sethead->time, sethead->state);
 					for (; vecthead; vecthead = vecthead->right)
 					{
 						simals_trans_number_to_state(vecthead->state, s2);
-						xprintf(vout,"  %s %g\n", s2, vecthead->time);
+						xprintf(vout, "  %s %g\n", s2, vecthead->time);
 					}
 					break;
 				case 'N':
 					simals_compute_node_name((NODEPTR)sethead->ptr, s1);
 					simals_trans_number_to_state(sethead->state, s2);
-					xprintf(vout,"SET %s=%s@%d TIME=%g\n", s1, s2, sethead->strength,
+					xprintf(vout, "SET %s=%s@%d TIME=%g\n", s1, s2, sethead->strength,
 						sethead->time);
 			}
 		}
@@ -1710,14 +1715,14 @@ void simals_vector_command(INTSML count, char *par[])
 	{
 		if (count < 3)
 		{
-			ttyputerr("Usage: vector delete NODE OPTIONS");
+			ttyputusage("tellaid simulation als vector delete NODE OPTIONS");
 			return;
 		}
 		simals_convert_to_upper(par[1]);
 		nodehead = simals_find_node(par[1]);
 		if (! nodehead)
 		{
-			ttyputerr("ERROR: Unable to find node %s", par[1]);
+			ttyputerr(_("ERROR: Unable to find node %s"), par[1]);
 			return;
 		}
 
@@ -1765,7 +1770,7 @@ void simals_vector_command(INTSML count, char *par[])
 
 		if (count < 4)
 		{
-			ttyputerr("Usage: vector delete time TIME");
+			ttyputusage("tellaid simulation als vector delete time TIME");
 			return;
 		}
 		time = (float)atof(par[2]);
@@ -1810,7 +1815,7 @@ void simals_vector_command(INTSML count, char *par[])
 		return;
 	}
 
-	ttyputerr("Unknown VECTOR option: %s", pp);
+	ttyputbadusage("tellaid simulation als vector");
 }
 
 /****************************** ANNOTATE ******************************/
@@ -1825,13 +1830,13 @@ void simals_annotate_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputerr("Usage: annotate [minimum | typical | maximum]");
+		ttyputusage("tellaid simulation als annotate [minimum | typical | maximum]");
 		return;
 	}
 
 	if (simals_levelptr == 0)
 	{
-		ttyputerr("Must start simulator before annotating delay information");
+		ttyputerr(_("Must start simulator before annotating delay information"));
 		return;
 	}
 
@@ -1840,13 +1845,13 @@ void simals_annotate_command(INTSML count, char *par[])
 			else if (namesamen(par[0], "max", 3) == 0) simals_sdfdelaytype = DELAY_MAX;
 				else
 	{
-		ttyputerr("Unknown ANNOTATE option %s", par[0]);
+		ttyputbadusage("tellaid simulation als annotate");
 		return;
 	}
 
 	simals_sdfannotate(simals_levelptr);
 	simals_update_netlist();
-	ttyputmsg("Completed annotation of SDF %s delay values", par[0]);
+	ttyputmsg(_("Completed annotation of SDF %s delay values"), par[0]);
 }
 
 /*
@@ -1858,7 +1863,7 @@ void simals_sdfannotate(CONPTR cellhead)
 	CONPTR  subcell;
 	NODEINST *ni;
 
-	if (stopping("Display")) return;
+	if (stopping(STOPREASONDISPLAY)) return;
 	simals_compute_path_name(cellhead, s1);
 
 	ni = simals_getcellinstance(cellhead->model_name, s1);
@@ -2058,7 +2063,7 @@ void simals_order_command(INTSML count, char *par[])
 {
 	if (count < 1)
 	{
-		ttyputerr("Usage: order [save | restore]");
+		ttyputusage("tellaid simulation als order [save | restore]");
 		return;
 	}
 
@@ -2067,13 +2072,13 @@ void simals_order_command(INTSML count, char *par[])
 	{
 		if (count != 2)
 		{
-			ttyputerr("Missing ORDER RESTORE paramter");
+			ttyputusage("tellaid simulation als order restore OPTION");
 			return;
 		}
 		simals_order_restore(par[1]);
 	} else
 	{
-		ttyputerr("Unknown ORDER option %s", par[0]);
+		ttyputbadusage("tellaid simulation als order");
 		return;
 	}
 }
@@ -2237,9 +2242,9 @@ void simals_update_netlist(void)
 						{
 							rowhead->abs = (float)max_delay * 1.0e-12f;
 						}
-						ttyputmsg("*** DEBUG *** gate: %s, level: %s, delay: %g(%s)",
+						ttyputmsg(_("*** DEBUG *** gate: %s, level: %s, delay: %g(%s)"),
 							primhead->name, primhead->level, (float)max_delay * 1.0e-12, rowhead->delay);
-						ttyputmsg("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g",
+						ttyputmsg(_("  Timing: D=%g, L=%g, E=%g, R=%g, A=%g"),
 							rowhead->delta, rowhead->linear, rowhead->exp, rowhead->random, rowhead->abs);
 						simals_print_in_entry(rowhead);
 						simals_print_out_entry(rowhead);
@@ -2248,7 +2253,7 @@ void simals_update_netlist(void)
 				break;
 
 			default:
-				ttyputerr("Illegal primitive type '%c', database is bad", primhead->type);
+				ttyputerr(_("Illegal primitive type '%c', database is bad"), primhead->type);
 				break;
 		}
 	}
