@@ -89,7 +89,7 @@ static struct
 	{"DFFLOP",         simals_DFFLOP},				/* D flip-flop */
 	{"PMOStran",       simals_PMOSTRAN},			/* pMOS transistor */
 	{"nMOStran",       simals_NMOSTRAN},			/* nMOS transistor */
-#if 0
+#if 0			/* special case simulation elements */
 	{"Q_CALC",         simals_Q_CALC},
 	{"STATS",          simals_STATS},
 	{"COUNTER",        simals_COUNTER},
@@ -115,7 +115,7 @@ INTBIG *simals_get_function_address(char *s1)
 		if (! namesame(s1, func_table[i].name))
 			return((INTBIG *)func_table[i].address);
 	}
-	ttyputerr("ERROR: Unable to find user function %s in library", s1);
+	ttyputerr(_("ERROR: Unable to find user function %s in library"), s1);
 	return(0);
 }
 
@@ -517,7 +517,7 @@ INTSML simals_bidir_path_search(MODPTR primhead)
 	return((INTSML)i);
 }
 
-#if 0
+#if 0			/* special case simulation elements */
 /*
  * Name: simals_Q_CALC
  *
@@ -584,7 +584,7 @@ void simals_STATS(MODPTR primhead)
 	argptr = primhead->exptr;
 	if (argptr->nodeptr->sum_state % 100) return;
 
-	ttyputmsg("Characters arriving into Station (N%ld) = %ld, Time = %g",
+	ttyputmsg(_("Characters arriving into Station (N%ld) = %ld, Time = %g"),
 		argptr->nodeptr->num, argptr->nodeptr->sum_state, simals_time_abs);
 }
 
@@ -723,7 +723,7 @@ void simals_FIFO(MODPTR primhead)
 		(void)simals_schedule_node_update(input_ptr, '=', LOGIC_X, 0, simals_time_abs);
 		if (size_ptr->nodeptr->sum_state >= FIFO_SIZE)
 		{
-			ttyputerr("Data loss has occured: Value = %ld, Time = %g",
+			ttyputerr(_("Data loss has occured: Value = %ld, Time = %g"),
 			input_ptr->nodeptr->sum_state, simals_time_abs);
 			simals_window_max = simals_time_abs;
 			return;
@@ -1045,10 +1045,10 @@ void simals_WRITE_OUT(MODPTR primhead)
 	FILE  *fp;
 	EXPTR  ptr;
 
-	fp = xcreate("als.out", FILETYPETEXT, "Simulation Trace File", &truename);
+	fp = xcreate("als.out", el_filetypetext, _("Simulation Trace File"), &truename);
 	if (fp == 0)
 	{
-		if (truename != 0) ttyputmsg("ERROR: cannot open %s", truename);
+		if (truename != 0) ttyputmsg(_("ERROR: cannot open %s"), truename);
 		return;
 	}
 
