@@ -63,24 +63,23 @@ void sim_writemossim(NODEPROTO *np)
 {
 	char name[100], *truename;
 	REGISTER NODEPROTO *lnp;
-	extern AIDENTRY *net_aid;
 	REGISTER LIBRARY *lib;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the simulation command");
+		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
 
 	(void)strcpy(name, np->cell->cellname);
 	(void)strcat(name, ".ntk");
-	sim_mossimfile = xcreate(name, FILETYPEMOSSIM, "MOSSIM File", &truename);
+	sim_mossimfile = xcreate(name, sim_filetypemossim, _("MOSSIM File"), &truename);
 	if (sim_mossimfile == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 
@@ -93,10 +92,10 @@ void sim_writemossim(NODEPROTO *np)
 		for(lnp = lib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 			lnp->temp1 = 0;
 	if (sim_writemossimfacet(np, 1) != 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	xclose(sim_mossimfile);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 }
 
 /*
@@ -112,10 +111,9 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai, *nai;
 	REGISTER PORTPROTO *pp, *opp, *gate, *source, *drain, *spp;
-	extern AIDENTRY *net_aid;
 
 	/* stop if requested */
-	if (stopping("Deck generation") != 0) return(0);
+	if (stopping(STOPREASONDECK)) return(0);
 
 	/* mark this facet as written */
 	np->temp1 = 1;
@@ -248,10 +246,10 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 			if (var != NOVARIABLE)
 			{
 				if (var->addr < 0)
-					ttyputerr("Warning: arc %s has negative strength", describearcinst(nai)); else
+					ttyputerr(_("Warning: arc %s has negative strength"), describearcinst(nai)); else
 				{
 					if (strength >= 0 && strength != var->addr)
-						ttyputerr("Warning: net has multiple strengths: %d and %ld", strength,
+						ttyputerr(_("Warning: net has multiple strengths: %d and %ld"), strength,
 							var->addr);
 					strength = (INTSML)var->addr;
 				}
@@ -348,7 +346,8 @@ INTSML sim_writemossimfacet(NODEPROTO *np, INTSML top)
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 			if (var == NOVARIABLE)
 			{
-				ttyputerr("MOSSIM generation warning: no name on node %s", describenodeinst(ni));
+				ttyputerr(_("MOSSIM generation warning: no name on node %s"),
+					describenodeinst(ni));
 				(void)addstringtoinfstr("INST");
 				(void)sprintf(temp, "%d", inst++);
 				(void)addstringtoinfstr(temp);
@@ -461,8 +460,8 @@ void sim_addmossimnode(NODEINST *ni, PORTPROTO *pp)
 
 /*
  * routine to write the net name of arc "ai".  There are two types of arcs:
- * those connected to exported ports, and those that are internal.  When
- * the "temp1" field is -1, the arc is connected to an exported port which
+ * those connected to exports, and those that are internal.  When
+ * the "temp1" field is -1, the arc is connected to an export which
  * is saved in the "temp2" field.  In other cases, the actual string name
  * of the net is in the "temp2" field.
  */
