@@ -51,7 +51,7 @@
 #define SILOSXOR		 5		/* XOR */
 #define SILOSINV		 6		/* Inverter */
 #define SILOSBUF		 7		/* Buffer */
-#define SILOSSOURCE		 8		/* Source, not  .CLK */
+#define SILOSSOURCE		 8		/* Source, not .CLK */
 #define SILOSRES		 9		/* Resistor in SILOS */
 #define SILOSCAP		10		/* Capacitor */
 #define SILOSDFF		11		/* D flip flop */
@@ -97,7 +97,6 @@ void sim_writesilnetlist(NODEPROTO *np)
 {
 	char name[100], numberstring[100], *truename;
 	REGISTER NODEPROTO *lnp;
-	extern AIDENTRY *net_aid;
 	REGISTER LIBRARY *lib;
 	UINTBIG cdate, rdate;
 	INTBIG rnum;
@@ -105,25 +104,25 @@ void sim_writesilnetlist(NODEPROTO *np)
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the simulation command");
+		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
 
 	/* first write the "sil" file */
 	(void)strcpy(name, np->cell->cellname);
 	(void)strcat(name, ".sil");
-	sim_silfile = xcreate(name, FILETYPESILOS, "SILOS File", &truename);
+	sim_silfile = xcreate(name, sim_filetypesilos, _("SILOS File"), &truename);
 	if (sim_silfile == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 	sim_sendtosil("\n");
 	sim_sendtosil("$ FACET ");
 	sim_sendtosil(describenodeproto(np));
-	sim_sendtosil("  FROM LIBRARY:");
+	sim_sendtosil(" FROM LIBRARY:");
 	sim_sendtosil(np->cell->lib->libname);
 	sim_sendtosil("\n");
 	cdate = np->creationdate;
@@ -136,7 +135,7 @@ void sim_writesilnetlist(NODEPROTO *np)
 	rnum = np->version;
 	if (rnum)
 	{
-		(void)sprintf(numberstring,"$ VERSION  %ld",rnum);
+		(void)sprintf(numberstring,"$ VERSION %ld",rnum);
 		sim_sendtosil(numberstring);
 		sim_sendtosil("\n");
 	}
@@ -166,12 +165,12 @@ void sim_writesilnetlist(NODEPROTO *np)
 		for(lnp = lib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 			lnp->temp1 = 0;
 	if (sim_writesilfacet(np, 1) != 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	sim_sendtosil("\n");
 
 	/* clean up */
 	xclose(sim_silfile);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 
 }
 
@@ -192,63 +191,62 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 	REGISTER FILE *f;
 	char line[100], *filename;
 	char *extra, **model, *name;
-	extern AIDENTRY *net_aid;
 
 	/* stop if requested */
 	if (el_pleasestop != 0)
 	{
-		stopping("SILOS deck generation");
+		(void)stopping(STOPREASONDECK);
 		return(0);
 	}
 	backannotate = 0;
 
-	/* First look for any global sources  */
+	/* First look for any global sources */
 	if (top != 0)
 	{
 		for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if (ni->proto->primindex == 0) continue;	/* only real sources */
 
-			nodetype = nodefunction(ni,&extra);
+			nodetype = nodefunction(ni, &extra);
 			if (nodetype != NPSOURCE) continue;
 
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name);
 			if (var != NOVARIABLE)	/* is this a global source ? */
 			{
 				name = (char *)var->addr;
-				(void)sprintf(line,".GLOBAL %s",sim_silspecials(name));
+				(void)sprintf(line, ".GLOBAL %s", sim_silspecials(name));
 				sim_sendtosil(line);
 				sim_sendtosil("\n");
 			}
 
 			/* Get the source type */
-			var = getvalkey((INTBIG)ni, VNODEINST,  VSTRING, sch_sourcekey);
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sch_sourcekey);
 			if (var == NOVARIABLE)
 			{
-				ttyputerr("Unspecified source:");
+				ttyputerr(_("Unspecified source:"));
 				sprintf(line,"$$$$$ Unspecified source: \n");
 			} else	/* There is more */
 			{
 				clktype = 0;	/* Extra data required if 1 */
-				for(extra=(char *)var->addr; *extra!=0 && *extra !=  '/'; extra++)
+				for(extra = (char *)var->addr; *extra != 0 && *extra != '/'; extra++)
 				{
 					switch(*extra)
 					{
-						case 'g':	/*  a global clock */
-							(void)sprintf(line,"%s .CLK ", name);
+						case 'g':	/* a global clock */
+							(void)sprintf(line, "%s .CLK ", name);
 							clktype = 1;
 							break;
-						case 'h':	/*  a fixed high source */
-							(void)sprintf(line,"%s .CLK 0 S1  $ HIGH LEVEL",name);
+						case 'h':	/* a fixed high source */
+							(void)sprintf(line, "%s .CLK 0 S1 $ HIGH LEVEL", name);
 							break;
-						case 'l':	/*  a fixed low source */
-							(void)sprintf(line,"%s .CLK 0 S0  $ LOW LEVEL",name);
+						case 'l':	/* a fixed low source */
+							(void)sprintf(line, "%s .CLK 0 S0 $ LOW LEVEL", name);
 							break;
 					}
 				}
 				if (*extra == '/') extra++;
 				if (clktype == 1) strcat(line, extra);
-			}	/* end else */
+			}
 			sim_sendtosil(line);
 			sim_sendtosil("\n");
 		}
@@ -260,9 +258,9 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 		var = getval((INTBIG)onp, VNODEPROTO, VSTRING, "SIM_silos_behavior_file");
 		if (var != NOVARIABLE)
 		{
-			f = xopen(truepath((char *)var->addr), FILETYPESILOS, "", &filename);
+			f = xopen(truepath((char *)var->addr), sim_filetypesilos, "", &filename);
 			if (f == NULL)
-				ttyputerr("Cannot find SILOS behavior file %s on facet %s",
+				ttyputerr(_("Cannot find SILOS behavior file %s on facet %s"),
 					(char *)var->addr, describenodeproto(onp)); else
 			{
 				/* copy the file */
@@ -271,7 +269,7 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 					count = (INTSML)xfread(buf, 1, 256, f);
 					if (count <= 0) break;
 					if (xfwrite(buf, 1, count, sim_silfile) != count)
-						ttyputerr("Error copying file");
+						ttyputerr(_("Error copying file"));
 				}
 				xclose(f);
 				sim_sendtosil("\n");
@@ -296,8 +294,8 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 			j = (INTSML)getlength(var);
 			for(i = 0; i < j; i++)
 				xprintf(sim_silfile, "%s\n", model[i]);
-
 			sim_sendtosil("\n");
+
 			/* mark this facet as written */
 			np->temp1++;
 			return(backannotate);
@@ -336,15 +334,15 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 	{
 		sim_sendtosil("\n");
 		sim_sendtosil(".MACRO");
-		(void)strcpy(line,(np->cell->cellname) );
+		(void)strcpy(line, (np->cell->cellname));
 		for (i=0; line[i] && line[i] != '{'; i++)
 			;
-		line[i] = 0;            /* explicit termination of line */
+		line[i] = 0;			/* explicit termination of line */
 		if(strlen(line) > MAXNAME)
 		{
-			ttyputerr(".MACRO name %s is too long;",line);
+			ttyputerr(_(".MACRO name %s is too long;"), line);
 			line[MAXNAME] = 0;
-			ttyputerr("truncated to %s\n",line);
+			ttyputerr(_("truncated to %s"), line);
 		}
 		sim_sendtosil(" ");
 		sim_sendtosil(sim_siltext(line));
@@ -355,7 +353,7 @@ INTSML sim_writesilfacet(NODEPROTO *np, INTSML top)
 		 */
 		if (np->firstportproto != NOPORTPROTO)
 		{
-			for(pp=np->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
+			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			{
 				if (portispower(pp) || portisground(pp)) continue;
 				(void)strcpy(line, sim_convertsub(pp->protoname));
@@ -412,18 +410,18 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 		/* Reset flag for output port */
 		outpp = NOPORTPROTO;
 
-		nodetype = sim_silostype(ni,&extra);
-		switch(nodetype)
+		nodetype = sim_silostype(ni, &extra);
+		switch (nodetype)
 		{
 			case SILOSFACET:		/* Complex cell uses instance name */
 				sim_sendtosil("(");
 				sim_sendtosil(sim_silname(ni));
 				sim_sendtosil(" ");
-				sim_sendtosil(sim_silproto(ni,0));	/* write the type  */
+				sim_sendtosil(sim_silproto(ni, 0));	/* write the type */
 
 				/* write the rest of the port(s), connected or not */
 				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-					sim_sendtosil(sim_silportname(top,ni,pp,np));
+					sim_sendtosil(sim_silportname(top, ni, pp, np));
 				break;
 
 			case SILOSNMOS:
@@ -432,25 +430,26 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 			case SILOSDFF:
 			case SILOSJKFF:
 			case SILOSSRFF:
-				/* Transistors and flip-flops need a part number  */
+				/* Transistors and flip-flops need a part number */
 				sim_sendtosil(sim_silname(ni));
 				sim_sendtosil(" ");
-				sim_sendtosil(sim_silproto(ni,0));
+				sim_sendtosil(sim_silproto(ni, 0));
+
 				/* write the names of the port(s) */
 				if (nodetype == SILOSTFF || nodetype == SILOSDFF ||
 					nodetype == SILOSJKFF || nodetype == SILOSSRFF)
 				{
-					(void)sim_silwriteflipflop(top,ni,np,nodetype);
+					(void)sim_silwriteflipflop(top, ni, np, nodetype);
 				} else
 				{
 					for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-						sim_sendtosil(sim_silportname(top,ni,pp,np));
+						sim_sendtosil(sim_silportname(top, ni, pp, np));
 				}
 				break;
 
 			case SILOSCLOCK:
 			case SILOSSOURCE:
-				if (top ==0) ttyputerr("WARNING: Global Clock in a sub-facet");
+				if (top ==0) ttyputerr(_("WARNING: Global Clock in a sub-facet"));
 				break;
 
 			case SILOSAND:	/* only need positive logic here */
@@ -460,12 +459,13 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 				/* Gates use their output port as a name */
 				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				{
-					/* write the output signal as the name  */
+					/* write the output signal as the name */
 					if ((pp->userbits&STATEBITS) == OUTPORT)
 					{
 						/* Find the name of the output port */
-						sim_sendtosil(sim_silportname(top,ni,pp,np));
-						/* Record that we used it  */
+						sim_sendtosil(sim_silportname(top, ni, pp, np));
+
+						/* Record that we used it */
 						outpp = pp;
 						sim_sendtosil(" ");
 
@@ -475,14 +475,15 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 						 */
 						for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 							if (pi->proto == pp) break;
+
 						/* sim_silnegated handles NOPORTARCINST */
 						sim_sendtosil(sim_silproto(ni,sim_silnegated(pi)));
-					}				/* end if OUTPORT  */
+					}
 					if (outpp != NOPORTPROTO)	/* found the output name */
 						break;
-				}					/* end for (pp  */
+				}
 				if (pp == NOPORTPROTO)
-					ttyputerr("Could not find an output connection on %s\n", ni->proto->primname);
+					ttyputerr(_("Could not find an output connection on %s"), ni->proto->primname);
 
 				/* get the fall and rise times */
 				sim_sendtosil(sim_silrisetime(ni));
@@ -499,7 +500,7 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 							;
 
 					if (pi != NOPORTARCINST)	/* ... port is connected */
-						sim_sendtosil(sim_silportname(top,ni,pp,np));
+						sim_sendtosil(sim_silportname(top, ni, pp, np));
 				}
 				break;
 
@@ -519,26 +520,27 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
 				if (pp != NOPORTPROTO)	/* ...there is a connection */
 				{
 					/* write port name as output */
-					sim_sendtosil(sim_silportname(top,ni,pp,np));
+					sim_sendtosil(sim_silportname(top, ni, pp, np));
 
 					sim_sendtosil(" ");
 					sim_sendtosil(sim_silproto(ni, 0));
 
-					if (( j = sim_silgetcapacitance(ni))>=0)
+					j = sim_silgetcapacitance(ni);
+					if (j >= 0)
 					{
-						(void)sprintf(line," %d",j);
+						(void)sprintf(line, " %d", j);
 						sim_sendtosil(line);
 					} else
-						ttyputerr("Warning: capacitor with no value");
+						ttyputerr(_("Warning: capacitor with no value"));
 				}
 				break;
 
 			case SILOSRES:	/* sorry! can't handle the resistive gate yet */
 			default:	/* some compilers may not like this empty default */
 				break;
-		}    /* end switch */
+		}
 		sim_sendtosil("\n");
-	}						/* end for (ni  */
+	}
 }
 
 /*
@@ -547,20 +549,20 @@ void sim_writesilinstances(NODEPROTO *np, INTSML top)
  * If there is an arc connected to the port, use the net name, or NETn.
  * If there are more than one arc (that are not electrically connected)
  * on the port, concatenate the names (with spaces between them).
- * If there is no arc, but the port is exported, use the exported name.
+ * If there is no arc, but the port is an export, use the exported name.
  * If the port is a power or ground port, ignore it
  * If this is not the top level facet (ie. a .macro) remove [] notation.
  */
 char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 {
-	REGISTER PORTPROTO  *epp;
+	REGISTER PORTPROTO *epp;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER ARCINST *ai = NOARCINST;
 	char *portname;
 	INTSML noarcs;	/* boolean flag */
 
-	if (portispower(pp) || portisground (pp)) return ("");
+	if (portispower(pp) || portisground (pp)) return("");
 
 	(void)initinfstr();
 
@@ -580,7 +582,8 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 					addtoinfstr(' ');
 
 			/* find the arc connected to this pi */
-			if ((ai = pi->conarcinst) != NOARCINST)
+			ai = pi->conarcinst;
+			if (ai != NOARCINST)
 			{
 				/*
 				 * get the name...
@@ -588,10 +591,10 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 				 */
 				if (top)
 					addstringtoinfstr(sim_silspecials(sim_silarcname(ai))); else
-						addstringtoinfstr(sim_sil_isaport(np,sim_silspecials(sim_silarcname(ai))));
+						addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(sim_silarcname(ai))));
 			} else /* this is a database error, and won't ever occur */
 			{
-				ttyputerr("Uh Oh! there is a PORTARCINST without a CONARCINST");
+				ttyputerr(_("Uh Oh! there is a PORTARCINST without a CONARCINST"));
 				return("");
 			}
 
@@ -605,14 +608,14 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 	/* if this is the top facet and we didn't find an arc */
 	if (top && noarcs)
 	{
-		/* search for an exported port */
+		/* search for an export */
 		for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 		{
-			if (pe->proto == pp)	/* this port is exported */
+			if (pe->proto == pp)	/* this port is an export */
 			{
 				addtoinfstr(' ');
 
-				/* write the exported port name */
+				/* write the export name */
 				epp = pe->exportproto;
 				if (epp->network->namecount > 0)
 				{
@@ -620,7 +623,7 @@ char *sim_silportname(INTSML top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 						addstringtoinfstr(sim_sil_isaport(np, sim_silspecials(epp->network->netname)));
 				} else	/* this would be a database error - won't happen */
 				{
-					ttyputerr("Uh Oh! there is an exported net, but no net name");
+					ttyputerr(_("Uh Oh! there is a net on an export, but no net name"));
 					return("");
 				}
 				break;	/* out of "for (pe..." */
@@ -673,7 +676,7 @@ char *sim_silproto(NODEINST *ni,INTSML neg)
 	/* facets use their real name */
 	if (ni->proto->primindex == 0)
 	{
-		sprintf(name,"%s",sim_siltext(ni->proto->cell->cellname));
+		sprintf(name,"%s", sim_siltext(ni->proto->cell->cellname));
 		if (strlen(name) > MAXNAME) name[MAXNAME] = 0;
 		return(name);
 	}
@@ -703,16 +706,16 @@ char *sim_silproto(NODEINST *ni,INTSML neg)
 		case SILOSCAP:
 			return(".CAP");
 		case SILOSJKFF:
-			if (namesamen(extra,"jkn",3) == 0) return(".JKNEFF");
+			if (namesamen(extra, "jkn", 3) == 0) return(".JKNEFF");
 			return(".JKPEFF");
 		case SILOSDFF:
-			if (namesamen(extra,"dn",2) == 0) return(".DNEFF");
+			if (namesamen(extra, "dn", 2) == 0) return(".DNEFF");
 			return(".DPEFF");
 		case SILOSSRFF:
-			if (namesamen(extra,"rsn",3) == 0) return(".SRNEFF");
+			if (namesamen(extra, "rsn", 3) == 0) return(".SRNEFF");
 			return(".SRPEFF");
 		case SILOSTFF:
-			if (namesamen(extra,"tn",2) == 0) return(".TNEFF");
+			if (namesamen(extra, "tn", 2) == 0) return(".TNEFF");
 			return(".TPEFF");
 	}
 	return(sim_siltext(ni->proto->primname));
@@ -728,18 +731,18 @@ char *sim_siltext(char *p)
 {
 	REGISTER char *t;
 
-	for(t=p; *t != 0; t++) if (!isprint(*t)) break;
+	for(t = p; *t != 0; t++) if (!isprint(*t)) break;
 	if (*t == 0 && (!isdigit(*p))) return(p);
 
 	(void)initinfstr();
-	if ( isdigit(*p)) (void)addtoinfstr('_');
-	for(t=p; *t != 0 ; t++)
-		if (isprint(*t) ) (void)addtoinfstr(*t); else
+	if (isdigit(*p)) (void)addtoinfstr('_');
+	for(t = p; *t != 0; t++)
+		if (isprint(*t)) (void)addtoinfstr(*t); else
 			(void)addtoinfstr('_');
 	return(returninfstr());
 }
 
-/* Write to the .sil file, but break into printable lines  */
+/* Write to the .sil file, but break into printable lines */
 
 void sim_sendtosil(char *str)
 {
@@ -747,7 +750,7 @@ void sim_sendtosil(char *str)
 	INTSML i;
 
 	if (*str == '\n') count = 0;
-	if ((count + (i = strlen(str))) > MAXSTR )
+	if ((count + (i = strlen(str))) > MAXSTR)
 	{
 		if(*str == '$')
 		{
@@ -787,7 +790,7 @@ INTSML sim_silnegated(PORTARCINST *pi)
 	if (pi == NOPORTARCINST) return(0);
 
 	ai = pi->conarcinst;
-	if ( ai == NOARCINST) return(0);
+	if (ai == NOARCINST) return(0);
 	if ((ai->userbits&ISNEGATED) == 0) return(0);
 
 	if (ai->end[0].portarcinst == pi) thisend = 0; else
@@ -803,12 +806,12 @@ INTSML sim_silnegated(PORTARCINST *pi)
 
 char *sim_silspecials(char *str)
 {
-	if (namesamen(str, "vdd",3) == 0) return (".VDD");
-	if (namesamen(str, "vss",3) == 0) return (".VSS");
-	if (namesamen(str, "vcc",3) == 0) return (".VCC");
-	if (namesamen(str, "gnd",3) == 0) return (".GND");
-	if (namesamen(str, "low",3) == 0) return (".GND");
-	if (namesamen(str, "hig",3) == 0) return (".VDD");
+	if (namesamen(str, "vdd",3) == 0) return(".VDD");
+	if (namesamen(str, "vss",3) == 0) return(".VSS");
+	if (namesamen(str, "vcc",3) == 0) return(".VCC");
+	if (namesamen(str, "gnd",3) == 0) return(".GND");
+	if (namesamen(str, "low",3) == 0) return(".GND");
+	if (namesamen(str, "hig",3) == 0) return(".VDD");
 	return(str);
 }
 
@@ -852,10 +855,10 @@ INTSML sim_silostype(NODEINST *ni, char **info)
 				string = (char *)var->addr;
 				*info = string;
 			}
-			if(*string == 'd') return(SILOSDFF);
-			if(*string == 'j') return(SILOSJKFF);
-			if(*string == 'r') return(SILOSSRFF);
-			if(*string == 't') return(SILOSTFF);
+			if (*string == 'd') return(SILOSDFF);
+			if (*string == 'j') return(SILOSJKFF);
+			if (*string == 'r') return(SILOSSRFF);
+			if (*string == 't') return(SILOSTFF);
 			return(SILOSDFF);
 		case NPSOURCE:
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, sim_silos_global_name);
@@ -864,7 +867,7 @@ INTSML sim_silostype(NODEINST *ni, char **info)
 				string = (char *)var->addr;
 				*info = string;
 			}
-			return (SILOSCLOCK);
+			return(SILOSCLOCK);
 		case NPMETER:
 			return(SILOSOUT);
 		default:
@@ -947,7 +950,7 @@ INTSML sim_silgetcapacitance(NODEINST *ni)
 	REGISTER VARIABLE *var;
 
 	var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, sch_capacitancekey);
-	if (var != NOVARIABLE) return ((INTSML )var->addr);
+	if (var != NOVARIABLE) return((INTSML)var->addr);
 	return(-1);
 }
 
@@ -963,18 +966,18 @@ INTSML sim_silgetcapacitance(NODEINST *ni)
 #define CK	 4
 #define PRE  5
 #define CLR  6
-void sim_silwriteflipflop(INTSML top,NODEINST *ni,NODEPROTO *np,INTSML type)
+void sim_silwriteflipflop(INTSML top, NODEINST *ni, NODEPROTO *np, INTSML type)
 {
 	REGISTER PORTPROTO *pp;
 	char line[8][50], out[100];
 	INTSML i;
 
-	for(pp = ni->proto->firstportproto,i=0; pp != NOPORTPROTO && i < 7; pp = pp->nextportproto,i++)
+	for(pp = ni->proto->firstportproto, i=0; pp != NOPORTPROTO && i < 7; pp = pp->nextportproto, i++)
 	{
 		/* find arcs on this port */
-		(void)sprintf(line[i]," %s", sim_silportname(top,ni,pp,np));
+		(void)sprintf(line[i]," %s", sim_silportname(top, ni, pp, np));
 	}
-	if ((namesamen(line[PRE]," .SKIP",4)==0) && (namesamen(line[CLR]," .SKIP",4)==0))
+	if (namesamen(line[PRE], " .SKIP", 4) == 0 && namesamen(line[CLR], " .SKIP", 4) == 0)
 	{
 		*line[CLR] = 0;		/* If neither on, don't print */
 		*line[PRE] = 0;
@@ -986,7 +989,6 @@ void sim_silwriteflipflop(INTSML top,NODEINST *ni,NODEPROTO *np,INTSML type)
 	sim_sendtosil(out);
 }
 
-
 /* Function to check if a port of an instance is connected to one of
 the ports of the containing instance. If so, get rid of the '[]' format;
 replace '[' with '__', ignore ']'.
@@ -999,7 +1001,7 @@ char *sim_sil_isaport(NODEPROTO *np, char *portname)
 
 	for (pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
-		if (namesame( pp->protoname, portname ) == 0) return(sim_convertsub(portname));
+		if (namesame(pp->protoname, portname) == 0) return(sim_convertsub(portname));
 	}
 	return(portname);
 }
@@ -1026,7 +1028,7 @@ static char *sim_convertsub(char *string)
 		}
 	}
 	*ptr = 0;
-	return (newname);
+	return(newname);
 }
 
-#endif  /* SIMAID - at top */
+#endif	/* SIMAID - at top */
