@@ -34,6 +34,7 @@
 #include "global.h"
 #include "sim.h"
 #include "efunction.h"
+#include "usr.h"
 #include "tecschem.h"
 #include <setjmp.h>
 
@@ -60,14 +61,13 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	REGISTER PORTPROTO *pp, *spt, *shpt;
 	char *truename, *presimloc, *execargs[5];
 	REGISTER char *simprog, *presimtmp, *presimprog, *netfile;
-	extern AIDENTRY *net_aid;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the simulation command");
+		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
 
@@ -96,10 +96,10 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	(void)allocstring(&sim_inputfile, netfile, sim_aid->cluster);
 
 	/* create the simulation file */
-	f = xcreate(netfile, FILETYPEESIM, "Netlist File", &truename);
+	f = xcreate(netfile, sim_filetypeesim, _("Netlist File"), &truename);
 	if (f == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 	xprintf(f,"| %s\n", netfile);
@@ -176,8 +176,8 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	}
 	sim_namethresh = sim_index;
 
-	if (sim_vdd == 0) ttyputmsg("Warning: no exported power port in this facet");
-	if (sim_gnd == 0) ttyputmsg("Warning: no exported ground port in this facet");
+	if (sim_vdd == 0) ttyputmsg(_("Warning: no power export in this facet"));
+	if (sim_gnd == 0) ttyputmsg(_("Warning: no ground export in this facet"));
 
 	/* select the shortest name for electrically equivalent ports */
 	for(pp = simnt->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -221,7 +221,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 		if (pp->temp2 < 0) continue;
 
 		/* just a normal node: write its characteristics */
-		if (i++ == 0) ttyputmsg("These exported names are available:");
+		if (i++ == 0) ttyputmsg(_("These export names are available:"));
 		ttyputmsg("   %s", pp->protoname);
 		if (format == COSMOS)
 		{
@@ -241,8 +241,8 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	if (format == COSMOS || (var != NOVARIABLE && var->addr == SIMRUNNO))
 	{
 		if (count_unconn != 0)
-			ttyputmsg("Warning: %ld unconnected nodes were found", count_unconn);
-		ttyputmsg("%s written", truename);
+			ttyputmsg(_("Warning: %ld unconnected nodes were found"), count_unconn);
+		ttyputmsg(_("%s written"), truename);
 		return;
 	}
 
@@ -267,8 +267,8 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 		if (sim_process == 1)
 		{
 			if (count_unconn != 0)
-				ttyputmsg("Warning: %ld unconnected nodes were found", count_unconn);
-			ttyputverbose("Created simulation file %s", netfile);
+				ttyputmsg(_("Warning: %ld unconnected nodes were found"), count_unconn);
+			ttyputverbose(_("Created simulation file %s"), netfile);
 			return;
 		}
 
@@ -286,11 +286,11 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 			eexec(presimloc, execargs);
 			channelrestore(1, save1);
 			channelrestore(2, save2);
-			ttyputerr("Cannot run the presimulator");
+			ttyputerr(_("Cannot run the presimulator"));
 			exit(1);
 		}
 		ewait(sim_process);
-		ttyputmsg("Pre-simulator finished");
+		ttyputmsg(_("Pre-simulator finished"));
 		(void)reallocstring(&sim_inputfile, presimtmp, sim_aid->cluster);
 	}
 
@@ -328,8 +328,8 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 	if (sim_process == 1)
 	{
 		if (count_unconn != 0)
-			ttyputmsg("Warning: %ld unconnected nodes were found", count_unconn);
-		ttyputverbose("Created simulation file %s", netfile);
+			ttyputmsg(_("Warning: %ld unconnected nodes were found"), count_unconn);
+		ttyputverbose(_("Created simulation file %s"), netfile);
 		return;
 	}
 
@@ -353,7 +353,7 @@ void sim_writesim(NODEPROTO *simnt, INTSML format)
 		channelrestore(0, save0);
 		channelrestore(1, save1);
 		channelrestore(2, save2);
-		ttyputerr("Cannot run simulator %s", simprog);
+		ttyputerr(_("Cannot run simulator %s"), simprog);
 		exit(1);
 	}
 
@@ -374,14 +374,14 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 
 	if (sim_simnt == NONODEPROTO)
 	{
-		ttyputerr("No simulation done");
+		ttyputerr(_("No simulation done"));
 		return(1);
 	}
 
 	/* make sure user is still in the same facet */
 	if (sim_simnt != getcurfacet())
 	{
-		ttyputerr("Simulation was done on facet %s; please edit that facet",
+		ttyputerr(_("Simulation was done on facet %s; please edit that facet"),
 			describenodeproto(sim_simnt));
 		return(1);
 	}
@@ -393,7 +393,7 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 			if (namesame(nonum, pp->protoname) == 0) break;
 		if (pp == NOPORTPROTO)
 		{
-			ttyputerr("Cannot find a port called '%s'", nonum);
+			ttyputerr(_("Cannot find a port called '%s'"), nonum);
 			return(1);
 		}
 		want = (INTSML)pp->temp1;
@@ -457,7 +457,7 @@ INTSML sim_simpointout(char *nonum, INTSML format)
 	/* look for node number */
 	if (sim_simsearch(want, sim_simnt, format) != 0)
 	{
-		ttyputerr("Cannot find node '%s'", nonum);
+		ttyputerr(_("Cannot find node '%s'"), nonum);
 		return(1);
 	}
 	return(0);
@@ -473,7 +473,6 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER NODEINST *ni;
-	extern AIDENTRY *us_aid, *net_aid;
 	REGISTER NODEPROTO *np, *snp;
 	REGISTER INTBIG type;
 
@@ -551,7 +550,7 @@ INTSML sim_simsearch(INTSML want, NODEPROTO *facet, INTSML format)
 		/* initialize network numbers on every portinst on this nodeinst */
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto) pp->temp1 = 0;
 
-		/* set network numbers from arcs and exported ports */
+		/* set network numbers from arcs and exports */
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			pp = pi->proto;
@@ -612,14 +611,14 @@ void sim_resumesim(INTSML firsttime)
 
 	if (sim_process == 1)
 	{
-		ttyputerr("Cannot communicate with the simulator");
+		ttyputerr(_("Cannot communicate with the simulator"));
 		return;
 	}
-	ttyputmsg("YOU ARE TALKING TO THE SIMULATOR '%s'", sim_name);
+	ttyputmsg(_("YOU ARE TALKING TO THE SIMULATOR '%s'"), sim_name);
 
 	if (firsttime)
 	{
-		ttyputmsg("Type 'help' if you need it");
+		ttyputmsg(_("Type 'help' if you need it"));
 		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_format);
 		if (var == NOVARIABLE) format = -1; else format = var->addr;
 		if (format == RNL)
@@ -648,11 +647,11 @@ void sim_resumesim(INTSML firsttime)
 				sim_process = -1;
 				var = getvalkey((INTBIG)sim_aid, VAID, VSTRING, sim_netfile);
 				if (var != NOVARIABLE)
-					ttyputmsg("Net list saved in '%s'", (char *)var->addr);
+					ttyputmsg(_("Net list saved in '%s'"), (char *)var->addr);
 				return;
 			case 3:			/* pause the simulation */
 				if (firsttime)
-					ttyputmsg("Type '-tellaid simulation resume' to return");
+					ttyputmsg(_("Type '-tellaid simulation resume' to return"));
 				return;
 		}
 
@@ -678,7 +677,7 @@ void sim_resumesim(INTSML firsttime)
 		}
 		if (ttydataready() != 0) sim_simtell();
 
-		ttyputmsg("Abnormal simulator termination");
+		ttyputmsg(_("Abnormal simulator termination"));
 		longjmp(sim_userdone, 2);
 	}
 }
@@ -688,7 +687,6 @@ void sim_simtell(void)
 	char *newpar[2];
 	REGISTER char *pp;
 	REGISTER INTSML len;
-	extern AIDENTRY *us_aid;
 	REGISTER VARIABLE *var;
 
 	for(;;)
@@ -714,12 +712,12 @@ void sim_simtell(void)
 	if (*pp == 'q')
 	{
 		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_format);
-		if (var != NOVARIABLE && var->addr == RNL) *pp = 04;
+		if (var != NOVARIABLE && var->addr == RNL) *pp = CTRLDKEY;
 	}
 	len = strlen(pp);
 	if (len > 0) (void)ewrite(sim_tosim[1], pp, len);
 	(void)ewrite(sim_tosim[1], "\n", 1);
-	if (*pp == 'q' || *pp == 04) longjmp(sim_userdone, 2);
+	if (*pp == 'q' || *pp == CTRLDKEY) longjmp(sim_userdone, 2);
 	longjmp(sim_userdone, 1);
 }
 
@@ -737,7 +735,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 	REGISTER char *str;
 
 	/* stop if requested */
-	if (stopping("Deck generation") != 0) return;
+	if (stopping(STOPREASONDECK)) return;
 
 	/* reset the arcinst node values */
 	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -795,7 +793,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 		for(pp=np->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
 			pp->temp1 = 0;
 
-		/* set network numbers from arcs and exported ports */
+		/* set network numbers from arcs and exports */
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			pp = pi->proto;
@@ -850,7 +848,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTSML format)
 		if ((type == NPSUBSTRATE && np->firstportproto->temp1 != sim_vdd) ||
 			(type == NPWELL && np->firstportproto->temp1 != sim_gnd))
 		{
-			ttyputmsg("WARNING: node %s in facet %s not connected to proper supply",
+			ttyputmsg(_("WARNING: node %s in facet %s not connected to proper supply"),
 				describenodeinst(ni), describenodeproto(facet));
 		}
 
@@ -931,11 +929,11 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 	REGISTER char *str;
 
 	/* stop if requested */
-	if (stopping("Deck generation") != 0) return;
+	if (stopping(STOPREASONDECK)) return;
 
 	xprintf(f, "| cell %s\n", facet->cell->cellname);
 
-	lambda = el_curtech->deflambda; /* setup lambda for scaling */
+	lambda = lambdaoffacet(facet); /* setup lambda for scaling */
 	lambda_2 = lambda*lambda;
 
 	/* reset the arcinst node values */
@@ -1006,7 +1004,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 		for(pp=np->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
 			pp->temp1 = 0;
 
-		/* set network numbers from arcs and exported ports */
+		/* set network numbers from arcs and exports */
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			pp = pi->proto;
@@ -1062,7 +1060,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 		if ((type == NPSUBSTRATE && np->firstportproto->temp1 != sim_vdd) ||
 			(type == NPWELL && np->firstportproto->temp1 != sim_gnd))
 		{
-			ttyputmsg("WARNING: node %s in facet %s not connected to proper supply",
+			ttyputmsg(_("WARNING: node %s in facet %s not connected to proper supply"),
 				describenodeinst(ni), describenodeproto(facet));
 		}
 
@@ -1120,11 +1118,11 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 					if (pi->proto->network == source->network) xprintf(f, " s="); else
 						if (pi->proto->network == drain->network) xprintf(f, " d="); else
 							if (pi->proto->network == gate->network) xprintf(f, " g="); else
-								ttyputerr("Bad cosmos gate/source/drain transistor variable %s",
+								ttyputerr(_("Bad cosmos gate/source/drain transistor variable %s"),
 									(char *)var->addr);
 					if (var->type == VINTEGER) xprintf(f, "Sim:%ld", var->addr); else
 						if (var->type == VSTRING) xprintf(f, "Sim:%s", (char *)var->addr); else
-							ttyputerr("Bad cosmos attribute type");
+							ttyputerr(_("Bad cosmos attribute type"));
 				}
 			}
 			var = getvalkey((INTBIG)ni, VNODEINST, -1, sim_cosmos_attribute);
@@ -1153,7 +1151,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTSML format)
 
 /*
  * routine to generate the name of simulation node "node" and return the
- * string name (either a numeric node number if internal, an exported port
+ * string name (either a numeric node number if internal, an export
  * name if at the top level, or "power", "ground", etc. if special).  The
  * "format" is the particular simuator being used
  */
@@ -1183,13 +1181,13 @@ char *sim_makenodename(INTBIG node, INTSML format)
 	}
 	if (node == sim_phi2l) return("phi2l");
 
-	/* see if it is an exported port name */
+	/* see if it is an export name */
 	for(pp = sim_simnt->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (pp->temp1 == node && pp->temp2 >= 0) break;
 	if (pp != NOPORTPROTO) return(pp->protoname);
 
 	/* this is an error, but can be handled anyway */
-	ttyputmsg("simsim: should have real name for node %ld", node);
+	ttyputmsg(_("simsim: should have real name for node %ld"), node);
 	(void)sprintf(line, "%ld", node);
 	return(line);
 }
