@@ -100,10 +100,12 @@
  * SRP921116: Changed warning messages in spice file to comments so that
  *      simulator can test file
  *
+ * TADR20000805 Added dependent sources CCVS CCCS VCVS VCCS
+ *
  * To properly simulate a facet, it must have the following (many of these
  * commands are found in the "spice.mac" command file):
  *
- * 1) Power and ground must be exported and explicitly connected to sources.
+ * 1) Power and ground must be exports and explicitly connected to sources.
  *    You can do this with a power source (the primitive node prototype
  *    "schematic:source") which must be connected to power at the top and to
  *    ground at the bottom.  The source should then be parameterized to
@@ -111,7 +113,7 @@
  *    to make a 5 volt supply, create a source node and use:
  *        setsource v "DC 5"
  *
- * 2) All input ports must be exported and connected to the positive side
+ * 2) All input ports must be exports and connected to the positive side
  *    of sources (again, the "schematic:source" node).  Time values may be
  *    placed on the source nodes.  For example, if the source is to produce
  *    values that are 0 volts from 0 to 10NS and then 5 volts, use:
@@ -134,7 +136,7 @@
  *    Where X is a unique name or number, and N+ and N- are the nodes which
  *    are connected to the source.
  *
- * 3) All values that are being watched must be exported and have meters
+ * 3) All values that are being watched must be exports and have meters
  *    placed on them.  The primitive nodeproto "schematic:meter" can be placed
  *    anywhere and it should have the top and bottom ports connected
  *    appropriately.  For the meter to watch voltage from 0 to 5 volts, use:
@@ -213,11 +215,9 @@
  *
  * (11) You can use the contents of a file to replace the extracted description
  *    of any facet, by attaching the name of the file as a variable
- *    called "SIM_spice_behave_file" to the prototype. This can be done by
- *    using the "variables" menu of the GUI, or by the 'var set ~.proto'
- *    keyboard command. The extractor will always use the file, if found,
- *    instead of extracting the facet network, but it will still extract
- *    any subfacets in the facet. These in turn could also be described by
+ *    called "SIM_spice_behave_file" to the prototype.  The extractor will always
+ *    use the file, if found, instead of extracting the facet network, but it will
+ *    still extract any subfacets in the facet. These in turn could also be described by
  *    behavior files. If an icon or different view is used, it can have a
  *    different behavior file than the other views.
  *
@@ -306,6 +306,11 @@
 #define SPICETRANS      29	/* generic (special) transistor */
 #define SPICEGROUND     30	/* A node connected to ground */
 #define SPICEPOWER      31	/* A node connected to power */
+#define SPICECCCS       32	/* Current Controlled Current Source */
+#define SPICECCVS       33	/* Current Controlled Voltage Source */
+#define SPICEVCCS       34	/* Voltage Controlled Current Source */
+#define SPICEVCVS       35	/* Voltage Controlled Voltage Source */
+#define SPICETLINE      36	/* Transmission Line */
 
 /* Types of spice sources */
 #define SPICENORMAL     0	/* normal source */
@@ -498,20 +503,19 @@ void sim_writespice(NODEPROTO *np)
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *onp;
 	REGISTER TECHNOLOGY *tech, *t;
-	extern AIDENTRY *net_aid;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the simulation command");
+		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
 
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Must have a facet to edit");
+		ttyputerr(_("Must have a facet to edit"));
 		return;
 	}
 
@@ -552,11 +556,11 @@ void sim_writespice(NODEPROTO *np)
 	(void)strcpy(deckfile, np->cell->cellname);
 	(void)strcat(deckfile, ".spi");
 	pt = deckfile;
-	spfile = xcreate(deckfile, FILETYPESPICE, "SPICE File", &pt);
+	spfile = xcreate(deckfile, sim_filetypespice, _("SPICE File"), &pt);
 	if (pt != 0) (void)strcpy(deckfile, pt);
 	if (spfile == NULL)
 	{
-		ttyputerr("Cannot create SPICE file: %s", deckfile);
+		ttyputerr(_("Cannot create SPICE file: %s"), deckfile);
 		return;
 	}
 
@@ -587,15 +591,15 @@ void sim_writespice(NODEPROTO *np)
 
 	/* recursively write all facets below this one */
 	retval = sim_spicewritefacet(np, spfile, 1);
-	if (retval < 0) ttyputerr("No memory");
+	if (retval < 0) ttyputnomemory();
 	if (retval > 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	/* handle DC and TRAN cards */
 	if (sim_spice_dc == NULL && sim_spice_tran == NULL && sim_spice_ac == NULL)
-		ttyputerr("Warning: should have a DC, Transient or AC source node");
+		ttyputerr(_("Warning: should have a DC, Transient or AC source node"));
 	if ((sim_spice_dc!=NULL)+(sim_spice_tran!=NULL)+(sim_spice_ac!=NULL) > 1)
-		ttyputerr("Warning: can only have one DC, Transient or AC source node");
+		ttyputerr(_("Warning: can only have one DC, Transient or AC source node"));
 	if (sim_spice_tran != NULL)
 	{
 		sim_spice_xprintf(spfile, "%s\n", sim_spice_tran);
@@ -612,7 +616,7 @@ void sim_writespice(NODEPROTO *np)
 
 	sim_spice_writetrailer(np->cell, spfile, tech);
 	sim_spice_xprintf(spfile, ".END\n");
-	ttyputmsg("%s written", deckfile);
+	ttyputmsg(_("%s written"), deckfile);
 	xclose(spfile);
 	efree((char *)sim_spice_extra_area);
 
@@ -623,7 +627,7 @@ void sim_writespice(NODEPROTO *np)
 	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_dontrun);
 	if (var != NOVARIABLE && var->addr != SIMRUNNO)
 	{
-		ttyputmsg("Running SPICE...");
+		ttyputmsg(_("Running SPICE..."));
 		var = getvalkey((INTBIG)sim_aid, VAID, VSTRING, sim_listingfile);
 		if (var == NOVARIABLE) sim_spice_execute(deckfile, ""); else
 			sim_spice_execute(deckfile, (char *)var->addr);
@@ -666,7 +670,7 @@ void sim_spice_writeheader(CELL *cell, FILE *spfile, TECHNOLOGY *tech)
 	var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING, "SIM_spice_model_file");
 	if (var != NOVARIABLE)
 	{
-		if ((modelfile = xopen((char *)var->addr, FILETYPESPICE, el_libdir, &filename)) != NULL)
+		if ((modelfile = xopen((char *)var->addr, sim_filetypespice, el_libdir, &filename)) != NULL)
 		{
 			/* copy file */
 			c = (char)xgetc(modelfile);
@@ -676,7 +680,7 @@ void sim_spice_writeheader(CELL *cell, FILE *spfile, TECHNOLOGY *tech)
 				c = (char)xgetc(modelfile);
 			}
 			xclose(modelfile);
-		} else ttyputerr("Warning: cannot open model file: %s", (char **)var->addr);
+		} else ttyputerr(_("Warning: cannot open model file: %s"), (char **)var->addr);
 	} else
 	{
 		/* get the spice level and header from technology */
@@ -690,7 +694,7 @@ void sim_spice_writeheader(CELL *cell, FILE *spfile, TECHNOLOGY *tech)
 			name = (char **)var->addr;
 			j = (INTSML)getlength(var);
 			for(i=0; i<j; i++) sim_spice_xprintf(spfile, "%s\n", name[i]);
-		} else ttyputerr("Warning: no model cards for SPICE level %d in %s technology",
+		} else ttyputerr(_("Warning: no model cards for SPICE level %d in %s technology"),
 			level, tech->techname);
 	}
 
@@ -714,7 +718,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 	PORTPROTO *gate, *source, *drain, *gatedummy;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai;
-	REGISTER NET *net, *gaten, *sourcen, *drainn, *nnet, *posnet, *negnet, *subnet, *tempnet;
+	REGISTER NET *net, *gaten, *gatedn, *sourcen, *drainn, *nnet, *posnet, *negnet, *subnet, *tempnet;
 	float a, b;
 	REGISTER INTSML netindex, state, j, first, found, meterit, i, nodetype, backannotate, retval;
 	INTSML subfacetindex, nodeindex, resistnum, capacnum, inductnum, diodenum;
@@ -726,10 +730,9 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 	char *dummy, c, *filename;
 	FILE *modelfile;
 	char *uncon_diff_type;
-	extern AIDENTRY *net_aid;
 
 	/* stop if requested */
-	if (stopping("Deck generation") != 0) return(-1);
+	if (stopping(STOPREASONDECK)) return(-1);
 
 	/* Look for a model file on the current facet (view) */
 	var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_spice_behave_file");
@@ -741,6 +744,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 		np = sim_spice_topview(np);
 	}
 
+	/* first pass through the node list */
 	/* if there are any sub-facets that have not been written, write them */
 	backannotate = 0;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -775,7 +779,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 	var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_spice_behave_file");
 	if (var != NOVARIABLE)
 	{
-		modelfile = xopen((char *)var->addr, FILETYPESPICE,  el_libdir, &filename);
+		modelfile = xopen((char *)var->addr, sim_filetypespice,  el_libdir, &filename);
 		if (modelfile != NULL)
 		{
 			/* copy file */
@@ -785,8 +789,12 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				(void)xputc(c, f);
 				c = (char)xgetc(modelfile);
 			}
+#if 1
+			for(i=1, pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				pp->temp1 = i++;
+#endif
 			return(backannotate);
-		} else ttyputerr("Warning: cannot open model file: %s", (char *)var->addr);
+		} else ttyputerr(_("Warning: cannot open model file: %s"), (char *)var->addr);
 	}
 
 	/* zero the temp1 for arcs and nodes to compute area */
@@ -826,7 +834,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 		net->nextnet = sim_spice_firstnet;
 		sim_spice_firstnet = net;
 
-		if (sim_spice_debug != 0) ttyputmsg("Starting net %ld",net->netnumber);
+		if (sim_spice_debug != 0) ttyputmsg(_("Starting net %ld"), net->netnumber);
 		sim_spice_arcarea(net, ai); /* builds areas, etc */
 
 		/* get merged polygons so far */
@@ -834,7 +842,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 		mrgdonefacet(sim_spice_evalpolygon);
 	}
 
-	/* now add any unwired but exported ports to the list of nets */
+	/* now add any unwired but exports to the list of nets */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		/* determine the net number of the arc already mentioned */
@@ -901,6 +909,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 
 	posnet = negnet = subnet = NONET;
 
+	/* second pass through the node list */ 
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		state = sim_spice_nodetype(ni, &extra);
@@ -911,14 +920,15 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			posnet = sim_spice_getnet(ni, posport);
 			negnet = sim_spice_getnet(ni, negport);
 			if (posnet == NONET || negnet == NONET)
-				ttyputerr("Warning: %s component not properly connected",
+				ttyputerr(_("Warning: %s component not properly connected"),
 					describenodeinst(ni));
 			continue;
 		}
 		if (state == SPICEUNKNOWN || state == SPICEMETER || state == SPICESOURCEV ||
 			state == SPICESOURCEC || state == SPICESOURCECM || state == SPICESOURCET ||
 			state == SPICESOURCEDC || state == SPICESOURCEAC || state == SPICESOURCEN ||
-			state == SPICESOURCEX || state == SPICESOURCES) continue;
+			state == SPICESOURCEX || state == SPICESOURCES || state == SPICECCCS ||
+			state == SPICECCVS || state == SPICEVCCS || state == SPICEVCVS) continue;
 		if (state == SPICESUBSTRATE)
 		{
 			if (subnet == NONET)
@@ -932,7 +942,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			if (sim_spice_power == NONET) sim_spice_power = tempnet; else
 			{
 				if (tempnet->network != sim_spice_power->network)
-					ttyputerr("Warning: there may be inconsistent power networks in %s",
+					ttyputerr(_("Warning: there may be inconsistent power networks in %s"),
 						describenodeproto(np));
 			}
 		}
@@ -944,7 +954,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			if (sim_spice_ground == NONET) sim_spice_ground = tempnet; else
 			{
 				if (tempnet->network != sim_spice_ground->network)
-					ttyputerr("Warning: there may be inconsistent ground networks in %s",
+					ttyputerr(_("Warning: there may be inconsistent ground networks in %s"),
 						describenodeproto(np));
 			}
 		}
@@ -999,20 +1009,20 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 
 	if (sim_spice_power == NONET && top)
 	{
-		ttyputerr("Warning: cannot find power in the circuit");
-		ttyputmsg("     Must export power port or use a 'DC' source node");
+		ttyputerr(_("Warning: cannot find power in the circuit"));
+		ttyputmsg(_("     Must have power export or use a 'DC' source node"));
 	}
 	if (sim_spice_ground == NONET && top)
 	{
-		ttyputerr("Warning: cannot find ground in the circuit");
-		ttyputmsg("     Must export ground port or use a 'DC' source node");
+		ttyputerr(_("Warning: cannot find ground in the circuit"));
+		ttyputmsg(_("     Must have ground export or use a 'DC' source node"));
 	}
 
 	if (pmostrans != 0 && posnet == NONET)
 	{
 		if (sim_spice_power == NONET)
 		{
-			ttyputerr("Warning: no power connection for P-transistor wells in %s",
+			ttyputerr(_("Warning: no power connection for P-transistor wells in %s"),
 				describenodeproto(np));
 		} else posnet = sim_spice_power;
 	}
@@ -1020,16 +1030,16 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 	{
 		if (sim_spice_ground == NONET)
 		{
-			ttyputerr("Warning: no connection for N-transistor wells in %s",
+			ttyputerr(_("Warning: no connection for N-transistor wells in %s"),
 				describenodeproto(np));
 		} else negnet = sim_spice_ground;
 	}
 
 	if (bipolars != 0 && subnet == NONET)
 	{
-		ttyputerr("Warning: no explicit connection to the substrate in cell %s",
+		ttyputerr(_("Warning: no explicit connection to the substrate in cell %s"),
 			describenodeproto(np));
-		ttyputmsg("     A connection to ground will be assumed if necessary.");
+		ttyputmsg(_("     A connection to ground will be assumed if necessary."));
 		subnet = sim_spice_ground;
 	}
 
@@ -1085,6 +1095,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 	/* now run through all components in the facet */
 	resistnum = capacnum = inductnum = diodenum = 1;
 
+	/* third pass through the node list, print it this time */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* get the type of this node */
@@ -1138,7 +1149,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			{
 				sim_spice_xprintf(f, "**ERROR: subfacet %s is not fully connected\n",
 					describenodeinst(ni));
-				ttyputmsg("ERROR: subfacet %s is not fully connected in facet %s",
+				ttyputmsg(_("ERROR: subfacet %s is not fully connected in facet %s"),
 					describenodeinst(ni), describenodeproto(np));
 			}
 			continue;
@@ -1187,6 +1198,8 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 		gaten = sim_spice_getnet(ni, gate);     /* base */
 		sourcen = sim_spice_getnet(ni, source); /* emitter */
 		drainn = sim_spice_getnet(ni, drain);   /* collector */
+		if (gatedummy != NOPORTPROTO)
+			gatedn = sim_spice_getnet(ni, gatedummy);
 
 		/* make sure transistor is connected to nets */
 		if (sourcen == NONET || gaten == NONET || drainn == NONET)
@@ -1226,6 +1239,58 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				sim_spice_xputs(sim_spice_node_name(negnet), f);
 				sim_spice_xprintf(f, " %s", ni->proto->primname);
 				break;
+			case SPICEVCVS:	    /* current controlled Current source */
+				sim_spice_xputs(sim_spice_element_name(ni, 'E', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gatedn), f);
+				sim_spice_xputs(sim_spice_node_name(drainn), f);
+				sim_spice_xputs(sim_spice_node_name(gaten), f);
+				sim_spice_xputs(sim_spice_node_name(sourcen), f);
+				if (info != NULL) sim_spice_xprintf(f, " %s",info);
+				break;
+			case SPICEVCCS:	    /* current controlled Current source */
+				sim_spice_xputs(sim_spice_element_name(ni, 'G', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gatedn), f);
+				sim_spice_xputs(sim_spice_node_name(drainn), f);
+				sim_spice_xputs(sim_spice_node_name(gaten), f);
+				sim_spice_xputs(sim_spice_node_name(sourcen), f);
+				if (info != NULL) sim_spice_xprintf(f, " %s",info);
+				break;
+			case SPICECCVS:	    /* current controlled Current source */
+				sim_spice_xputs("*CCVS\n", f); 
+				sim_spice_xputs(sim_spice_element_name(ni, 'V', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gaten), f);
+				sim_spice_xputs(sim_spice_node_name(sourcen), f);
+				sim_spice_xputs(" 0V\n", f);
+				sim_spice_xputs(sim_spice_element_name(ni, 'H', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gatedn), f);
+				sim_spice_xputs(sim_spice_node_name(drainn), f);
+				sim_spice_xputs(" ", f);  /* y */
+				sim_spice_xputs(sim_spice_element_name(ni, 'V', &nodeindex), f);
+				if (info != NULL) sim_spice_xprintf(f, " %s",info);
+				sim_spice_xputs("\n*", f);
+				break;
+			case SPICECCCS:	    /* current controlled Current source */
+				sim_spice_xputs("*CCCS\n", f); 
+				sim_spice_xputs(sim_spice_element_name(ni, 'V', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gaten), f);
+				sim_spice_xputs(sim_spice_node_name(sourcen), f);
+				sim_spice_xputs(" 0V\n", f);
+				sim_spice_xputs(sim_spice_element_name(ni, 'F', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gatedn), f);
+				sim_spice_xputs(sim_spice_node_name(drainn), f);
+				sim_spice_xputs(" ", f);  /* y */
+				sim_spice_xputs(sim_spice_element_name(ni, 'V', &nodeindex), f);
+				if (info != NULL) sim_spice_xprintf(f, " %s",info);
+				sim_spice_xputs("\n*", f);
+				break;
+			case SPICETLINE:	    /* transmission line source */
+				sim_spice_xputs(sim_spice_element_name(ni, 'T', &nodeindex), f);
+				sim_spice_xputs(sim_spice_node_name(gaten), f);
+				sim_spice_xputs(sim_spice_node_name(sourcen), f);
+				sim_spice_xputs(sim_spice_node_name(gatedn), f);
+				sim_spice_xputs(sim_spice_node_name(drainn), f);
+				if (info != NULL) sim_spice_xprintf(f, " %s",info);
+				break;
 			case SPICENMOS:	  /* NMOS (Enhancement) transistor */
 				sim_spice_xputs(sim_spice_element_name(ni, 'M', &nodeindex), f);
 				sim_spice_xputs(sim_spice_node_name(drainn), f);
@@ -1480,7 +1545,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				break;
 		}
 
-		/* make sure both connections are exported */
+		/* make sure both connections are exports */
 		if (found != SPICEEXTENSION)
 		{
 			if (sourcen != NONET)
@@ -1488,7 +1553,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					if (pp->temp1 == sourcen->netnumber) break;
 				if (pp == NOPORTPROTO)
-					ttyputerr("Warning: top of %s in facet %s not connected to exported port",
+					ttyputerr(_("Warning: top of %s in facet %s not connected to an export"),
 						sim_spice_describesource(ni), describenodeproto(np));
 			}
 			if (drainn != NONET)
@@ -1496,7 +1561,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					if (pp->temp1 == drainn->netnumber) break;
 				if (pp == NOPORTPROTO)
-					ttyputerr("Warning: bottom of %s in facet %s not connected to exported port",
+					ttyputerr(_("Warning: bottom of %s in facet %s not connected to an export"),
 						sim_spice_describesource(ni), describenodeproto(np));
 			}
 		}
@@ -1506,7 +1571,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			case SPICENORMAL:      /* handle normal source specification */
 				if (sourcen == NONET || drainn == NONET)
 				{
-					ttyputerr("ERROR: %s in facet %s is not fully connected",
+					ttyputerr(_("ERROR: %s in facet %s is not fully connected"),
 						sim_spice_describesource(ni), describenodeproto(np));
 					/* break; */
 				}
@@ -1521,7 +1586,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				if (meterit != 0)
 				{
 					if (!top)
-						ttyputerr("Warning: cannot meter source in subfacet: %s",
+						ttyputerr(_("Warning: cannot meter source in subfacet: %s"),
 							describenodeproto(ni->proto));
 					else
 					{
@@ -1540,11 +1605,11 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			case SPICETRAN:     /* handle transient analysis specification */
 				if (sim_spice_tran != 0)
 				{
-					ttyputerr("Warning: should be only one Transient source");
+					ttyputerr(_("Warning: should be only one Transient source"));
 					efree(sim_spice_tran);
 				}
 				if (top == 0)
-					ttyputerr("Warning: Transient source node found in subfacet %s",
+					ttyputerr(_("Warning: Transient source node found in subfacet %s"),
 						describenodeproto(np));
 
 				/* create the .TRAN card */
@@ -1558,17 +1623,17 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			case SPICEDC:       /* handle DC analysis specification */
 				if (sourcen == NONET || drainn == NONET)
 				{
-					ttyputerr("ERROR: DC %s in facet %s is not fully connected",
+					ttyputerr(_("ERROR: DC %s in facet %s is not fully connected"),
 						sim_spice_describesource(ni), describenodeproto(np));
 					/* break; */
 				}
 				if (sim_spice_dc != 0)
 				{
-					ttyputerr("Warning: should be only one DC source");
+					ttyputerr(_("Warning: should be only one DC source"));
 					efree(sim_spice_dc);
 				}
 				if (top == 0)
-					ttyputerr("Warning: DC source node found in subfacet %s", describenodeproto(np));
+					ttyputerr(_("Warning: DC source node found in subfacet %s"), describenodeproto(np));
 
 				/* write the source to the deck */
 				dummy = sim_spice_element_name(ni, sourcetype, &sim_spice_sourceindex);
@@ -1580,7 +1645,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 				if (meterit != 0)
 				{
 					if (!top)
-						ttyputerr("Warning: cannot meter source in subfacet: %s",
+						ttyputerr(_("Warning: cannot meter source in subfacet: %s"),
 							describenodeproto(ni->proto));
 					else
 					{
@@ -1608,10 +1673,10 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			case SPICEAC:			/* handle ac analysis specification */
 				if (sim_spice_ac != 0)
 				{
-					ttyputerr("Warning: should be only one AC source");
+					ttyputerr(_("Warning: should be only one AC source"));
 					efree(sim_spice_ac);
 				}
-				if (top == 0) ttyputerr("Warning: Transient source node found in subfacet %s",
+				if (top == 0) ttyputerr(_("Warning: Transient source node found in subfacet %s"),
 					describenodeproto(np));
 
 				/* create the .AC card */
@@ -1624,7 +1689,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 			case SPICENODESET:		/* handle NODESET specification */
 				if (sourcen == NONET)
 				{
-					ttyputerr("ERROR: %s in facet %s has unconnected positive terminal",
+					ttyputerr(_("ERROR: %s in facet %s has unconnected positive terminal"),
 						sim_spice_describesource(ni), describenodeproto(np));
 					break;
 				}
@@ -1682,26 +1747,26 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 		drainn = sim_spice_getnet(ni, drain);
 		if (sourcen == NONET)
 		{
-			ttyputerr("ERROR: Top of %s component in facet %s is not connected",
+			ttyputerr(_("ERROR: Top of %s component in facet %s is not connected"),
 				describenodeinst(ni), describenodeproto(np));
 			continue;
 		}
 
-		/* make sure meter is connected to exported ports */
+		/* make sure meter is connected to exports */
 		for(pp=np->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
 			if (pp->temp1 == sourcen->netnumber) break;
 		if (pp == NOPORTPROTO)
-			ttyputerr("Warning: top of %s component in facet %s not connected to exported port",
+			ttyputerr(_("Warning: top of %s component in facet %s not connected to an export"),
 				describenodeinst(ni), describenodeproto(np));
 		if (drainn != NONET)
 		{
 			for(pp=np->firstportproto; pp!=NOPORTPROTO; pp=pp->nextportproto)
 				if (pp->temp1 == sourcen->netnumber) break;
 			if (pp == NOPORTPROTO)
-				ttyputerr("Warning: bottom of %s component in facet %s not connected to exported port",
+				ttyputerr(_("Warning: bottom of %s component in facet %s not connected to anexport"),
 					describenodeinst(ni), describenodeproto(np));
 		}
-		if (top == 0) ttyputerr("Warning: Meter node found in subfacet %s", describenodeproto(np));
+		if (top == 0) ttyputerr(_("Warning: Meter node found in subfacet %s"), describenodeproto(np));
 
 		/* begin printing the meter card */
 		if (first == 0)
@@ -1786,7 +1851,7 @@ INTSML sim_spicewritefacet(NODEPROTO *np, FILE *f, INTSML top)
 					uncon_diff_type = "";
 					break;
 			}
-			ttyputerr("Warning: SPICE node%s has unconnected%s device diffusion",
+			ttyputerr(_("Warning: SPICE node%s has unconnected%s device diffusion"),
 				sim_spice_node_name(net), uncon_diff_type);
 		}
 	}
@@ -1844,6 +1909,11 @@ INTSML sim_spice_nodetype(NODEINST *ni, char **extra)
 		case NPARRAY:       return(SPICEARRAY);
 		case NPCONGROUND:   return(SPICEGROUND);
 		case NPCONPOWER:    return(SPICEPOWER);
+		case NPCCCS:        return(SPICECCCS);
+		case NPCCVS:        return(SPICECCVS);
+		case NPVCCS:        return(SPICEVCCS);
+		case NPVCVS:        return(SPICEVCVS);
+		case NPTLINE:       return(SPICETLINE);
 	}
 	return(SPICEUNKNOWN);
 }
@@ -1866,7 +1936,7 @@ NET *sim_spice_getnet(NODEINST *ni, PORTPROTO *pp)
 			if (pi->conarcinst->network == net->network) return(net);
 	}
 
-	/* search for exported ports on the node, connected to this port */
+	/* search for exports on the node, connected to this port */
 	for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 		if (pe->proto->network == pp->network)
 	{
@@ -1886,7 +1956,7 @@ NET *sim_spice_getnet(NODEINST *ni, PORTPROTO *pp)
  */
 void sim_spice_nodearea(NET *net, NODEINST *ni, PORTPROTO *pp)
 {
-	REGISTER INTSML tot, i, function;
+	REGISTER INTBIG tot, i, function;
 	REGISTER INTBIG fun;
 	XARRAY trans;
 	INTBIG lx, hx, ly, hy;
@@ -1928,7 +1998,7 @@ void sim_spice_nodearea(NET *net, NODEINST *ni, PORTPROTO *pp)
 
 		/* make linked list of polygons */
 		lastpoly = firstpoly = NOPOLYGON;
-		tot = nodeEpolys(ni);
+		tot = nodeEpolys(ni, 0);
 		for(i=0; i<tot; i++)
 		{
 			poly = sim_allocpolygon();
@@ -2002,13 +2072,13 @@ void sim_spice_nodearea(NET *net, NODEINST *ni, PORTPROTO *pp)
 			if (tech != el_curtech || j == 0)
 			{
 				if (sim_spice_debug != 0)
-					ttyputmsg("%s POLYGON ON %s NODE IGNORED IN %s TECHNOLOGY",
+					ttyputmsg(_("%s POLYGON ON %s NODE IGNORED IN %s TECHNOLOGY"),
 						layername(tech, poly->layer), ni->proto->cell->cellname, tech->techname);
 				continue;
 			}
 			sim_spice_store_box(tech, poly->layer, hx-lx, hy-ly, (lx+hx)/2, (ly+hy)/2);
 			if (sim_spice_debug != 0)
-				ttyputmsg("BOX: %ld to %ld; %ld to %ld; layer %s",lx,hx,ly,hy,
+				ttyputmsg(_("BOX: %ld to %ld; %ld to %ld; layer %s"), lx, hx, ly, hy,
 					layername(tech,poly->layer));
 			if (sim_spice_layerisdiff(tech, poly->layer) == ISNONE &&
 				poly->layer != dominant)
@@ -2043,7 +2113,7 @@ void sim_spice_nodearea(NET *net, NODEINST *ni, PORTPROTO *pp)
  */
 void sim_spice_arcarea(NET *net, ARCINST *ai)
 {
-	REGISTER INTSML i, tot;
+	REGISTER INTBIG i, tot;
 	REGISTER TECHNOLOGY *tech;
 	static POLYGON *poly = NOPOLYGON;
 	INTBIG lx, hx, ly, hy;
@@ -2064,7 +2134,7 @@ void sim_spice_arcarea(NET *net, ARCINST *ai)
 		if (tech != el_curtech || j == 0)
 		{
 			if (sim_spice_debug != 0)
-				ttyputmsg("%s POLYGON ON %s ARC IGNORED IN %s TECHNOLOGY",
+				ttyputmsg(_("%s POLYGON ON %s ARC IGNORED IN %s TECHNOLOGY"),
 					layername(tech, poly->layer), describearcinst(ai), tech->techname);
 			continue;
 		}
@@ -2073,7 +2143,8 @@ void sim_spice_arcarea(NET *net, ARCINST *ai)
 			(!isdiffarc && sim_spice_capacitance(tech, poly->layer) > 0.0))
 				sim_spice_store_box(tech, poly->layer, hx-lx, hy-ly, (lx+hx)/2, (ly+hy)/2);
 		if (sim_spice_debug != 0)
-			ttyputmsg("BOX: %ld to %ld; %ld to %ld; layer %s",lx,hx,ly,hy, layername(tech,poly->layer));
+			ttyputmsg(_("BOX: %ld to %ld; %ld to %ld; layer %s"), lx, hx, ly, hy,
+				layername(tech,poly->layer));
 	}
 
 	/* propagate to all of the nodes on this arc */
@@ -2127,7 +2198,7 @@ char *sim_spice_element_name(NODEINST *ni, char first, INTSML *counter)
 	varname = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 	if (varname == NOVARIABLE)
 	{
-		ttyputerr("SPICE generation warning: no name on node %s", describenodeinst(ni));
+		ttyputerr(_("SPICE generation warning: no name on node %s"), describenodeinst(ni));
 		(void)sprintf(s, "%c%d", first, (*counter)++);
 	} else
 	{
@@ -2309,7 +2380,7 @@ void sim_spice_evalpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG
 
 	if (sim_spice_debug != 0)
 	{
-		ttyputmsg("** Evaluating polygon on Layer: %s; Net: %ld",
+		ttyputmsg(_("** Evaluating polygon on Layer: %s; Net: %ld"),
 			layername(tech, layer), sim_spice_cur_net->netnumber);
 	}
 
@@ -2344,7 +2415,7 @@ void sim_spice_evalpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG
 				sim_spice_mask_scale;
 	}
 	if (sim_spice_debug != 0)
-		ttyputmsg("Area: %f , Perim: %ld Cap: %f", area, perim, sim_spice_cur_net->capacitance);
+		ttyputmsg(_("Area: %f , Perim: %ld Cap: %f"), area, perim, sim_spice_cur_net->capacitance);
 }
 
 /******************** ROUTINES TO ACCESS VARIABLES ********************/
@@ -2432,7 +2503,7 @@ NODEPROTO *sim_spice_topview(NODEPROTO *np)
 
 	if (np == NONODEPROTO) return(NONODEPROTO);
 
-	if (np->primindex != 0) return (NONODEPROTO);    /* must be complex */
+	if (np->primindex != 0) return(NONODEPROTO);    /* must be complex */
 
 	/* Now look for views */
 	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
@@ -2520,7 +2591,7 @@ void sim_spice_writetrailer(CELL *cell, FILE *spfile, TECHNOLOGY *tech)
 	var = getval((INTBIG)tech, VTECHNOLOGY, VSTRING, "SIM_spice_trailer_file");
 	if (var != NOVARIABLE)
 	{
-		trailerfile = xopen((char *)var->addr, FILETYPESPICE, el_libdir, &truename);
+		trailerfile = xopen((char *)var->addr, sim_filetypespice, el_libdir, &truename);
 		if (trailerfile != NULL)
 		{
 			/* copy file */
@@ -2532,7 +2603,7 @@ void sim_spice_writetrailer(CELL *cell, FILE *spfile, TECHNOLOGY *tech)
 			}
 			xclose(trailerfile);
 		} else
-			ttyputerr("Warning: cannot open trailer file: %s", (char **)var->addr);
+			ttyputerr(_("Warning: cannot open trailer file: %s"), (char **)var->addr);
 	}
 }
 
