@@ -84,15 +84,15 @@ void sim_writetexnetlist(NODEPROTO *np)
 	/* write the "TDL" file */
 	(void)strcpy(filename, np->cell->cellname);
 	(void)strcat(filename, ".tdl");
-	sim_texfile = xcreate(filename, FILETYPETEGAS, "TEGAS File", &truename);
+	sim_texfile = xcreate(filename, sim_filetypetegas, _("TEGAS File"), &truename);
 	if (sim_texfile == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 
 	/* read list of reserved words into an infinite string, each separated by "\n" */
-	reservefile = xopen(RESFILE, FILETYPETEGASTAB, "", &resfilename);
+	reservefile = xopen(RESFILE, sim_filetypetegastab, "", &resfilename);
 
 	sim_texstrprint("/* GENERATED BY THE ELECTRIC VLSI DESIGN SYSTEM */\n\n");
 	sim_texstrprint("COMPILE  ;\n\n");
@@ -104,15 +104,15 @@ void sim_writetexnetlist(NODEPROTO *np)
 	length = strlen(libname);
 	if (length > 12)
 	{
-		ttyputmsg("Library name exceeds 12 characters, The name used for the");
-		ttyputmsg("TDL directory will be truncated to :- %s", sim_texname(libname));
+		ttyputmsg(_("Library name exceeds 12 characters, The name used for the"));
+		ttyputmsg(_("TDL directory will be truncated to :- %s"), sim_texname(libname));
 	}
 
 	/* check library name */
 	if (sim_texcheckname(sim_texname(libname)))
 		strcat(str1, sim_texname(libname)); else
 	{
-		ttyputerr("%s IS A RESERVED WORD, RENAME LIBRARY AND RE-RUN", sim_texname(libname));
+		ttyputerr(_("%s IS A RESERVED WORD, RENAME LIBRARY AND RE-RUN"), sim_texname(libname));
 		return;
 	}
 
@@ -136,7 +136,7 @@ void sim_writetexnetlist(NODEPROTO *np)
 	if (reservefile != NULL) xclose(reservefile);
 	xclose(sim_texfile);
 
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 }
 
 void sim_writetexcell(NODEPROTO *np, INTBIG top)
@@ -313,7 +313,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 				/* if there is a separator, directory name comes after it */
 				if ((separator = sim_strcspn(describenodeproto(ni->proto), "/")) != length)
 					(void)addstringtoinfstr(sim_texname(
-						describenodeproto(ni->proto) + separator + 1 )); else
+						describenodeproto(ni->proto) + separator + 1)); else
 
 				/* no separator, hence directory name = library name */
 				(void)addstringtoinfstr(sim_texlibname(ni->proto));
@@ -426,7 +426,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 	sim_texstrprint(" END MODULE;\n\n");
 
 	/* if compiled correctly then reset variable */
-	if (module_err != 0) ttyputerr("*** Errors in module %s",
+	if (module_err != 0) ttyputerr(_("*** Errors in module %s"),
 		sim_texname(describenodeproto(np)));
 }
 
@@ -476,7 +476,7 @@ INTSML sim_texcountwires(NODEINST *ni)
 
 /*
  * a routine to return the name of the network which may be net<x> or the
- * name of an exported port on the net
+ * name of an export on the net
  */
 char *sim_texsrcname(NODEINST *ni, PORTARCINST *pai)
 {
@@ -778,49 +778,42 @@ void sim_texerror(INTBIG error, INTBIG *lasterror, char *str)
 	switch (error)
 	{
 		case 1:
-			(void)addstringtoinfstr("UNABLE TO OPEN TDL FILE");
+			(void)addstringtoinfstr(_("UNABLE TO OPEN TDL FILE"));
 			break;
 		case 2:
-			(void)addstringtoinfstr("EXPORTED PORT ");
-			(void)addstringtoinfstr(str);
-			(void)addstringtoinfstr(" MUST BE EITHER INPUT OR OUTPUT");
+			(void)formatinfstr(_("EXPORT %s MUST BE EITHER INPUT OR OUTPUT"), str);
 			break;
 		case 3:
-			(void)addstringtoinfstr("NEGATED ARC MUST BE CONNECTED TO INPUT OR OUTPUT OF NODEINST");
+			(void)addstringtoinfstr(_("NEGATED ARC MUST BE CONNECTED TO INPUT OR OUTPUT OF NODEINST"));
 			break;
 		case 4:
-			(void)addstringtoinfstr("NODETYPE ");
-			(void)addstringtoinfstr(str);
-			(void)addstringtoinfstr(" NOT SUPPORTED");
+			(void)formatinfstr(_("NODETYPE %s NOT SUPPORTED"), str);
 			break;
 		case 5:
-			(void)addstringtoinfstr("UNABLE TO OPEN TDL LISTFILE");
+			(void)addstringtoinfstr(_("UNABLE TO OPEN TDL LISTFILE"));
 			break;
 		case 6:
-			(void)addstringtoinfstr("ERROR IN TDL LISTFILE");
+			(void)addstringtoinfstr(_("ERROR IN TDL LISTFILE"));
 			break;
 		case 7:
-			(void)addstringtoinfstr("PWR / GND NODE UNCONNECTED");
+			(void)addstringtoinfstr(_("PWR / GND NODE UNCONNECTED"));
 			break;
 		case 8:
-			(void)addstringtoinfstr("UNWIRED PORT ");
-			(void)addstringtoinfstr(str);
+			(void)formatinfstr(_("UNWIRED PORT %s"), str);
 			break;
 		case 9:
-			(void)addstringtoinfstr("ONLY ONE INPUT ON ");
-			(void)addstringtoinfstr(str);
+			(void)formatinfstr(_("ONLY ONE INPUT ON %s"), str);
 			break;
 		case 10:
-			(void)addstringtoinfstr("T TYPE FLIP-FLOP MUST BE MS");
+			(void)addstringtoinfstr(_("T TYPE FLIP-FLOP MUST BE MS"));
 			break;
 		case 11:
-			(void)addstringtoinfstr(str);
-			(void)addstringtoinfstr(" IS A RESERVED WORD");
+			(void)formatinfstr(_("%s IS A RESERVED WORD"), str);
 			break;
 	}
 
 	msg = returninfstr();
-	sim_texstrprint("\n/************* ERROR **************/\n/*** ");
+	sim_texstrprint(_("\n/************* ERROR **************/\n/*** "));
 	sim_texstrprint(msg);
 	sim_texstrprint(" ***\n\n");
 	ttyputerr("%s", msg);
@@ -852,7 +845,7 @@ void sim_texstrprint(char *str)
 			charcount = MAXLENGTH;
 
 			/* find a suitable place to break string */
-			while ( !(*max_line_ptr == ',' || *max_line_ptr == ' '))
+			while (!(*max_line_ptr == ',' || *max_line_ptr == ' '))
 			{
 				charcount -=1; max_line_ptr -=1;
 				if (max_line_ptr == start_ptr)   /* no suitable break point */
@@ -1104,7 +1097,7 @@ INTSML sim_texcheckname(char *str)
 		{
 			for(i=0; i != MAXNAMECHARS-1; i++) name[i]= 0;
 			i = 0;
-			while ( !(*p == '\n' || *p =='\0') ) name[i++] = *p++;
+			while (!(*p == '\n' || *p =='\0')) name[i++] = *p++;
 
 			p = fileline;
 			if ((x = strlen(str)) < 2) x = 2;  /* minimum abbrev. is 2 chars */
