@@ -1090,7 +1090,7 @@ void sim_window_drawtracedrag(WINDOWPART *wavewin, INTSML on)
 	if (line < 0 || line >= sim_window_vislines) return;
 	y_pos = (INTSML)((sim_window_vislines - 1 - line) * temp_trace_spacing +
 		31 + sim_window_tracedragyoff);
-	ly = y_pos + sim_window_tracedragtr->nameoff - 1;
+	ly = y_pos + sim_window_tracedragtr->nameoff + 1;
 	hy = ly + sim_window_txthei;
 	lx = 0;
 	hx = 112;
@@ -1234,7 +1234,6 @@ void sim_window_buttonhandler(WINDOWPART *w, INTSML button, INTSML inx, INTSML i
 	float newpos;
 	INTSML ind, temp_trace_spacing, tracelinesmoved;
 	char *par[2];
-	extern AIDENTRY *net_aid;
 	REGISTER DISCHANNEL *tr, *otr, *trprev, *otrprev;
 
 	ttynewcommand();
@@ -1527,8 +1526,9 @@ void sim_window_redisphandler(WINDOWPART *w)
 	screensettextsize(w, TXT10P);
 	sim_window_desc.col = el_colmentxt;
 	(void)initinfstr();
-	if ((w->state&WINDOWSIMULATING) == 0) (void)addstringtoinfstr("Inactive ");
-	(void)addstringtoinfstr("Simulation Window, ? for help");
+	if ((w->state&WINDOWSIMULATING) == 0)
+		(void)addstringtoinfstr(_("Inactive Simulation Window, ? for help")); else
+			(void)addstringtoinfstr(_("Simulation Window, ? for help"));
 	lx = w->uselx;
 	screendrawtext(w, (INTSML)(lx+5), (INTSML)(hy-18), returninfstr(), &sim_window_desc);
 	screeninvertbox(w, lx, hx, (INTSML)(hy-20), hy);
@@ -1587,7 +1587,7 @@ void sim_window_drawtimescale(WINDOWPART *wavewin)
 
 void sim_window_writetracename(WINDOWPART *wavewin, DISCHANNEL *tr)
 {
-	INTSML y_pos, temp_trace_spacing, line, lx, hx, ly, hy, px, py, wid, hei, size;
+	INTSML y_pos, temp_trace_spacing, line, px, py, wid, hei, size;
 	INTBIG maxheight, maxwidth, len, save;
 
 	/* compute positions */
@@ -1595,8 +1595,6 @@ void sim_window_writetracename(WINDOWPART *wavewin, DISCHANNEL *tr)
 	line = tr->position - sim_window_topline;
 	if (line < 0 || line >= sim_window_vislines) return;
 	y_pos = (sim_window_vislines - 1 - line) * temp_trace_spacing + 31;
-	ly = y_pos + tr->nameoff-1;   hy = ly + temp_trace_spacing;
-	lx = 0;                       hx = 112;
 
 	/* draw the vertical line between the label and the trace */
 	sim_window_setcolor(MENGLY);
@@ -1646,7 +1644,7 @@ void sim_window_highlighttrace(WINDOWPART *wavewin, DISCHANNEL *tr, INTSML color
 	line = tr->position - sim_window_topline;
 	if (line < 0 || line >= sim_window_vislines) return;
 	y_pos = (sim_window_vislines - 1 - line) * temp_trace_spacing + 31;
-	ly = y_pos + tr->nameoff-1;   hy = ly + sim_window_txthei;
+	ly = y_pos + tr->nameoff+1;   hy = ly + sim_window_txthei;
 	lx = 0;                       hx = 112;
 
 	sim_window_setmask(LAYERH);
@@ -1894,7 +1892,7 @@ void sim_window_drawgraph(WINDOWPART *wavewin)
 	/* plot it all */
 	for(tr = sim_window_plot; tr != NODISCHANNEL; tr = tr->nextdischannel)
 	{
-		if (stopping("Simulation Redraw") != 0) break;
+		if (stopping(STOPREASONDISPLAY)) break;
 
 		slot = tr->position - sim_window_topline;
 		if (slot < 0 || slot >= sim_window_vislines) continue;
@@ -2179,7 +2177,7 @@ void sim_window_savegraph(void)
 	/* plot it all */
 	for(tr = sim_window_plot; tr != NODISCHANNEL; tr = tr->nextdischannel)
 	{
-		if (stopping("Simulation Redraw") != 0) break;
+		if (stopping(STOPREASONDISPLAY)) break;
 
 		/* compute positions */
 		slot = tr->position - sim_window_topline;
