@@ -294,6 +294,7 @@ void gen_makeunivlist(void)
 	REGISTER INTSML tot;
 	REGISTER ARCPROTO *ap;
 	REGISTER TECHNOLOGY *t;
+	static INTBIG first = 1;
 
 	/* count the number of arcs in all technologies */
 	tot = 0;
@@ -309,21 +310,35 @@ void gen_makeunivlist(void)
 
 	/* fill the array */
 	tot = 0;
-	gen_upconn[tot++] = (ARCPROTO *)0;
+	if (first != 0)
+		gen_upconn[tot++] = (ARCPROTO *)0;
 	for(t = el_technologies; t != NOTECHNOLOGY; t = t->nexttechnology)
 	{
-		for(ap = t->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto) gen_upconn[tot++] = ap;
+		for(ap = t->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
+			gen_upconn[tot++] = ap;
 	}
 	gen_upconn[tot] = NOARCPROTO;
 
 	/* store the array in this technology */
-	gen_u_p[0].portarcs = (INTBIG *)gen_upconn;
-	gen_i_p[0].portarcs = (INTBIG *)gen_upconn;
+	if (first != 0)
+	{
+		/* on first entry, load the local descriptor */
+		gen_u_p[0].portarcs = (INTBIG *)gen_upconn;
+		gen_i_p[0].portarcs = (INTBIG *)gen_upconn;
+	} else
+	{
+		/* after initialization, simply change the connection array */
+		gen_univpinprim->firstportproto->connects = gen_upconn;
+		gen_invispinprim->firstportproto->connects = gen_upconn;
+	}
+	first = 0;
 }
 
-INTSML gen_nodepolys(NODEINST *ni)
+INTBIG gen_nodepolys(NODEINST *ni, INTBIG *reasonable)
 {
-	REGISTER INTSML pindex, count, start, end;
+	REGISTER INTBIG pindex, count;
+	REGISTER INTSML start, end;
+	REGISTER INTBIG lambda;
 	static INTBIG portangle = 0, portrange = 0;
 	REGISTER VARIABLE *var, *var2;
 
@@ -365,9 +380,9 @@ INTSML gen_nodepolys(NODEINST *ni)
 		if (portrange == 0) portrange = makekey("EDTEC_portrange");
 
 		/* port node becomes a cross when it is 1x1 */
-		if (ni->highx-ni->lowx == gen_tech->deflambda*2 &&
-			ni->highy-ni->lowy == gen_tech->deflambda*2)
-				gen_p_l[0].style = CROSS; else gen_p_l[0].style = CLOSED;
+		lambda = lambdaofnode(ni);
+		if (ni->highx-ni->lowx == lambda*2 && ni->highy-ni->lowy == lambda*2)
+			gen_p_l[0].style = CROSS; else gen_p_l[0].style = CLOSED;
 
 		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portangle);
 		var2 = getvalkey((INTBIG)ni, VNODEINST, VINTEGER, portrange);
@@ -389,14 +404,15 @@ INTSML gen_nodepolys(NODEINST *ni)
 	/* add in displayable variables */
 	tech_realpolys = count;
 	count += tech_displayablenvars(ni);
+	if (reasonable != 0) *reasonable = count;
 	return(count);
 }
 
-void gen_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void gen_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	REGISTER TECH_POLYGON *lay;
-	REGISTER INTSML pindex, count, i, j;
-	REGISTER INTBIG x, y, xoff, yoff, cross;
+	REGISTER INTBIG pindex, count, i, j;
+	REGISTER INTBIG x, y, xoff, yoff, cross, lambda;
 	REGISTER VARIABLE *var;
 
 	/* handle displayable variables */
@@ -408,6 +424,7 @@ void gen_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 		return;
 	}
 
+	lambda = lambdaofnode(ni);
 	lay = &gen_nodeprotos[pindex - 1]->layerlist[box];
 	if (lay->portnum < 0) poly->portproto = NOPORTPROTO; else
 		poly->portproto = ni->proto->tech->nodeprotos[pindex-1]->portlist[lay->portnum].addr;
@@ -421,12 +438,12 @@ void gen_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			/* make sure polygon can hold this description */
 			count = getlength(var) / 2;
 			j = count*4 + (count-1)*2;
-			if (poly->limit < j) (void)extendpolygon(poly, j);
+			if (poly->limit < j) (void)extendpolygon(poly, (INTSML)j);
 
 			/* fill the polygon */
 			xoff = (ni->highx + ni->lowx) / 2;
 			yoff = (ni->highy + ni->lowy) / 2;
-			cross = ni->proto->tech->deflambda / 4;
+			cross = lambda / 4;
 			j = 0;
 			for(i=0; i<count; i++)
 			{
@@ -452,14 +469,14 @@ void gen_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			/* add in peripheral information */
 			poly->layer = lay->layernum;
 			poly->style = VECTORS;
-			poly->count = j;
+			poly->count = (INTSML)j;
 			poly->desc = gen_layers[poly->layer];
 			return;
 		}
 	}
 
 	/* nontrace pins draw the normal way */
-	tech_fillpoly(poly, lay, ni, gen_tech->deflambda, FILLED);
+	tech_fillpoly(poly, lay, ni, lambda, FILLED);
 	poly->desc = gen_layers[poly->layer];
 }
 
@@ -472,9 +489,9 @@ void gen_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	tech_fillportpoly(ni, pp, poly, trans, gen_nodeprotos[pindex-1], OPENED);
 }
 
-INTSML gen_arcpolys(ARCINST *ai)
+INTBIG gen_arcpolys(ARCINST *ai)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	i = gen_arcprotos[ai->proto->arcindex]->laycount;
 
@@ -484,9 +501,9 @@ INTSML gen_arcpolys(ARCINST *ai)
 	return(i);
 }
 
-void gen_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void gen_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex;
+	REGISTER INTBIG aindex;
 	REGISTER TECH_ARCLAY *thista;
 
 	/* handle displayable variables */
@@ -498,7 +515,7 @@ void gen_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 
 	aindex = ai->proto->arcindex;
 	thista = &gen_arcprotos[aindex]->list[box];
-	makearcpoly(ai->length, ai->width-thista->off*gen_tech->deflambda/WHOLE, ai, poly, thista->style);
+	makearcpoly(ai->length, ai->width-thista->off*lambdaofarc(ai)/WHOLE, ai, poly, thista->style);
 	poly->layer = thista->lay;
 	poly->desc = gen_layers[poly->layer];
 }
