@@ -82,7 +82,7 @@ static KEYWORD mocmosopt[] =
 	TERMKEY
 };
 COMCOMP mocmos_parse = {mocmosopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, 0, " \t", "MOSIS CMOS option", "show current options"};
+	NOBACKUP, 0, " \t", M_("MOSIS CMOS option"), M_("show current options")};
 
 #define	EITHER    1		/* set for either, cleared for general */
 #define	OUTLINE   2		/* set to outline layers, clear for stipple */
@@ -1499,14 +1499,14 @@ void mocmos_setmode(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		if ((mocmos_state&NWELL) == 0) ttyputmsg("Technology currently set for p-well"); else
-			ttyputmsg("Technology currently set for n-well");
+		if ((mocmos_state&NWELL) == 0) ttyputmsg(_("Technology currently set for p-well")); else
+			ttyputmsg(_("Technology currently set for n-well"));
 		if ((mocmos_state&EITHER) == 0)
-			ttyputmsg("CIF output uses general (p/n-well switchable) layers"); else
-				ttyputmsg("CIF output runs in either p-well or n-well");
+			ttyputmsg(_("CIF output uses general (p/n-well switchable) layers")); else
+				ttyputmsg(_("CIF output runs in either p-well or n-well"));
 		if ((mocmos_state&OUTLINE) == 0)
-			ttyputmsg("%s layers use stipple patterns", mocmos_stipplelayers); else
-				ttyputmsg("%s layers use outlines", mocmos_stipplelayers);
+			ttyputmsg(_("%s layers use stipple patterns"), mocmos_stipplelayers); else
+				ttyputmsg(_("%s layers use outlines"), mocmos_stipplelayers);
 		return;
 	}
 
@@ -1514,10 +1514,10 @@ void mocmos_setmode(INTSML count, char *par[])
 
 	if (namesamen(pp, "convert-old-format-library", l) == 0)
 	{
-		ttyputmsg("This operation will irreversibly alter the current library");
-		count = ttygetparam("Proceed? [n] ", &us_noyesp, MAXPARS, par);
+		ttyputmsg(_("This operation will irreversibly alter the current library"));
+		count = ttygetparam(_("Proceed? [n] "), &us_noyesp, MAXPARS, par);
 		if (count <= 0 || namesamen(par[0], "yes", strlen(par[0])) != 0)
-			ttyputmsg("No changes made"); else
+			ttyputmsg(_("No changes made")); else
 				tech_convertmocmoslib(el_curlib);
 		return;
 	}
@@ -1548,7 +1548,7 @@ void mocmos_setmode(INTSML count, char *par[])
 		}
 
 		mocmos_state &= ~OUTLINE;
-		ttyputmsg("%s layers will use stipple patterns", mocmos_stipplelayers);
+		ttyputmsg(_("%s layers will use stipple patterns"), mocmos_stipplelayers);
 		return;
 	}
 
@@ -1578,7 +1578,7 @@ void mocmos_setmode(INTSML count, char *par[])
 		}
 
 		mocmos_state |= OUTLINE;
-		ttyputmsg("%s layers will use outlines", mocmos_stipplelayers);
+		ttyputmsg(_("%s layers will use outlines"), mocmos_stipplelayers);
 		return;
 	}
 
@@ -1596,7 +1596,7 @@ void mocmos_setmode(INTSML count, char *par[])
 		(void)setval((INTBIG)mocmos_tech, VTECHNOLOGY, "IO_cif_layer_names",
 			(INTBIG)mocmos_cif_layers, VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH));
 		mocmos_state &= ~EITHER;
-		ttyputverbose("CIF output will use general (p/n-well switchable) layers");
+		ttyputverbose(_("CIF output will use general (p/n-well switchable) layers"));
 		return;
 	}
 
@@ -1614,7 +1614,7 @@ void mocmos_setmode(INTSML count, char *par[])
 		(void)setval((INTBIG)mocmos_tech, VTECHNOLOGY, "IO_cif_layer_names",
 			(INTBIG)mocmos_cif_layers, VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH));
 		mocmos_state |= EITHER;
-		ttyputverbose("CIF output will be able to run in p-well or n-well");
+		ttyputverbose(_("CIF output will be able to run in p-well or n-well"));
 		return;
 	}
 
@@ -1674,10 +1674,10 @@ void mocmos_setmode(INTSML count, char *par[])
 		mocmos_setpseudo();
 
 		/* change the technology description */
-		mocmos_tech->techdescript = "Complementary MOS (from MOSIS, P-Well, double metal)";
+		mocmos_tech->techdescript = _("Complementary MOS (from MOSIS, P-Well, double metal)");
 
 		mocmos_state &= ~NWELL;
-		ttyputverbose("MOSIS CMOS technology is P-well");
+		ttyputverbose(_("MOSIS CMOS technology is P-well"));
 		return;
 	}
 
@@ -1737,13 +1737,13 @@ void mocmos_setmode(INTSML count, char *par[])
 		mocmos_setpseudo();
 
 		/* change the technology description */
-		mocmos_tech->techdescript = "Complementary MOS (from MOSIS, N-Well, double metal)";
+		mocmos_tech->techdescript = _("Complementary MOS (from MOSIS, N-Well, double metal)");
 
 		mocmos_state |= NWELL;
-		ttyputverbose("MOSIS CMOS technology is N-well");
+		ttyputverbose(_("MOSIS CMOS technology is N-well"));
 		return;
 	}
-	ttyputerr("Unknown MOSIS CMOS option: %s", pp);
+	ttyputbadusage("technology tell mocmos");
 }
 
 void mocmos_setpseudo(void)
@@ -1831,9 +1831,9 @@ void mocmos_setpseudo(void)
 
 static VARIABLE *mocmos_shrinkvar;
 
-INTSML mocmos_arcpolys(ARCINST *ai)
+INTBIG mocmos_arcpolys(ARCINST *ai)
 {
-	REGISTER INTSML total;
+	REGISTER INTBIG total;
 	static INTBIG arc_shrinkback = 0;
 
 	if (arc_shrinkback == 0) arc_shrinkback = makekey("ARC_shrinkback");
@@ -1849,10 +1849,10 @@ INTSML mocmos_arcpolys(ARCINST *ai)
 	return(total);
 }
 
-void mocmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void mocmos_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
 	REGISTER INTSML aindex, i;
-	REGISTER INTBIG shrinkback, len, oldbits, thisend;
+	REGISTER INTBIG shrinkback, len, oldbits, thisend, lambda;
 	REGISTER TECH_ARCLAY *thista;
 	INTBIG oldx[2], oldy[2];
 
@@ -1867,11 +1867,12 @@ void mocmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	if (box >= mocmos_arcprotos[aindex]->laycount) tech_makearrow(ai, poly); else
 	{
 		thista = &mocmos_arcprotos[aindex]->list[box];
+		lambda = lambdaofarc(ai);
 
 		if (mocmos_shrinkvar != NOVARIABLE)
 		{
-			/* shrink arc if connected to exported port */
-			shrinkback = mocmos_shrinkvar->addr * mocmos_tech->deflambda;
+			/* shrink arc if connected to export */
+			shrinkback = mocmos_shrinkvar->addr * lambda;
 			len = ai->length;
 			oldbits = ai->userbits;
 			ai->userbits |= (NOEXTEND|NOTEND0|NOTEND1);
@@ -1906,7 +1907,7 @@ void mocmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 							ai->end[i].xpos -= shrinkback;
 				}
 			}
-			makearcpoly(ai->length, ai->width-thista->off*mocmos_tech->deflambda/WHOLE, ai, poly,
+			makearcpoly(ai->length, ai->width-thista->off*lambda/WHOLE, ai, poly,
 				thista->style);
 
 			/* restore end co-ordinates */
@@ -1917,7 +1918,7 @@ void mocmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 			ai->userbits = oldbits;
 		} else
 		{
-			makearcpoly(ai->length, ai->width-thista->off*mocmos_tech->deflambda/WHOLE, ai, poly,
+			makearcpoly(ai->length, ai->width-thista->off*lambda/WHOLE, ai, poly,
 				thista->style);
 		}
 		poly->layer = thista->lay;
