@@ -937,10 +937,10 @@ INTSML rcmos_initprocess(TECHNOLOGY *tech, INTSML pass)
 	return(0);
 }
 
-INTSML rcmos_arcpolys(ARCINST *ai)
+INTBIG rcmos_arcpolys(ARCINST *ai)
 {
 	REGISTER INTBIG widestp, widestd, i, lambda, pwid, dwid, orip, orid, amt;
-	REGISTER INTSML total, aindex;
+	REGISTER INTBIG total, aindex;
 	INTBIG lx, ly, hx, hy;
 	REGISTER NODEINST *ni;
 
@@ -949,7 +949,7 @@ INTSML rcmos_arcpolys(ARCINST *ai)
 	total = rcmos_arcprotos[aindex]->laycount;
 	if (aindex == ASTRANS || aindex == ADTRANS)
 	{
-		lambda = rcmos_tech->deflambda;
+		lambda = lambdaofarc(ai);
 
 		/* set defaults for the arc */
 		if (aindex == ASTRANS) amt = K4; else amt = K8;
@@ -972,8 +972,8 @@ INTSML rcmos_arcpolys(ARCINST *ai)
 			pwid = hx - lx;
 			dwid = hy - ly;
 			if (pwid > orip || dwid > orid)
-				ttyputmsg("Warning: arc %s is too narrow for its %s node",
-					describearcinst(ai), (i==0 ? "tail" : "head"));
+				ttyputmsg(_("Warning: arc %s is too narrow for its %s node"),
+					describearcinst(ai), (i==0 ? _("tail") : _("head")));
 			if (pwid < widestp) widestp = pwid;
 			if (dwid < widestd) widestd = dwid;
 		}
@@ -983,7 +983,7 @@ INTSML rcmos_arcpolys(ARCINST *ai)
 		rcmos_arcprotos[aindex]->list[1].off = (ai->width - widestp) * WHOLE / lambda;
 		rcmos_arcprotos[aindex]->list[2].off = rcmos_arcprotos[aindex]->list[0].off - amt;
 	}
-	total = tech_initcurvedarc(ai, total);
+	total = tech_initcurvedarc(ai, (INTSML)total);
 
 	/* add in displayable variables */
 	tech_realpolys = total;
@@ -991,9 +991,9 @@ INTSML rcmos_arcpolys(ARCINST *ai)
 	return(total);
 }
 
-void rcmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void rcmos_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex;
+	REGISTER INTBIG aindex;
 	REGISTER TECH_ARCLAY *thista;
 
 	/* handle displayable variables */
@@ -1013,7 +1013,7 @@ void rcmos_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	/* finally handle straight arcs */
 	aindex = ai->proto->arcindex;
 	thista = &rcmos_arcprotos[aindex]->list[box];
-	makearcpoly(ai->length, ai->width-thista->off*rcmos_tech->deflambda/WHOLE, ai, poly, thista->style);
+	makearcpoly(ai->length, ai->width-thista->off*lambdaofarc(ai)/WHOLE, ai, poly, thista->style);
 	poly->layer = thista->lay;
 	poly->desc = rcmos_layers[poly->layer];
 }
