@@ -232,7 +232,7 @@
 
 /* the options table */
 static COMCOMP schnegp = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "size of negating bubble", "show current size"};
+	0, " \t", M_("size of negating bubble"), M_("show current size")};
 static KEYWORD schopt[] =
 {
 	{"negating-bubble-diameter",    1,{&schnegp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -241,7 +241,7 @@ static KEYWORD schopt[] =
 	TERMKEY
 };
 COMCOMP sch_parse = {schopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Schematic option", "show current options"};
+	0, " \t", M_("Schematic option"), M_("show current options")};
 
 TECHNOLOGY    *sch_tech;
 INTBIG         sch_flipfloptypekey;		/* key for "SCHEM_flipflop_type" */
@@ -304,14 +304,14 @@ static char *sch_layer_letters[MAXLAYERS] = {"a", "b", "n", "t"};
 #define	ABUS            1	/* bus                */
 
 /* wire arc */
-static TECH_ARCLAY sch_al_w[] = { {LARC,0,FILLED}, {LARC,0,CIRCLE}, {LARC,0,VECTORS} };
+static TECH_ARCLAY sch_al_w[] = { {LARC,0,FILLED}, {LARC,0,CIRCLE}, {LARC,0,VECTORS}};
 static TECH_ARCS sch_a_w = {
 	"wire",0,AWIRE,																	/* name */
 	1,sch_al_w,																		/* layers */
 	(APMETAL1<<AFUNCTIONSH)|WANTFIXANG|WANTCANTSLIDE|(45<<AANGLEINCSH)};			/* userbits */
 
 /* bus arc */
-static TECH_ARCLAY sch_al_b[] = { {LBUS,0,FILLED}, {LBUS,0,CIRCLE}, {LBUS,0,VECTORS} };
+static TECH_ARCLAY sch_al_b[] = { {LBUS,0,FILLED}, {LBUS,0,CIRCLE}, {LBUS,0,VECTORS}};
 static TECH_ARCS sch_a_b = {
 	"bus",K1,ABUS,																	/* name */
 	1,sch_al_b,																		/* layers */
@@ -367,21 +367,13 @@ static char sch_R[] = "R";
 static char sch_S[] = "S";
 static char sch_T[] = "T";
 static char sch_V[] = "V";
-static char sch_ACANAL[] = "AC ANAL.";
-static char sch_DCANAL[] = "DC ANAL.";
 static char sch_PR[] = "PR";
 static char sch_QB[] = "QB";
-static char sch_CLR[] = "CLR";
-static char sch_TRANANAL[] = "TRAN ANAL.";
-static char sch_BULK[] = "BULK";
-static char sch_METER[] = "METER";
-static char sch_NODESET[] = "NODE SET";
-static char sch_EXTENSION[] = "EXTENSION";
-static char sch_SPECIAL[] = "SPECIAL";
 
 static INTBIG sch_g_nullpin[]    = {CENTER,    CENTER,    CENTER,    CENTER};
 static INTBIG sch_g_pindisc[]    = {CENTER,    CENTER,    RIGHTEDGE, CENTER};
 static INTBIG sch_g_buspindisc[] = {CENTER,    CENTER,    RIGHTBYP5, CENTER};
+static INTBIG sch_g_bustapdisc[] = {CENTER,    CENTER,    RIGHTBYP25,CENTER};
 static char  *sch_g_wireconj[]   = {0,  0,     0, 0,      sch_J};
 static INTBIG sch_g_inv[]        = {RIGHTBYP66,CENTER,    LEFTEDGE,  TOPBYP875,
 								    LEFTEDGE,  BOTBYP875};
@@ -422,7 +414,7 @@ static char *sch_g_fftextpr[]   = {(char *)-D6,0,  (char *)D6,0,   (char *)-D6,0
 								   sch_PR};
 static char *sch_g_fftextclr[]  = {(char *)-D6,0,  (char *)-D6,0,   (char *)-D6,0,  (char *)-H0,  0,
 								   (char *)D6,0, (char *)-H0,  0,   (char *)D6,0, (char *)-D6,0,
-								   sch_CLR};
+								   0 /* "CLR" */};
 static char *sch_g_meterv[]     = {(char *)-H0,  0,  (char *)-H0,  0,   (char *)H0,  0, (char *)H0,  0,
 								   sch_V};
 static INTBIG sch_g_ffn[]        = {LEFTBYP6,  TOPBYP2,   LEFTBYP4,  TOPBYP2,
@@ -450,14 +442,14 @@ static INTBIG sch_g_gnd[]        = {CENTER,    CENTER,    CENTER,    TOPEDGE,
 								    LEFTBYP166,BOTBYP75,  RIGHTBYP166,BOTBYP75,
 								    CENTER,    BOTEDGE,   CENTER,    BOTEDGE};
 
-static char *sch_g_sourcet[]    = {0,  0,    (char *)-D4,0,   sch_TRANANAL};
-static char *sch_g_sourced[]    = {0,  0,    (char *)-D4,0,   sch_DCANAL};
-static char *sch_g_sourcea[]    = {0,  0,    (char *)-D4,0,   sch_ACANAL};
-static char *sch_g_sourceb[]    = {0,  0,    (char *)-D4,0,   sch_BULK};
-static char *sch_g_sourcem[]    = {0,  0,    (char *)-D4,0,   sch_METER};
-static char *sch_g_sourcen[]    = {0,  0,    (char *)-D4,0,   sch_NODESET};
-static char *sch_g_sourcex[]    = {0,  0,    (char *)-D4,0,   sch_EXTENSION};
-static char *sch_g_sources[]    = {0,  0,    (char *)-D4,0,   sch_SPECIAL};
+static char *sch_g_sourcet[]    = {0,  0,    (char *)-D4,0,   0 /* "TRAN ANAL." */};
+static char *sch_g_sourced[]    = {0,  0,    (char *)-D4,0,   0 /* "DC ANAL." */};
+static char *sch_g_sourcea[]    = {0,  0,    (char *)-D4,0,   0 /* "AC ANAL." */};
+static char *sch_g_sourceb[]    = {0,  0,    (char *)-D4,0,   0 /* "BULK" */};
+static char *sch_g_sourcem[]    = {0,  0,    (char *)-D4,0,   0 /* "METER" */};
+static char *sch_g_sourcen[]    = {0,  0,    (char *)-D4,0,   0 /* "NODE SET" */};
+static char *sch_g_sourcex[]    = {0,  0,    (char *)-D4,0,   0 /* "EXTENSION" */};
+static char *sch_g_sources[]    = {0,  0,    (char *)-D4,0,   0 /* "SPECIAL" */};
 static INTBIG sch_g_source[]     = {CENTER,    CENTER,    RIGHTEDGE, CENTER};
 static INTBIG sch_g_sourcec[]    = {CENTER,    TOPBYP9,   CENTER,    BOTBYP9,
 								    CENTER,    BOTBYP9,   RIGHTBYP3, BOTBYP6,
@@ -590,7 +582,8 @@ static TECH_PORTS sch_buspin_p[] = {				/* ports */
 	{sch_pc_either, "bus", NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON sch_buspin_l[] = {				/* layers */
-	{LBUS, 0, 2, DISC, POINTS, sch_g_buspindisc}};
+	{LBUS, 0, 2, DISC, POINTS, sch_g_buspindisc},
+	{LARC, 0, 2, DISC, POINTS, sch_g_bustapdisc}};
 TECH_NODES sch_buspin = {
 	"Bus_Pin",NBUSPIN,NONODEPROTO,					/* name */
 	K2,K2,											/* size */
@@ -1234,6 +1227,17 @@ INTSML sch_initprocess(TECHNOLOGY *tech, INTSML pass)
 
 		/* differential ports are enabled */
 		sch_anddiffports = sch_ordiffports = sch_xordiffports = NOPORTPROTO;
+
+		/* translate strings on schematic nodes */
+		sch_g_sourcea[4] = _("AC ANAL.");
+		sch_g_sourced[4] = _("DC ANAL.");
+		sch_g_fftextclr[16] = _("CLR");
+		sch_g_sourcet[4] = _("TRAN ANAL.");
+		sch_g_sourceb[4] = _("BULK");
+		sch_g_sourcem[4] = _("METER");
+		sch_g_sourcen[4] = _("NODE SET");
+		sch_g_sourcex[4] = _("EXTENSION");
+		sch_g_sources[4] = _("SPECIAL");
 	}
 	return(0);
 }
@@ -1256,7 +1260,7 @@ void sch_setmode(INTSML count, char *par[])
 	if (count == 0)
 	{
 		/* report size of negating bubbles */
-		ttyputmsg("Diameter of negating bubbles is %s", frtoa(sch_bubblediameter));
+		ttyputmsg(_("Diameter of negating bubbles is %s"), frtoa(sch_bubblediameter));
 		return;
 	}
 
@@ -1266,19 +1270,19 @@ void sch_setmode(INTSML count, char *par[])
 		/* get new negating bubble diameter */
 		if (count <= 1)
 		{
-			ttyputmsg("Diameter of negating bubbles is %s", frtoa(sch_bubblediameter));
+			ttyputmsg(_("Diameter of negating bubbles is %s"), frtoa(sch_bubblediameter));
 			return;
 		}
 		l = (INTSML)atofr(par[1]);
 		if (l > 0) sch_bubblediameter = l; else
-			ttyputerr("Bubble diameter must be positive and nonzero");
+			ttyputerr(_("Bubble diameter must be positive and nonzero"));
 		return;
 	}
 	if (namesamen(pp, "disable-differential-ports", l) == 0)
 	{
 		if (sch_anddiffports != NOPORTPROTO)
 		{
-			ttyputerr("Differential ports are already disabled");
+			ttyputerr(_("Differential ports are already disabled"));
 			return;
 		}
 		sch_anddiffports = sch_andprim->firstportproto->nextportproto->nextportproto;
@@ -1295,7 +1299,7 @@ void sch_setmode(INTSML count, char *par[])
 	{
 		if (sch_anddiffports == NOPORTPROTO)
 		{
-			ttyputerr("Differential ports are already enabled");
+			ttyputerr(_("Differential ports are already enabled"));
 			return;
 		}
 		sch_andprim->firstportproto->nextportproto->nextportproto = sch_anddiffports;
@@ -1304,7 +1308,7 @@ void sch_setmode(INTSML count, char *par[])
 		sch_anddiffports = sch_ordiffports = sch_xordiffports = NOPORTPROTO;
 		return;
 	}
-	ttyputerr("Unknown SCHEMATIC option: %s", pp);
+	ttyputbadusage("technology tell schematic");
 }
 
 INTBIG sch_request(char *command, va_list ap)
@@ -1325,12 +1329,12 @@ static TECH_POLYGON *sch_layerlist;
 static INTBIG sch_specialkey;		/* variable key for current node info */
 static INTSML sch_advancestring;		/* amount to adjust string in variable */
 
-INTSML sch_nodepolys(NODEINST *ni)
+INTBIG sch_nodepolys(NODEINST *ni, INTBIG *reasonable)
 {
 	REGISTER VARIABLE *var;
 	char *extra;
 	REGISTER char *str;
-	REGISTER INTSML total, pindex, i;
+	REGISTER INTBIG total, pindex, buscon, nonbuscon;
 	REGISTER INTBIG hei;
 	REGISTER PORTARCINST *pi;
 
@@ -1348,18 +1352,26 @@ INTSML sch_nodepolys(NODEINST *ni)
 			break;
 
 		case NBUSPIN:	/* bus pins get bigger in "T" configurations, disappear when alone and exported */
-			for (i=0, pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
-				if (pi->conarcinst->proto == sch_busarc) i++;
-			if (i > 2)
+			buscon = nonbuscon = 0;
+			for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 			{
-				/* larger pin because it is connected to 3 or more arcs */
+				if (pi->conarcinst->proto == sch_busarc) buscon++; else
+					nonbuscon++;
+			}
+			if (buscon > 2)
+			{
+				/* larger pin because it is connected to 3 or more bus arcs */
 				sch_g_buspindisc[4] = H0;
 			} else
 			{
 				/* smaller pin because it has 0, 1, or 2 connections */
 				sch_g_buspindisc[4] = Q0;
-				if (i == 0 && ni->firstportexpinst != NOPORTEXPINST) total = 0;
+				if (buscon == 0 && nonbuscon == 0 && ni->firstportexpinst != NOPORTEXPINST)
+					total = 0;
 			}
+
+			/* bus pins also show wire pin in center if tapped */
+			if (nonbuscon != 0) total++;
 			break;
 
 		case NFF:	/* add on more if this is a special flip-flop */
@@ -1405,7 +1417,7 @@ INTSML sch_nodepolys(NODEINST *ni)
 			break;
 
 		case NSWITCH:	/* add in multiple connection sites for switch */
-			hei = (ni->highy - ni->lowy) / sch_tech->deflambda;
+			hei = (ni->highy - ni->lowy) / lambdaofnode(ni);
 			if (hei >= 4) total += (hei/2)-1;
 			if (((hei/2)&1) == 0) sch_g_switchbar[7] = 0; else
 				sch_g_switchbar[7] = K1;
@@ -1563,19 +1575,23 @@ INTSML sch_nodepolys(NODEINST *ni)
 	/* add in displayable variables */
 	tech_realpolys = total;
 	total += tech_displayablenvars(ni);
+	if (reasonable != 0) *reasonable = total;
 	return(total);
 }
 
-INTSML sch_nodeEpolys(NODEINST *ni)
+INTBIG sch_nodeEpolys(NODEINST *ni, INTBIG *reasonable)
 {
+	if (reasonable != 0) *reasonable = 0;
 	return(0);
 }
 
-void sch_shapeEnodepoly(NODEINST *ni, INTSML box, POLYGON *poly) {}
+void sch_shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly) {}
 
-void sch_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void sch_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	REGISTER VARIABLE *var;
+	REGISTER INTBIG lambda;
+	static char shortenedstring[14];
 
 	/* handle displayable variables */
 	if (box >= tech_realpolys)
@@ -1586,6 +1602,15 @@ void sch_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			/* store character offset in the variable */
 			var->type |= (sch_advancestring << VLENGTHSH);
 			poly->string += sch_advancestring;
+			if (strlen(poly->string) > 10)
+			{
+				strncpy(shortenedstring, poly->string, 10);
+				poly->string = shortenedstring;
+				shortenedstring[10] = '.';
+				shortenedstring[11] = '.';
+				shortenedstring[12] = '.';
+				shortenedstring[13] = 0;
+			}
 		}
 		return;
 	}
@@ -1597,15 +1622,16 @@ void sch_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 		box = 2;
 	}
 
+	lambda = lambdaofnode(ni);
 #ifdef SCALABLEGATES
 	if (ni->proto->primindex == NAND || ni->proto->primindex == NOR ||
 		ni->proto->primindex == NXOR)
 	{
-		sch_fillpoly(poly, &sch_layerlist[box], ni, sch_tech->deflambda, FILLED);
+		sch_fillpoly(poly, &sch_layerlist[box], ni, lambda, FILLED);
 	} else
 #endif
 	{
-		tech_fillpoly(poly, &sch_layerlist[box], ni, sch_tech->deflambda, FILLED);
+		tech_fillpoly(poly, &sch_layerlist[box], ni, lambda, FILLED);
 	}
 
 	poly->font = sch_layerlist[box].portnum;
@@ -1723,7 +1749,6 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 		bestx, besty, dist;
 	REGISTER PORTARCINST *pi;
 	REGISTER ARCINST *ai;
-	extern AIDENTRY *us_aid;
 	REGISTER WINDOWPART *w;
 
 	pindex = ni->proto->primindex;
@@ -1735,7 +1760,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 		wantx = poly->xv[0];   wanty = poly->yv[0];
 		poly->count = 1;
 		poly->style = FILLED;
-		lambda = ni->proto->tech->deflambda;
+		lambda = lambdaofnode(ni);
 		bestdist = HUGEINT;
 
 		/* schematic gates must keep connections discrete and separate */
@@ -1755,7 +1780,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 
 				/* compute indentation (for OR and XOR) */
 				if (pindex != NMUX) xposition = -K4; else
-					xposition = -(ni->highx - ni->lowx) * 4 / 10 * WHOLE / sch_tech->deflambda;
+					xposition = -(ni->highx - ni->lowx) * 4 / 10 * WHOLE / lambda;
 				if (pindex == NOR || pindex == NXOR) switch (i)
 				{
 					case 0: xposition += T0;   break;
@@ -1787,7 +1812,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 					}
 				}
 			}
-			if (bestdist == HUGEINT) ttyputerr("Warning: cannot find gate port");
+			if (bestdist == HUGEINT) ttyputerr(_("Warning: cannot find gate port"));
 
 			/* set the closest port */
 			poly->xv[0] = bestx;   poly->yv[0] = besty;
@@ -1826,7 +1851,7 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 					bestdist = dist;   bestx = x;   besty = y;   besti = i;
 				}
 			}
-			if (bestdist == HUGEINT) ttyputerr("Warning: cannot find switch port");
+			if (bestdist == HUGEINT) ttyputerr(_("Warning: cannot find switch port"));
 
 			/* set the closest port */
 			poly->xv[0] = bestx;   poly->yv[0] = besty;
@@ -1836,9 +1861,9 @@ void sch_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	tech_fillportpoly(ni, pp, poly, trans, sch_nodeprotos[pindex-1], CLOSED);
 }
 
-INTSML sch_arcpolys(ARCINST *ai)
+INTBIG sch_arcpolys(ARCINST *ai)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 
 	i = sch_arcprotos[ai->proto->arcindex]->laycount;
 	sch_bubblebox = sch_arrowbox = -1;
@@ -1851,9 +1876,10 @@ INTSML sch_arcpolys(ARCINST *ai)
 	return(i);
 }
 
-void sch_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void sch_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex, angle, bubbleend;
+	REGISTER INTBIG aindex, bubbleend;
+	REGISTER INTSML angle;
 	REGISTER INTBIG x1,y1, cosdist, sindist, x2,y2, lambda, i,
 		saveendx, saveendy, bubblesize;
 	REGISTER TECH_ARCLAY *thista;
@@ -1870,7 +1896,7 @@ void sch_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	thista = &sch_arcprotos[aindex]->list[box];
 	poly->layer = thista->lay;
 	poly->desc = sch_layers[poly->layer];
-	lambda = sch_tech->deflambda;
+	lambda = lambdaofarc(ai);
 	if (sch_bubblebox < 0 && sch_arrowbox < 0)
 	{
 		/* simple arc */
@@ -1949,6 +1975,7 @@ void sch_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 		poly->count = 2;
 		poly->xv[0] = x1;   poly->yv[0] = y1;
 		poly->xv[1] = x2;   poly->yv[1] = y2;
-		if ((ai->userbits&NOTEND1) == 0) tech_addheadarrow(poly, angle, x2, y2);
+		if ((ai->userbits&NOTEND1) == 0)
+			tech_addheadarrow(poly, angle, x2, y2, lambda);
 	}
 }
