@@ -73,7 +73,7 @@ void us_echo(INTSML count, char *par[])
 	}
 	if (i != 0)
 	{
-		ttyputerr("No space for message!");
+		ttyputnomemory();
 		return;
 	}
 	ttyputmsg("%s", returninfstr());
@@ -84,6 +84,7 @@ void us_editfacet(INTSML count, char *par[])
 {
 	REGISTER INTSML implicit, i, len, newwindow, nonredundant, newframe, push;
 	INTBIG lx, hx, ly, hy;
+	REGISTER INTBIG lambda;
 	REGISTER NODEPROTO *np, *onp, *np1, *curfacet;
 	REGISTER NODEINST *ni, *stacknodeinst;
 	REGISTER LIBRARY *lib, *olib;
@@ -125,7 +126,7 @@ void us_editfacet(INTSML count, char *par[])
 			if (namesamen(par[i], "new-window", len) == 0 && len > 1) newwindow++; else
 			if (namesamen(par[i], "non-redundant", len) == 0 && len > 1) nonredundant++; else
 			{
-				us_abortcommand("Unknown EDITFACET parameter: %s", par[i]);
+				ttyputbadusage("editfacet");
 				return;
 			}
 		}
@@ -147,7 +148,7 @@ void us_editfacet(INTSML count, char *par[])
 				*pt = (char)i;
 				if (lib == NOLIBRARY)
 				{
-					us_abortcommand("Cannot find library for new facet %s", par[0]);
+					us_abortcommand(_("Cannot find library for new facet %s"), par[0]);
 					return;
 				}
 				pt++;
@@ -155,13 +156,13 @@ void us_editfacet(INTSML count, char *par[])
 			np = newnodeproto(pt, lib);
 			if (np == NONODEPROTO)
 			{
-				us_abortcommand("Cannot create facet %s", par[0]);
+				us_abortcommand(_("Cannot create facet %s"), par[0]);
 				return;
 			}
 
 			/* icon facets should always be expanded */
 			if (np->cellview == el_iconview) np->userbits |= WANTNEXPAND;
-			ttyputverbose("Editing new facet: %s", par[0]);
+			ttyputverbose(_("Editing new facet: %s"), par[0]);
 		}
 
 		/* look through window for instances of this facet */
@@ -181,7 +182,7 @@ void us_editfacet(INTSML count, char *par[])
 	/* make sure nodeinst is not primitive and in proper technology */
 	if (np->primindex != 0)
 	{
-		us_abortcommand("Cannot edit primitive nodes");
+		us_abortcommand(_("Cannot edit primitive nodes"));
 		return;
 	}
 
@@ -229,10 +230,11 @@ void us_editfacet(INTSML count, char *par[])
 		ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
 		if (el_curwindowpart->curnodeproto == NONODEPROTO)
 		{
-			lx = -el_curtech->deflambda * 25;
-			hx =  el_curtech->deflambda * 25;
-			ly = -el_curtech->deflambda * 25;
-			hy =  el_curtech->deflambda * 25;
+			lambda = el_curlib->lambda[el_curtech->techindex];
+			lx = -lambda * 25;
+			hx =  lambda * 25;
+			ly = -lambda * 25;
+			hy =  lambda * 25;
 		}
 	}
 	if (implicit == 0)
@@ -268,21 +270,21 @@ void us_erase(INTSML count, char *par[])
 	REGISTER PORTARCINST *pi;
 	REGISTER NODEPROTO *np;
 	HIGHLIGHT high;
-	REGISTER char *pp;
+	REGISTER char *pt;
 	REGISTER GEOM **list;
 	REGISTER VARIABLE *highvar;
 
 	if (count > 0)
 	{
-		l = strlen(pp = par[0]);
-		if (namesamen(pp, "clean-up-all", l) == 0 && l > 8)
+		l = strlen(pt = par[0]);
+		if (namesamen(pt, "clean-up-all", l) == 0 && l > 8)
 		{
 			us_clearhighlightcount();
 			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 				us_cleanupfacet(np, 0);
 			return;
 		}
-		if (namesamen(pp, "clean-up", l) == 0)
+		if (namesamen(pt, "clean-up", l) == 0)
 		{
 			np = us_needfacet();
 			if (np == NONODEPROTO) return;
@@ -290,7 +292,7 @@ void us_erase(INTSML count, char *par[])
 			us_cleanupfacet(np, 1);
 			return;
 		}
-		if (namesamen(pp, "geometry", l) == 0)
+		if (namesamen(pt, "geometry", l) == 0)
 		{
 			np = us_needfacet();
 			if (np == NONODEPROTO) return;
@@ -304,7 +306,7 @@ void us_erase(INTSML count, char *par[])
 	highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 	if (highvar == NOVARIABLE)
 	{
-		us_abortcommand("First highlight something to erase");
+		us_abortcommand(_("First highlight something to erase"));
 		return;
 	}
 	(void)us_makehighlight(((char **)highvar->addr)[0], &high);
@@ -319,14 +321,25 @@ void us_erase(INTSML count, char *par[])
 		if (high.fromvar != NOVARIABLE)
 		{
 			us_clearhighlightcount();
-			if (high.fromgeom->entrytype == OBJNODEINST)
+			if (high.fromgeom == NOGEOM)
+			{
+				us_undrawfacetvariable(high.fromvar, np);
+				(void)delval((INTBIG)np, VNODEPROTO, makename(high.fromvar->key));
+			} else if (high.fromgeom->entrytype == OBJNODEINST)
 			{
 				ni = high.fromgeom->entryaddr.ni;
 				startobjectchange((INTBIG)ni, VNODEINST);
 
-				/* if deleting text on invisible pin, delete pin too */
-				if (ni->proto == gen_invispinprim) us_erasenodeinst(ni); else
-					(void)delval((INTBIG)ni, VNODEINST, makename(high.fromvar->key));
+				/* if deleting port variables, do that */
+				if (high.fromport != NOPORTPROTO)
+				{
+					(void)delval((INTBIG)high.fromport, VPORTPROTO, makename(high.fromvar->key));
+				} else
+				{
+					/* if deleting text on invisible pin, delete pin too */
+					if (ni->proto == gen_invispinprim) us_erasenodeinst(ni); else
+						(void)delval((INTBIG)ni, VNODEINST, makename(high.fromvar->key));
+				}
 				endobjectchange((INTBIG)ni, VNODEINST);
 			} else
 			{
@@ -345,7 +358,7 @@ void us_erase(INTSML count, char *par[])
 			high.status = HIGHFROM;
 			(void)us_addhighlight(&high);
 		} else if (high.fromgeom->entrytype == OBJNODEINST)
-			us_abortcommand("Cannot delete facet name");
+			us_abortcommand(_("Cannot delete facet name"));
 		return;
 	}
 
@@ -353,13 +366,13 @@ void us_erase(INTSML count, char *par[])
 	np = us_needfacet();
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand("No current facet");
+		us_abortcommand(_("No current facet"));
 		return;
 	}
 	list = us_gethighlighted(OBJARCINST|OBJNODEINST);
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand("Find an object to erase");
+		us_abortcommand(_("Find an object to erase"));
 		return;
 	}
 
@@ -378,7 +391,7 @@ void us_erase(INTSML count, char *par[])
 	list[j] = NOGEOM;
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand("All selected objects are locked");
+		us_abortcommand(_("All selected objects are locked"));
 		return;
 	}
 
@@ -393,7 +406,7 @@ void us_erase(INTSML count, char *par[])
 	{
 		if (list[1] != NOGEOM || list[0]->entrytype != OBJNODEINST)
 		{
-			us_abortcommand("Must erase a single node to pass arcs through");
+			us_abortcommand(_("Must erase a single node to pass arcs through"));
 			return;
 		}
 		us_clearhighlightcount();
@@ -403,13 +416,13 @@ void us_erase(INTSML count, char *par[])
 			case 2:
 				break;
 			case -1:
-				us_abortcommand("Arcs to this node are of different type");
+				us_abortcommand(_("Arcs to this node are of different type"));
 				break;
 			case -5:
-				us_abortcommand("Cannot create connecting arc");
+				us_abortcommand(_("Cannot create connecting arc"));
 				break;
 			default:
-				us_abortcommand("Must be 2 arcs on this node (it has %d)", j);
+				us_abortcommand(_("Must be 2 arcs on this node (it has %d)"), j);
 				break;
 		}
 		return;
@@ -465,7 +478,7 @@ void us_erase(INTSML count, char *par[])
 			startobjectchange((INTBIG)ni2, VNODEINST);
 
 		startobjectchange((INTBIG)ai, VARCINST);
-		if (killarcinst(ai)) ttyputerr("Error killing arc");
+		if (killarcinst(ai)) ttyputerr(_("Error killing arc"));
 
 		/* see if nodes need to be redrawn to account for "Steiner Point" changes */
 		if (ni1->temp1 == 1 && (ni1->proto->userbits&WIPEON1OR2) != 0)
@@ -541,10 +554,10 @@ void us_find(INTSML count, char *par[])
 				findangle = (INTSML)var->addr;
 			if (findangle == 0)
 			{
-				ttyputverbose("Interactive dragging done with no constraints");
+				ttyputverbose(_("Interactive dragging done with no constraints"));
 			} else
 			{
-				ttyputverbose("Interactive dragging constrained to %d degree angles",
+				ttyputverbose(_("Interactive dragging constrained to %d degree angles"),
 					findangle);
 			}
 			return;
@@ -567,10 +580,10 @@ void us_find(INTSML count, char *par[])
 			}
 			if ((us_useroptions&FLIPINTERACTIVECON) != 0)
 			{
-				ttyputverbose("Interactive selection constrains to one axis");
+				ttyputverbose(_("Interactive selection constrains to one axis"));
 			} else
 			{
-				ttyputverbose("Interactive selection allows motion in either axis");
+				ttyputverbose(_("Interactive selection allows motion in either axis"));
 			}
 			return;
 		}
@@ -581,12 +594,12 @@ void us_find(INTSML count, char *par[])
 	if (np == NONODEPROTO) return;
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
-		us_abortcommand("There are no components to select in a text-only facet");
+		us_abortcommand(_("There are no components to select in a text-only facet"));
 		return;
 	}
 	if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
 	{
-		us_abortcommand("Cannot select objects in a 3D window");
+		us_abortcommand(_("Cannot select objects in a 3D window"));
 		return;
 	}
 
@@ -648,12 +661,12 @@ void us_find(INTSML count, char *par[])
 		{
 			if (newhigh.status == 0)
 			{
-				us_abortcommand("Find an object before working 'within' it");
+				us_abortcommand(_("Find an object before working 'within' it"));
 				return;
 			}
 			if ((newhigh.status&HIGHTYPE) != HIGHFROM || newhigh.fromgeom->entrytype != OBJNODEINST)
 			{
-				us_abortcommand("Must find a node before working 'within'");
+				us_abortcommand(_("Must find a node before working 'within'"));
 				return;
 			}
 
@@ -682,7 +695,7 @@ void us_find(INTSML count, char *par[])
 			if (findpoint != 0 || findwithin != 0 || findmore != 0 ||
 				findexclusively != 0 || findstill != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find all'");
+				us_abortcommand(_("Illegal options given to 'find all'"));
 				return;
 			}
 			findeasy = findhard = 1;
@@ -692,7 +705,7 @@ void us_find(INTSML count, char *par[])
 				if (namesamen(pt, "easy", l) == 0) findhard = 0; else
 				if (namesamen(pt, "hard", l) == 0) findeasy = 0; else
 				{
-					us_abortcommand("Usage: find all [easy|hard]");
+					ttyputusage("find all [easy|hard]");
 					return;
 				}
 			}
@@ -759,17 +772,17 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count <= 1)
 			{
-				us_abortcommand("Usage: find arc ARCNAME");
+				ttyputusage("find arc ARCNAME");
 				return;
 			}
 			if (findport != 0 || findpoint != 0 || findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find arc'");
+				us_abortcommand(_("Illegal options given to 'find arc'"));
 				return;
 			}
 			if (findexclusively != 0 && us_curarcproto == NOARCPROTO)
 			{
-				us_abortcommand("Must select an arc for exclusive finding");
+				us_abortcommand(_("Must select an arc for exclusive finding"));
 				return;
 			}
 			for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -781,7 +794,7 @@ void us_find(INTSML count, char *par[])
 			}
 			if (ai == NOARCINST)
 			{
-				us_abortcommand("Sorry, no %s arc named '%s' in this facet",
+				us_abortcommand(_("Sorry, no %s arc named '%s' in this facet"),
 					(findexclusively==0 ? "" : describearcproto(us_curarcproto)), par[1]);
 				return;
 			}
@@ -798,7 +811,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find area-define'");
+				us_abortcommand(_("Illegal options given to 'find area-define'"));
 				return;
 			}
 
@@ -828,7 +841,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find area-move'");
+				us_abortcommand(_("Illegal options given to 'find area-move'"));
 				return;
 			}
 			if (us_demandxy(&xcur, &ycur)) return;
@@ -871,7 +884,7 @@ void us_find(INTSML count, char *par[])
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findnobox != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find area-size'");
+				us_abortcommand(_("Illegal options given to 'find area-size'"));
 				return;
 			}
 			if (us_demandxy(&xcur, &ycur)) return;
@@ -879,12 +892,12 @@ void us_find(INTSML count, char *par[])
 
 			if (newhigh.status != HIGHBBOX)
 			{
-				us_abortcommand("Use 'find area-move' first, then this");
+				us_abortcommand(_("Use 'find area-move' first, then this"));
 				return;
 			}
 			if (np != newhigh.facet)
 			{
-				us_abortcommand("Not in same facet as highlight area");
+				us_abortcommand(_("Not in same facet as highlight area"));
 				return;
 			}
 
@@ -922,7 +935,7 @@ void us_find(INTSML count, char *par[])
 		{
 			if (findpoint != 0 || findexclusively != 0 || extrainfo != 0)
 			{
-				us_abortcommand("Illegal options given to 'find comp-interactive'");
+				us_abortcommand(_("Illegal options given to 'find comp-interactive'"));
 				return;
 			}
 
@@ -959,11 +972,11 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find down-stack'");
+				us_abortcommand(_("Illegal options given to 'find down-stack'"));
 				return;
 			}
 			us_pushhighlight();
-			ttyputverbose("Pushed");
+			ttyputverbose(_("Pushed"));
 			return;
 		}
 
@@ -971,20 +984,20 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count <= 1)
 			{
-				us_abortcommand("Usage: find export PORTNAME");
+				ttyputusage("find export PORTNAME");
 				return;
 			}
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 || findwithin != 0 ||
 				findspecial != 0)
 			{
-				us_abortcommand("'find export' cannot accept other control");
+				us_abortcommand(_("'find export' cannot accept other control"));
 				return;
 			}
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				if (namesame(par[1], pp->protoname) == 0) break;
 			if (pp == NOPORTPROTO)
 			{
-				us_abortcommand("Sorry, no exported port named '%s' in this facet", par[1]);
+				us_abortcommand(_("Sorry, no export named '%s' in this facet"), par[1]);
 				return;
 			}
 			newhigh.status = HIGHFROM;
@@ -999,7 +1012,7 @@ void us_find(INTSML count, char *par[])
 		{
 			if (findexclusively != 0)
 			{
-				us_abortcommand("Illegal options given to 'find interactively'");
+				us_abortcommand(_("Illegal options given to 'find interactively'"));
 				return;
 			}
 
@@ -1064,13 +1077,13 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count <= 1)
 			{
-				us_abortcommand("Usage: find name HIGHLIGHTNAME");
+				ttyputusage("find name HIGHLIGHTNAME");
 				return;
 			}
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find name'");
+				us_abortcommand(_("Illegal options given to 'find name'"));
 				return;
 			}
 			(void)initinfstr();
@@ -1079,7 +1092,7 @@ void us_find(INTSML count, char *par[])
 			var = getval((INTBIG)us_aid, VAID, VSTRING|VISARRAY, returninfstr());
 			if (var == NOVARIABLE)
 			{
-				us_abortcommand("Cannot find saved highlight '%s'", par[1]);
+				us_abortcommand(_("Cannot find saved highlight '%s'"), par[1]);
 				return;
 			}
 
@@ -1092,17 +1105,17 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count <= 1)
 			{
-				us_abortcommand("Usage: find node NODENAME");
+				ttyputusage("find node NODENAME");
 				return;
 			}
 			if (findport != 0 || findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find node'");
+				us_abortcommand(_("Illegal options given to 'find node'"));
 				return;
 			}
 			if (findexclusively != 0 && us_curnodeproto == NONODEPROTO)
 			{
-				us_abortcommand("Must select a node for exclusive finding");
+				us_abortcommand(_("Must select a node for exclusive finding"));
 				return;
 			}
 			for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1114,7 +1127,7 @@ void us_find(INTSML count, char *par[])
 			}
 			if (ni == NONODEINST)
 			{
-				us_abortcommand("Sorry, no %s node named '%s' in this facet",
+				us_abortcommand(_("Sorry, no %s node named '%s' in this facet"),
 					(findexclusively==0 ? "" : describenodeproto(us_curnodeproto)), par[1]);
 				return;
 			}
@@ -1178,8 +1191,8 @@ void us_find(INTSML count, char *par[])
 				(void)us_addhighlight(&newhigh);
 				i++;
 			}
-			if (i == 0) ttyputmsg("No nonmanhattan objects in this facet"); else
-				ttyputmsg("%ld objects are not manhattan in this facet", i);
+			if (i == 0) ttyputmsg(_("No nonmanhattan objects in this facet")); else
+				ttyputmsg(_("%ld objects are not manhattan in this facet"), i);
 			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			{
 				if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
@@ -1200,15 +1213,15 @@ void us_find(INTSML count, char *par[])
 					}
 					if (l == 1)
 					{
-						ttyputmsg("Found nonmanhattan geometry in facet%s", returninfstr());
+						ttyputmsg(_("Found nonmanhattan geometry in facet%s"), returninfstr());
 					} else
 					{
-						ttyputmsg("Found nonmanhattan geometry in these facets:%s",
+						ttyputmsg(_("Found nonmanhattan geometry in these facets:%s"),
 							returninfstr());
 					}
 				} else
 				{
-					ttyputmsg("Found nonmanhattan geometry in library %s", lib->libname);
+					ttyputmsg(_("Found nonmanhattan geometry in library %s"), lib->libname);
 				}
 			}
 			return;
@@ -1218,13 +1231,13 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count < 2)
 			{
-				us_abortcommand("Usage: find object (TYPE ADDRESS | TYPEADDRESS)");
+				ttyputusage("find object (TYPE ADDRESS | TYPEADDRESS)");
 				return;
 			}
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				findwithin != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find object'");
+				us_abortcommand(_("Illegal options given to 'find object'"));
 				return;
 			}
 
@@ -1259,7 +1272,7 @@ void us_find(INTSML count, char *par[])
 			}
 			if (type == VUNKNOWN)
 			{
-				us_abortcommand("Unknown object type in 'find object' command");
+				us_abortcommand(_("Unknown object type in 'find object' command"));
 				return;
 			}
 			switch (type)
@@ -1269,7 +1282,7 @@ void us_find(INTSML count, char *par[])
 					if (ni == 0 || ni == NONODEINST) return;
 					if (ni->parent != np)
 					{
-						us_abortcommand("Cannot find node %ld in this facet", addr);
+						us_abortcommand(_("Cannot find node %ld in this facet"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
@@ -1283,7 +1296,7 @@ void us_find(INTSML count, char *par[])
 					if (ai == 0 || ai == NOARCINST) return;
 					if (ai->parent != np)
 					{
-						us_abortcommand("Cannot find arc %ld in this facet", addr);
+						us_abortcommand(_("Cannot find arc %ld in this facet"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
@@ -1297,7 +1310,7 @@ void us_find(INTSML count, char *par[])
 					if (net == 0 || net == NONETWORK) return;
 					if (net->parent != np)
 					{
-						us_abortcommand("Cannot find network %ld in this facet", addr);
+						us_abortcommand(_("Cannot find network %ld in this facet"), addr);
 						return;
 					}
 					for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1324,7 +1337,7 @@ void us_find(INTSML count, char *par[])
 					if (pp == 0 || pp == NOPORTPROTO) return;
 					if (pp->parent != np)
 					{
-						us_abortcommand("Cannot find port %ld in this facet", addr);
+						us_abortcommand(_("Cannot find port %ld in this facet"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
@@ -1334,7 +1347,7 @@ void us_find(INTSML count, char *par[])
 					us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 					break;
 				default:
-					us_abortcommand("Cannot highlight objects of type %s",
+					us_abortcommand(_("Cannot highlight objects of type %s"),
 						us_variabletypename(type));
 					return;
 			}
@@ -1345,26 +1358,26 @@ void us_find(INTSML count, char *par[])
 		{
 			if (count <= 1)
 			{
-				us_abortcommand("Usage: find save HIGHLIGHTNAME");
+				ttyputusage("find save HIGHLIGHTNAME");
 				return;
 			}
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find save'");
+				us_abortcommand(_("Illegal options given to 'find save'"));
 				return;
 			}
 			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 			if (var == NOVARIABLE)
 			{
-				us_abortcommand("Highlight something before saving highlight");
+				us_abortcommand(_("Highlight something before saving highlight"));
 				return;
 			}
 			(void)initinfstr();
 			(void)addstringtoinfstr("USER_highlight_");
 			(void)addstringtoinfstr(par[1]);
 			(void)setval((INTBIG)us_aid, VAID, returninfstr(), var->addr, var->type|VDONTSAVE);
-			ttyputverbose("%s saved", par[1]);
+			ttyputverbose(_("%s saved"), par[1]);
 			return;
 		}
 
@@ -1373,7 +1386,7 @@ void us_find(INTSML count, char *par[])
 			glist = us_gethighlighted(OBJARCINST|OBJNODEINST);
 			if (glist[0] == NOGEOM)
 			{
-				us_abortcommand("Select something before making it easy-to-select");
+				us_abortcommand(_("Select something before making it easy-to-select"));
 				return;
 			}
 			for(i=0; glist[i] != NOGEOM; i++)
@@ -1397,7 +1410,7 @@ void us_find(INTSML count, char *par[])
 			glist = us_gethighlighted(OBJARCINST|OBJNODEINST);
 			if (glist[0] == NOGEOM)
 			{
-				us_abortcommand("Select something before making it easy-to-select");
+				us_abortcommand(_("Select something before making it easy-to-select"));
 				return;
 			}
 			for(i=0; glist[i] != NOGEOM; i++)
@@ -1421,7 +1434,7 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find snap-mode'");
+				us_abortcommand(_("Illegal options given to 'find snap-mode'"));
 				return;
 			}
 
@@ -1429,14 +1442,14 @@ void us_find(INTSML count, char *par[])
 			{
 				switch (us_state&SNAPMODE)
 				{
-					case SNAPMODENONE:     ttyputmsg("Snapping mode: none");              break;
-					case SNAPMODECENTER:   ttyputmsg("Snapping mode: center");            break;
-					case SNAPMODEMIDPOINT: ttyputmsg("Snapping mode: midpoint");          break;
-					case SNAPMODEENDPOINT: ttyputmsg("Snapping mode: end point");         break;
-					case SNAPMODETANGENT:  ttyputmsg("Snapping mode: tangent");           break;
-					case SNAPMODEPERP:     ttyputmsg("Snapping mode: perpendicular");     break;
-					case SNAPMODEQUAD:     ttyputmsg("Snapping mode: quadrant");          break;
-					case SNAPMODEINTER:    ttyputmsg("Snapping mode: any intersection");  break;
+					case SNAPMODENONE:     ttyputmsg(_("Snapping mode: none"));              break;
+					case SNAPMODECENTER:   ttyputmsg(_("Snapping mode: center"));            break;
+					case SNAPMODEMIDPOINT: ttyputmsg(_("Snapping mode: midpoint"));          break;
+					case SNAPMODEENDPOINT: ttyputmsg(_("Snapping mode: end point"));         break;
+					case SNAPMODETANGENT:  ttyputmsg(_("Snapping mode: tangent"));           break;
+					case SNAPMODEPERP:     ttyputmsg(_("Snapping mode: perpendicular"));     break;
+					case SNAPMODEQUAD:     ttyputmsg(_("Snapping mode: quadrant"));          break;
+					case SNAPMODEINTER:    ttyputmsg(_("Snapping mode: any intersection"));  break;
 				}
 				return;
 			}
@@ -1444,52 +1457,52 @@ void us_find(INTSML count, char *par[])
 			if (namesamen(pt, "none", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODENONE;
-				ttyputverbose("Snapping mode: none");
+				ttyputverbose(_("Snapping mode: none"));
 				return;
 			}
 			if (namesamen(pt, "center", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODECENTER;
-				ttyputverbose("Snapping mode: center");
+				ttyputverbose(_("Snapping mode: center"));
 				return;
 			}
 			if (namesamen(pt, "midpoint", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODEMIDPOINT;
-				ttyputverbose("Snapping mode: midpoint");
+				ttyputverbose(_("Snapping mode: midpoint"));
 				return;
 			}
 			if (namesamen(pt, "endpoint", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODEENDPOINT;
-				ttyputverbose("Snapping mode: endpoint");
+				ttyputverbose(_("Snapping mode: endpoint"));
 				return;
 			}
 			if (namesamen(pt, "tangent", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODETANGENT;
-				ttyputverbose("Snapping mode: tangent");
+				ttyputverbose(_("Snapping mode: tangent"));
 				return;
 			}
 			if (namesamen(pt, "perpendicular", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODEPERP;
-				ttyputverbose("Snapping mode: perpendicular");
+				ttyputverbose(_("Snapping mode: perpendicular"));
 				return;
 			}
 			if (namesamen(pt, "quadrant", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODEQUAD;
-				ttyputverbose("Snapping mode: quadrant");
+				ttyputverbose(_("Snapping mode: quadrant"));
 				return;
 			}
 			if (namesamen(pt, "intersection", l) == 0)
 			{
 				us_state = (us_state & ~SNAPMODE) | SNAPMODEINTER;
-				ttyputverbose("Snapping mode: any intersection");
+				ttyputverbose(_("Snapping mode: any intersection"));
 				return;
 			}
-			us_abortcommand("Unknown snapping mode: %s", pt);
+			us_abortcommand(_("Unknown snapping mode: %s"), pt);
 			return;
 		}
 
@@ -1498,13 +1511,13 @@ void us_find(INTSML count, char *par[])
 			if (findport != 0 || findpoint != 0 || findexclusively != 0 ||
 				extrainfo != 0 || findwithin != 0 || findmore != 0 || findspecial != 0)
 			{
-				us_abortcommand("Illegal options given to 'find up-stack'");
+				us_abortcommand(_("Illegal options given to 'find up-stack'"));
 				return;
 			}
-			if (us_pophighlight(0) != 0) us_abortcommand("The stack is empty");
+			if (us_pophighlight(0) != 0) us_abortcommand(_("The stack is empty"));
 			return;
 		}
-		us_abortcommand("Bad FIND option: %s", pt);
+		ttyputbadusage("find");
 		return;
 	}
 
@@ -1527,7 +1540,6 @@ void us_getproto(INTSML count, char *par[])
 	REGISTER INTSML doarc, l;
 	REGISTER char *pp;
 	HIGHLIGHT high;
-	INTBIG xcur, ycur;
 	extern COMCOMP us_getproto1p;
 	REGISTER VARIABLE *highvar;
 	GEOM *fromgeom, *togeom;
@@ -1535,7 +1547,7 @@ void us_getproto(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam("Getproto option: ", &us_getproto1p, MAXPARS, par);
+		count = ttygetparam(_("Getproto option: "), &us_getproto1p, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -1549,7 +1561,7 @@ void us_getproto(INTSML count, char *par[])
 		np = getnodeproto(par[1]);
 		if (np == NONODEPROTO)
 		{
-			us_abortcommand("Cannot find node '%s'", par[1]);
+			us_abortcommand(_("Cannot find node '%s'"), par[1]);
 			return;
 		}
 		us_setnodeproto(np);
@@ -1558,14 +1570,14 @@ void us_getproto(INTSML count, char *par[])
 	if (namesamen(pp, "arc", l) == 0 && l >= 1 && count > 1)
 	{
 		ap = getarcproto(par[1]);
-		if (ap == NOARCPROTO) us_abortcommand("Cannot find arc '%s'", par[1]); else
+		if (ap == NOARCPROTO) us_abortcommand(_("Cannot find arc '%s'"), par[1]); else
 			us_setarcproto(ap, 1);
 		return;
 	}
 
 	if (namesamen(pp, "this-proto", l) == 0 && l >= 1)
 	{
-		if (us_demandxy(&xcur, &ycur)) return;
+/*		if (us_demandxy(&xcur, &ycur)) return; */
 		np = us_needfacet();
 		if (np == NONODEPROTO) return;
 		us_setnodeproto(np);
@@ -1649,8 +1661,8 @@ void us_getproto(INTSML count, char *par[])
 	np = getnodeproto(pp);
 	if (np == NONODEPROTO)
 	{
-		if (doarc != 0) us_abortcommand("Cannot find node or arc '%s'", pp); else
-			us_abortcommand("Cannot find node '%s'", pp);
+		if (doarc != 0) us_abortcommand(_("Cannot find node or arc '%s'"), pp); else
+			us_abortcommand(_("Cannot find node '%s'"), pp);
 		return;
 	}
 	us_setnodeproto(np);
@@ -1688,12 +1700,12 @@ void us_grid(INTSML count, char *par[])
 			i = atola(par[1]);
 			if (i < 0)
 			{
-				us_abortcommand("Alignment must be positive");
+				us_abortcommand(_("Alignment must be positive"));
 				return;
 			}
 			(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_obj, i, VINTEGER|VDONTSAVE);
 		}
-		ttyputverbose("Cursor alignment is %s lambda", latoa(us_alignment));
+		ttyputverbose(_("Cursor alignment is %s lambda"), latoa(us_alignment));
 		return;
 	}
 
@@ -1704,13 +1716,13 @@ void us_grid(INTSML count, char *par[])
 			i = atola(par[1]);
 			if (i < 0)
 			{
-				us_abortcommand("Alignment must be positive");
+				us_abortcommand(_("Alignment must be positive"));
 				return;
 			}
 			(void)setvalkey((INTBIG)us_aid, VAID, us_alignment_edge, i, VINTEGER|VDONTSAVE);
 		}
-		if (us_edgealignment == 0) ttyputverbose("No edge alignment done"); else
-			ttyputverbose("Edge alignment is %s lambda", latoa(us_edgealignment));
+		if (us_edgealignment == 0) ttyputverbose(_("No edge alignment done")); else
+			ttyputverbose(_("Edge alignment is %s lambda"), latoa(us_edgealignment));
 		return;
 	}
 
@@ -1718,7 +1730,7 @@ void us_grid(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: grid size X [Y]");
+			ttyputusage("grid size X [Y]");
 			return;
 		}
 		i = atola(par[1]);
@@ -1730,7 +1742,7 @@ void us_grid(INTSML count, char *par[])
 		} else j = i;
 		if (i <= 0 || j <= 0)
 		{
-			us_abortcommand("Invalid grid spacing");
+			us_abortcommand(_("Invalid grid spacing"));
 			return;
 		}
 
@@ -1758,7 +1770,7 @@ void us_grid(INTSML count, char *par[])
 		(void)us_pophighlight(0);
 		return;
 	}
-	us_abortcommand("Bad GRID option: %s", pp);
+	ttyputbadusage("grid");
 }
 
 #define	NEWSFILE   "newsfile"			/* file with news */
@@ -1768,7 +1780,6 @@ void us_grid(INTSML count, char *par[])
 void us_help(INTSML count, char *par[])
 {
 	REGISTER INTSML len;
-	char *paramstart[MAXPARS];
 	REGISTER char *pp;
 	REGISTER INTSML lastquiet, nday, nmonth, nyear, on;
 	INTSML day, month, year, hour, minute, second;
@@ -1781,6 +1792,18 @@ void us_help(INTSML count, char *par[])
 	/* show the user manual */
 	if (count >= 1 && namesamen(pp, "manual", len) == 0)
 	{
+#ifdef DOCDIR
+		strcpy(line, DOCDIR);
+		strcat(line, "index.html");
+		if (fileexistence(line) == 1)
+		{
+			if (browsefile(line) != 0)
+			{
+				us_abortcommand(_("Cannot bring up the user's manual on this system"));
+			}
+			return;
+		}
+#endif
 		strcpy(line, el_libdir);
 		len = strlen(line);
 		if (line[len-1] == DIRSEP) line[len-1] = 0;
@@ -1792,10 +1815,15 @@ void us_help(INTSML count, char *par[])
 		strcat(line, "manual");
 		strcat(line, sep);
 		strcat(line, "index.html");
+		if (fileexistence(line) != 1)
+		{
+			us_abortcommand(_("Sorry, cannot locate the user's manual"));
+			return;
+		}
 
 		if (browsefile(line) != 0)
 		{
-			us_abortcommand("Cannot bring up the user's manual on this system");
+			us_abortcommand(_("Cannot bring up the user's manual on this system"));
 		}
 		return;
 	}
@@ -1824,10 +1852,10 @@ void us_help(INTSML count, char *par[])
 		(void)addstringtoinfstr(el_libdir);
 		(void)addstringtoinfstr(NEWSFILE);
 		pp = truepath(returninfstr());
-		in = xopen(pp, FILETYPENEWS, "", &filename);
+		in = xopen(pp, us_filetypenews, "", &filename);
 		if (in == NULL)
 		{
-			ttyputerr("Sorry, cannot find the news file: %s", pp);
+			ttyputerr(_("Sorry, cannot find the news file: %s"), pp);
 			return;
 		}
 
@@ -1865,7 +1893,7 @@ void us_help(INTSML count, char *par[])
 		/* restore message output state */
 		(void)ttyquiet(lastquiet);
 
-		if (on == 0) ttyputmsg("No news");
+		if (on == 0) ttyputmsg(_("No news"));
 
 		/* now mark the current date */
 		(void)initinfstr();
@@ -1873,7 +1901,7 @@ void us_help(INTSML count, char *par[])
 		if (hd == 0) (void)addstringtoinfstr(el_libdir); else
 			(void)addstringtoinfstr(hd);
 		(void)addstringtoinfstr(NEWSDATE);
-		xclose(xcreate(truepath(returninfstr()), FILETYPENEWS, 0, 0));
+		xclose(xcreate(truepath(returninfstr()), us_filetypenews, 0, 0));
 		return;
 	}
 
@@ -1884,8 +1912,15 @@ void us_help(INTSML count, char *par[])
 		return;
 	}
 
+	/* dump pulldown menus */
+	if (count >= 1 && namesamen(pp, "pulldowns", len) == 0)
+	{
+		us_dumppulldownmenus();
+		return;
+	}
+
 	/* general dialog-based help on command-line */
-	(void)us_helpdlog("CL", paramstart);
+	(void)us_helpdlog("CL");
 }
 
 void us_if(INTSML count, char *par[])
@@ -1897,7 +1932,7 @@ void us_if(INTSML count, char *par[])
 	/* make sure the proper number of parameters is given */
 	if (count < 4)
 	{
-		us_abortcommand("Usage: if TERM1 RELATION TERM2 COMMAND");
+		ttyputusage("if TERM1 RELATION TERM2 COMMAND");
 		return;
 	}
 
@@ -1947,14 +1982,14 @@ void us_if(INTSML count, char *par[])
 	if (strcmp(par[1], ">=") == 0) relation = 5;
 	if (relation < 0)
 	{
-		us_abortcommand("Unknown relation: %s", par[1]);
+		us_abortcommand(_("Unknown relation: %s"), par[1]);
 		return;
 	}
 
 	/* make sure that qualitative comparison is done on numbers */
 	if (relation > 1 && term1type != VINTEGER)
 	{
-		us_abortcommand("Inequality comparisons must be done on numbers");
+		us_abortcommand(_("Inequality comparisons must be done on numbers"));
 		return;
 	}
 
@@ -1997,7 +2032,7 @@ void us_if(INTSML count, char *par[])
 	com = us_buildcommand((INTSML)(count-3), &par[3]);
 	if (com == NOUSERCOM)
 	{
-		us_abortcommand("Condition true but there is no command to execute");
+		us_abortcommand(_("Condition true but there is no command to execute"));
 		return;
 	}
 	us_execute(com, 0, 0, 0);
@@ -2046,7 +2081,7 @@ void us_interpret(INTSML count, char *par[])
 	{
 		if (count <= 0)
 		{
-			us_abortcommand("Usage: interpret file LANGUAGE FILENAME");
+			ttyputusage("interpret file LANGUAGE FILENAME");
 			return;
 		}
 		loadcode(par[0], language);
@@ -2058,13 +2093,13 @@ void us_interpret(INTSML count, char *par[])
 	{
 		/* "languageconverse" returns 0 if it wants to continue conversation */
 		if (languageconverse(language) == 0) us_state |= LANGLOOP; else
-			ttyputmsg("Back to Electric");
+			ttyputmsg(_("Back to Electric"));
 		return;
 	}
 
 	if (count > 1)
 	{
-		us_abortcommand("Please provide only one parameter to be interpreted");
+		us_abortcommand(_("Please provide only one parameter to be interpreted"));
 		return;
 	}
 
@@ -2103,7 +2138,7 @@ void us_iterate(INTSML count, char *par[])
 		/* make sure there was a valid previous command */
 		if (us_lastcom == NOUSERCOM || us_lastcom->active < 0)
 		{
-			us_abortcommand("No last command to repeat");
+			us_abortcommand(_("No last command to repeat"));
 			return;
 		}
 
@@ -2111,13 +2146,13 @@ void us_iterate(INTSML count, char *par[])
 		uc = us_allocusercom();
 		if (uc == NOUSERCOM)
 		{
-			ttyputerr("No memory");
+			ttyputnomemory();
 			return;
 		}
 		for(i=0; i<us_lastcom->count; i++)
 			if (allocstring(&uc->word[i], us_lastcom->word[i], us_aid->cluster) != 0)
 		{
-			ttyputerr("No memory");
+			ttyputnomemory();
 			return;
 		}
 		uc->active = us_lastcom->active;
@@ -2133,12 +2168,12 @@ void us_iterate(INTSML count, char *par[])
 		/* implement the iterate over array-variable form */
 		if (count < 2)
 		{
-			us_abortcommand("Usage: iterate ARRAY-VARIABLE MACRO");
+			ttyputusage("iterate ARRAY-VARIABLE MACRO");
 			return;
 		}
 		if (us_getvar(par[0], &objaddr, &objtype, &qual, &comvar, &cindex) != 0)
 		{
-			us_abortcommand("Incorrect iterator variable name: %s", par[0]);
+			us_abortcommand(_("Incorrect iterator variable name: %s"), par[0]);
 			return;
 		}
 		if (*qual != 0)
@@ -2146,7 +2181,7 @@ void us_iterate(INTSML count, char *par[])
 			var = getval(objaddr, objtype, -1, qual);
 			if (var == NOVARIABLE)
 			{
-				us_abortcommand("Cannot find iterator variable: %s", par[0]);
+				us_abortcommand(_("Cannot find iterator variable: %s"), par[0]);
 				return;
 			}
 		} else
@@ -2197,7 +2232,7 @@ void us_iterate(INTSML count, char *par[])
 			if (com->active < 0) { us_freeusercom(com);   break; }
 			us_execute(com, 0, 0, 0);
 			us_freeusercom(com);
-			if (stopping("iteration") != 0) break;
+			if (stopping(STOPREASONITERATE)) break;
 		}
 	}
 }
@@ -2211,7 +2246,7 @@ void us_killfacet(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam("Facet name: ", &us_showdp, MAXPARS, par);
+		count = ttygetparam(_("Facet name: "), &us_showdp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -2222,12 +2257,12 @@ void us_killfacet(INTSML count, char *par[])
 	np = getnodeproto(par[0]);
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand("No facet called %s", par[0]);
+		us_abortcommand(_("No facet called %s"), par[0]);
 		return;
 	}
 	if (np->primindex != 0)
 	{
-		us_abortcommand("Can only kill facets");
+		us_abortcommand(_("Can only kill facets"));
 		return;
 	}
 
@@ -2242,15 +2277,15 @@ void us_killfacet(INTSML count, char *par[])
 				onp->temp1 = 0;
 		for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			ni->parent->temp1++;
-		ttyputerr("Erase all of the following instances of this facet first:");
+		ttyputerr(_("Erase all of the following instances of this facet first:"));
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			for(onp = lib->firstnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
 				if (onp->temp1 != 0)
-					ttyputmsg("  %ld instance(s) in facet %s", onp->temp1, describenodeproto(onp));
+					ttyputmsg(_("  %ld instance(s) in facet %s"), onp->temp1, describenodeproto(onp));
 		return;
 	}
 
 	/* kill the facet */
 	us_dokillfacet(np);
-	ttyputmsg("Facet %s deleted", par[0]);
+	ttyputmsg(_("Facet %s deleted"), par[0]);
 }
