@@ -74,7 +74,7 @@ void us_outhier(INTSML count, char *par[])
 		total = atoi(par[0]);
 		if (total <= 0)
 		{
-			us_abortcommand("Specify a positive number");
+			us_abortcommand(_("Specify a positive number"));
 			return;
 		}
 	}
@@ -87,7 +87,7 @@ void us_outhier(INTSML count, char *par[])
 	lx = el_curwindowpart->screenlx;   hx = el_curwindowpart->screenhx;
 	ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
 
-	/* see if a node with an exported port is highlighted */
+	/* see if a node with an export is highlighted */
 	curpp = NOPORTPROTO;
 	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 	if (var != NOVARIABLE)
@@ -113,7 +113,7 @@ void us_outhier(INTSML count, char *par[])
 					ni = high.fromgeom->entryaddr.ni;
 					np = ni->proto;
 
-					/* see if port is exported */
+					/* see if port is an export */
 					for (pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 						if (pe->proto == pp) break;
 					if (pe != NOPORTEXPINST)
@@ -153,10 +153,10 @@ void us_outhier(INTSML count, char *par[])
 			{
 				if (i == 0)
 				{
-					us_abortcommand("Not in any facets");
+					us_abortcommand(_("Not in any facets"));
 					return;
 				}
-				ttyputerr("Only in %d deep", i);
+				ttyputerr(_("Only in %d deep"), i);
 				hinp = curnp;
 				break;
 			}
@@ -221,13 +221,13 @@ void us_package(INTSML count, char *par[])
 	/* get the specified area */
 	if (us_getareabounds(&lx, &hx, &ly, &hy) == NONODEPROTO)
 	{
-		us_abortcommand("Enclose an area to be packaged");
+		us_abortcommand(_("Enclose an area to be packaged"));
 		return;
 	}
 
 	if (count == 0)
 	{
-		count = ttygetparam("New facet name: ", &us_packagep, MAXPARS, par);
+		count = ttygetparam(_("New facet name: "), &us_packagep, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -244,7 +244,7 @@ void us_package(INTSML count, char *par[])
 		lib = getlibrary(par[0]);
 		if (lib == NOLIBRARY)
 		{
-			us_abortcommand("Cannot find library '%s'", par[0]);
+			us_abortcommand(_("Cannot find library '%s'"), par[0]);
 			return;
 		}
 		par[0] = pt;
@@ -254,7 +254,7 @@ void us_package(INTSML count, char *par[])
 	np = newnodeproto(par[0], lib);
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand("Cannot create facet %s", par[0]);
+		us_abortcommand(_("Cannot create facet %s"), par[0]);
 		return;
 	}
 
@@ -284,7 +284,7 @@ void us_package(INTSML count, char *par[])
 			ni->highy, ni->transpose, ni->rotation, np);
 		if (newni == NONODEINST)
 		{
-			us_abortcommand("Cannot create node in new facet");
+			us_abortcommand(_("Cannot create node in new facet"));
 			return;
 		}
 		ni->temp1 = (INTBIG)newni;
@@ -292,7 +292,7 @@ void us_package(INTSML count, char *par[])
 		newni->textdescript = ni->textdescript;
 		if (copyvars((INTBIG)ni, VNODEINST, (INTBIG)newni, VNODEINST) != 0)
 		{
-			us_abortcommand("Memory low");
+			ttyputnomemory();
 			return;
 		}
 
@@ -306,7 +306,7 @@ void us_package(INTSML count, char *par[])
 			npt->textdescript = ppt->textdescript;
 			if (copyvars((INTBIG)ppt, VPORTPROTO, (INTBIG)npt, VPORTPROTO) != 0)
 			{
-				us_abortcommand("Memory low");
+				ttyputnomemory();
 				return;
 			}
 		}
@@ -328,7 +328,7 @@ void us_package(INTSML count, char *par[])
 					ai->end[1].xpos,ai->end[1].ypos, np);
 		if (newar == NOARCINST)
 		{
-			us_abortcommand("Cannot create arc in new facet");
+			us_abortcommand(_("Cannot create arc in new facet"));
 			return;
 		}
 		if (copyvars((INTBIG)ai, VARCINST, (INTBIG)newar, VARCINST) != 0 ||
@@ -337,7 +337,7 @@ void us_package(INTSML count, char *par[])
 			copyvars((INTBIG)ai->end[1].portarcinst, VPORTARCINST,
 				(INTBIG)newar->end[1].portarcinst, VPORTARCINST) != 0)
 		{
-			us_abortcommand("Memory low");
+			ttyputnomemory();
 			return;
 		}
 	}
@@ -345,7 +345,7 @@ void us_package(INTSML count, char *par[])
 	/* recompute bounds of new facet */
 	(*el_curconstraint->solve)(np);
 
-	ttyputmsg("Facet %s created", describenodeproto(np));
+	ttyputmsg(_("Facet %s created"), describenodeproto(np));
 }
 
 void us_port(INTSML count, char *par[])
@@ -371,7 +371,7 @@ void us_port(INTSML count, char *par[])
 	/* get options */
 	if (count == 0)
 	{
-		count = ttygetparam("Port option: ", &us_portp, MAXPARS, par);
+		count = ttygetparam(_("Port option: "), &us_portp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -390,7 +390,7 @@ void us_port(INTSML count, char *par[])
 			if (namesamen(pt, "short", l) == 0 && l >= 2) labels = PORTSSHORT; else
 			if (namesamen(pt, "long", l) == 0 && l >= 1) labels = PORTSFULL; else
 			{
-				us_abortcommand("Usage: port labels none|short|long|crosses");
+				ttyputusage("port labels none|short|long|crosses");
 				return;
 			}
 			(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
@@ -398,10 +398,10 @@ void us_port(INTSML count, char *par[])
 		}
 		switch (us_useroptions&PORTLABELS)
 		{
-			case PORTSOFF:   ttyputverbose("No ports are indicated");     break;
-			case PORTSCROSS: ttyputverbose("Ports shown as crosses");     break;
-			case PORTSFULL:  ttyputverbose("Long port names displayed");  break;
-			case PORTSSHORT: ttyputverbose("Short port names displayed"); break;
+			case PORTSOFF:   ttyputverbose(_("No ports are indicated"));     break;
+			case PORTSCROSS: ttyputverbose(_("Ports shown as crosses"));     break;
+			case PORTSFULL:  ttyputverbose(_("Long port names displayed"));  break;
+			case PORTSSHORT: ttyputverbose(_("Short port names displayed")); break;
 		}
 		return;
 	}
@@ -410,18 +410,18 @@ void us_port(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			us_abortcommand("Usage: port synchronize-library LIBRARY");
+			ttyputusage("port synchronize-library LIBRARY");
 			return;
 		}
 		olib = getlibrary(par[1]);
 		if (olib == NOLIBRARY)
 		{
-			us_abortcommand("No library called %s is read in", par[1]);
+			us_abortcommand(_("No library called %s is read in"), par[1]);
 			return;
 		}
 		if (olib == el_curlib)
 		{
-			us_abortcommand("Must synchronize with a different library");
+			us_abortcommand(_("Must synchronize with a different library"));
 			return;
 		}
 		us_portsynchronize(olib);
@@ -435,7 +435,7 @@ void us_port(INTSML count, char *par[])
 		if (np == NONODEPROTO) return;
 		if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
 		{
-			us_abortcommand("Cannot show ports in a 3D window");
+			us_abortcommand(_("Cannot show ports in a 3D window"));
 			return;
 		}
 		us_identifyports(NONODEINST, np, LAYERA);
@@ -446,12 +446,12 @@ void us_port(INTSML count, char *par[])
 	{
 		if (us_gettwoobjects(&fromgeom, &fromport, &togeom, &toport) != 0)
 		{
-			us_abortcommand("Must select two nodes");
+			us_abortcommand(_("Must select two nodes"));
 			return;
 		}
 		if (fromport == NOPORTPROTO || toport == NOPORTPROTO)
 		{
-			us_abortcommand("Must select two nodes AND their ports");
+			us_abortcommand(_("Must select two nodes AND their ports"));
 			return;
 		}
 
@@ -459,7 +459,7 @@ void us_port(INTSML count, char *par[])
 		np = geomparent(fromgeom);
 		if (np != geomparent(togeom))
 		{
-			us_abortcommand("Port motion must be within a single facet");
+			us_abortcommand(_("Port motion must be within a single facet"));
 			return;
 		}
 
@@ -473,13 +473,13 @@ void us_port(INTSML count, char *par[])
 			if (namesamen(pt, "remain-highlighted", l) == 0) reducehighlighting = 0;
 		}
 
-		/* get the "source" node and exported port */
+		/* get the "source" node and export */
 		oni = fromgeom->entryaddr.ni;
 		for(pe = oni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 			if (pe->proto == fromport) break;
 		if (pe == NOPORTEXPINST)
 		{
-			us_abortcommand("Port %s of node %s is not exported", fromport->protoname,
+			us_abortcommand(_("Port %s of node %s is not an export"), fromport->protoname,
 				describenodeinst(oni));
 			return;
 		}
@@ -488,7 +488,7 @@ void us_port(INTSML count, char *par[])
 		ni = togeom->entryaddr.ni;
 		if (ni == oni && fromport == toport)
 		{
-			us_abortcommand("This does not move the port");
+			us_abortcommand(_("This does not move the port"));
 			return;
 		}
 
@@ -500,11 +500,11 @@ void us_port(INTSML count, char *par[])
 		pt = pe->exportproto->protoname;
 		startobjectchange((INTBIG)ni, VNODEINST);
 		startobjectchange((INTBIG)oni, VNODEINST);
-		if (moveportproto(np, pe->exportproto, ni, toport) != 0) ttyputerr("Port not moved"); else
+		if (moveportproto(np, pe->exportproto, ni, toport) != 0) ttyputerr(_("Port not moved")); else
 		{
 			endobjectchange((INTBIG)ni, VNODEINST);
 			endobjectchange((INTBIG)oni, VNODEINST);
-			ttyputverbose("Port %s moved from node %s to node %s", pt, describenodeinst(oni),
+			ttyputverbose(_("Port %s moved from node %s to node %s"), pt, describenodeinst(oni),
 				describenodeinst(ni));
 		}
 
@@ -544,7 +544,7 @@ void us_port(INTSML count, char *par[])
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				pp->temp1 = 0;
 
-			/* mark the connected and exported ports */
+			/* mark the connected and exports */
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				pi->proto->temp1++;
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
@@ -562,8 +562,8 @@ void us_port(INTSML count, char *par[])
 				total++;
 			}
 		}
-		if (total == 0) ttyputmsg("No ports to re-export"); else
-			ttyputmsg("%d ports re-exported", total);
+		if (total == 0) ttyputmsg(_("No ports to export")); else
+			ttyputmsg(_("%d ports exported"), total);
 
 		/* restore highlighting */
 		(void)us_pophighlight(0);
@@ -579,7 +579,7 @@ void us_port(INTSML count, char *par[])
 		np = us_getareabounds(&lx, &hx, &ly, &hy);
 		if (np == NONODEPROTO)
 		{
-			us_abortcommand("Must select an area enclosing ports to re-export");
+			us_abortcommand(_("Must select an area enclosing ports to export"));
 			return;
 		}
 
@@ -590,7 +590,7 @@ void us_port(INTSML count, char *par[])
 		g = us_gethighlighted(OBJNODEINST);
 		if (g[0] == NOGEOM)
 		{
-			us_abortcommand("Must select some nodes for exporting ports");
+			us_abortcommand(_("Must select some nodes for making exports"));
 			return;
 		}
 
@@ -611,7 +611,7 @@ void us_port(INTSML count, char *par[])
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				pp->temp1 = 0;
 
-			/* mark the connected and exported ports */
+			/* mark the connected and make exports */
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				pi->proto->temp1++;
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
@@ -632,8 +632,8 @@ void us_port(INTSML count, char *par[])
 				total++;
 			}
 		}
-		if (total == 0) ttyputmsg("No ports to re-export"); else
-			ttyputmsg("%d ports re-exported", total);
+		if (total == 0) ttyputmsg(_("No ports to export")); else
+			ttyputmsg(_("%d ports exported"), total);
 
 		/* restore highlighting */
 		(void)us_pophighlight(0);
@@ -644,7 +644,7 @@ void us_port(INTSML count, char *par[])
 	{
 		if (count <= 1 || namesamen(par[1], "export", strlen(par[1])) != 0)
 		{
-			us_abortcommand("Usage: port not export [OPTIONS]");
+			ttyputusage("port not export [OPTIONS]");
 			return;
 		}
 		if (count == 3 && namesame(par[2], "geometry") == 0)
@@ -653,7 +653,7 @@ void us_port(INTSML count, char *par[])
 			np = us_getareabounds(&lx, &hx, &ly, &hy);
 			if (np == NONODEPROTO)
 			{
-				us_abortcommand("Outline an area first");
+				us_abortcommand(_("Outline an area first"));
 				return;
 			}
 
@@ -674,10 +674,10 @@ void us_port(INTSML count, char *par[])
 					shapeportpoly(ni, pe->proto, poly, 0);
 					getcenter(poly, &x, &y);
 					if (x < lx || x > hx || y < ly || y > hy) continue;
-					ttyputmsg("Deleting port %s", pe->exportproto->protoname);
+					ttyputmsg(_("Deleting port %s"), pe->exportproto->protoname);
 					if (i == 0) startobjectchange((INTBIG)ni, VNODEINST);
 					if (killportproto(np, pe->exportproto))
-						ttyputerr("killportproto error");
+						ttyputerr(_("killportproto error"));
 					i = 1;
 					deleted++;
 				}
@@ -686,7 +686,7 @@ void us_port(INTSML count, char *par[])
 
 			/* restore highlighting */
 			(void)us_pophighlight(0);
-			if (deleted == 0) ttyputmsg("No exported ports are in the selected area");
+			if (deleted == 0) ttyputmsg(_("No exports are in the selected area"));
 			return;
 		}
 		if (count == 3 && namesame(par[2], "all") == 0)
@@ -694,7 +694,7 @@ void us_port(INTSML count, char *par[])
 			g = us_gethighlighted(OBJNODEINST);
 			if (g[0] == NOGEOM)
 			{
-				us_abortcommand("Must first select nodes with exported ports");
+				us_abortcommand(_("Must first select nodes with exports"));
 				return;
 			}
 
@@ -714,9 +714,9 @@ void us_port(INTSML count, char *par[])
 				for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = nextpe)
 				{
 					nextpe = pe->nextportexpinst;
-					ttyputmsg("Deleting port %s", pe->exportproto->protoname);
+					ttyputmsg(_("Deleting export %s"), pe->exportproto->protoname);
 					if (killportproto(ni->parent, pe->exportproto))
-						ttyputerr("killportproto error");
+						ttyputerr(_("killportproto error"));
 					deleted++;
 				}
 				endobjectchange((INTBIG)ni, VNODEINST);
@@ -724,7 +724,7 @@ void us_port(INTSML count, char *par[])
 
 			/* restore highlighting */
 			(void)us_pophighlight(0);
-			if (deleted == 0) ttyputmsg("No exported ports are on the selected nodes");
+			if (deleted == 0) ttyputmsg(_("No exports are on the selected nodes"));
 			return;
 		}
 
@@ -735,7 +735,7 @@ void us_port(INTSML count, char *par[])
 		{
 			if (high->fromvar != NOVARIABLE || high->fromport == NOPORTPROTO)
 			{
-				us_abortcommand("Selected text must be a port name");
+				us_abortcommand(_("Selected text must be a port name"));
 				return;
 			}
 			ni = high->fromgeom->entryaddr.ni;
@@ -750,7 +750,7 @@ void us_port(INTSML count, char *par[])
 		/* first see if there is a port on this nodeinst */
 		if (ni->firstportexpinst == NOPORTEXPINST)
 		{
-			us_abortcommand("No exported ports on this node");
+			us_abortcommand(_("No exports on this node"));
 			return;
 		}
 
@@ -773,7 +773,7 @@ void us_port(INTSML count, char *par[])
 		/* restore highlighting */
 		(void)us_pophighlight(0);
 
-		ttyputverbose("Port %s deleted", pp->protoname);
+		ttyputverbose(_("Port %s deleted"), pp->protoname);
 		return;
 	}
 
@@ -787,7 +787,7 @@ void us_port(INTSML count, char *par[])
 
 		if (count <= 1)
 		{
-			count = ttygetparam("Port name: ", &us_portep, MAXPARS-1, &par[1])+1;
+			count = ttygetparam(_("Port name: "), &us_portep, MAXPARS-1, &par[1])+1;
 			if (count <= 1)
 			{
 				us_abortedmsg();
@@ -800,14 +800,14 @@ void us_port(INTSML count, char *par[])
 		while (*pt == ' ') pt++;
 		if (*pt == 0)
 		{
-			us_abortcommand("Null name");
+			us_abortcommand(_("Null name"));
 			return;
 		}
 
 		/* find a unique port name */
 		portname = us_uniqueportname(pt, ni->parent);
 		if (namesame(portname, pt) != 0)
-			ttyputmsg("Already a port called %s, calling this %s", pt, portname);
+			ttyputmsg(_("Already a port called %s, calling this %s"), pt, portname);
 
 		/* get the specification details */
 		pp = us_portdetails(NOPORTPROTO, (INTSML)(count-2), &par[2], ni, &bits, &mask, 0, pt);
@@ -823,7 +823,7 @@ void us_port(INTSML count, char *par[])
 		/* restore highlighting */
 		(void)us_pophighlight(0);
 
-		ttyputverbose("Port %s created", pp->protoname);
+		ttyputverbose(_("Port %s created"), pp->protoname);
 		return;
 	}
 
@@ -835,7 +835,7 @@ void us_port(INTSML count, char *par[])
 		{
 			if (high->fromvar != NOVARIABLE || high->fromport == NOPORTPROTO)
 			{
-				us_abortcommand("Selected text must be a port name");
+				us_abortcommand(_("Selected text must be a port name"));
 				return;
 			}
 			ni = high->fromgeom->entryaddr.ni;
@@ -868,24 +868,21 @@ void us_port(INTSML count, char *par[])
 		changeallports(pp);
 
 		(void)initinfstr();
-		(void)addstringtoinfstr("Port '");
-		(void)addstringtoinfstr(pp->protoname);
+		(void)formatinfstr(_("Port '%s'"), pp->protoname);
 		if ((pp->userbits&STATEBITS) == 0)
-			(void)addstringtoinfstr("' has no characteristics "); else
+			(void)addstringtoinfstr(_(" has no characteristics")); else
 		{
-			(void)addstringtoinfstr("' is ");
-			(void)addstringtoinfstr(us_describeportbits(pp));
+			(void)formatinfstr(_(" is %s"), us_describeportbits(pp));
 		}
-		(void)addstringtoinfstr(" (label ");
-		(void)addstringtoinfstr(us_describetextdescript(pp->textdescript));
-		if ((pp->userbits&PORTDRAWN) != 0) (void)addstringtoinfstr(",always-drawn");
-		if ((pp->userbits&BODYONLY) != 0) (void)addstringtoinfstr(",only-on-body");
+		(void)formatinfstr(_(" (label %s"), us_describetextdescript(pp->textdescript));
+		if ((pp->userbits&PORTDRAWN) != 0) (void)addstringtoinfstr(_(",always-drawn"));
+		if ((pp->userbits&BODYONLY) != 0) (void)addstringtoinfstr(_(",only-on-body"));
 		(void)addstringtoinfstr(") ");
 		ttyputmsg("%s", returninfstr());
 		return;
 	}
 
-	us_abortcommand("Bad PORT option: %s", pt);
+	ttyputbadusage("port");
 }
 
 void us_quit(INTSML count, char *par[])
