@@ -87,15 +87,12 @@ GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
 void us_showemptywindow(WINDOWPART*);
 void us_graphicsarcs(PORTPROTO*, INTSML*, INTSML*);
 void us_combinelayers(ARCINST*, INTSML*, INTSML*);
-void us_writeprotoname(PORTPROTO*, INTSML, XARRAY, INTSML, INTSML, WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 POLYGON *us_makeprotopoly(PORTPROTO*, XARRAY, WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 INTSML us_drawall(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, XARRAY, INTSML);
 INTSML us_drawarcinstpeek(ARCINST*, XARRAY, INTSML);
 INTSML us_drawnodeinstpeek(NODEINST*, XARRAY, INTSML);
 void us_peeksetlayer(INTSML, TECHNOLOGY*);
 void us_peekwritepolygon(INTBIG*, INTBIG*, INTSML, float);
-void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w);
-void us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w);
 
 /******************** WINDOW CONTROL ********************/
 
@@ -247,7 +244,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 				}
 			}
 
-			/* include exported ports that have an offset */
+			/* include exports that have an offset */
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 			{
 				pp = pe->exportproto;
@@ -330,10 +327,11 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 
 		if (*screenlx >= *screenhx && *screenly >= *screenhy)
 		{
-			*screenlx -= 20 * el_curtech->deflambda;
-			*screenhx += 20 * el_curtech->deflambda;
-			*screenly -= 20 * el_curtech->deflambda;
-			*screenhy += 20 * el_curtech->deflambda;
+			lambda = el_curlib->lambda[el_curtech->techindex];
+			*screenlx -= 25 * lambda;
+			*screenhx += 25 * lambda;
+			*screenly -= 25 * lambda;
+			*screenhy += 25 * lambda;
 		}
 	}
 }
@@ -351,7 +349,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 void us_squarescreen(WINDOWPART *w, WINDOWPART *formerw, INTSML largescale, INTBIG *screenlx,
 	INTBIG *screenhx, INTBIG *screenly, INTBIG *screenhy)
 {
-	REGISTER INTBIG i, units, image, design;
+	REGISTER INTBIG i, units, image, design, lambda;
 	float prod1, prod2, prodswap, fslx, fshx, fsly, fshy, bump, ysize, xsize;
 
 	if (formerw != NOWINDOWPART)
@@ -413,13 +411,16 @@ void us_squarescreen(WINDOWPART *w, WINDOWPART *formerw, INTSML largescale, INTB
 	{
 		/* adjust window so that it matches well with screen pixels */
 		if (*screenhx == *screenlx) return;
-		design = (*screenhx - *screenlx) / el_curtech->deflambda;
+		if (w->curnodeproto == NONODEPROTO)
+			lambda = el_curlib->lambda[el_curtech->techindex]; else
+				lambda = lambdaoffacet(w->curnodeproto);
+		design = (*screenhx - *screenlx) / lambda;
 		if (design <= 0) design = 1;
 		image = w->usehx - w->uselx;
 		if (image > design)
 		{
 			/* force integral number of pixels per lambda unit */
-			i = (muldiv(image, el_curtech->deflambda, image / design) - (*screenhx - *screenlx)) / 2;
+			i = (muldiv(image, lambda, image / design) - (*screenhx - *screenlx)) / 2;
 			(*screenhx) += i;   (*screenlx) -= i;
 			i = muldiv(*screenhx - *screenlx, w->usehy - w->usely,
 				w->usehx - w->uselx) - (*screenhy - *screenly);
@@ -428,7 +429,7 @@ void us_squarescreen(WINDOWPART *w, WINDOWPART *formerw, INTSML largescale, INTB
 		} else
 		{
 			/* force integral number of lambda units per pixel */
-			units = muldiv(design, el_curtech->deflambda, image);
+			units = muldiv(design, lambda, image);
 			i = ((units * (w->usehx - w->uselx)) - (*screenhx - *screenlx)) / 2;
 			(*screenhx) += i;   (*screenlx) -= i;
 			i = muldiv(*screenhx - *screenlx, w->usehy - w->usely,
@@ -947,7 +948,7 @@ void us_redisplaynow(WINDOWPART *w, INTSML now)
 		}
 	}
 
-	/* show this facet and exported port variables */
+	/* show this facet and export variables */
 	us_drawnodeprotovariables(facet, el_matid, w);
 
 	/* re-draw grid if on */
@@ -1034,7 +1035,7 @@ void us_showemptywindow(WINDOWPART *w)
 	if ((w->state&WINDOWTYPE) == DISP3DWINDOW) return;
 	makerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 	poly->style = TEXTBOX;
-	poly->string = "No facet in this window";
+	poly->string = _("No facet in this window");
 	poly->font = TXT20P;
 	poly->tech = el_curtech;
 	poly->desc = &us_box;
@@ -1052,7 +1053,7 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG x0, y0, x1, y1;
 
-	if (stopping("Grid")) return;
+	if (stopping(STOPREASONDISPLAY)) return;
 
 	if ((state&GRIDON) == 0)
 	{
@@ -1063,7 +1064,7 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 	np = w->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputmsg("Edit a facet before manipulating the grid");
+		ttyputmsg(_("Edit a facet before manipulating the grid"));
 		return;
 	}
 
@@ -1077,13 +1078,13 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 	{
 		if ((w->state&GRIDTOOSMALL) == 0)
 		{
-			ttyputverbose("Grid too small, turned off");
+			ttyputverbose(_("Grid too small, turned off"));
 			(void)setval((INTBIG)w, VWINDOWPART, "state", w->state | GRIDTOOSMALL | GRIDON, VINTEGER);
 		}
 		return;
 	}
 
-	if ((w->state&GRIDTOOSMALL) != 0) ttyputverbose("Grid turned back on");
+	if ((w->state&GRIDTOOSMALL) != 0) ttyputverbose(_("Grid turned back on"));
 	(void)setval((INTBIG)w, VWINDOWPART, "state", (w->state & ~GRIDTOOSMALL) | GRIDON, VINTEGER);
 }
 
@@ -1147,7 +1148,8 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on)
 	}
 	if (total == 0)
 	{
-		if (ignored > 0) ttyputmsg("All %ld ports are outside of the window", ignored);
+		if (ignored <= 0) ttyputmsg(_("There are no ports on facet %s"), describenodeproto(np)); else
+			ttyputmsg(_("All %ld ports are outside of the window"), ignored);			
 		return;
 	}
 
@@ -1250,7 +1252,7 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on)
 		poly->desc = &us_hbox;
 		poly->style = TEXTCENT;
 		poly->font = TXTLARGE;
-		poly->tech = whattech(subni->proto);
+		poly->tech = subni->proto->tech;
 		us_hbox.col = HIGHLIT&on;
 		(void)us_showpoly(poly, w);
 		(void)strcpy(line, "");
@@ -1276,8 +1278,8 @@ void us_identifyports(NODEINST *ni, NODEPROTO *np, INTSML on)
 	efree((char *)portused);
 	efree((char *)portpp);
 	if (ignored > 0)
-		ttyputmsg("Could not display %ld %s (outside of the window)", ignored,
-			makeplural("port", ignored));
+		ttyputmsg(_("Could not display %ld %s (outside of the window)"), ignored,
+			makeplural(_("port"), ignored));
 }
 
 /******************** NODE/ARC DISPLAY ********************/
@@ -1325,11 +1327,12 @@ INTSML us_drawfacet(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers, WI
  */
 INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers, WINDOWPART *w)
 {
-	REGISTER INTSML i, j, res, displaytotal, dontdraw;
-	INTSML color, bits, moretodo, low, high;
+	REGISTER INTBIG i, j, res, displaytotal, dontdraw, low, high, cutsizex, cutsizey;
+	INTSML color, bits, moretodo;
 	XARRAY localtran, subrot, trans;
-	INTBIG bx, by, ux, uy, portcliplx, portcliphx, portcliply, portcliphy;
-	REGISTER INTBIG ratio, swap;
+	INTBIG bx, by, ux, uy, portcliplx, portcliphx, portcliply, portcliphy, drawport, saveopt,
+		reasonable;
+	REGISTER INTBIG ratio, swap, lambda;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER GRAPHICS *gra;
 	REGISTER NODEPROTO *np;
@@ -1343,7 +1346,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 	/* initialize for drawing of facets */
 	us_stopevent++;
 	if ((us_stopevent%25) == 0)
-		if (stopping("Display")) return(-2);
+		if (stopping(STOPREASONDISPLAY)) return(-2);
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
@@ -1388,7 +1391,15 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 		if (dontdraw == 0)
 		{
 			downhierarchy(ni);
-			i = nodepolys(ni);
+			i = nodepolys(ni, &reasonable);
+
+			/* if the amount of geometry can be reduced, do so at large scales */
+			if (i != reasonable)
+			{
+				cutsizex = applyxscale(w, ni->highx - ni->lowx);
+				cutsizey = applyyscale(w, ni->highy - ni->lowy);
+				if (cutsizex*cutsizey < i * 75) i = reasonable;
+			}
 			if ((us_state&NONOVERLAPPABLEDISPLAY) != 0)
 			{
 				/* no overlappable display: just draw everything */
@@ -1432,7 +1443,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 				/* draw the nodeinst and restore the color */
 				if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 					(*us_displayroutine)(poly, w);
-				gra->col = i;
+				gra->col = (INTSML)i;
 			}
 			uphierarchy();
 		}
@@ -1499,7 +1510,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 					poly->xv[0] = (ni->lowx + ni->highx) / 2;
 					poly->yv[0] = (ni->lowy + ni->highy) / 2;
 				}
-				adjustdisoffset((INTBIG)ni, VNODEINST, whattech(ni->proto), poly, ni->textdescript);
+				adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, poly, ni->textdescript);
 				xformpoly(poly, prevtrans);
 				poly->desc = &us_facetgra;   us_facetgra.col = el_colfacettxt;
 				poly->string = describenodeproto(ni->proto);
@@ -1565,7 +1576,8 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 			/* if the resolution is too fine, just draw texture pattern */
 			if ((us_useroptions&DRAWTINYFACETS) == 0 && (w->state&WINDOWTYPE) != DISP3DWINDOW)
 			{
-				ratio = el_curtech->deflambda * us_tinyratio / WHOLE;
+				lambda = lambdaoffacet(ni->parent);
+				ratio = lambda * us_tinyratio / WHOLE;
 				if ((w->screenhx - w->screenlx) / ratio > w->usehx - w->uselx &&
 					(w->screenhy - w->screenly) / ratio > w->usehy - w->usely)
 				{
@@ -1589,18 +1601,34 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 			{
 				/* write ports that must always be displayed */
 				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
-					if ((pp->userbits&PORTDRAWN) != 0)
 				{
-					if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
+					drawport = 0;
+					if ((pp->userbits&PORTDRAWN) != 0) drawport = 1;
+					saveopt = us_useroptions;
+					for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+						if (pi->proto == pp) break;
+					for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+						if (pe->proto == pp) break;
+					if (pi == NOPORTARCINST && pe == NOPORTEXPINST)
 					{
-						us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colfacettxt, w,
-							portcliplx, portcliphx, portcliply, portcliphy);
-					} else
+						if (drawport == 0)
+							us_useroptions = (us_useroptions & ~PORTLABELS) | PORTSCROSS;
+						drawport = 1;
+					}
+					if (drawport != 0)
 					{
-						makerot(pp->subnodeinst, localtran);
-						transmult(localtran, subrot, trans);
-						us_writeprotoname(pp, LAYERA, trans, LAYERO, el_colfacettxt, w,
-							portcliplx, portcliphx, portcliply, portcliphy);
+						if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
+						{
+							us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colfacettxt, w,
+								portcliplx, portcliphx, portcliply, portcliphy);
+						} else
+						{
+							makerot(pp->subnodeinst, localtran);
+							transmult(localtran, subrot, trans);
+							us_writeprotoname(pp, LAYERA, trans, LAYERO, el_colfacettxt, w,
+								portcliplx, portcliphx, portcliply, portcliphy);
+						}
+						us_useroptions = saveopt;
 					}
 				}
 
@@ -1637,7 +1665,7 @@ INTSML us_drawnodeinst(NODEINST *ni, INTSML on, XARRAY prevtrans, INTSML layers,
 		}
 	}
 
-	/* write exported port names if appropriate */
+	/* write export names if appropriate */
 	if (ni->firstportexpinst != NOPORTEXPINST && ni->parent == w->curnodeproto)
 	{
 		if ((layers&2) == 0) moretodo |= 2; else
@@ -1674,14 +1702,12 @@ void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w)
 void us_drawportprotovariables(PORTPROTO *pp, INTSML on, XARRAY trans, WINDOWPART *w)
 {
 	REGISTER INTBIG i, displaytotal;
-/*	INTBIG xc, yc; */
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
 
 	displaytotal = tech_displayableportvars(pp);
-/*	portposition(pp->subnodeinst, pp->subportproto, &xc, &yc); */
 	for(i = 0; i < displaytotal; i++)
 	{
 		(void)tech_filldisplayableportvar(pp, poly);
@@ -1741,7 +1767,8 @@ void us_graphicsarcs(PORTPROTO *pp, INTSML *bitplanes, INTSML *color)
  */
 void us_combinelayers(ARCINST *ai, INTSML *bitplanes, INTSML *color)
 {
-	REGISTER INTSML j, k, b, c;
+	REGISTER INTBIG j, k;
+	REGISTER INTSML b, c;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* get polygon */
@@ -1764,14 +1791,15 @@ void us_combinelayers(ARCINST *ai, INTSML *bitplanes, INTSML *color)
  */
 INTSML us_drawarcinst(ARCINST *ai, INTSML on, XARRAY trans, INTSML layers, WINDOWPART *w)
 {
-	REGISTER INTSML i, j, moretodo, low, high;
+	REGISTER INTBIG i, j, low, high;
+	REGISTER INTSML moretodo;
 	REGISTER ARCPROTO *ap;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* ask the technology how to draw the arcinst */
 	us_stopevent++;
 	if ((us_stopevent%25) == 0)
-		if (stopping("Display")) return(-1);
+		if (stopping(STOPREASONDISPLAY)) return(-1);
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
@@ -1814,7 +1842,7 @@ INTSML us_drawarcinst(ARCINST *ai, INTSML on, XARRAY trans, INTSML layers, WINDO
 		/* draw the nodeinst and restore the color */
 		if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 			(*us_displayroutine)(poly, w);
-		poly->desc->col = i;
+		poly->desc->col = (INTSML)i;
 	}
 	return(moretodo);
 }
@@ -1839,7 +1867,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 	XARRAY localtran, tempt1, tempt2, *t1, *t2, *swapt;
 	INTBIG px, py;
 	INTSML wid, hei;
-	REGISTER INTBIG sx, sy;
+	REGISTER INTBIG sx, sy, lambda;
 	REGISTER char *pt;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
@@ -1861,6 +1889,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 		rpp = rpp->subportproto;
 	}
 	tech = ni->proto->tech;
+	lambda = lambdaofnode(ni);
 
 	/* account for port offset */
 	t1 = (XARRAY *)tempt1;   t2 = (XARRAY *)tempt2;
@@ -1869,10 +1898,10 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 		transid(localtran);
 		localtran[2][0] = (pp->textdescript&VTXOFF)>>VTXOFFSH;
 		if ((pp->textdescript&VTXOFFNEG) != 0) localtran[2][0] = -localtran[2][0];
-		localtran[2][0] = localtran[2][0] * tech->deflambda / 4;
+		localtran[2][0] = localtran[2][0] * lambda / 4;
 		localtran[2][1] = (pp->textdescript&VTYOFF)>>VTYOFFSH;
 		if ((pp->textdescript&VTYOFFNEG) != 0) localtran[2][1] = -localtran[2][1];
-		localtran[2][1] = localtran[2][1] * tech->deflambda / 4;
+		localtran[2][1] = localtran[2][1] * lambda / 4;
 		transmult(localtran, prevtrans, *t1);
 	} else transcpy(prevtrans, *t1);
 
@@ -1898,10 +1927,10 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 			transid(localtran);
 			localtran[2][0] = (rpp->textdescript&VTXOFF)>>VTXOFFSH;
 			if ((rpp->textdescript&VTXOFFNEG) != 0) localtran[2][0] = -localtran[2][0];
-			localtran[2][0] = localtran[2][0] * tech->deflambda / 4;
+			localtran[2][0] = localtran[2][0] * lambda / 4;
 			localtran[2][1] = (rpp->textdescript&VTYOFF)>>VTYOFFSH;
 			if ((rpp->textdescript&VTYOFFNEG) != 0) localtran[2][1] = -localtran[2][1];
-			localtran[2][1] = localtran[2][1] * tech->deflambda / 4;
+			localtran[2][1] = localtran[2][1] * lambda / 4;
 			transmult(localtran, *t1, *t2);
 			swapt = t1;   t1 = t2;   t2 = swapt;
 		}
@@ -1922,7 +1951,7 @@ void us_writeprotoname(PORTPROTO *pp, INTSML on, XARRAY prevtrans, INTSML bits,
 		/* writing text name: setup polygon */
 		poly->font = (INTSML)((pp->textdescript & VTSIZE) >> VTSIZESH);
 		poly->font = truefontsize(poly->font, w, tech);
-		poly->tech = whattech(ni->proto);
+		poly->tech = ni->proto->tech;
 
 		/* convert text description to polygon description */
 		switch (pp->textdescript&VTPOSITION)
@@ -2082,7 +2111,7 @@ INTSML us_drawall(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *np, XAR
 		/* check for interrupts */
 		us_stopevent++;
 		if ((us_stopevent%25) == 0)
-			if (stopping("Display")) { termsearch(search);   break; }
+			if (stopping(STOPREASONDISPLAY)) { termsearch(search);   break; }
 
 		/* get the next object to draw */
 		look = nextobject(search);
@@ -2137,13 +2166,14 @@ INTSML us_drawall(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *np, XAR
 			uphierarchy();
 		}
 	}
-	if (stopping("Display")) return(-1);
+	if (stopping(STOPREASONDISPLAY)) return(-1);
 	return(moretodo);
 }
 
 INTSML us_drawarcinstpeek(ARCINST *ai, XARRAY trans, INTSML layers)
 {
-	REGISTER INTSML i, j, moretodo, low, high;
+	REGISTER INTBIG i, j, low, high;
+	REGISTER INTSML moretodo;
 	REGISTER ARCPROTO *ap;
 	REGISTER GRAPHICS *gra;
 	static POLYGON *poly = NOPOLYGON;
@@ -2196,8 +2226,9 @@ INTSML us_drawarcinstpeek(ARCINST *ai, XARRAY trans, INTSML layers)
 
 INTSML us_drawnodeinstpeek(NODEINST *ni, XARRAY prevtrans, INTSML layers)
 {
-	REGISTER INTSML i, j;
-	INTSML moretodo, low, high;
+	REGISTER INTBIG i, j, low, high, cutsizex, cutsizey;
+	INTSML moretodo;
+	INTBIG reasonable;
 	REGISTER VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER GRAPHICS *gra;
@@ -2218,7 +2249,15 @@ INTSML us_drawnodeinstpeek(NODEINST *ni, XARRAY prevtrans, INTSML layers)
 	}
 
 	/* determine which polygons to draw */
-	i = nodepolys(ni);
+	i = nodepolys(ni, &reasonable);
+
+	/* if the amount of geometry can be reduced, do so at large scales */
+	if (i != reasonable)
+	{
+		cutsizex = applyxscale(us_peekwindow, ni->highx - ni->lowx);
+		cutsizey = applyyscale(us_peekwindow, ni->highy - ni->lowy);
+		if (cutsizex*cutsizey < i * 75) i = reasonable;
+	}
 	moretodo = 0;
 	if ((us_state&NONOVERLAPPABLEDISPLAY) != 0)
 	{
@@ -2228,7 +2267,7 @@ INTSML us_drawnodeinstpeek(NODEINST *ni, XARRAY prevtrans, INTSML layers)
 	{
 		if ((np->userbits&NHASOPA) == 0) j = i; else
 		{
-			j = (INTSML)((np->userbits&NFIRSTOPA) >> NFIRSTOPASH);
+			j = (np->userbits&NFIRSTOPA) >> NFIRSTOPASH;
 			if (i < j) j = i;
 		}
 		if ((layers&1) != 0) low = 0; else low = j;
