@@ -39,7 +39,8 @@
 
 #define	MAXNAMELEN 25		/* max chars in a new name */
 
-INTSML us_maxlayers;
+INTSML us_teceddrclayers = 0;
+char **us_teceddrclayernames = 0;
 
 /* the known technology variables */
 TECHVAR us_knownvars[] =
@@ -278,7 +279,7 @@ void us_tecedentry(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		us_abortcommand("Usage: technology edit OPTION");
+		ttyputusage("technology edit OPTION");
 		return;
 	}
 
@@ -287,20 +288,24 @@ void us_tecedentry(INTSML count, char *par[])
 	{
 		if (us_teceddrc != 0)
 		{
-			us_abortcommand("Cannot generate technology while editing DRC");
+			us_abortcommand(_("Cannot generate technology while editing DRC"));
 			return;
 		}
-		us_tecfromlibinit(el_curlib, 1);
+		if (count <= 1) pp = 0; else
+			pp = par[1];
+		us_tecfromlibinit(el_curlib, pp, 1);
 		return;
 	}
 	if (namesamen(pp, "library-to-tech", l) == 0)
 	{
 		if (us_teceddrc != 0)
 		{
-			us_abortcommand("Cannot generate technology while editing DRC");
+			us_abortcommand(_("Cannot generate technology while editing DRC"));
 			return;
 		}
-		us_tecfromlibinit(el_curlib, 0);
+		if (count <= 1) pp = 0; else
+			pp = par[1];
+		us_tecfromlibinit(el_curlib, pp, 0);
 		return;
 	}
 	if (namesamen(pp, "tech-to-library", l) == 0)
@@ -310,13 +315,13 @@ void us_tecedentry(INTSML count, char *par[])
 			tech = gettechnology(par[1]);
 			if (tech == NOTECHNOLOGY)
 			{
-				us_abortcommand("Technology '%s' unknown", par[1]);
+				us_abortcommand(_("Technology '%s' unknown"), par[1]);
 				return;
 			}
 		}
 		if ((tech->userbits&NONSTANDARD) != 0)
 		{
-			us_abortcommand("Cannot convert technology '%s', it is nonstandard", tech->techname);
+			us_abortcommand(_("Cannot convert technology '%s', it is nonstandard"), tech->techname);
 			return;
 		}
 
@@ -324,7 +329,7 @@ void us_tecedentry(INTSML count, char *par[])
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			if (namesame(lib->libname, tech->techname) == 0) break;
 		if (lib != NOLIBRARY)
-			ttyputmsg("Already a library called %s, using that", lib->libname); else
+			ttyputmsg(_("Already a library called %s, using that"), lib->libname); else
 				lib = us_tecedmakelibfromtech(tech);
 		if (lib != NOLIBRARY)
 		{
@@ -344,7 +349,7 @@ void us_tecedentry(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: technology edit place-layer SHAPE");
+			ttyputusage("technology edit place-layer SHAPE");
 			return;
 		}
 
@@ -360,7 +365,7 @@ void us_tecedentry(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: technology edit edit-node NODENAME");
+			ttyputusage("technology edit edit-node NODENAME");
 			return;
 		}
 		(void)initinfstr();
@@ -388,7 +393,7 @@ void us_tecedentry(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: technology edit edit-arc ARCNAME");
+			ttyputusage("technology edit edit-arc ARCNAME");
 			return;
 		}
 		(void)initinfstr();
@@ -407,7 +412,7 @@ void us_tecedentry(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: technology edit edit-layer LAYERNAME");
+			ttyputusage("technology edit edit-layer LAYERNAME");
 			return;
 		}
 		(void)initinfstr();
@@ -483,7 +488,7 @@ void us_tecedentry(INTSML count, char *par[])
 			efree((char *)sequence);
 			return;
 		}
-		ttyputerr("Must be editing a layer, node, or arc to advance to the next");
+		ttyputerr(_("Must be editing a layer, node, or arc to advance to the next"));
 		return;
 	}
 	if (namesamen(pp, "edit-colors", l) == 0 && l >= 6)
@@ -530,15 +535,15 @@ void us_tecedentry(INTSML count, char *par[])
 		{
 			/* display dependent library names */
 			var = getval((INTBIG)el_curlib, VLIBRARY, VSTRING|VISARRAY, "EDTEC_dependent_libraries");
-			if (var == NOVARIABLE) ttyputmsg("There are no dependent libraries"); else
+			if (var == NOVARIABLE) ttyputmsg(_("There are no dependent libraries")); else
 			{
 				i = (INTSML)getlength(var);
-				ttyputmsg("%d dependent librar%s:", i, (i==1 ? "y" : "ies"));
+				ttyputmsg(_("%d dependent %s:"), i, makeplural("library", i));
 				for(l=0; l<i; l++)
 				{
 					pp = ((char **)var->addr)[l];
 					lib = getlibrary(pp);
-					ttyputmsg("    %s%s", pp, (lib == NOLIBRARY ? " (not read in)" : ""));
+					ttyputmsg("    %s%s", pp, (lib == NOLIBRARY ? _(" (not read in)") : ""));
 				}
 			}
 			return;
@@ -562,7 +567,7 @@ void us_tecedentry(INTSML count, char *par[])
 		efree((char *)dependentlist);
 		return;
 	}
-	us_abortcommand("Bad TECHNOLOGY EDIT option: %s", pp);
+	ttyputbadusage("technology edit");
 }
 
 /*
@@ -579,32 +584,40 @@ void us_teceditdrc(void)
 
 	if (us_teceddrc != 0)
 	{
-		ttyputerr("Already editing design rules");
+		ttyputerr(_("Already editing design rules"));
 		return;
 	}
 
-	/* count the number of layers */
-	us_maxlayers = 0;
-	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-		if (namesamen(np->cell->cellname, "layer-", 6) == 0) us_maxlayers++;
-	if (us_maxlayers <= 0)
+	/* free any former layer name information */
+	if (us_teceddrclayernames != 0)
 	{
-		ttyputerr("Define layers before creating design rules");
+		for(i=0; i<us_teceddrclayers; i++) efree(us_teceddrclayernames[i]);
+		efree((char *)us_teceddrclayernames);
+		us_teceddrclayernames = 0;
+	}
+
+	/* count the number of layers */
+	us_teceddrclayers = 0;
+	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (namesamen(np->cell->cellname, "layer-", 6) == 0) us_teceddrclayers++;
+	if (us_teceddrclayers <= 0)
+	{
+		ttyputerr(_("Define layers before creating design rules"));
 		return;
 	}
 
 	/* build and fill array of layers for DRC parsing */
-	us_teclayer_names = (char **)emalloc(us_maxlayers * (sizeof (char *)), us_aid->cluster);
-	if (us_teclayer_names == 0) return;
+	us_teceddrclayernames = (char **)emalloc(us_teceddrclayers * (sizeof (char *)), us_aid->cluster);
+	if (us_teceddrclayernames == 0) return;
 	for(i = 0, np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (namesamen(np->cell->cellname, "layer-", 6) == 0)
-			(void)allocstring(&us_teclayer_names[i++], &np->cell->cellname[6], us_aid->cluster);
+			(void)allocstring(&us_teceddrclayernames[i++], &np->cell->cellname[6], us_aid->cluster);
 
 	/* make the editor window */
 	w = us_wantnewwindow(0);
 	if (w == NOWINDOWPART) return;
 
-	if (us_makeeditor(w, "Design Rules (Format: [C]SPACING LAYER LAYER)", &dummy,
+	if (us_makeeditor(w, _("Design Rules (Format: [C]SPACING LAYER LAYER)"), &dummy,
 		&dummy) == NOWINDOWPART) return;
 	e = w->editor;
 	if (e == NOEDITOR) return;
@@ -622,7 +635,7 @@ void us_teceditdrc(void)
 		us_resumegraphics(w);
 	}
 	w->changehandler = us_teceddrcchange;
-	ttyputverbose("Editing design rules");
+	ttyputverbose(_("Editing design rules"));
 }
 
 /*
@@ -679,27 +692,27 @@ void us_teceditcolormap(void)
 	/* set defaults */
 	if (layerlabel[0] == 0)
 	{
-		layerlabel[0] = "Ovrlap 1";
+		layerlabel[0] = _("Ovrlap 1");
 		(void)allocstring(&layerabbrev[0], "1", el_tempcluster);
 	}
 	if (layerlabel[1] == 0)
 	{
-		layerlabel[1] = "Ovrlap 2";
+		layerlabel[1] = _("Ovrlap 2");
 		(void)allocstring(&layerabbrev[1], "2", el_tempcluster);
 	}
 	if (layerlabel[2] == 0)
 	{
-		layerlabel[2] = "Ovrlap 3";
+		layerlabel[2] = _("Ovrlap 3");
 		(void)allocstring(&layerabbrev[2], "3", el_tempcluster);
 	}
 	if (layerlabel[3] == 0)
 	{
-		layerlabel[3] = "Ovrlap 4";
+		layerlabel[3] = _("Ovrlap 4");
 		(void)allocstring(&layerabbrev[3], "4", el_tempcluster);
 	}
 	if (layerlabel[4] == 0)
 	{
-		layerlabel[4] = "Ovrlap 5";
+		layerlabel[4] = _("Ovrlap 5");
 		(void)allocstring(&layerabbrev[4], "5", el_tempcluster);
 	}
 
@@ -761,7 +774,7 @@ void us_teceditcreat(INTSML count, char *par[])
 
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Unrecoginzed shape: '%s'", pp);
+		ttyputerr(_("Unrecoginzed shape: '%s'"), pp);
 		return;
 	}
 
@@ -771,17 +784,17 @@ void us_teceditcreat(INTSML count, char *par[])
 	if (namesamen(facet->cell->cellname, "node-", 5) != 0 &&
 		namesamen(facet->cell->cellname, "arc-", 4) != 0)
 	{
-		us_abortcommand("Must be editing a node or arc to place geometry");
+		us_abortcommand(_("Must be editing a node or arc to place geometry"));
 		if ((us_aid->aidstate&NODETAILS) == 0)
-			ttyputmsg("Use 'edit-node' or 'edit-arc' options");
+			ttyputmsg(_("Use 'edit-node' or 'edit-arc' options"));
 		return;
 	}
 	if (np == gen_portprim &&
 		namesamen(facet->cell->cellname, "node-", 5) != 0)
 	{
-		us_abortcommand("Can only place ports in node descriptions");
+		us_abortcommand(_("Can only place ports in node descriptions"));
 		if ((us_aid->aidstate&NODETAILS) == 0)
-			ttyputmsg("Use the 'edit-node' options");
+			ttyputmsg(_("Use the 'edit-node' options"));
 		return;
 	}
 
@@ -807,7 +820,7 @@ void us_teceditcreat(INTSML count, char *par[])
 		/* a port layer */
 		if (count == 1)
 		{
-			name = ttygetline("Port name: ");
+			name = ttygetline(_("Port name: "));
 			if (name == 0 || name[0] == 0)
 			{
 				us_abortedmsg();
@@ -817,42 +830,42 @@ void us_teceditcreat(INTSML count, char *par[])
 		var = setval((INTBIG)ni, VNODEINST, "EDTEC_portname", (INTBIG)name, VSTRING|VDISPLAY);
 		if (var != NOVARIABLE) var->textdescript = defaulttextdescript(NOGEOM);
 		if ((us_aid->aidstate&NODETAILS) == 0)
-			ttyputmsg("Use 'change' option to set arc connectivity and port angle");
+			ttyputmsg(_("Use 'change' option to set arc connectivity and port angle"));
 	}
 	if (namesamen(pp, "highlight", l) == 0 && l >= 1)
 	{
 		/* a highlight layer */
 		us_teceditsetpatch(ni, &us_edtechigh);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)NONODEPROTO, VNODEPROTO);
-		ttyputmsg("Keep highlight a constant distance from the example edge");
+		ttyputmsg(_("Keep highlight a constant distance from the example edge"));
 	}
 	if (namesamen(pp, "circle-half", l) == 0 && l >= 8)
 		setarcdegrees(ni, 0.0, 180.0*EPI/180.0);
 	if ((us_aid->aidstate&NODETAILS) == 0)
 	{
 		if (namesamen(pp, "rectangle-", 10) == 0)
-			ttyputmsg("Use 'change' option to set a layer for this shape");
+			ttyputmsg(_("Use 'change' option to set a layer for this shape"));
 		if (namesamen(pp, "polygon-", 8) == 0)
 		{
-			ttyputmsg("Use 'change' option to set a layer for this shape");
-			ttyputmsg("Use 'polygonedit' command to describe polygonal shape");
+			ttyputmsg(_("Use 'change' option to set a layer for this shape"));
+			ttyputmsg(_("Use 'polygonedit' command to describe polygonal shape"));
 		}
 		if (namesamen(pp, "lines-", 6) == 0)
-			ttyputmsg("Use 'change' option to set a layer for this line");
+			ttyputmsg(_("Use 'change' option to set a layer for this line"));
 		if (namesamen(pp, "circle-", 7) == 0)
-			ttyputmsg("Use 'change' option to set a layer for this circle");
+			ttyputmsg(_("Use 'change' option to set a layer for this circle"));
 		if (namesamen(pp, "text", l) == 0 && l >= 1)
 		{
-			ttyputmsg("Use 'change' option to set a layer for this text");
-			ttyputmsg("Use 'var textedit ~.ART_message' command to set text");
-			ttyputmsg("Then use 'var change ~.ART_message display' command");
+			ttyputmsg(_("Use 'change' option to set a layer for this text"));
+			ttyputmsg(_("Use 'var textedit ~.ART_message' command to set text"));
+			ttyputmsg(_("Then use 'var change ~.ART_message display' command"));
 		}
 	}
 	if (namesamen(pp, "circle-arc", l) == 0 && l >= 8)
 	{
 		setarcdegrees(ni, 0.0, 45.0*EPI/180.0);
 		if ((us_aid->aidstate&NODETAILS) == 0)
-			ttyputmsg("Use 'setarc' command to set portion of circle");
+			ttyputmsg(_("Use 'setarc' command to set portion of circle"));
 	}
 }
 
@@ -878,9 +891,9 @@ void us_teceditidentify(INTSML doports)
 	{
 		if (namesamen(np->cell->cellname, "node-", 5) != 0)
 		{
-			us_abortcommand("Must be editing a node to identify ports");
+			us_abortcommand(_("Must be editing a node to identify ports"));
 			if ((us_aid->aidstate&NODETAILS) == 0)
-				ttyputmsg("Use the 'edit-node' option");
+				ttyputmsg(_("Use the 'edit-node' option"));
 			return;
 		}
 	} else
@@ -888,9 +901,9 @@ void us_teceditidentify(INTSML doports)
 		if (namesamen(np->cell->cellname, "node-", 5) != 0 &&
 			namesamen(np->cell->cellname, "arc-", 4) != 0)
 		{
-			us_abortcommand("Must be editing a node or arc to identify layers");
+			us_abortcommand(_("Must be editing a node or arc to identify layers"));
 			if ((us_aid->aidstate&NODETAILS) == 0)
-				ttyputmsg("Use 'edit-node' or 'edit-arc' options");
+				ttyputmsg(_("Use 'edit-node' or 'edit-arc' options"));
 			return;
 		}
 	}
@@ -916,7 +929,7 @@ void us_teceditidentify(INTSML doports)
 	if (total == 0)
 	{
 		us_tecedfreeexamples(nelist);
-		us_abortcommand("There are no %s to identify", (doports == 0 ? "layers" : "ports"));
+		us_abortcommand(_("There are no %s to identify"), (doports == 0 ? _("layers") : _("ports")));
 		return;
 	}
 
@@ -1091,7 +1104,7 @@ void us_teceditinquire(void)
 	high = us_getonehighlight();
 	if ((high->status&HIGHTYPE) != HIGHTEXT && (high->status&HIGHTYPE) != HIGHFROM)
 	{
-		us_abortcommand("Must select a single object for inquiry");
+		us_abortcommand(_("Must select a single object for inquiry"));
 		return;
 	}
 	if ((high->status&HIGHTYPE) == HIGHFROM && high->fromgeom->entrytype == OBJARCINST)
@@ -1100,20 +1113,20 @@ void us_teceditinquire(void)
 		ai = high->fromgeom->entryaddr.ai;
 		if (ai->proto != gen_universalarc)
 		{
-			ttyputmsg("This is an unimportant %s arc", describearcproto(ai->proto));
+			ttyputmsg(_("This is an unimportant %s arc"), describearcproto(ai->proto));
 			return;
 		}
 		if (ai->end[0].nodeinst->proto != gen_portprim ||
 			ai->end[1].nodeinst->proto != gen_portprim)
 		{
-			ttyputmsg("This arc makes an unimportant connection");
+			ttyputmsg(_("This arc makes an unimportant connection"));
 			return;
 		}
 		var = getval((INTBIG)ai->end[0].nodeinst, VNODEINST, VSTRING, "EDTEC_portname");
 		var2 = getval((INTBIG)ai->end[1].nodeinst, VNODEINST, VSTRING, "EDTEC_portname");
 		if (var == NOVARIABLE || var2 == NOVARIABLE)
-			ttyputmsg("This arc connects two port objects"); else
-				ttyputmsg("This arc connects ports '%s' and '%s'",
+			ttyputmsg(_("This arc connects two port objects")); else
+				ttyputmsg(_("This arc connects ports '%s' and '%s'"),
 					(char *)var->addr, (char *)var2->addr);
 		return;
 	}
@@ -1122,116 +1135,116 @@ void us_teceditinquire(void)
 	opt = us_tecedgetoption(ni);
 	if (opt < 0)
 	{
-		ttyputmsg("This object has no relevance to technology editing");
+		ttyputmsg(_("This object has no relevance to technology editing"));
 		return;
 	}
 
 	switch (opt)
 	{
 		case ARCFIXANG:
-			ttyputmsg("This object defines the fixed-angle factor of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the fixed-angle factor of %s"), describenodeproto(np));
 			break;
 		case ARCFUNCTION:
-			ttyputmsg("This object defines the function of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the function of %s"), describenodeproto(np));
 			break;
 		case ARCINC:
-			ttyputmsg("This object defines the prefered angle increment of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the prefered angle increment of %s"), describenodeproto(np));
 			break;
 		case ARCNOEXTEND:
-			ttyputmsg("This object defines the arc extension of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the arc extension of %s"), describenodeproto(np));
 			break;
 		case ARCWIPESPINS:
-			ttyputmsg("This object defines the arc coverage of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the arc coverage of %s"), describenodeproto(np));
 			break;
 		case CENTEROBJ:
-			ttyputmsg("This object identifies the grab point of %s", describenodeproto(np));
+			ttyputmsg(_("This object identifies the grab point of %s"), describenodeproto(np));
 			break;
 		case LAYER3DHEIGHT:
-			ttyputmsg("This object defines the 3D height of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the 3D height of %s"), describenodeproto(np));
 			break;
 		case LAYER3DTHICK:
-			ttyputmsg("This object defines the 3D thickness of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the 3D thickness of %s"), describenodeproto(np));
 			break;
 		case LAYERCIF:
-			ttyputmsg("This object defines the CIF name of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the CIF name of %s"), describenodeproto(np));
 			break;
 		case LAYERCOLOR:
-			ttyputmsg("This object defines the color of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the color of %s"), describenodeproto(np));
 			break;
 		case LAYERDXF:
-			ttyputmsg("This object defines the DXF name(s) of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the DXF name(s) of %s"), describenodeproto(np));
 			break;
 		case LAYERDRCMINWID:
-			ttyputmsg("This object defines the minimum DRC width of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the minimum DRC width of %s"), describenodeproto(np));
 			break;
 		case LAYERFUNCTION:
-			ttyputmsg("This object defines the function of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the function of %s"), describenodeproto(np));
 			break;
 		case LAYERGDS:
-			ttyputmsg("This object defines the Calma GDS-II number of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the Calma GDS-II number of %s"), describenodeproto(np));
 			break;
 		case LAYERLETTERS:
-			ttyputmsg("This object defines the letters to use for %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the letters to use for %s"), describenodeproto(np));
 			break;
 		case LAYERPATTERN:
-			ttyputmsg("This is one of the bitmap squares in %s", describenodeproto(np));
+			ttyputmsg(_("This is one of the bitmap squares in %s"), describenodeproto(np));
 			break;
 		case LAYERSPICAP:
-			ttyputmsg("This object defines the SPICE capacitance of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the SPICE capacitance of %s"), describenodeproto(np));
 			break;
 		case LAYERSPIECAP:
-			ttyputmsg("This object defines the SPICE edge capacitance of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the SPICE edge capacitance of %s"), describenodeproto(np));
 			break;
 		case LAYERSPIRES:
-			ttyputmsg("This object defines the SPICE resistance of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the SPICE resistance of %s"), describenodeproto(np));
 			break;
 		case LAYERSTYLE:
-			ttyputmsg("This object defines the style of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the style of %s"), describenodeproto(np));
 			break;
 		case LAYERPATCH:
 		case HIGHLIGHTOBJ:
 			var = getval((INTBIG)ni, VNODEINST, VNODEPROTO, "EDTEC_layer");
 			if (var == NOVARIABLE)
-				ttyputerr("This is an object with no valid layer!"); else
+				ttyputerr(_("This is an object with no valid layer!")); else
 			{
 				np = (NODEPROTO *)var->addr;
-				if (np == NONODEPROTO) ttyputmsg("This is a highlight box"); else
-					ttyputmsg("This is a '%s' layer", &np->cell->cellname[6]);
+				if (np == NONODEPROTO) ttyputmsg(_("This is a highlight box")); else
+					ttyputmsg(_("This is a '%s' layer"), &np->cell->cellname[6]);
 				var = getval((INTBIG)ni, VNODEINST, VSTRING, "EDTEC_minbox");
 				if (var != NOVARIABLE)
-					ttyputmsg("   It is at minimum size");
+					ttyputmsg(_("   It is at minimum size"));
 			}
 			break;
 		case NODEFUNCTION:
-			ttyputmsg("This object defines the function of %s", describenodeproto(np));
+			ttyputmsg(_("This object defines the function of %s"), describenodeproto(np));
 			break;
 		case NODELOCKABLE:
-			ttyputmsg("This object tells if %s can be locked (used in array technologies)",
+			ttyputmsg(_("This object tells if %s can be locked (used in array technologies)"),
 				describenodeproto(np));
 			break;
 		case NODESERPENTINE:
-			ttyputmsg("This object tells if %s is a serpentine transistor", describenodeproto(np));
+			ttyputmsg(_("This object tells if %s is a serpentine transistor"), describenodeproto(np));
 			break;
 		case NODESQUARE:
-			ttyputmsg("This object tells if %s is square", describenodeproto(np));
+			ttyputmsg(_("This object tells if %s is square"), describenodeproto(np));
 			break;
 		case NODEWIPES:
-			ttyputmsg("This object tells if %s disappears when conencted to one or two arcs",
+			ttyputmsg(_("This object tells if %s disappears when conencted to one or two arcs"),
 				describenodeproto(np));
 			break;
 		case PORTOBJ:
 			var = getval((INTBIG)ni, VNODEINST, VSTRING, "EDTEC_portname");
-			if (var == NOVARIABLE) ttyputmsg("This is a port object"); else
-				ttyputmsg("This is port '%s'", (char *)var->addr);
+			if (var == NOVARIABLE) ttyputmsg(_("This is a port object")); else
+				ttyputmsg(_("This is port '%s'"), (char *)var->addr);
 			break;
 		case TECHDESCRIPT:
-			ttyputmsg("This object contains the technology description");
+			ttyputmsg(_("This object contains the technology description"));
 			break;
 		case TECHLAMBDA:
-			ttyputmsg("This object defines the value of lambda");
+			ttyputmsg(_("This object defines the value of lambda"));
 			break;
 		default:
-			ttyputerr("This object has unknown information");
+			ttyputerr(_("This object has unknown information"));
 			break;
 	}
 }
@@ -1326,7 +1339,7 @@ void us_teceditmodobject(INTSML count, char *par[])
 		case NODEWIPES:      us_tecednodewipes(ni, count, par);      break;
 		case TECHDESCRIPT:   us_tecedinfodescript(ni, count, par);   break;
 		case TECHLAMBDA:     us_tecedinfolambda(ni, count, par);     break;
-		default:             us_abortcommand("Cannot modify this object");   break;
+		default:             us_abortcommand(_("Cannot modify this object"));   break;
 	}
 	(void)us_pophighlight(0);
 }
@@ -1337,7 +1350,7 @@ void us_tecedlayer3dheight(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the height of the layer when viewed in 3D");
+		us_abortcommand(_("Enter the height of the layer when viewed in 3D"));
 		return;
 	}
 	(void)initinfstr();
@@ -1350,7 +1363,7 @@ void us_tecedlayer3dthick(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the thickness of the layer when viewed in 3D");
+		us_abortcommand(_("Enter the thickness of the layer when viewed in 3D"));
 		return;
 	}
 	(void)initinfstr();
@@ -1363,7 +1376,7 @@ void us_tecedlayerdrcminwid(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the minimum DRC width (negative for none)");
+		us_abortcommand(_("Enter the minimum DRC width (negative for none)"));
 		return;
 	}
 	(void)initinfstr();
@@ -1376,7 +1389,7 @@ void us_tecedlayercolor(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("New color required");
+		us_abortcommand(_("New color required"));
 		return;
 	}
 	(void)initinfstr();
@@ -1392,7 +1405,7 @@ void us_tecedlayerstyle(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Layer style required");
+		us_abortcommand(_("Layer style required"));
 		return;
 	}
 	(void)initinfstr();
@@ -1424,7 +1437,7 @@ void us_tecedlayergds(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the GDS layer number (-1 for none)");
+		us_abortcommand(_("Enter the GDS layer number (-1 for none)"));
 		return;
 	}
 	(void)initinfstr();
@@ -1437,7 +1450,7 @@ void us_tecedlayerspires(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the SPICE layer resistance");
+		us_abortcommand(_("Enter the SPICE layer resistance"));
 		return;
 	}
 	(void)initinfstr();
@@ -1450,7 +1463,7 @@ void us_tecedlayerspicap(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the SPICE layer capacitance");
+		us_abortcommand(_("Enter the SPICE layer capacitance"));
 		return;
 	}
 	(void)initinfstr();
@@ -1463,7 +1476,7 @@ void us_tecedlayerspiecap(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Enter the SPICE layer edge capacitance");
+		us_abortcommand(_("Enter the SPICE layer edge capacitance"));
 		return;
 	}
 	(void)initinfstr();
@@ -1480,7 +1493,7 @@ void us_tecedlayerfunction(NODEINST *ni, INTSML count, char *par[])
 
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Layer function required");
+		us_abortcommand(_("Layer function required"));
 		return;
 	}
 
@@ -1519,7 +1532,7 @@ void us_tecedlayerletters(NODEINST *ni, INTSML count, char *par[])
 
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Layer letter(s) required");
+		us_abortcommand(_("Layer letter(s) required"));
 		return;
 	}
 
@@ -1539,7 +1552,7 @@ void us_tecedlayerletters(NODEINST *ni, INTSML count, char *par[])
 		{
 			for(i=0; par[0][i] != 0; i++) if (par[0][i] == *pt)
 			{
-				us_abortcommand("Cannot use letter '%c', it is in %s", *pt, describenodeproto(np));
+				us_abortcommand(_("Cannot use letter '%c', it is in %s"), *pt, describenodeproto(np));
 				efree(layerletters);
 				return;
 			}
@@ -1564,7 +1577,7 @@ void us_tecedlayerpattern(NODEINST *ni)
 	if (ni->proto == art_boxprim)
 	{
 		startobjectchange((INTBIG)ni, VNODEINST);
-		newni = replacenodeinst(ni, art_filledboxprim);
+		newni = replacenodeinst(ni, art_filledboxprim, 0);
 		if (newni == NONODEINST) return;
 		endobjectchange((INTBIG)newni, VNODEINST);
 		ni = newni;
@@ -1608,7 +1621,7 @@ void us_tecedlayertype(NODEINST *ni, INTSML count, char *par[])
 
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a layer name");
+		us_abortcommand(_("Requires a layer name"));
 		return;
 	}
 
@@ -1618,8 +1631,8 @@ void us_tecedlayertype(NODEINST *ni, INTSML count, char *par[])
 	{
 		if (namesamen(np->cell->cellname, "node-", 5) != 0)
 		{
-			us_abortcommand("Can only set minimum size in node descriptions");
-			if ((us_aid->aidstate&NODETAILS) == 0) ttyputmsg("Use 'edit-node' option");
+			us_abortcommand(_("Can only set minimum size in node descriptions"));
+			if ((us_aid->aidstate&NODETAILS) == 0) ttyputmsg(_("Use 'edit-node' option"));
 			return;
 		}
 		startobjectchange((INTBIG)ni, VNODEINST);
@@ -1632,7 +1645,7 @@ void us_tecedlayertype(NODEINST *ni, INTSML count, char *par[])
 	{
 		if (getval((INTBIG)ni, VNODEINST, VSTRING, "EDTEC_minbox") == NOVARIABLE)
 		{
-			ttyputmsg("Minimum size is not set on this layer");
+			ttyputmsg(_("Minimum size is not set on this layer"));
 			return;
 		}
 		startobjectchange((INTBIG)ni, VNODEINST);
@@ -1649,7 +1662,7 @@ void us_tecedlayertype(NODEINST *ni, INTSML count, char *par[])
 	np = getnodeproto(name);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Cannot find layer primitive %s", name);
+		ttyputerr(_("Cannot find layer primitive %s"), name);
 		return;
 	}
 
@@ -1756,7 +1769,7 @@ void us_tecedarcfunction(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a layer function");
+		us_abortcommand(_("Requires a layer function"));
 		return;
 	}
 	(void)initinfstr();
@@ -1769,7 +1782,7 @@ void us_tecedarcfixang(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1782,7 +1795,7 @@ void us_tecedarcwipes(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1795,7 +1808,7 @@ void us_tecedarcnoextend(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1808,7 +1821,7 @@ void us_tecedarcinc(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires an angle increment in degrees");
+		us_abortcommand(_("Requires an angle increment in degrees"));
 		return;
 	}
 	(void)initinfstr();
@@ -1821,7 +1834,7 @@ void us_tecednodefunction(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a node function");
+		us_abortcommand(_("Requires a node function"));
 		return;
 	}
 	(void)initinfstr();
@@ -1834,7 +1847,7 @@ void us_tecednodeserpentine(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1847,7 +1860,7 @@ void us_tecednodesquare(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1860,7 +1873,7 @@ void us_tecednodewipes(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1873,7 +1886,7 @@ void us_tecednodelockable(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a yes or no");
+		us_abortcommand(_("Requires a yes or no"));
 		return;
 	}
 	(void)initinfstr();
@@ -1886,7 +1899,7 @@ void us_tecedinfolambda(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a value of lambda");
+		us_abortcommand(_("Requires a value of lambda"));
 		return;
 	}
 	(void)initinfstr();
@@ -1899,7 +1912,7 @@ void us_tecedinfodescript(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires a technology description");
+		us_abortcommand(_("Requires a technology description"));
 		return;
 	}
 	(void)initinfstr();
@@ -1912,7 +1925,7 @@ void us_tecedinfounits(NODEINST *ni, INTSML count, char *par[])
 {
 	if (par[0][0] == 0)
 	{
-		us_abortcommand("Requires units for this technology");
+		us_abortcommand(_("Requires units for this technology"));
 		return;
 	}
 	(void)initinfstr();
@@ -1962,8 +1975,8 @@ void us_teceddrcchange(WINDOWPART *w, INTSML nature, char *oldline, char *newlin
 	while (*newline == ' ') newline++;
 	if (*newline == 0) return;
 	if (us_tecedgetdrc(newline, &connected, &amt, &layer1, &layer2,
-		us_maxlayers, us_teclayer_names) != 0)
-			ttyputmsg("DRC line is '%s'", newline);
+		us_teceddrclayers, us_teceddrclayernames) != 0)
+			ttyputmsg(_("DRC line is '%s'"), newline);
 }
 
 /*
@@ -1990,8 +2003,8 @@ void us_teceddrcterm(WINDOWPART *w)
 				pt = us_getline(w, i);
 				while (*pt == ' ') pt++;
 				if (*pt == 0) continue;
-				if (us_tecedgetdrc(pt, &connected, &amt, &layer1, &layer2, us_maxlayers,
-					us_teclayer_names) != 0) ttyputmsg("DRC line is '%s'", pt);
+				if (us_tecedgetdrc(pt, &connected, &amt, &layer1, &layer2, us_teceddrclayers,
+					us_teceddrclayernames) != 0) ttyputmsg(_("DRC line is '%s'"), pt);
 				(void)allocstring(&lines[j++], pt, el_tempcluster);
 			}
 			if (j > 0)
@@ -2002,10 +2015,6 @@ void us_teceddrcterm(WINDOWPART *w)
 		}
 	}
 
-	/* free layer name information */
-	for(i=0; i<us_maxlayers; i++) efree(us_teclayer_names[i]);
-	efree((char *)us_teclayer_names);
-
 	/* now do the rest of the termination of this window */
 	us_editorterm(w);
 }
@@ -2201,7 +2210,7 @@ INTSML us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG
 				color = getecolor(&str[l]);
 				if (color < 0)
 				{
-					ttyputerr("Unknown color '%s' in %s", &str[l], describenodeproto(np));
+					ttyputerr(_("Unknown color '%s' in %s"), &str[l], describenodeproto(np));
 					return(1);
 				}
 				desc->col = color;
@@ -2323,7 +2332,7 @@ INTSML us_teceditgetlayerinfo(NODEPROTO *np, GRAPHICS *desc, char **cif, INTBIG
 
 	if (patterncount != 16*8)
 	{
-		ttyputerr("Incorrect number of pattern boxes in %s (has %d, not %d)",
+		ttyputerr(_("Incorrect number of pattern boxes in %s (has %d, not %d)"),
 			describenodeproto(np), patterncount, 16*8);
 		return(1);
 	}
@@ -2370,7 +2379,7 @@ INTSML us_teceditparsefun(char *str)
 		*pt = (char)save;
 		if (us_teclayer_functions[i].name == 0)
 		{
-			ttyputerr("Unknown layer function: %s", str);
+			ttyputerr(_("Unknown layer function: %s"), str);
 			return(0);
 		}
 
@@ -2379,7 +2388,7 @@ INTSML us_teceditparsefun(char *str)
 		{
 			if (func != 0)
 			{
-				ttyputerr("Cannot be both function %s and %s",
+				ttyputerr(_("Cannot be both function %s and %s"),
 					us_teclayer_functions[func&LFTYPE].name, us_teclayer_functions[i].name);
 				func = 0;
 			}
