@@ -130,7 +130,6 @@ INTSML us_addhighlight(HIGHLIGHT *thishigh)
 	char *onelist[1];
 	REGISTER VARIABLE *var;
 	HIGHLIGHT oldhigh;
-	extern AIDENTRY *net_aid;
 
 	/* see if anything is currently highlighted */
 	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
@@ -169,6 +168,8 @@ INTSML us_addhighlight(HIGHLIGHT *thishigh)
 		} else
 		{
 			if (oldhigh.fromgeom != thishigh->fromgeom) continue;
+			if ((oldhigh.status&HIGHTYPE) == HIGHTEXT && oldhigh.fromvar != thishigh->fromvar)
+				continue;
 		}
 		return(1);
 	}
@@ -247,6 +248,8 @@ INTSML us_delhighlight(HIGHLIGHT *thishigh)
 		} else
 		{
 			if (oldhigh.fromgeom != thishigh->fromgeom) continue;
+			if ((oldhigh.status&HIGHTYPE) == HIGHTEXT && oldhigh.fromvar != thishigh->fromvar)
+				continue;
 		}
 		break;
 	}
@@ -353,28 +356,28 @@ UINTBIG us_getobject(INTSML type, INTSML canbetext)
 	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
-		us_abortcommand("Nothing is highlighted");
+		us_abortcommand(_("Nothing is highlighted"));
 		return((UINTBIG)-1);
 	}
 	len = (INTSML)getlength(var);
 	if (len > 1)
 	{
-		us_abortcommand("Too much is highlighted");
+		us_abortcommand(_("Too much is highlighted"));
 		return((UINTBIG)-1);
 	}
 
 	/* get the highlighted object */
 	if (us_makehighlight(((char **)var->addr)[0], &high) != 0)
 	{
-		us_abortcommand("Highlight unintelligible");
+		us_abortcommand(_("Highlight unintelligible"));
 		return((UINTBIG)-1);
 	}
 
 	if ((high.status&HIGHTYPE) == HIGHTEXT && canbetext != 0) high.status = HIGHFROM;
 	if ((high.status&HIGHTYPE) != HIGHFROM || high.fromgeom->entrytype != type)
 	{
-		if (type == OBJARCINST) us_abortcommand("Select an arc"); else
-			us_abortcommand("Select a node");
+		if (type == OBJARCINST) us_abortcommand(_("Select an arc")); else
+			us_abortcommand(_("Select a node"));
 		return((UINTBIG)-1);
 	}
 
@@ -396,20 +399,20 @@ HIGHLIGHT *us_getonehighlight(void)
 	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 	if (var == NOVARIABLE)
 	{
-		us_abortcommand("Nothing is highlighted");
+		us_abortcommand(_("Nothing is highlighted"));
 		return(NOHIGHLIGHT);
 	}
 	len = (INTSML)getlength(var);
 	if (len > 1)
 	{
-		us_abortcommand("Too much is highlighted");
+		us_abortcommand(_("Too much is highlighted"));
 		return(NOHIGHLIGHT);
 	}
 
 	/* get the highlighted object */
 	if (us_makehighlight(((char **)var->addr)[0], &high) != 0)
 	{
-		us_abortcommand("Highlight unintelligible");
+		us_abortcommand(_("Highlight unintelligible"));
 		return(NOHIGHLIGHT);
 	}
 	return(&high);
@@ -455,7 +458,7 @@ GEOM **us_gethighlighted(INTSML type)
 {
 	HIGHLIGHT high;
 	REGISTER VARIABLE *var;
-	REGISTER INTSML total, len, i, j, k;
+	REGISTER INTBIG total, len, i, j, k;
 	REGISTER INTBIG search;
 	REGISTER GEOM *geom;
 	REGISTER NODEINST *ni;
@@ -486,7 +489,7 @@ GEOM **us_gethighlighted(INTSML type)
 				if ((geom->entrytype & type) != 0) total++;
 		}
 
-		/* special case: accept ports and invisible node if it holds highlighted text */
+		/* special case: accept invisible node if it holds highlighted text */
 		if ((high.status&HIGHTYPE) == HIGHTEXT)
 		{
 			if (high.fromvar != NOVARIABLE && high.fromgeom != NOGEOM &&
@@ -504,7 +507,7 @@ GEOM **us_gethighlighted(INTSML type)
 		us_gethighlist = (GEOM **)emalloc(((total+1) * (sizeof (GEOM *))), us_aid->cluster);
 		if (us_gethighlist == 0)
 		{
-			ttyputerr("No memory for selection");
+			ttyputnomemory();
 			nulllist[0] = NOGEOM;
 			return(nulllist);
 		}
@@ -542,7 +545,7 @@ GEOM **us_gethighlighted(INTSML type)
 					(geom->entryaddr.ni->proto->userbits&NEDGESELECT) != 0)
 				{
 					ni = geom->entryaddr.ni;
-					k = nodepolys(ni);
+					k = nodepolys(ni, 0);
 					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
 					makerot(ni, trans);
 					for(j=0; j<k; j++)
@@ -598,7 +601,7 @@ INTBIG *us_getallhighlighted(void)
 {
 	HIGHLIGHT high;
 	REGISTER VARIABLE *var;
-	REGISTER INTSML total, len, i, j, k;
+	REGISTER INTBIG total, len, i, j, k;
 	REGISTER INTBIG search;
 	REGISTER GEOM *geom;
 	REGISTER NODEINST *ni;
@@ -643,7 +646,7 @@ INTBIG *us_getallhighlighted(void)
 		us_getallhighlist = (INTBIG *)emalloc((total+1)*2 * SIZEOFINTBIG, us_aid->cluster);
 		if (us_getallhighlist == 0)
 		{
-			ttyputerr("No memory for selection");
+			ttyputnomemory();
 			nulllist[0] = nulllist[1] = 0;
 			return(nulllist);
 		}
@@ -687,7 +690,7 @@ INTBIG *us_getallhighlighted(void)
 					(geom->entryaddr.ni->proto->userbits&NEDGESELECT) != 0)
 				{
 					ni = geom->entryaddr.ni;
-					k = nodepolys(ni);
+					k = nodepolys(ni, 0);
 					if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
 					makerot(ni, trans);
 					for(j=0; j<k; j++)
@@ -778,7 +781,7 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 		(void)us_makehighlight(((char **)var->addr)[i], &high);
 		if (high.facet != thisfacet)
 		{
-			us_abortcommand("Highlighted areas must be in one facet");
+			us_abortcommand(_("Highlighted areas must be in one facet"));
 			return(NONODEPROTO);
 		}
 		if ((high.status&HIGHTYPE) == HIGHTEXT)
@@ -799,10 +802,10 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 					makedisparrayvarpoly(high.fromgeom, el_curwindowpart, high.fromvar, poly);
 				} else
 				{
-					if (ni != NONODEINST) tech = whattech(ni->proto); else
+					if (ni != NONODEINST) tech = ni->proto->tech; else
 					{
 						if (high.fromgeom != NOGEOM) tech = high.fromgeom->entryaddr.ai->proto->tech; else
-							tech = whattech(high.facet);
+							tech = high.facet->tech;
 					}
 					us_maketextpoly(describevariable(high.fromvar, -1, -1), el_curwindowpart,
 						(high.fromgeom->lowx + high.fromgeom->highx) / 2,
@@ -818,14 +821,14 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 			{
 				portposition(high.fromport->subnodeinst, high.fromport->subportproto, &xc, &yc);
 				us_maketextpoly(high.fromport->protoname, el_curwindowpart, xc, yc,
-					high.fromport->subnodeinst, whattech(high.fromport->subnodeinst->proto),
+					high.fromport->subnodeinst, high.fromport->subnodeinst->proto->tech,
 						high.fromport->textdescript, poly);
 			} else if (high.fromgeom->entrytype == OBJNODEINST)
 			{
 				ni = high.fromgeom->entryaddr.ni;
 				us_maketextpoly(describenodeproto(ni->proto), el_curwindowpart,
 					(ni->lowx + ni->highx) / 2, (ni->lowy + ni->highy) / 2,
-						ni, whattech(ni->proto), ni->textdescript, poly);
+						ni, ni->proto->tech, ni->textdescript, poly);
 			}
 			getbbox(poly, &tlx, &thx, &tly, &thy);
 		}
@@ -1036,14 +1039,14 @@ void us_buildtexthighpoly(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
 			if (poly->limit < 12) (void)extendpolygon(poly, 12);
 			xsh = (hx - lx) / 6;
 			ysh = (hy - ly) / 6;
-			poly->xv[4] = lx + xsh;   poly->yv[4] = ly;
-			poly->xv[5] = hx - xsh;  poly->yv[5] = ly;
-			poly->xv[6] = lx + xsh;   poly->yv[6] = hy;
-			poly->xv[7] = hx - xsh;  poly->yv[7] = hy;
-			poly->xv[8] = lx;         poly->yv[8] = ly + ysh;
-			poly->xv[9] = lx;         poly->yv[9] = hy - ysh;
-			poly->xv[10] = hx;       poly->yv[10] = ly + ysh;
-			poly->xv[11] = hx;       poly->yv[11] = hy - ysh;
+			poly->xv[4] = lx + xsh;    poly->yv[4] = ly;
+			poly->xv[5] = hx - xsh;    poly->yv[5] = ly;
+			poly->xv[6] = lx + xsh;    poly->yv[6] = hy;
+			poly->xv[7] = hx - xsh;    poly->yv[7] = hy;
+			poly->xv[8] = lx;          poly->yv[8] = ly + ysh;
+			poly->xv[9] = lx;          poly->yv[9] = hy - ysh;
+			poly->xv[10] = hx;         poly->yv[10] = ly + ysh;
+			poly->xv[11] = hx;         poly->yv[11] = hy - ysh;
 			poly->count = 12;
 			break;
 		case TEXTBOT:
@@ -1340,7 +1343,7 @@ void us_highlightverbose(GEOM *look, PORTPROTO *pp, INTSML color, NODEPROTO *par
 			if (ni->temp1 == 0) continue;
 			poly->xv[0] = (ni->lowx + ni->highx) / 2;
 			poly->yv[0] = (ni->lowy + ni->highy) / 2;
-			poly->xv[1] = poly->xv[0] + el_curtech->deflambda/4;
+			poly->xv[1] = poly->xv[0] + el_curlib->lambda[el_curtech->techindex]/4;
 			poly->yv[1] = poly->yv[0];
 			poly->count = 2;
 			poly->style = DISC;
@@ -1440,7 +1443,7 @@ void us_pushhighlight(void)
 		len = getlength(var);
 		for(i=0; i<len; i++)
 		{
-			if (i != 0) (void)addtoinfstr('/');
+			if (i != 0) (void)addtoinfstr('\n');
 			(void)addstringtoinfstr(((char **)var->addr)[i]);
 		}
 	}
@@ -1482,7 +1485,7 @@ INTSML us_pophighlight(INTSML clearsnap)
 	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlightstack);
 	if (var == NOVARIABLE) return(1);
 	len = (INTSML)getlength(var);
-	vaddr = (char **) var->addr;
+	vaddr = (char **)var->addr;
 
 	/* set the configuration */
 	us_setmultiplehighlight(vaddr[len-1], clearsnap);
@@ -1517,7 +1520,7 @@ void us_setmultiplehighlight(char *str, INTSML clearsnap)
 	pp = str;
 	for(total=0; ; total++)
 	{
-		line = getkeyword(&pp, "/");
+		line = getkeyword(&pp, "\n");
 		if (line == NOSTRING) break;
 		if (*line == 0) break;
 		(void)tonextchar(&pp);
@@ -1532,7 +1535,7 @@ void us_setmultiplehighlight(char *str, INTSML clearsnap)
 	pp = str;
 	for(total=0; ; )
 	{
-		line = getkeyword(&pp, "/");
+		line = getkeyword(&pp, "\n");
 		if (line == NOSTRING) break;
 		if (*line == 0) break;
 
@@ -1550,10 +1553,11 @@ void us_setmultiplehighlight(char *str, INTSML clearsnap)
 		{
 			(void)allocstring(&list[total++], line, el_tempcluster);
 		}
-		if (tonextchar(&pp) != '/') break;
+		if (tonextchar(&pp) != '\n') break;
 	}
 
 	/* set the multiple list */
+	if (total == 0) return;
 	(void)setvalkey((INTBIG)us_aid, VAID, us_highlighted, (INTBIG)list,
 		VSTRING|VISARRAY|(total<<VLENGTHSH)|VDONTSAVE);
 
@@ -1755,50 +1759,31 @@ INTSML us_makehighlight(char *str, HIGHLIGHT *high)
  */
 char *us_makehighlightstring(HIGHLIGHT *high)
 {
-	char line[100];
 
 	(void)initinfstr();
-	(void)addstringtoinfstr("FACET=");
-	(void)addstringtoinfstr(describenodeproto(high->facet));
+	(void)formatinfstr("FACET=%s", describenodeproto(high->facet));
 	switch (high->status&HIGHTYPE)
 	{
 		case HIGHFROM:
-			(void)addstringtoinfstr(" FROM=");
-			(void)sprintf(line, "0%lo;", (UINTBIG)high->fromgeom);
-			(void)addstringtoinfstr(line);
+			(void)formatinfstr(" FROM=0%lo;", (UINTBIG)high->fromgeom);
 			if (high->fromport == NOPORTPROTO) (void)addstringtoinfstr("-1;"); else
-			{
-				(void)sprintf(line, "0%lo;", (UINTBIG)high->fromport);
-				(void)addstringtoinfstr(line);
-			}
-			(void)sprintf(line, "%d", high->frompoint);
-			(void)addstringtoinfstr(line);
+				(void)formatinfstr("0%lo;", (UINTBIG)high->fromport);
+			(void)formatinfstr("%d", high->frompoint);
 			if ((high->status&HIGHEXTRA) != 0) (void)addstringtoinfstr(";EXTRA");
 			if ((high->status&HIGHNOBOX) != 0) (void)addstringtoinfstr(";NOBBOX");
 			break;
 		case HIGHTEXT:
-			(void)addstringtoinfstr(" TEXT=");
-			(void)sprintf(line, "0%lo;", (UINTBIG)high->fromgeom);
-			(void)addstringtoinfstr(line);
+			(void)formatinfstr(" TEXT=0%lo;", (UINTBIG)high->fromgeom);
 			if (high->fromport == NOPORTPROTO) (void)addstringtoinfstr("-1;"); else
-			{
-				(void)sprintf(line, "0%lo;", (UINTBIG)high->fromport);
-				(void)addstringtoinfstr(line);
-			}
+				(void)formatinfstr("0%lo;", (UINTBIG)high->fromport);
 			if (high->fromvar == NOVARIABLE) (void)addstringtoinfstr("-"); else
-			{
 				(void)addstringtoinfstr(makename(high->fromvar->key));
-			}
 			break;
 		case HIGHBBOX:
-			(void)addstringtoinfstr(" AREA=");
-			(void)sprintf(line, "%ld,%ld,%ld,%ld", high->stalx, high->stahx, high->staly, high->stahy);
-			(void)addstringtoinfstr(line);
+			(void)formatinfstr(" AREA=%ld,%ld,%ld,%ld", high->stalx, high->stahx, high->staly, high->stahy);
 			break;
 		case HIGHLINE:
-			(void)addstringtoinfstr(" LINE=");
-			(void)sprintf(line, "%ld,%ld,%ld,%ld", high->stalx, high->stahx, high->staly, high->stahy);
-			(void)addstringtoinfstr(line);
+			(void)formatinfstr(" LINE=%ld,%ld,%ld,%ld", high->stalx, high->stahx, high->staly, high->stahy);
 			break;
 	}
 	if ((high->status&HIGHSNAP) != 0)
@@ -1806,8 +1791,7 @@ char *us_makehighlightstring(HIGHLIGHT *high)
 		if ((high->status&HIGHSNAPTAN) != 0) (void)addstringtoinfstr(";SNAPTAN="); else
 			if ((high->status&HIGHSNAPPERP) != 0) (void)addstringtoinfstr(";SNAPPERP="); else
 				(void)addstringtoinfstr(";SNAP=");
-		(void)sprintf(line, "%ld,%ld", high->snapx, high->snapy);
-		(void)addstringtoinfstr(line);
+		(void)formatinfstr("%ld,%ld", high->snapx, high->snapy);
 	}
 	return(returninfstr());
 }
@@ -1824,6 +1808,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 	REGISTER ARCINST *ai;
 	XARRAY trans;
 	INTBIG newxc, newyc;
+	REGISTER INTSML saverot, savetrn;
 	REGISTER INTBIG descript, lambda;
 
 	/* get polygon */
@@ -1836,9 +1821,13 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 		descript = high->fromvar->textdescript;
 		if (high->fromport != NOPORTPROTO)
 		{
-			portposition(high->fromport->subnodeinst, high->fromport->subportproto,
+			ni = high->fromport->subnodeinst;
+			saverot = ni->rotation;   savetrn = ni->transpose;
+			ni->rotation = ni->transpose = 0;
+			portposition(ni, high->fromport->subportproto,
 				&poly->xv[0], &poly->yv[0]);
-			adjustdisoffset((INTBIG)high->fromport, VPORTPROTO, whattech(high->facet),
+			ni->rotation = saverot;   ni->transpose = savetrn;
+			adjustdisoffset((INTBIG)high->fromport, VPORTPROTO, high->facet->tech,
 				poly, descript);
 			makerot(high->fromport->subnodeinst, trans);
 			xformpoly(poly, trans);
@@ -1849,7 +1838,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 				ni = high->fromgeom->entryaddr.ni;
 				poly->xv[0] = (ni->lowx + ni->highx) / 2;
 				poly->yv[0] = (ni->lowy + ni->highy) / 2;
-				adjustdisoffset((INTBIG)ni, VNODEINST, whattech(ni->proto), poly, descript);
+				adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, poly, descript);
 				makerot(ni, trans);
 				xformpoly(poly, trans);
 			} else
@@ -1863,7 +1852,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 		{
 			poly->xv[0] = (high->facet->lowx + high->facet->highx) / 2;
 			poly->yv[0] = (high->facet->lowy + high->facet->highy) / 2;
-			adjustdisoffset((INTBIG)high->facet, VNODEPROTO, whattech(high->facet),
+			adjustdisoffset((INTBIG)high->facet, VNODEPROTO, high->facet->tech,
 				poly, descript);
 		}
 		*style = poly->style;
@@ -1903,7 +1892,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTSML *style
 		descript = ni->textdescript;
 		poly->xv[0] = (ni->lowx + ni->highx) / 2;
 		poly->yv[0] = (ni->lowy + ni->highy) / 2;
-		adjustdisoffset((INTBIG)ni, VNODEINST, whattech(ni->proto), poly, descript);
+		adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, poly, descript);
 		makerot(ni, trans);
 		xformpoly(poly, trans);
 		*style = poly->style;
@@ -2019,16 +2008,16 @@ TECHNOLOGY *us_hightech(HIGHLIGHT *high)
 	if (high->fromvar != NOVARIABLE)
 	{
 		if (high->fromport != NOPORTPROTO)
-			return(whattech(high->fromport->subnodeinst->proto));
-		if (high->fromgeom == NOGEOM) return(whattech(high->facet));
+			return(high->fromport->subnodeinst->proto->tech);
+		if (high->fromgeom == NOGEOM) return(high->facet->tech);
 		if (high->fromgeom->entrytype == OBJNODEINST)
-			return(whattech(high->fromgeom->entryaddr.ni->proto));
+			return(high->fromgeom->entryaddr.ni->proto->tech);
 		return(high->fromgeom->entryaddr.ai->proto->tech);
 	}
 	if (high->fromport != NOPORTPROTO)
-		return(whattech(high->fromgeom->entryaddr.ni->proto));
+		return(high->fromgeom->entryaddr.ni->proto->tech);
 	if (high->fromgeom->entrytype == OBJNODEINST)
-		return(whattech(high->fromgeom->entryaddr.ni->proto));
+		return(high->fromgeom->entryaddr.ni->proto->tech);
 	if (high->fromgeom->entrytype == OBJARCINST)
 		return(high->fromgeom->entryaddr.ai->proto->tech);
 	return(NOTECHNOLOGY);
@@ -2047,7 +2036,7 @@ TECHNOLOGY *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, I
 			ni = (NODEINST *)addr;
 			*lx = ni->geom->lowx;   *hx = ni->geom->highx;
 			*ly = ni->geom->lowy;   *hy = ni->geom->highy;
-			return(whattech(ni->proto));
+			return(ni->proto->tech);
 		case VARCINST:
 			ai = (ARCINST *)addr;
 			*lx = ai->geom->lowx;   *hx = ai->geom->highx;
@@ -2058,12 +2047,12 @@ TECHNOLOGY *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, I
 			ni = pp->subnodeinst;
 			*lx = ni->geom->lowx;   *hx = ni->geom->highx;
 			*ly = ni->geom->lowy;   *hy = ni->geom->highy;
-			return(whattech(pp->parent));
+			return(pp->parent->tech);
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
 			*lx = np->lowx;   *hx = np->highx;
 			*ly = np->lowy;   *hy = np->highy;
-			return(whattech(np));
+			return(np->tech);
 	}
 	return(NOTECHNOLOGY);
 }
@@ -2106,7 +2095,7 @@ void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
 	extern GRAPHICS us_ebox;
 
 	if ((var->type&VDISPLAY) == 0) return;
-	tech = whattech(np);
+	tech = np->tech;
 	font = (INTSML)((var->textdescript & VTSIZE) >> VTSIZESH);
 	str = describevariable(var, -1, -1);
 	for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
