@@ -33,34 +33,31 @@
 #include "edialogs.h"
 
 INTSML   us_ttymute;					/* nonzero to supress unimportant messages */
-INTBIG	 us_ttypamyItemHit;			/* item hit during parsing */
+INTBIG	 us_ttypamyItemHit;				/* item hit during parsing */
 INTSML	 us_ttyttywriteseparator;		/* nonzero to write separator before next text */
 INTSML   us_ttyttyinited;
 
-/* general ttygetparam() Dialog */
-extern DIALOG us_listdialog;
-
 /* ttygetline() Dialog */
 DIALOGITEM us_ttyinputdialogitems[] =
 {
- /*  1 */ {0, {96,200,120,264}, BUTTON, "OK"},
- /*  2 */ {0, {96,24,120,88}, BUTTON, "Cancel"},
+ /*  1 */ {0, {96,200,120,264}, BUTTON, N_("OK")},
+ /*  2 */ {0, {96,24,120,88}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {58,38,74,246}, EDITTEXT, ""},
  /*  4 */ {0, {3,9,51,281}, MESSAGE, ""}
 };
-DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 4, us_ttyinputdialogitems};
+DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 0, 4, us_ttyinputdialogitems};
 
 /* Full Input Dialog */
 DIALOGITEM us_ttyfulldialogitems[] =
 {
- /*  1 */ {0, {160,328,184,392}, BUTTON, "OK"},
- /*  2 */ {0, {104,328,128,392}, BUTTON, "Cancel"},
+ /*  1 */ {0, {160,328,184,392}, BUTTON, N_("OK")},
+ /*  2 */ {0, {104,328,128,392}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {24,8,56,408}, EDITTEXT, ""},
  /*  4 */ {0, {3,8,19,408}, MESSAGE, ""},
  /*  5 */ {0, {88,8,212,294}, SCROLL, ""},
- /*  6 */ {0, {72,56,88,270}, MESSAGE, "Type '?' for a list of options"}
+ /*  6 */ {0, {72,56,88,270}, MESSAGE, N_("Type '?' for a list of options")}
 };
-DIALOG us_ttyfulldialog = {{50,75,271,493}, "Command Completion", 6, us_ttyfulldialogitems};
+DIALOG us_ttyfulldialog = {{50,75,271,493}, N_("Command Completion"), 0, 6, us_ttyfulldialogitems};
 
 /* prototypes for local routines */
 INTSML us_ttyinttychar(COMCOMP**, INTSML*);
@@ -169,6 +166,39 @@ void ttyputerr(char *msg, ...)
 	va_end(ap);
 }
 
+/*
+ * Routine to put out a message that is in 2 parts: a keystroke and a meaning.
+ * The length of the "keystroke" field is "length".
+ */
+void ttyputinstruction(char *keystroke, INTBIG length, char *meaning)
+{
+	REGISTER INTBIG i;
+
+	(void)initinfstr();
+	for(i=0; i<length; i++)
+	{
+		if (*keystroke == 0) (void)addtoinfstr(' '); else
+			(void)addtoinfstr(*keystroke++);
+	}
+	(void)addstringtoinfstr(meaning);
+	ttyputmsg("%s", returninfstr());
+}
+
+void ttyputusage(char *usage)
+{
+	ttyputerr(_("Usage: %s"), usage);
+}
+
+void ttyputbadusage(char *command)
+{
+	ttyputerr(_("Bad '%s' command"), command);
+}
+
+void ttyputnomemory(void)
+{
+	ttyputerr(_("No memory"));
+}
+
 /*
  * routine to cause the current command to be aborted by removing it from
  * any macro and by printing the message on the terminal
@@ -182,7 +212,7 @@ void us_abortcommand(char *msg, ...)
 	va_end(ap);
 	us_state |= COMMANDFAILED;
 	if (getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding) != NOVARIABLE)
-		ttyputmsg("Command ignored from macro definition");
+		ttyputmsg(_("Command ignored from macro definition"));
 	us_unknowncommand();
 }
 
@@ -256,6 +286,7 @@ char *ttygetlinemessages(char *prompt)
 INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *paramstart[])
 {
 	REGISTER INTBIG itemHit;
+	extern DIALOG us_listdialog;
 
 	/* is this necessary?  if not, us_pathiskey does not need to be global */
 	us_pathiskey = parameter->ifmatch;
@@ -284,7 +315,9 @@ INTSML ttygetparam(char *prompt, COMCOMP *parameter, INTSML keycount, char *para
 }
 
 /*
- * routine to get a string with "parameter" information (does command completion)
+ * Routine to get a string with "parameter" information (does command completion).
+ * Returns the number of strings parsed into "paramstart" (-1 if cancelled or
+ * on error).
  */
 INTSML ttygetfullparam(char *prompt, COMCOMP *parameter, INTSML keycount,
 	char *paramstart[])
@@ -303,7 +336,7 @@ INTSML ttygetfullparam(char *prompt, COMCOMP *parameter, INTSML keycount,
 	us_paparamtype[us_paparamcount+1] = NOCOMCOMP;
 
 	/* display the dialog box */
-	if (DiaInitDialog(&us_ttyfulldialog) != 0) return(0);
+	if (DiaInitDialog(&us_ttyfulldialog) != 0) return(-1);
 	DiaInitTextDialog(5, DiaNullDlogList, DiaNullDlogItem, DiaNullDlogDone, -1, 0);
  	DiaCharacterEdit(3);
 
@@ -313,11 +346,7 @@ INTSML ttygetfullparam(char *prompt, COMCOMP *parameter, INTSML keycount,
 	{
 		(void)addstringtoinfstr(parameter->noise);
 		if (parameter->def != 0)
-		{
-			(void)addstringtoinfstr(" (");
-			(void)addstringtoinfstr(parameter->def);
-			(void)addstringtoinfstr(")");
-		}
+			(void)formatinfstr(" (%s)", parameter->def);
 	} else (void)addstringtoinfstr(prompt);
 	DiaSetText(4, returninfstr());
 
@@ -330,7 +359,7 @@ INTSML ttygetfullparam(char *prompt, COMCOMP *parameter, INTSML keycount,
 	}
 
 	/* parse the line if not cancelled */
-	if (us_ttypamyItemHit == CANCEL) us_paparamcount = 0; else
+	if (us_ttypamyItemHit == CANCEL) us_paparamcount = -1; else
 	{
 		us_paparamcount++;
 		for(i=1; i<us_paparamcount; i++) (us_paparamstart[i])[-1] = 0;
@@ -366,6 +395,7 @@ void us_ttyprint(INTSML important, char *msg, va_list ap)
 			"================================= %ld =================================",
 				sepcount);
 		putmessagesstring(line, important);
+		if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", line);
 		us_ttyttywriteseparator = 0;
 	}
 
@@ -384,11 +414,16 @@ void us_ttyprint(INTSML important, char *msg, va_list ap)
 		{
 			line[j] = 0;
 			putmessagesstring(&line[k], important);
+			if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", &line[k]);
 			k = j + 1;
 		}
 	}
 
-	if (k < i) putmessagesstring(&line[k], important);
+	if (k < i)
+	{
+		putmessagesstring(&line[k], important);
+		if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", &line[k]);
+	}
 }
 
 INTSML us_ttyinttychar(COMCOMP **newcomcomp, INTSML *reset)
@@ -407,7 +442,7 @@ INTSML us_ttyinttychar(COMCOMP **newcomcomp, INTSML *reset)
 		}
 		break;
 	}
-	if (chr == 03) chr = '\n';
+	if (chr == CTRLCKEY) chr = '\n';
 	return(chr);
 }
 
