@@ -58,6 +58,7 @@ static INTBIG      us_arrowlx, us_arrowhx, us_arrowly, us_arrowhy;
 static WINDOWPART *us_dragwindow;
 static POLYGON    *us_dragpoly = NOPOLYGON;
 static NODEPROTO  *us_dragnodeproto;
+static PORTPROTO  *us_dragportproto;
 static NODEINST   *us_dragnodeinst, **us_dragnodelist;
 static ARCINST    *us_dragarcinst;
 static GEOM       *us_dragobject, **us_dragobjectlist;
@@ -67,6 +68,8 @@ static char        us_dragmessage[100];
 static UINTBIG     us_beforepantime = 0;
 static INTBIG      us_initthumbcoord;
 static WINDOWPART  us_trackww;
+static INTBIG      us_dragnumtext, us_dragtotaltext = 0;
+static char      **us_dragtextlist;
 
 /* prototypes for local routines */
 void us_finddoibegin(INTSML);
@@ -76,6 +79,14 @@ void us_wanttoinvert(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, WINDOWPART *w);
 INTSML us_geominrect(GEOM *geom, INTBIG slx, INTBIG shx, INTBIG sly, INTBIG shy);
 void us_drawdistance(void);
 
+/*
+ * Routine to free all memory associated with this module.
+ */
+void us_freetrackmemory(void)
+{
+	if (us_dragtotaltext > 0) efree((char *)us_dragtextlist);
+}
+
 /************************* NODE TRACE *************************/
 
 /* initialization routine when reading a cursor trace */
@@ -451,7 +462,7 @@ INTSML us_textmovedown(INTBIG x, INTBIG y)
 	adjustdisoffset(us_dragaddr, us_dragtype, tech, us_dragpoly, us_dragdescript);
 
 	/* clip range of text descriptor */
-	lambda = tech->deflambda;
+	lambda = el_curlib->lambda[tech->techindex];
 	xcur = (us_lastcurx - us_dragx) * 4 / lambda;
 	us_lastcurx = us_lastcurx - us_dragx + us_dragoffx;
 	if (xcur > 1023)
@@ -869,11 +880,10 @@ void us_finddoibegin(INTSML compl)
 	REGISTER ARCINST *ai;
 	REGISTER PORTPROTO *pp;
 	REGISTER INTSML len, another;
-	REGISTER char *str;
+	REGISTER char **newtext;
 	HIGHLIGHT newhigh, oldhigh;
-	REGISTER TECHNOLOGY *tech;
-	INTSML i, tsx, tsy, j;
-	INTBIG xc, yc, xw, yw, xcur, ycur, dist, bestdist, lx, hx, ly, hy;
+	INTSML i, j;
+	INTBIG xcur, ycur, dist, bestdist, numhigh, newcount;
 
 	/* remember initial time of this action */
 	us_initialtime = ticktime();
@@ -884,6 +894,7 @@ void us_finddoibegin(INTSML compl)
 	us_dragpoly->desc = &us_highl;
 	us_dragstate = -1;
 	us_dragshown = 0;
+	us_dragnumtext = 0;
 	us_dragwindow = el_curwindowpart;
 
 	/* get cursor coordinates */
@@ -942,12 +953,17 @@ void us_finddoibegin(INTSML compl)
 					bestdist = dist;   newhigh.fromport = pp;
 				}
 			}
-		} else us_findobject(xcur, ycur, el_curwindowpart, &newhigh, 0, 0, us_dragfport, 1, us_dragspecial);
+		} else
+		{
+			/* control NOT held, nothing under cursor */
+			us_findobject(xcur, ycur, el_curwindowpart, &newhigh, 0, 0, us_dragfport, 1, us_dragspecial);
+		}
 	} else
 	{
 		another = 0;
 		if (compl != 0)
 		{
+			/* control-shift held or nothing highlighted and shift held */
 			for(i=0; i<len; i++)
 			{
 				(void)us_makehighlight(((char **)highvar->addr)[i], &newhigh);
@@ -955,12 +971,16 @@ void us_finddoibegin(INTSML compl)
 			}
 			if (i < len)
 			{
+				/* remove current highlight, find another */
 				another = 1;
 				(void)us_delhighlight(&newhigh);
 				highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 				if (highvar == NOVARIABLE) len = 0; else
 					len = (INTSML)getlength(highvar);
 			}
+		} else
+		{
+			/* control held or nothing highlighted */
 		}
 		us_findobject(xcur, ycur, el_curwindowpart, &newhigh, 0, another, us_dragfport, 1, us_dragspecial);
 	}
@@ -988,6 +1008,7 @@ void us_finddoibegin(INTSML compl)
 		if (oldhigh.facet != newhigh.facet) continue;
 		if ((oldhigh.status&HIGHTYPE) != (newhigh.status&HIGHTYPE)) continue;
 		if (oldhigh.fromgeom != newhigh.fromgeom) continue;
+		if ((oldhigh.status&HIGHTYPE) == HIGHTEXT && oldhigh.fromvar != newhigh.fromvar) continue;
 		break;
 	}
 
@@ -1009,7 +1030,7 @@ void us_finddoibegin(INTSML compl)
 		}
 	} else
 	{
-		/* SHIFT find/move */
+		/* SHIFT held: find/move */
 		if (i >= len)
 		{
 			/* object not highlighted: add it and move */
@@ -1037,52 +1058,10 @@ void us_finddoibegin(INTSML compl)
 	/* get the objects to be moved */
 	highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 	if (highvar == NOVARIABLE) return;
+	numhigh = getlength(highvar);
 
-	/* see if a text object is highlighted */
-	if (getlength(highvar) == 1)
-	{
-		(void)us_makehighlight(((char **)highvar->addr)[0], &us_draghigh);
-		if ((us_draghigh.status&HIGHTYPE) == HIGHTEXT)
-		{
-			/* get descriptor and text string */
-			us_gethighaddrtype(&us_draghigh, &us_dragaddr, &us_dragtype);
-			us_dragnodeinst = us_gethighnodeinst(&us_draghigh);
-			tech = us_hightech(&us_draghigh);
-			us_dragdescript = us_gethighdescript(&us_draghigh);
-			str = us_gethighstring(&us_draghigh);
-
-			/* determine number of lines of text and text size */
-			len = 1;
-			if (us_draghigh.fromvar != NOVARIABLE && (us_draghigh.fromvar->type&VISARRAY) != 0)
-				len = (INTSML)getlength(us_draghigh.fromvar);
-			if (len > 1)
-			{
-				makedisparrayvarpoly(us_draghigh.fromgeom, el_curwindowpart, us_draghigh.fromvar, us_dragpoly);
-				getbbox(us_dragpoly, &lx, &hx, &ly, &hy);
-				xw = hx - lx;
-				yw = hy - ly;
-			} else
-			{
-				screensettextsize(el_curwindowpart, truefontsize((INTSML)((us_dragdescript&VTSIZE)>>VTSIZESH),
-					el_curwindowpart, tech));
-				screengettextsize(el_curwindowpart, str, &tsx, &tsy);
-				xw = muldiv(tsx, el_curwindowpart->screenhx-el_curwindowpart->screenlx,
-					el_curwindowpart->usehx-el_curwindowpart->uselx);
-				yw = muldiv(tsy, el_curwindowpart->screenhy-el_curwindowpart->screenly,
-					el_curwindowpart->usehy-el_curwindowpart->usely);
-			}
-
-			/* get offset */
-			us_gethightextcenter(&us_draghigh, &xc, &yc, &j);
-			us_dragoffx = xc;  us_dragoffy = yc;
-			us_dragox = xw;    us_dragoy = yw;
-			us_dragstate = 3;
-			return;
-		}
-	}
-
+	/* get the selected nodes and arcs */
 	us_dragobjectlist = us_gethighlighted(OBJNODEINST | OBJARCINST);
-	if (us_dragobjectlist[0] == NOGEOM) return;
 	for(i=0; us_dragobjectlist[i] != NOGEOM; i++)
 		if (us_dragnodeproto != geomparent(us_dragobjectlist[i])) return;
 
@@ -1099,6 +1078,43 @@ void us_finddoibegin(INTSML compl)
 		if (us_dragobjectlist[i]->entrytype == OBJNODEINST)
 			us_dragobjectlist[i]->entryaddr.ni->temp1 = 1;
 
+	/* build list of selected text, removing invisible nodes from node list */
+	us_dragnumtext = 0;
+	for(i=0; i<numhigh; i++)
+	{
+		(void)us_makehighlight(((char **)highvar->addr)[i], &us_draghigh);
+		if ((us_draghigh.status&HIGHTYPE) != HIGHTEXT) continue;
+		us_gethighaddrtype(&us_draghigh, &us_dragaddr, &us_dragtype);
+		if (us_dragtype == VNODEINST)
+		{
+			ni = (NODEINST *)us_dragaddr;
+			if (ni->proto == gen_invispinprim) ni->temp1 = 0;
+		}
+		if (us_dragnumtext >= us_dragtotaltext)
+		{
+			newcount = us_dragnumtext + 5;
+			newtext = (char **)emalloc(newcount * (sizeof (char *)), us_aid->cluster);
+			if (newtext == 0) return;
+			for(j=0; j<us_dragtotaltext; j++)
+				newtext[j] = us_dragtextlist[j];
+			for( ; j<newcount; j++) newtext[j] = 0;
+			if (us_dragtotaltext > 0) efree((char *)us_dragtextlist);
+			us_dragtextlist = newtext;
+			us_dragtotaltext = newcount;
+		}
+		if (us_dragtextlist[us_dragnumtext] == 0)
+		{
+			allocstring(&us_dragtextlist[us_dragnumtext], ((char **)highvar->addr)[i],
+				us_aid->cluster);
+		} else
+		{
+			reallocstring(&us_dragtextlist[us_dragnumtext], ((char **)highvar->addr)[i],
+				us_aid->cluster);
+		}
+		us_dragnumtext++;
+	}
+	if (us_dragobjectlist[0] == NOGEOM && us_dragnumtext == 0) return;
+
 	/* count the number of nodes, excluding locked ones */
 	us_dragnodetotal = 0;
 	for(ni = us_dragnodeproto->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1111,7 +1127,7 @@ void us_finddoibegin(INTSML compl)
 		}
 		us_dragnodetotal++;
 	}
-	if (us_dragnodetotal == 0) us_cantdrag = 1; else
+	if (us_dragnodetotal == 0 && us_dragnumtext == 0) us_cantdrag = 1; else
 		us_cantdrag = 0;
 
 	/* remove from list all arcs touching locked nodes */
@@ -1218,11 +1234,6 @@ INTSML us_findidown(INTBIG x, INTBIG y)
 		case 2:
 			ret = us_stretchdown(x, y);
 			break;
-		case 3:
-			now = ticktime();
-			if (now < us_initialtime + us_doubleclicktime) ret = 0; else
-				ret = us_textmovedown(x, y);
-			break;
 	}
 
 	/* if panning happened, finish redraw */
@@ -1233,10 +1244,10 @@ INTSML us_findidown(INTBIG x, INTBIG y)
 
 void us_findiup(void)
 {
-	INTBIG xcur, ycur, search, lambda, dx, dy;
+	INTBIG xcur, ycur, search, dx, dy;
 	XARRAY trans;
-	REGISTER INTSML i, j;
-	REGISTER INTBIG len, k, slx, shx, sly, shy, addtotal;
+	REGISTER INTBIG j;
+	REGISTER INTBIG i, len, k, slx, shx, sly, shy, addtotal, lambda;
 	REGISTER GEOM *geom;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -1257,10 +1268,87 @@ void us_findiup(void)
 			(void)getxy(&xcur, &ycur);
 			gridalign(&xcur, &ycur, us_alignment);
 			us_setcursorpos(NOWINDOWFRAME, xcur, ycur);
-			us_getslide(us_dragangle, us_dragox, us_dragoy, xcur, ycur, &dx, &dy);
-			if (dx != us_dragox || dy != us_dragoy)
-				us_manymove(us_dragobjectlist, us_dragnodelist, (INTSML)us_dragnodetotal,
-					dx-us_dragox, dy-us_dragoy);
+			us_getslide(us_dragangle, us_dragox, us_dragoy, xcur, ycur, &us_dragx, &us_dragy);
+			if (us_dragx != us_dragox || us_dragy != us_dragoy)
+				us_manymove(us_dragobjectlist, us_dragnodelist, us_dragnodetotal,
+					us_dragx-us_dragox, us_dragy-us_dragoy);
+
+			/* adjust text that moved */
+			for(i=0; i<us_dragnumtext; i++)
+			{
+				(void)us_makehighlight(us_dragtextlist[i], &us_draghigh);
+				if ((us_draghigh.status&HIGHTYPE) != HIGHTEXT) continue;
+
+				/* get object and movement amount */
+				us_gethighaddrtype(&us_draghigh, &us_dragaddr, &us_dragtype);
+				dx = us_dragx - us_dragox;
+				dy = us_dragy - us_dragoy;
+
+				/* undraw the text */
+				if (us_dragtype == VPORTPROTO)
+				{
+					ni = ((PORTPROTO *)us_dragaddr)->subnodeinst;
+					startobjectchange((INTBIG)ni, VNODEINST);
+					if (ni->transpose != 0)
+						makeangle(ni->rotation, ni->transpose, trans); else
+							makeangle((INTSML)((3600-ni->rotation)%3600), 0, trans);
+					xform(dx, dy, &dx, &dy, trans);
+				} else
+				{
+					startobjectchange(us_dragaddr, us_dragtype);
+					if (us_dragtype == VNODEINST)
+					{
+						ni = (NODEINST *)us_dragaddr;
+						if (ni->proto == gen_invispinprim)
+						{
+							modifynodeinst(ni, dx, dy, dx, dy, 0, 0);
+							endobjectchange((INTBIG)ni, VNODEINST);
+							continue;
+						}
+						if (ni->transpose != 0)
+							makeangle(ni->rotation, ni->transpose, trans); else
+								makeangle((INTSML)((3600-ni->rotation)%3600), 0, trans);
+						xform(dx, dy, &dx, &dy, trans);
+					}
+				}
+				if (us_dragtype == VNODEPROTO && us_draghigh.fromvar != NOVARIABLE)
+					us_undrawfacetvariable(us_draghigh.fromvar, (NODEPROTO *)us_dragaddr);
+
+				/* set the new descriptor on the text */
+				lambda = el_curlib->lambda[us_hightech(&us_draghigh)->techindex];
+				dx = dx*4/lambda;   dy = dy*4/lambda;
+				us_dragdescript = us_gethighdescript(&us_draghigh);
+				if ((us_dragdescript&VTXOFFNEG) != 0) dx -= (us_dragdescript&VTXOFF) >> VTXOFFSH; else
+					dx += (us_dragdescript&VTXOFF) >> VTXOFFSH;
+				if ((us_dragdescript&VTYOFFNEG) != 0) dy -= (us_dragdescript&VTYOFF) >> VTYOFFSH; else
+					dy += (us_dragdescript&VTYOFF) >> VTYOFFSH;
+				us_dragdescript = us_setdescriptoffset(us_dragdescript, dx, dy);
+				us_modifytextdescript(&us_draghigh, us_dragdescript);
+
+				/* redisplay the text */
+				if (us_dragtype == VNODEPROTO && us_draghigh.fromvar != NOVARIABLE)
+					us_drawfacetvariable(us_draghigh.fromvar, (NODEPROTO *)us_dragaddr);
+				if (us_dragtype == VPORTPROTO)
+				{
+					endobjectchange((INTBIG)ni, VNODEINST);
+				} else
+				{
+					endobjectchange(us_dragaddr, us_dragtype);
+				}
+				(void)us_addhighlight(&us_draghigh);
+
+				/* modify all higher-level nodes if port moved */
+				if (us_draghigh.fromvar == NOVARIABLE && us_draghigh.fromport != NOPORTPROTO)
+				{
+					for(ni = us_draghigh.fromport->parent->firstinst; ni != NONODEINST; ni = ni->nextinst)
+					{
+						if ((ni->userbits&NEXPAND) != 0 &&
+							(us_draghigh.fromport->userbits&PORTDRAWN) == 0) continue;
+						startobjectchange((INTBIG)ni, VNODEINST);
+						endobjectchange((INTBIG)ni, VNODEINST);
+					}
+				}
+			}
 		}
 		if (us_dragnodetotal > 0) efree((char *)us_dragnodelist);
 		(void)us_pophighlight(1);
@@ -1278,7 +1366,7 @@ void us_findiup(void)
 		while ((geom = nextobject(search)) != NOGEOM)
 		{
 			if ((addtotal%50) == 49)
-				if (stopping("Selection")) { termsearch(search);   return; }
+				if (stopping(STOPREASONSELECT)) { termsearch(search);   return; }
 
 			/* don't find facets if not requested */
 			if (us_dragspecial == 0 && (us_useroptions&NOINSTANCESELECT) != 0 &&
@@ -1298,7 +1386,7 @@ void us_findiup(void)
 		while ((geom = nextobject(search)) != NOGEOM)
 		{
 			if ((addtotal%50) == 49)
-				if (stopping("Selection")) { termsearch(search);   break; }
+				if (stopping(STOPREASONSELECT)) { termsearch(search);   break; }
 
 			/* eliminate objects that aren't really in the selected area */
 			if (us_geominrect(geom, slx, shx, sly, shy) == 0) continue;
@@ -1318,7 +1406,7 @@ void us_findiup(void)
 				if (ni->proto->primindex != 0 &&
 					(ni->proto->userbits&NEDGESELECT) != 0)
 				{
-					i = nodepolys(ni);
+					i = nodepolys(ni, 0);
 					makerot(ni, trans);
 					for(j=0; j<i; j++)
 					{
@@ -1413,7 +1501,7 @@ void us_findiup(void)
 		search = initsearch(slx, shx, sly, shy, us_dragnodeproto);
 		while ((geom = nextobject(search)) != NOGEOM)
 		{
-			if (stopping("Selection")) { termsearch(search);   break; }
+			if (stopping(STOPREASONSELECT)) { termsearch(search);   break; }
 
 			/* don't find facets if not requested */
 			if (us_dragspecial == 0 && (us_useroptions&NOINSTANCESELECT) != 0 &&
@@ -1431,7 +1519,7 @@ void us_findiup(void)
 				(geom->entryaddr.ni->proto->userbits&NEDGESELECT) != 0)
 			{
 				ni = geom->entryaddr.ni;
-				i = nodepolys(ni);
+				i = nodepolys(ni, 0);
 				if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
 				makerot(ni, trans);
 				for(j=0; j<i; j++)
@@ -1514,83 +1602,6 @@ void us_findiup(void)
 			highvar = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_highlighted);
 			if (highvar != NOVARIABLE) len = getlength(highvar); else len = 0;
 		}
-	} else if (us_dragstate == 3)
-	{
-		us_dragup();
-		if (el_pleasestop != 0) return;
-		now = ticktime();
-		if (now < us_initialtime + us_doubleclicktime) return;
-		(void)getxy(&xcur, &ycur);
-		gridalign(&xcur, &ycur, us_alignment);
-		us_setcursorpos(NOWINDOWFRAME, xcur, ycur);
-		dx = xcur-us_dragx;    dy = ycur-us_dragy;
-		us_clearhighlightcount();
-
-		/* move entire node if it is an "invisible pin" */
-		if (us_dragnodeinst != NONODEINST &&
-			us_dragnodeinst->proto == gen_invispinprim &&
-			us_dragtype == VNODEINST)
-		{
-			startobjectchange((INTBIG)us_dragnodeinst, VNODEINST);
-			modifynodeinst(us_dragnodeinst, dx, dy, dx, dy, 0, 0);
-			endobjectchange((INTBIG)us_dragnodeinst, VNODEINST);
-			(void)us_addhighlight(&us_draghigh);
-			return;
-		}
-
-		/* undraw the text */
-		if (us_dragtype == VPORTPROTO)
-		{
-			startobjectchange((INTBIG)(((PORTPROTO *)us_dragaddr)->subnodeinst),
-				VNODEINST);
-		} else
-		{
-			startobjectchange(us_dragaddr, us_dragtype);
-		}
-		if (us_dragtype == VNODEPROTO && us_draghigh.fromvar != NOVARIABLE)
-			us_undrawfacetvariable(us_draghigh.fromvar, (NODEPROTO *)us_dragaddr);
-
-		/* set the new descriptor on the text */
-		if (us_dragnodeinst != NONODEINST)
-		{
-			if (us_dragnodeinst->transpose != 0)
-				makeangle(us_dragnodeinst->rotation, us_dragnodeinst->transpose, trans); else
-					makeangle((INTSML)((3600-us_dragnodeinst->rotation)%3600), 0, trans);
-			xform(dx, dy, &dx, &dy, trans);
-		}
-		lambda = us_hightech(&us_draghigh)->deflambda;
-		dx = dx*4/lambda;   dy = dy*4/lambda;
-		if ((us_dragdescript&VTXOFFNEG) != 0) dx -= (us_dragdescript&VTXOFF) >> VTXOFFSH; else
-			dx += (us_dragdescript&VTXOFF) >> VTXOFFSH;
-		if ((us_dragdescript&VTYOFFNEG) != 0) dy -= (us_dragdescript&VTYOFF) >> VTYOFFSH; else
-			dy += (us_dragdescript&VTYOFF) >> VTYOFFSH;
-		us_dragdescript = us_setdescriptoffset(us_dragdescript, dx, dy);
-		us_modifytextdescript(&us_draghigh, us_dragdescript);
-
-		/* redisplay the text */
-		if (us_dragtype == VNODEPROTO && us_draghigh.fromvar != NOVARIABLE)
-			us_drawfacetvariable(us_draghigh.fromvar, (NODEPROTO *)us_dragaddr);
-		if (us_dragtype == VPORTPROTO)
-		{
-			endobjectchange((INTBIG)(((PORTPROTO *)us_dragaddr)->subnodeinst),
-				VNODEINST);
-		} else
-		{
-			endobjectchange(us_dragaddr, us_dragtype);
-		}
-		(void)us_addhighlight(&us_draghigh);
-
-		/* modify all higher-level nodes if port moved */
-		if (us_draghigh.fromvar == NOVARIABLE && us_draghigh.fromport != NOPORTPROTO)
-		{
-			for(ni = us_draghigh.fromport->parent->firstinst; ni != NONODEINST; ni = ni->nextinst)
-			{
-				if ((ni->userbits&NEXPAND) != 0 &&
-					(us_draghigh.fromport->userbits&PORTDRAWN) == 0) continue;
-				startobjectchange((INTBIG)ni, VNODEINST);
-				endobjectchange((INTBIG)ni, VNODEINST);
-			}
-		}
 	}
 }
 
@@ -1632,7 +1643,7 @@ INTSML us_geominrect(GEOM *geom, INTBIG slx, INTBIG shx, INTBIG sly, INTBIG shy)
 	/* handle arcs */
 	ai = geom->entryaddr.ai;
 	wid = ai->width - arcwidthoffset(ai);
-	if (wid == 0) wid = ai->proto->tech->deflambda;
+	if (wid == 0) wid = lambdaofarc(ai);
 	if (curvedarcoutline(ai, poly, FILLED, wid) != 0)
 		makearcpoly(ai->length, wid, ai, poly, FILLED);
 	if (polyinrect(poly, slx, shx, sly, shy) == 0) return(0);
@@ -1733,15 +1744,19 @@ void us_createabegin(void)
 	us_dragx = xcur;   us_dragy = ycur;
 	us_dragwindow = el_curwindowpart;
 	us_dragobject = NOGEOM;
+	us_dragportproto = NOPORTPROTO;
 }
 
 /* cursor advance routine when creating along an angle */
 INTSML us_createadown(INTBIG x, INTBIG y)
 {
-	REGISTER INTBIG dx, dy;
+	REGISTER INTBIG dx, dy, dist, bestdist;
 	REGISTER INTSML i;
-	INTBIG rdx, rdy, pxs, pys;
+	INTBIG pxs, pys, unalx, unaly;
+	REGISTER PORTPROTO *pp, *foundpp;
+	REGISTER NODEINST *ni;
 	REGISTER GEOM *foundgeom;
+	static POLYGON *poly = NOPOLYGON;
 
 	/* grid align the cursor value */
 	if (us_setxy((INTSML)x, (INTSML)y) != 0 || us_dragwindow != el_curwindowpart)
@@ -1750,36 +1765,76 @@ INTSML us_createadown(INTBIG x, INTBIG y)
 		return(0);
 	}
 	(void)getxy(&us_lastcurx, &us_lastcury);
+	unalx = us_lastcurx;   unaly = us_lastcury;
 	gridalign(&us_lastcurx, &us_lastcury, us_alignment);
 	us_setcursorpos(NOWINDOWFRAME, us_lastcurx, us_lastcury);
 
-	us_getslide(us_dragangle, us_dragox, us_dragoy, us_lastcurx, us_lastcury, &rdx, &rdy);
-	dx = rdx - us_dragoffx;
-	dy = rdy - us_dragoffy;
+	us_getslide(us_dragangle, us_dragox, us_dragoy, us_lastcurx, us_lastcury, &pxs, &pys);
+	dx = pxs - us_dragoffx;
+	dy = pys - us_dragoffy;
 
 	/* find the object under the cursor */
-	if (us_dragjoinfactor == 0) foundgeom = NOGEOM; else
+	foundpp = NOPORTPROTO;
+	foundgeom = NOGEOM;
+	if (us_dragjoinfactor != 0)
 	{
 		defaultnodesize(us_dragnodeproto, &pxs, &pys);
-		foundgeom = us_getclosest(dx+pxs/2, dy+pys/2, us_dragwindow->curnodeproto);
+		foundgeom = us_getclosest(us_lastcurx-us_dragoffx+pxs/2, us_lastcury-us_dragoffy+pys/2,
+			us_dragwindow->curnodeproto);
+
+		/* determine closest port if a node was found */
+		if (foundgeom != NOGEOM && foundgeom->entrytype == OBJNODEINST)
+		{
+			/* find the closest port if this is a nodeinst and no port hit directly */
+			ni = foundgeom->entryaddr.ni;
+			if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			{
+				shapeportpoly(ni, pp, poly, 0);
+
+				/* get distance of desired point to polygon */
+				dist = polydistance(poly, unalx, unaly);
+				if (dist < 0)
+				{
+					foundpp = pp;
+					break;
+				}
+				if (foundpp == NOPORTPROTO) bestdist = dist;
+				if (dist > bestdist) continue;
+				bestdist = dist;   foundpp = pp;
+			}
+		}
 	}
 
-	/* if the box is already being shown, erase it */
-	if (us_dragshown != 0)
-	{
-		/* if it didn't actually move, go no further */
-		if (us_dragx == dx && us_dragy == dy) return(0);
-
-		/* undraw the box */
-		us_highl.col = 0;
-		(void)us_showpoly(us_dragpoly, us_dragwindow);
-	}
-
-	/* if the selected other object is being shown, erase it */
+	/* remove previous highlighting */
 	if (us_dragobject != NOGEOM)
 	{
-		if (us_dragobject != foundgeom)
-			us_highlighteverywhere(us_dragobject, NOPORTPROTO, 0,0, ALLOFF, 0);
+		if (us_dragshown != 0)
+		{
+			/* undraw the box */
+			us_highl.col = 0;
+			(void)us_showpoly(us_dragpoly, us_dragwindow);
+			us_dragshown = 0;
+		}
+		if (us_dragobject == foundgeom && us_dragportproto == foundpp) return(0);
+		us_highlighteverywhere(us_dragobject, us_dragportproto, 0, 0, ALLOFF, 0);
+	} else
+	{
+		if (us_dragobject != NOGEOM)
+		{
+			us_highlighteverywhere(us_dragobject, us_dragportproto, 0, 0, ALLOFF, 0);
+			us_dragobject = NOGEOM;
+		}
+		if (us_dragshown != 0)
+		{
+			/* if it didn't actually move, go no further */
+			if (us_dragx == dx && us_dragy == dy) return(0);
+
+			/* undraw the box */
+			us_highl.col = 0;
+			(void)us_showpoly(us_dragpoly, us_dragwindow);
+			us_dragshown = 0;
+		}
 	}
 
 	/* advance the box */
@@ -1791,16 +1846,29 @@ INTSML us_createadown(INTBIG x, INTBIG y)
 	us_dragx = dx;
 	us_dragy = dy;
 
-	/* draw the new box */
-	us_highl.col = HIGHLIT;
-	(void)us_showpoly(us_dragpoly, us_dragwindow);
-	us_dragshown = 1;
-	if (foundgeom != NOGEOM && foundgeom != us_dragobject)
-		us_highlighteverywhere(foundgeom, NOPORTPROTO, 0, 0, HIGHLIT, 0);
+	/* set highlighted destination object */
 	us_dragobject = foundgeom;
+	us_dragportproto = foundpp;
+
+	/* draw the new highlight */
+	if (us_dragobject != NOGEOM)
+	{
+		us_highlighteverywhere(us_dragobject, us_dragportproto, 0, 0, HIGHLIT, 0);
+	} else
+	{
+		us_highl.col = HIGHLIT;
+		(void)us_showpoly(us_dragpoly, us_dragwindow);
+		us_dragshown = 1;
+	}
 	return(0);
 }
 
+void us_createajoinedobject(GEOM **thegeom, PORTPROTO **theport)
+{
+	*theport = us_dragportproto;
+	*thegeom = us_dragobject;
+}
+
 /* cursor advance routine when creating inside an arc */
 INTSML us_createinsdown(INTBIG x, INTBIG y)
 {
@@ -1862,14 +1930,14 @@ void us_createaup(void)
 		(void)us_showpoly(us_dragpoly, us_dragwindow);
 	}
 	if (us_dragobject != NOGEOM)
-		us_highlighteverywhere(us_dragobject, NOPORTPROTO, 0, 0, ALLOFF, 0);
+		us_highlighteverywhere(us_dragobject, us_dragportproto, 0, 0, ALLOFF, 0);
 }
 
 /************************* DUPLICATE and multiple MOVE *************************/
 
 /* preinitialization routine when duplicating objects */
 void us_multidraginit(INTBIG xc, INTBIG yc, GEOM **geomlist, NODEINST **nodelist,
-	INTSML total, INTSML angle, INTSML extra)
+	INTBIG total, INTSML angle)
 {
 	us_dragox = xc;
 	us_dragoy = yc;
@@ -1877,7 +1945,7 @@ void us_multidraginit(INTBIG xc, INTBIG yc, GEOM **geomlist, NODEINST **nodelist
 	us_dragnodelist = nodelist;
 	us_dragnodetotal = total;
 	us_dragangle = angle;
-	us_dragextra = extra;
+	us_dragextra = 0;
 	us_cantdrag = 0;
 }
 
@@ -1948,7 +2016,7 @@ INTSML us_multidragdown(INTBIG x, INTBIG y)
 		if (us_dragx != us_lastcurx || us_dragy != us_lastcury)
 		{
 			if (us_cantdrag == 1)
-				us_abortcommand("Sorry, changes are currently disallowed");
+				us_abortcommand(_("Sorry, changes are currently disallowed"));
 			us_cantdrag++;
 			return(0);
 		}
@@ -1979,17 +2047,18 @@ void us_multidragup(void)
 
 void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 {
-	REGISTER INTSML i, j, thisend, portcount, len, endfixed;
-	REGISTER INTBIG wid, lambda, xcur, ycur, xw, yw;
-	INTBIG lx, ly, hx, hy, xc, yc;
+	REGISTER INTSML i, thisend, portcount, endfixed;
+	REGISTER INTBIG wid, lambda, xcur, ycur, xw, yw, len;
+	INTBIG lx, ly, hx, hy, xc, yc, tlx, tly, thx, thy;
 	XARRAY trans;
-	INTSML tsx, tsy;
+	INTSML tsx, tsy, j;
 	REGISTER char *str;
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
+	REGISTER TECHNOLOGY *tech;
 
 	us_highl.col = (INTSML)col;
 	if (us_dragextra != 0) us_dragextra++;
@@ -2034,7 +2103,7 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 				us_dragpoly->style = FILLED;
 				us_dragpoly->xv[0] = (ni->lowx + ni->highx) / 2;
 				us_dragpoly->yv[0] = (ni->lowy + ni->highy) / 2;
-				adjustdisoffset((INTBIG)ni, VNODEINST, whattech(ni->proto), us_dragpoly, var->textdescript);
+				adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, us_dragpoly, var->textdescript);
 				makerot(ni, trans);
 				xformpoly(us_dragpoly, trans);
 				getcenter(us_dragpoly, &xc, &yc);
@@ -2115,7 +2184,7 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 					portcount++;
 					if ((portcount%20) == 0)
 					{
-						if (stopping("highlight")) break;
+						if (stopping(STOPREASONDISPLAY)) break;
 					}
 				}
 			}
@@ -2175,6 +2244,68 @@ void us_multidragdraw(INTBIG col, INTBIG dx, INTBIG dy)
 		}
 		(void)us_showpoly(us_dragpoly, us_dragwindow);
 	}
+
+	/* update selected text, too */
+	for(i=0; i<us_dragnumtext; i++)
+	{
+		(void)us_makehighlight(us_dragtextlist[i], &us_draghigh);
+		if ((us_draghigh.status&HIGHTYPE) != HIGHTEXT) continue;
+
+		/* get object and extent */
+		us_gethighaddrtype(&us_draghigh, &us_dragaddr, &us_dragtype);
+		tech = us_getobjectinfo(us_dragaddr, us_dragtype, &lx, &hx, &ly, &hy);
+
+		/* determine number of lines of text and text size */
+		len = 1;
+		if (us_draghigh.fromvar != NOVARIABLE && (us_draghigh.fromvar->type&VISARRAY) != 0)
+			len = (INTSML)getlength(us_draghigh.fromvar);
+		if (len > 1)
+		{
+			makedisparrayvarpoly(us_draghigh.fromgeom, el_curwindowpart,
+				us_draghigh.fromvar, us_dragpoly);
+			getbbox(us_dragpoly, &tlx, &thx, &tly, &thy);
+			xw = thx - tlx;
+			yw = thy - tly;
+		} else
+		{
+			str = us_gethighstring(&us_draghigh);
+			us_dragdescript = us_gethighdescript(&us_draghigh);
+			screensettextsize(el_curwindowpart,
+				truefontsize((INTSML)((us_dragdescript&VTSIZE)>>VTSIZESH),
+					el_curwindowpart, tech));
+			screengettextsize(el_curwindowpart, str, &tsx, &tsy);
+			xw = muldiv(tsx, el_curwindowpart->screenhx-el_curwindowpart->screenlx,
+				el_curwindowpart->usehx-el_curwindowpart->uselx);
+			yw = muldiv(tsy, el_curwindowpart->screenhy-el_curwindowpart->screenly,
+				el_curwindowpart->usehy-el_curwindowpart->usely);
+		}
+		us_gethightextcenter(&us_draghigh, &xc, &yc, &j);
+		us_dragpoly->style = j;
+
+#if 0
+		/* clip range of text descriptor */
+		lambda = el_curlib->lambda[tech->techindex];
+		xcur = (us_lastcurx - us_dragx) * 4 / lambda;
+		us_lastcurx = us_lastcurx - us_dragx + us_dragoffx;
+		if (xcur > 1023)
+			us_lastcurx = 1023 * lambda / 4 + us_dragoffx; else
+				if (xcur < -1023)
+					us_lastcurx = -1023 * lambda / 4 + us_dragoffx;
+		ycur = (us_lastcury - us_dragy) * 4 / lambda;
+		us_lastcury = us_lastcury - us_dragy + us_dragoffy;
+		if (ycur > 1023)
+			us_lastcury = 1023 * lambda / 4 + us_dragoffy; else
+				if (ycur < -1023)
+					us_lastcury = -1023 * lambda / 4 + us_dragoffy;
+#endif
+
+		/* draw the descriptor */
+		us_buildtexthighpoly(lx, hx, ly, hy, xc+dx, yc+dy,
+			xw, yw, us_dragpoly->style, us_dragpoly);
+
+		/* draw the new box */
+		(void)us_showpoly(us_dragpoly, us_dragwindow);
+	}
 }
 
 /************************* DISTANCE TRACKING *************************/
@@ -2237,7 +2368,7 @@ INTSML us_distancedown(INTBIG x, INTBIG y)
 	us_dragpoly->font = TXTMEDIUM;
 	us_dragpoly->tech = el_curtech;
 	dist = computedistance(us_dragox, us_dragoy, us_dragx, us_dragy);
-	(void)strcpy(us_dragmessage, "Distance: ");
+	(void)strcpy(us_dragmessage, _("Distance: "));
 	(void)strcat(us_dragmessage, latoa(dist));
 	(void)strcat(us_dragmessage, " (dX=");
 	(void)strcat(us_dragmessage, latoa(us_dragx - us_dragox));
@@ -3082,7 +3213,7 @@ INTSML us_stoponchar(INTBIG x, INTBIG y, INTSML chr)
 	if (chr == 'a' || chr == 'A')
 	{
 		el_pleasestop = 1;
-		stopping("Tracking");
+		(void)stopping(STOPREASONTRACK);
 	}
 	return(1);
 }
@@ -3096,7 +3227,7 @@ INTSML us_stopandpoponchar(INTBIG x, INTBIG y, INTSML chr)
 	if (chr == 'a' || chr == 'A')
 	{
 		el_pleasestop = 1;
-		stopping("Tracking");
+		(void)stopping(STOPREASONTRACK);
 		(void)us_pophighlight(0);
 	}
 	return(1);
