@@ -32,6 +32,7 @@
 #include "egraphics.h"
 #include "efunction.h"
 #include "usr.h"
+#include "tecgen.h"
 #include <math.h>
 
 /***** REDRAW MODULES *****/
@@ -193,7 +194,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 	NODEINST *focusinst, PORTPROTO *facetinstport, INTSML newframe, INTSML pushpop)
 {
 	HIGHLIGHT newhigh;
-	REGISTER INTSML i, l, resethandlers;
+	REGISTER INTSML i, l, resethandlers, turnoffsim;
 	INTSML dummy;
 	REGISTER VARIABLE *var;
 	char *one[1];
@@ -204,6 +205,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 
 	us_clearhighlightcount();
 	oldw = el_curwindowpart;
+	turnoffsim = 0;
 	if (oldw == NOWINDOWPART)
 	{
 		oldstate = DISPWINDOW;
@@ -216,23 +218,30 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 				if (neww != oldw && neww->frame == oldw->frame) break;
 			if (neww != NOWINDOWPART) oldw = neww;
 		}
+		if (pushpop == 0 && (oldw->state&WINDOWSIMULATING) != 0) turnoffsim = 1;
+		if (turnoffsim != 0) us_setwindowsimulation(oldw, 0);
 		oldstate = oldw->state;
 		location = oldw->location;
 	}
 	startobjectchange((INTBIG)us_aid, VAID);
+
 	if (newframe == 0)
 	{
 		/* delete current window and create a new window for this facet */
 		neww = newwindowpart(location, oldw);
 		if (neww == NOWINDOWPART) return;
-		if (oldw != NOWINDOWPART) killwindowpart(oldw);
+		if (oldw != NOWINDOWPART)
+		{
+			if (turnoffsim != 0) us_setwindowsimulation(oldw, 1);
+			killwindowpart(oldw);
+		}
 	} else
 	{
 		/* just create a new window for this facet */
 		neww = us_wantnewwindow(0);
 		if (neww == NOWINDOWPART)
 		{
-			us_abortcommand("Cannot create new window");
+			us_abortcommand(_("Cannot create new window"));
 			return;
 		}
 		oldstate = DISPWINDOW;
@@ -283,11 +292,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		/* change the window type to be appropriate for editing */
 		neww->state = (oldstate & ~WINDOWTYPE) | DISPWINDOW;
 		resethandlers = 1;
-		if (pushpop == 0)
-		{
-			if ((neww->state&WINDOWSIMULATING) != 0)
-				us_setwindowsimulation(neww, 0);
-		} else
+		if (pushpop != 0)
 		{
 			if ((neww->state&WINDOWSIMULATING) != 0 &&
 				((oldstate&WINDOWTYPE) == DISPWINDOW))
@@ -360,6 +365,42 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 	(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)neww, VWINDOWPART|VDONTSAVE);
 }
 
+/*
+ * Routine to switch technologies.  If "forcedtechnology" is nonzero, switch to that
+ * technology, otherwise determine technology from facet "facet".  If "always" is zero,
+ * only switch if the user has selected "auto-switching".
+ */
+void us_ensurepropertechnology(NODEPROTO *facet, char *forcedtechnology, INTSML always)
+{
+	REGISTER USERCOM *uc;
+	REGISTER TECHNOLOGY *tech;
+	REGISTER WINDOWFRAME *curframe, *lastframe;
+
+	/* if not auto-switching technologies, quit */
+	if ((us_useroptions&AUTOSWITCHTECHNOLOGY) == 0) return;
+
+	/* see if facet has a technology */
+	if (facet == NONODEPROTO) return;
+	if ((facet->cellview->viewstate&TEXTVIEW) != 0) return;
+	tech = facet->tech;
+	if (tech == gen_tech) return;
+
+	/* switch technologies */
+	lastframe = getwindowframe(1);
+	if (us_getmacro("pmtesetup") == NOVARIABLE) return;
+	(void)initinfstr();
+	(void)formatinfstr("pmtesetup \"%s\"", us_techname(facet));
+	uc = us_makecommand(returninfstr());
+	if (uc != NOUSERCOM)
+	{
+		us_execute(uc, 0, 0, 0);
+		us_freeusercom(uc);
+	}
+	curframe = getwindowframe(1);
+	if (curframe != lastframe && lastframe != NOWINDOWFRAME)
+		bringwindowtofront(lastframe);
+}
+
 /*
  * routine to initialize for changes to the screen
  */
@@ -623,7 +664,7 @@ void us_queueredraw(GEOM *p, INTSML local)
 	r = us_allocredraw();
 	if (r == NOREDRAW)
 	{
-		ttyputerr("No memory for display!");
+		ttyputnomemory();
 		return;
 	}
 	r->entrytype = p->entrytype;
@@ -743,7 +784,7 @@ void us_queueopaque(GEOM *p, INTSML local)
 	r = us_allocredraw();
 	if (r == NOREDRAW)
 	{
-		ttyputerr("No memory for display!");
+		ttyputnomemory();
 		return;
 	}
 	r->entrytype = p->entrytype;
@@ -929,8 +970,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 				screendrawpolygon(w, objc->xv, objc->yv, objc->count, objc->desc);
 
 				/* for patterned and outlined polygons, draw the outline too */
-				if ((objc->desc->colstyle&(NATURE|OUTLINEPAT)) ==
-					(PATTERNED|OUTLINEPAT))
+				if ((gra->colstyle&(NATURE|OUTLINEPAT)) == (PATTERNED|OUTLINEPAT))
 				{
 					for(i=0; i<objc->count; i++)
 					{
@@ -989,7 +1029,7 @@ INTSML us_showpoly(POLYGON *obj, WINDOWPART *w)
 
 		case VECTORS:		/* many lines */
 			if (obj->count % 2 != 0)
-				ttyputmsg("Cannot display vector with %d vertices (must be even)");
+				ttyputmsg(_("Cannot display vector with %d vertices (must be even)"));
 			for(i=0; i<obj->count; i += 2)
 				us_wanttodraw(obj->xv[i], obj->yv[i], obj->xv[i+1], obj->yv[i+1], w, gra, 0);
 			return(0);
@@ -1301,18 +1341,6 @@ INTSML us_writetext(INTBIG lx, INTBIG ux, INTBIG ly, INTBIG uy, GRAPHICS *desc,
  */
 void us_slideup(INTBIG dist)
 {
-	INTBIG schx, schy;
-	REGISTER NODEPROTO *np;
-
-	/* on windows with schematic frames, limit sliding to maximum frame extent */
-	np = getcurfacet();
-	if (np != NONODEPROTO && framesize(&schx, &schy, np) == 0)
-	{
-		if (el_curwindowpart->screenhy - dist > schy/2) dist = el_curwindowpart->screenhy - schy/2;
-		if (el_curwindowpart->screenly - dist < -schy/2) dist = el_curwindowpart->screenly + schy/2;
-		if (dist == 0) return;
-	}
-
 	/* save and erase highlighting */
 	us_pushhighlight();
 	us_clearhighlightcount();
@@ -1333,18 +1361,6 @@ void us_slideup(INTBIG dist)
  */
 void us_slideleft(INTBIG dist)
 {
-	INTBIG schx, schy;
-	REGISTER NODEPROTO *np;
-
-	/* on windows with schematic frames, limit sliding to maximum frame extent */
-	np = getcurfacet();
-	if (np != NONODEPROTO && framesize(&schx, &schy, np) == 0)
-	{
-		if (el_curwindowpart->screenhx + dist > schx/2) dist = schx/2 - el_curwindowpart->screenhx;
-		if (el_curwindowpart->screenlx + dist < -schx/2) dist = -schx/2 - el_curwindowpart->screenlx;
-		if (dist == 0) return;
-	}
-
 	/* save and erase highlighting */
 	us_pushhighlight();
 	us_clearhighlightcount();
@@ -1412,7 +1428,7 @@ void us_reverse(POLYGON *poly)
 void us_3dsetupviewing(WINDOWPART *w)
 {
 	REGISTER TECHNOLOGY *tech;
-	REGISTER INTBIG i, lowheight, highheight;
+	REGISTER INTBIG i, lowheight, highheight, lambda;
 	INTBIG thickness, height;
 	float scale, cx, cy, cz, sx, sy, sz;
 	REGISTER NODEPROTO *np;
@@ -1441,10 +1457,11 @@ void us_3dsetupviewing(WINDOWPART *w)
 	if (np == NONODEPROTO) return;
 	cx = (np->lowx + np->highx) / 2.0f;
 	cy = (np->lowy + np->highy) / 2.0f;
-	cz = (float)((highheight + lowheight) / 2 * el_curtech->deflambda);
+	lambda = el_curlib->lambda[el_curtech->techindex];
+	cz = (float)((highheight + lowheight) / 2 * lambda);
 	sx = (float)(np->highx - np->lowx);
 	sy = (float)(np->highy - np->lowy);
-	sz = (float)((highheight - lowheight) * el_curtech->deflambda);
+	sz = (float)((highheight - lowheight) * lambda);
 	scale = (sx > sy) ? sx : sy;
 	scale = (sz > scale) ? sz : scale;
 
@@ -1655,7 +1672,7 @@ void us_3denddrawing(void)
  */
 void us_3drender(WINDOWPART *w)
 {
-	REGISTER INTBIG i, j, k, passes;
+	REGISTER INTBIG i, j, k, passes, lambda;
 	INTBIG start[2], finish[2], incr[2];
 	REGISTER INTSML save, isneg;
 	POLY3D *poly3d;
@@ -1671,7 +1688,8 @@ void us_3drender(WINDOWPART *w)
 	us_erasewindow(w);
 
 	/* see if the view is from the back */
-	for(zplane = us_3dhighz; zplane >= us_3dlowz; zplane -= el_curtech->deflambda)
+	lambda = el_curlib->lambda[el_curtech->techindex];
+	for(zplane = us_3dhighz; zplane >= us_3dlowz; zplane -= lambda)
 	{
 		vec[0] = us_3dcenterx; vec[1] = us_3dcentery; vec[2] = zplane; vec[3] = 1.0;
 		matrixxform3d(vec, xf3->xform, res);
@@ -1880,7 +1898,7 @@ INTSML us_3deachdown(INTBIG x, INTBIG y)
  */
 INTSML us_3dshowpoly(POLYGON *poly, WINDOWPART *w)
 {
-	REGISTER INTBIG i, previ, topdepth, botdepth, centerdepth;
+	REGISTER INTBIG i, previ, topdepth, botdepth, centerdepth, lambda;
 	float topheight, botheight;
 	INTBIG lx, hx, ly, hy, thickness, depth;
 	REGISTER POLY3D *poly3d;
@@ -1932,14 +1950,15 @@ INTSML us_3dshowpoly(POLYGON *poly, WINDOWPART *w)
 	if (get3dfactors(poly->tech, poly->layer, &depth, &thickness) != 0) return(1);
 
 	/* setup a 3D polygon */
-	topdepth = (depth + thickness/2) * el_curtech->deflambda;
+	lambda = el_curlib->lambda[el_curtech->techindex];
+	topdepth = (depth + thickness/2) * lambda;
 	topheight = (float)topdepth;
 	if (thickness != 0)
 	{
 		topdepth++;
-		centerdepth = depth * el_curtech->deflambda;
-		botdepth = (depth - thickness/2) * el_curtech->deflambda - 1;
-		botheight = (float)((depth - thickness/2) * el_curtech->deflambda);
+		centerdepth = depth * lambda;
+		botdepth = (depth - thickness/2) * lambda - 1;
+		botheight = (float)((depth - thickness/2) * lambda);
 	}
 
 	/* fill the 3D polygon points */
