@@ -45,7 +45,6 @@ PTREE			*vhdl_ptree = NULL;
 TOKENLIST		*vhdl_nexttoken;
 static jmp_buf	vhdl_notoken_err;
 INTBIG			vhdl_errorcount;
-extern AIDENTRY	*vhdl_aid;
 
 /* prototypes for local routines */
 VINTERFACE *vhdl_parseinterface(void);
@@ -152,7 +151,7 @@ INTSML vhdl_parser(TOKENLIST *tlist)
 					pointer = (char *)vhdl_parseuse();
 					break;
 				default:
-					vhdl_reporterrormsg(vhdl_nexttoken, "No entry keyword - entity, architectural, behavioral");
+					vhdl_reporterrormsg(vhdl_nexttoken, _("No entry keyword - entity, architectural, behavioral"));
 					vhdl_nexttoken = vhdl_nexttoken->next;
 					break;
 			}
@@ -173,7 +172,7 @@ INTSML vhdl_parser(TOKENLIST *tlist)
 			}
 		} else
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "No entry keyword - entity, architectural, behavioral");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("No entry keyword - entity, architectural, behavioral"));
 			vhdl_nexttoken = vhdl_nexttoken->next;
 		}
 	}
@@ -189,14 +188,14 @@ void vhdl_reporterrormsg(TOKENLIST *tlist, char *err_msg)
 	vhdl_err = TRUE;
 	vhdl_errorcount++;
 	if (vhdl_errorcount == 30)
-		ttyputmsg("TOO MANY ERRORS...PRINTING NO MORE");
+		ttyputmsg(_("TOO MANY ERRORS...PRINTING NO MORE"));
 	if (vhdl_errorcount >= 30) return;
 	if (tlist == NULL)
 	{
-		ttyputmsg("ERROR %s", err_msg);
+		ttyputmsg(_("ERROR %s"), err_msg);
 		return;
 	}
-	ttyputmsg("ERROR on line %ld, %s:", tlist->line_num, err_msg);
+	ttyputmsg(_("ERROR on line %ld, %s:"), tlist->line_num, err_msg);
 
 	/* back up to start of line */
 	for (tstart = tlist; tstart->last != NOTOKENLIST; tstart = tstart->last)
@@ -277,7 +276,7 @@ VINTERFACE  *vhdl_parseinterface(void)
 	/* check for entity IDENTIFIER */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 	} else
 	{
 		name = vhdl_nexttoken;
@@ -289,14 +288,14 @@ VINTERFACE  *vhdl_parseinterface(void)
 	vhdl_getnexttoken();
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IS");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 	}
 
 	/* check for keyword PORT */
 	vhdl_getnexttoken();
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_PORT))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword PORT");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword PORT"));
 	}
 
 #endif
@@ -305,20 +304,20 @@ VINTERFACE  *vhdl_parseinterface(void)
 	vhdl_getnexttoken();
 	if (vhdl_nexttoken->token != TOKEN_LEFTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a left bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a left bracket"));
 	}
 
 	/* gather FORMAL_PORT_LIST */
 	vhdl_getnexttoken();
 	if ((ports = vhdl_parseformal_port_list()) == (FPORTLIST *)PARSE_ERR)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Interface must have ports");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Interface must have ports"));
 	}
 
 	/* check for closing bracket of FORMAL_PORT_LIST */
 	if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a right bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a right bracket"));
 	}
 
 	vhdl_getnexttoken();
@@ -326,13 +325,13 @@ VINTERFACE  *vhdl_parseinterface(void)
 	/* check for keyword IS */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IS");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 	}
 #else
 	/* check for SEMICOLON */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 #endif
 	else vhdl_getnexttoken();
@@ -340,7 +339,7 @@ VINTERFACE  *vhdl_parseinterface(void)
 	/* check for keyword END */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword END");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword END"));
 	}
 
 	/* check for optional entity IDENTIFIER */
@@ -349,7 +348,7 @@ VINTERFACE  *vhdl_parseinterface(void)
 	{
 		if (vhdl_nexttoken->pointer != name->pointer)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Unmatched entity identifier names");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Unmatched entity identifier names"));
 		}
 		vhdl_getnexttoken();
 	}
@@ -357,7 +356,7 @@ VINTERFACE  *vhdl_parseinterface(void)
 	/* check for closing SEMICOLON */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_nexttoken = vhdl_nexttoken->next;
 
@@ -403,7 +402,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* first should be keyword BODY */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_BODY))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword BODY");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword BODY"));
 	}
 	vhdl_getnexttoken();
 #endif
@@ -412,7 +411,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	body_name = NULL;
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 	} else
 	{
 		body_name = vhdl_nexttoken;
@@ -422,7 +421,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* check for keyword OF */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_OF))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword OF");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword OF"));
 	}
 	vhdl_getnexttoken();
 
@@ -434,7 +433,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* check for keyword IS */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IS");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 	}
 	vhdl_getnexttoken();
 
@@ -446,7 +445,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* should be at keyword BEGIN */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_BEGIN))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword BEGIN");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword BEGIN"));
 	}
 	vhdl_getnexttoken();
 
@@ -458,7 +457,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* should be at keyword END */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword END");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword END"));
 	}
 	vhdl_getnexttoken();
 
@@ -467,7 +466,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	{
 		if (vhdl_nexttoken->pointer != body_name->pointer)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Body name mismatch");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Body name mismatch"));
 		}
 		vhdl_getnexttoken();
 	}
@@ -475,7 +474,7 @@ BODY  *vhdl_parsebody(INTBIG vclass)
 	/* should be at final semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_nexttoken = vhdl_nexttoken->next;
 
@@ -601,7 +600,7 @@ COMPONENT  *vhdl_parsecomponent(void)
 	/* should be component identifier */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		entity = NULL;
 	} else
 	{
@@ -612,14 +611,14 @@ COMPONENT  *vhdl_parsecomponent(void)
 #ifndef VHDL50
 	/* Need keyword PORT */
 	if (!vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_PORT))
-	   vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword PORT");
+	   vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword PORT"));
 	else vhdl_getnexttoken();
 #endif
 
 	/* should be left bracket, start of port list */
 	if (vhdl_nexttoken->token != TOKEN_LEFTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a left bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a left bracket"));
 	}
 	vhdl_getnexttoken();
 
@@ -631,7 +630,7 @@ COMPONENT  *vhdl_parsecomponent(void)
 	/* should be pointing to RIGHTBRACKET */
 	if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a right bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a right bracket"));
 	}
 	vhdl_getnexttoken();
 
@@ -639,24 +638,24 @@ COMPONENT  *vhdl_parsecomponent(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
 	/* Need "END COMPONENT" */
 	if (!vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_END))
-	   vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword END");
+	   vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword END"));
 	vhdl_getnexttoken();
 
 	if (!vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_COMPONENT))
-	   vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword COMPONENT");
+	   vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword COMPONENT"));
 	vhdl_getnexttoken();
 #endif
 
 	/* should be at terminating semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 	compo = (COMPONENT *)emalloc((INTBIG)sizeof(COMPONENT), vhdl_aid->cluster);
@@ -765,7 +764,7 @@ OBJECTDECLARE  *vhdl_parseobject_declare(void)
 	{
 	} else
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Invalid object declaration");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Invalid object declaration"));
 	}
 	if (type != NOOBJECTDECLARE)
 	{
@@ -810,7 +809,7 @@ SIGNALDECLARE  *vhdl_parsesignal_declare(void)
 	/* should be at colon */
 	if (vhdl_nexttoken->token != TOKEN_COLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a colon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a colon"));
 	}
 	vhdl_getnexttoken();
 
@@ -820,7 +819,7 @@ SIGNALDECLARE  *vhdl_parsesignal_declare(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -863,7 +862,7 @@ CONSTANTDECLARE  *vhdl_parseconstant_declare(void)
 	 */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		ident = NULL;
 	} else
 	{
@@ -874,7 +873,7 @@ CONSTANTDECLARE  *vhdl_parseconstant_declare(void)
 	/* should be at colon */
 	if (vhdl_nexttoken->token != TOKEN_COLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a colon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a colon"));
 	}
 	vhdl_getnexttoken();
 
@@ -884,7 +883,7 @@ CONSTANTDECLARE  *vhdl_parseconstant_declare(void)
 	/* should be at assignment symbol */
 	if (vhdl_nexttoken->token != TOKEN_VARASSIGN)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting variable assignment symbol");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting variable assignment symbol"));
 	}
 	vhdl_getnexttoken();
 
@@ -894,7 +893,7 @@ CONSTANTDECLARE  *vhdl_parseconstant_declare(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -930,7 +929,7 @@ IDENTLIST  *vhdl_parseident_list(void)
 	/* must be at least one identifier */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		vhdl_getnexttoken();
 		return(NULL);
 	}
@@ -947,7 +946,7 @@ IDENTLIST  *vhdl_parseident_list(void)
 		/* should be another identifier */
 		if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 			vhdl_getnexttoken();
 			return(NULL);
 		}
@@ -1059,7 +1058,7 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 			/* should be a semicolon */
 			if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 			{
-				vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+				vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 			}
 			vhdl_getnexttoken();
 		}
@@ -1123,7 +1122,7 @@ STATEMENTS	*vhdl_parseset_of_statements(void)
 			}
 		} else
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Invalid ARCHITECTURAL statement");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Invalid ARCHITECTURAL statement"));
 			vhdl_nexttoken = vhdl_nexttoken->next;
 			break;
 		}
@@ -1175,14 +1174,14 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 		/* should be past label and at keyword FOR */
 		if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_FOR))
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword FOR");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword FOR"));
 		}
 	} else
 	{
 		/* should be past label and at keyword IF */
 		if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IF))
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IF");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IF"));
 		}
 	}
 	scheme = (GENSCHEME *)emalloc((INTBIG)sizeof(GENSCHEME), vhdl_aid->cluster);
@@ -1203,7 +1202,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 		/* should be generate parameter specification */
 		if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		} else
 		{
 			scheme->identifier = vhdl_nexttoken;
@@ -1213,7 +1212,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 		/* should be keyword IN */
 		if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IN))
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IN");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IN"));
 		}
 		vhdl_getnexttoken();
 
@@ -1227,7 +1226,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 	/* should be keyword GENERATE */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_GENERATE))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword GENERATE");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword GENERATE"));
 	}
 	vhdl_getnexttoken();
 
@@ -1237,14 +1236,14 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 	/* should be at keyword END */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword END");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword END"));
 	}
 	vhdl_getnexttoken();
 
 	/* should be at keyword GENERATE */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_GENERATE))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword GENERATE");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword GENERATE"));
 	}
 	vhdl_getnexttoken();
 
@@ -1258,15 +1257,15 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 		if (vhdl_nexttoken->token == TOKEN_IDENTIFIER)
 		{
 			if (label->pointer != vhdl_nexttoken->pointer)
-				vhdl_reporterrormsg(vhdl_nexttoken, "Label mismatch");
+				vhdl_reporterrormsg(vhdl_nexttoken, _("Label mismatch"));
 			vhdl_getnexttoken();
 		}
 #else
 		if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		else
 			if (label->pointer != vhdl_nexttoken->pointer)
-				vhdl_reporterrormsg(vhdl_nexttoken, "Label mismatch");
+				vhdl_reporterrormsg(vhdl_nexttoken, _("Label mismatch"));
 		vhdl_getnexttoken();
 #endif
 	}
@@ -1274,7 +1273,7 @@ GENERATE  *vhdl_parsegenerate(TOKENLIST *label, INTBIG gscheme)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -1368,7 +1367,7 @@ RANGESIMPLE  *vhdl_parserange_simple(void)
 	/* should be at double dot */
 	if (vhdl_nexttoken->token != TOKEN_DOUBLEDOT)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting double dot (..)");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting double dot (..)"));
 	}
 	vhdl_getnexttoken();
 #else
@@ -1377,7 +1376,7 @@ RANGESIMPLE  *vhdl_parserange_simple(void)
 	   vhdl_getnexttoken();
 	else
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword TO or DOWNTO");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword TO or DOWNTO"));
 		vhdl_getnexttoken(); /* absorb the token anyway (probably "..") */
 	}
 #endif
@@ -1414,7 +1413,7 @@ INSTANCE  *vhdl_parseinstance(void)
 	/* check for identifier */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		vhdl_getnexttoken();
 		return(inst);
 	}
@@ -1438,17 +1437,17 @@ INSTANCE  *vhdl_parseinstance(void)
 	/* Require PORT MAP */
 	if (vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_PORT))
 	   vhdl_getnexttoken();
-	else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword PORT");
+	else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword PORT"));
 
 	if (vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_MAP))
 	   vhdl_getnexttoken();
-	else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword MAP");
+	else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword MAP"));
 #endif
 
 	/* should be at left bracket */
 	if (vhdl_nexttoken->token != TOKEN_LEFTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a left bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a left bracket"));
 	}
 	vhdl_getnexttoken();
 	ports = vhdl_parseactual_port_list();
@@ -1456,14 +1455,14 @@ INSTANCE  *vhdl_parseinstance(void)
 	/* should be at right bracket */
 	if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a right bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a right bracket"));
 	}
 	vhdl_getnexttoken();
 
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -1515,7 +1514,7 @@ FPORTLIST  *vhdl_parseformal_port_list(void)
 	/* should be at colon */
 	if (vhdl_nexttoken->token != TOKEN_COLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a colon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a colon"));
 		return((FPORTLIST *)PARSE_ERR);
 	}
 	vhdl_getnexttoken();
@@ -1542,7 +1541,7 @@ FPORTLIST  *vhdl_parseformal_port_list(void)
 		/* should be at colon */
 		if (vhdl_nexttoken->token != TOKEN_COLON)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a colon");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a colon"));
 			return((FPORTLIST *)PARSE_ERR);
 		}
 		vhdl_getnexttoken();
@@ -1594,7 +1593,7 @@ INTBIG vhdl_parseport_mode(void)
 			case KEY_DOT:
 				vhdl_getnexttoken();
 				if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_OUT))
-					vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword OUT"); else
+					vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword OUT")); else
 						mode = MODE_DOTOUT;
 				vhdl_getnexttoken();
 				break;
@@ -1666,7 +1665,7 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 		aplist->pointer = NULL;
 	}
 #else
-	else vhdl_reporterrormsg(vhdl_nexttoken, "No identifier in port list");
+	else vhdl_reporterrormsg(vhdl_nexttoken, _("No identifier in port list"));
 #endif
 
 	aplist->next = NULL;
@@ -1695,7 +1694,7 @@ APORTLIST  *vhdl_parseactual_port_list(void)
 			newport->pointer = NULL;
 		}
 #else
-		else vhdl_reporterrormsg(vhdl_nexttoken, "No identifier in port list");
+		else vhdl_reporterrormsg(vhdl_nexttoken, _("No identifier in port list"));
 #endif
 
 		newport->next = NULL;
@@ -1734,7 +1733,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	/* should be at keyword package */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_PACKAGE))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword PACKAGE");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword PACKAGE"));
 		vhdl_getnexttoken();
 		return(package);
 	}
@@ -1743,7 +1742,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	/* should be package identifier */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		vhdl_getnexttoken();
 		return(package);
 	}
@@ -1753,7 +1752,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	/* should be at keyword IS */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IS");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 		vhdl_getnexttoken();
 		return(package);
 	}
@@ -1765,7 +1764,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	/* should be at keyword END */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword END");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword END"));
 		vhdl_getnexttoken();
 		return(package);
 	}
@@ -1776,7 +1775,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	{
 		if (vhdl_nexttoken->pointer != identifier->pointer)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Name mismatch");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Name mismatch"));
 			vhdl_getnexttoken();
 			return(package);
 		}
@@ -1786,7 +1785,7 @@ PACKAGE  *vhdl_parsepackage(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 		vhdl_getnexttoken();
 		return(package);
 	}
@@ -1832,7 +1831,7 @@ PACKAGEDPART *vhdl_parsepackage_declare_part(void)
 	/* should be at least one */
 	if (vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_END))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "No Package declarative part");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("No Package declarative part"));
 		return(dpart);
 	}
 	ditem = vhdl_parsebasic_declare();
@@ -1881,7 +1880,7 @@ WITH *vhdl_parsewith(void)
 	/* should be at keyword WITH */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_WITH))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword WITH");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword WITH"));
 		vhdl_getnexttoken();
 		return(with);
 	}
@@ -1891,7 +1890,7 @@ WITH *vhdl_parsewith(void)
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER
 		&& !vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_STANDARD))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Bad unit name for with clause");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Bad unit name for with clause"));
 		vhdl_getnexttoken();
 		return(with);
 	}
@@ -1907,7 +1906,7 @@ WITH *vhdl_parsewith(void)
 		if (vhdl_nexttoken->token != TOKEN_IDENTIFIER
 			&& !vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_STANDARD))
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Bad unit name for with clause");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Bad unit name for with clause"));
 			vhdl_getnexttoken();
 			return(with);
 		}
@@ -1922,7 +1921,7 @@ WITH *vhdl_parsewith(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -1957,7 +1956,7 @@ USE *vhdl_parseuse(void)
 	/* should be at keyword USE */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_USE))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword USE");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword USE"));
 		vhdl_getnexttoken();
 		return(use);
 	}
@@ -1966,7 +1965,7 @@ USE *vhdl_parseuse(void)
 	/* must be at least one unit */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Bad unit name for use clause");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Bad unit name for use clause"));
 		vhdl_getnexttoken();
 		return(use);
 	}
@@ -1979,11 +1978,11 @@ USE *vhdl_parseuse(void)
 	/* IEEE version uses form unit.ALL only */
 	if (vhdl_nexttoken->token == TOKEN_PERIOD)
 		vhdl_getnexttoken();
-	else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting period");
+	else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting period"));
 
 	if (vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_ALL))
 		vhdl_getnexttoken();
-	else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword ALL");
+	else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword ALL"));
 #endif
 
 	while (vhdl_nexttoken->token == TOKEN_COMMA)
@@ -1991,7 +1990,7 @@ USE *vhdl_parseuse(void)
 		vhdl_getnexttoken();
 		if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 		{
-			vhdl_reporterrormsg(vhdl_nexttoken, "Bad unit name for use clause");
+			vhdl_reporterrormsg(vhdl_nexttoken, _("Bad unit name for use clause"));
 			vhdl_getnexttoken();
 			return(use);
 		}
@@ -2005,18 +2004,18 @@ USE *vhdl_parseuse(void)
 		/* IEEE version uses form unit.ALL only */
 		if (vhdl_nexttoken->token == TOKEN_PERIOD)
 			vhdl_getnexttoken();
-		else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting period");
+		else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting period"));
 
 		if (vhdl_keysame(vhdl_nexttoken,(INTBIG)KEY_ALL))
 			vhdl_getnexttoken();
-		else vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword ALL");
+		else vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword ALL"));
 #endif
 	}
 
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 	}
 	vhdl_getnexttoken();
 
@@ -2073,7 +2072,7 @@ void vhdl_getnexttoken(void)
 {
 	if (vhdl_nexttoken->next == NOTOKENLIST)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Unexpected termination within block");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Unexpected termination within block"));
 		longjmp(vhdl_notoken_err, 1);
 	}
 	vhdl_nexttoken = vhdl_nexttoken->next;
